@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,6 +28,8 @@
 
 using namespace bec;
 using namespace wb;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 WBComponent::WBComponent(WBContext *context)
 : _wb(context)
@@ -36,26 +38,26 @@ WBComponent::WBComponent(WBContext *context)
 
 
 
-grt::ValueRef WBComponent::place_object_grt(grt::GRT *grt, ModelDiagramForm *form, const mdc::Point &pos,
+grt::ValueRef WBComponent::place_object_grt(grt::GRT *grt, ModelDiagramForm *form, const Point &pos,
                                                 const std::string &object_struct,
                                                 const grt::DictRef &args)
 {
   model_DiagramRef view(form->get_model_diagram());
   std::string object_type, object_struct_name;
 
-  mdc::Point offset= pos;
+  Point offset= pos;
   model_LayerRef layer= view->rootLayer();
 
   // find the layer that contains the point
   for (grt::ListRef<model_Layer>::const_iterator l= view->layers().begin();
        l != view->layers().end(); ++l)
   {
-    mdc::Rect rect((*l)->left(), (*l)->top(), (*l)->width(), (*l)->height());
+    Rect rect((*l)->left(), (*l)->top(), (*l)->width(), (*l)->height());
     if (mdc::bounds_contain_point(rect, pos.x, pos.y))
     {
       layer= *l;
-      offset.x= pos.x - rect.xmin();
-      offset.y= pos.y- rect.ymin();
+      offset.x= pos.x - rect.left();
+      offset.y= pos.y- rect.top();
       break;
     }
   }
@@ -122,11 +124,11 @@ grt::ValueRef WBComponent::place_object_grt(grt::GRT *grt, ModelDiagramForm *for
 }
 
 
-grt::ValueRef WBComponent::place_object(ModelDiagramForm *view, const mdc::Point &pos, const std::string &object_struct,
+grt::ValueRef WBComponent::place_object(ModelDiagramForm *view, const Point &pos, const std::string &object_struct,
                                             const grt::DictRef &args)
 {
   return _wb->execute_in_grt_thread("Place object in model",
-    sigc::bind<ModelDiagramForm*,mdc::Point,std::string,grt::DictRef>(sigc::mem_fun(this, &WBComponent::place_object_grt),
+    sigc::bind<ModelDiagramForm*, Point, std::string,grt::DictRef>(sigc::mem_fun(this, &WBComponent::place_object_grt),
                                                                      view,
                                                                      pos,
                                                                      object_struct,
