@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,11 +31,13 @@ using namespace wb;
 using namespace grt;
 using namespace bec;
 using namespace base;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 struct HandToolContext
 {
-  mdc::Point mouse_pos;
-  mdc::Point viewport_pos;
+  Point mouse_pos;
+  Point viewport_pos;
   bool moving;
 
   HandToolContext()
@@ -215,7 +217,7 @@ bool WBComponentBasic::handles_figure(const model_ObjectRef &object)
 
 
 grt::ValueRef WBComponentBasic::place_layer_grt(grt::GRT *grt, ModelDiagramForm *form,
-                                             const mdc::Rect &rect)
+                                             const Rect &rect)
 {
   model_DiagramRef view(form->get_model_diagram());
 
@@ -230,7 +232,7 @@ grt::ValueRef WBComponentBasic::place_layer_grt(grt::GRT *grt, ModelDiagramForm
 
   grt::AutoUndo undo(grt);
   
-  layer= view->placeNewLayer(rect.xmin(), rect.ymin(), rect.width(), rect.height(), _("New Layer"));
+  layer= view->placeNewLayer(rect.left(), rect.top(), rect.width(), rect.height(), _("New Layer"));
 
   if (layer.is_valid())
     layer->color(color);
@@ -241,12 +243,12 @@ grt::ValueRef WBComponentBasic::place_layer_grt(grt::GRT *grt, ModelDiagramForm
 }
 
 
-void WBComponentBasic::place_layer(ModelDiagramForm *view, const mdc::Rect &rect)
+void WBComponentBasic::place_layer(ModelDiagramForm *view, const Rect &rect)
 {
   try
   {
     _wb->execute_in_grt_thread("Place new layer in model",
-                        sigc::bind<ModelDiagramForm*,mdc::Rect>(sigc::mem_fun(this, &WBComponentBasic::place_layer_grt),
+                        sigc::bind<ModelDiagramForm*,Rect>(sigc::mem_fun(this, &WBComponentBasic::place_layer_grt),
                                                            view,
                                                            rect));
     _wb->show_status_text(_("Created new layer."));
@@ -325,7 +327,7 @@ bool WBComponentBasic::delete_model_object(const model_ObjectRef &object, std::m
 }
 
 
-void WBComponentBasic::delete_object(ModelDiagramForm *view, const mdc::Point &pos)
+void WBComponentBasic::delete_object(ModelDiagramForm *view, const Point &pos)
 {
   model_ObjectRef object(view->get_object_at(pos));
 
@@ -444,7 +446,7 @@ model_ObjectRef WBComponentBasic::clone_object(const model_ObjectRef &object, co
 // Handlers
 
 bool WBComponentBasic::handle_button_event(ModelDiagramForm *view, mdc::MouseButton button, bool press, 
-                                         mdc::Point pos, mdc::EventState state, void *data)
+                                         Point pos, mdc::EventState state, void *data)
 {
   std::string tool= view->get_tool();
 
@@ -454,11 +456,11 @@ bool WBComponentBasic::handle_button_event(ModelDiagramForm *view, mdc::MouseBut
     hcontext->moving= press;
     if (press)
     {
-      mdc::Rect r= view->get_view()->get_viewport();
+      Rect r= view->get_view()->get_viewport();
       int wx, wy;
       hcontext->viewport_pos= r.pos;
       view->get_view()->canvas_to_window(pos, wx, wy);
-      hcontext->mouse_pos= mdc::Point(wx, wy);
+      hcontext->mouse_pos= Point(wx, wy);
     }
     return true;
   }
@@ -478,8 +480,8 @@ bool WBComponentBasic::handle_button_event(ModelDiagramForm *view, mdc::MouseBut
       view->get_view()->start_dragging_rectangle(pos);
     else
     {
-      mdc::Rect rect= view->get_view()->finish_dragging_rectangle();
-      mdc::Size max_size = view->get_view()->get_total_view_size();
+      Rect rect= view->get_view()->finish_dragging_rectangle();
+      Size max_size = view->get_view()->get_total_view_size();
 
       if (rect.width() < 5 || rect.height() < 5)
       {
@@ -504,7 +506,7 @@ bool WBComponentBasic::handle_button_event(ModelDiagramForm *view, mdc::MouseBut
       view->get_view()->start_dragging_rectangle(pos);
     else
     {
-      mdc::Rect rect= view->get_view()->finish_dragging_rectangle();
+      Rect rect= view->get_view()->finish_dragging_rectangle();
 
       if (rect.width() < 5 || rect.height() < 5)
       {
@@ -572,7 +574,7 @@ bool WBComponentBasic::handle_button_event(ModelDiagramForm *view, mdc::MouseBut
 }
 
 
-bool WBComponentBasic::handle_motion_event(ModelDiagramForm *view, mdc::Point pos, mdc::EventState state, void *data)
+bool WBComponentBasic::handle_motion_event(ModelDiagramForm *view, Point pos, mdc::EventState state, void *data)
 {
   std::string tool= view->get_tool();
 
@@ -585,15 +587,15 @@ bool WBComponentBasic::handle_motion_event(ModelDiagramForm *view, mdc::Point po
     {
       int wx, wy;
       cview->canvas_to_window(pos, wx, wy);
-      mdc::Point wpos(wx, wy);
+      Point wpos(wx, wy);
 
-      mdc::Point mouse_pos= hcontext->mouse_pos;
-      mdc::Point viewport_pos= hcontext->viewport_pos;
+      Point mouse_pos= hcontext->mouse_pos;
+      Point viewport_pos= hcontext->viewport_pos;
 
-      mdc::Point newp= viewport_pos - wpos + mouse_pos;
+      Point newp= viewport_pos - wpos + mouse_pos;
 
-      mdc::Rect r= cview->get_viewport();
-      mdc::Size sz= cview->get_total_view_size();
+      Rect r= cview->get_viewport();
+      Size sz= cview->get_total_view_size();
 
       if(newp.x < 0)
         newp.x= 0;
