@@ -1,3 +1,22 @@
+/* 
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
+ */
+
 #ifndef _WB_COMPONENT_PHYSICAL_H_
 #define _WB_COMPONENT_PHYSICAL_H_
 
@@ -71,9 +90,9 @@ namespace wb {
     void interactive_place_db_objects(ModelDiagramForm *vform, int x, int y, 
       const std::list<db_DatabaseObjectRef> &objects);
     
-    model_FigureRef place_db_object(ModelDiagramForm *view, const mdc::Point &pos, const db_DatabaseObjectRef &object,
+    model_FigureRef place_db_object(ModelDiagramForm *view, const MySQL::Geometry::Point &pos, const db_DatabaseObjectRef &object,
                          bool select_figure= true);
-    void place_new_db_object(ModelDiagramForm *view, const mdc::Point &pos, ObjectType type);
+    void place_new_db_object(ModelDiagramForm *view, const MySQL::Geometry::Point &pos, ObjectType type);
 
     void clone_db_object_to_schema(const db_SchemaRef &schema, const db_DatabaseObjectRef &object, grt::CopyContext &copy_context);
 
@@ -149,7 +168,7 @@ namespace wb {
       bool add_column(const db_ColumnRef &column);
       bool add_refcolumn(const db_ColumnRef &column);
 
-      void on_figure_crossed(const model_ObjectRef &owner, mdc::CanvasItem *item, bool enter, const mdc::Point &pos);
+      void on_figure_crossed(const model_ObjectRef &owner, mdc::CanvasItem *item, bool enter, const MySQL::Geometry::Point &pos);
       void enter_table(const workbench_physical_TableFigureRef& table);
       void leave_table(const workbench_physical_TableFigureRef& table);
             
@@ -160,7 +179,7 @@ namespace wb {
       
       void cancel();
 
-      bool button_press(ModelDiagramForm *view, const mdc::Point &pos);
+      bool button_press(ModelDiagramForm *view, const MySQL::Geometry::Point &pos);
     };
 
     virtual void load_app_options(bool update);
@@ -227,9 +246,9 @@ namespace wb {
       const std::string &path);
 
     grt::ValueRef place_new_db_object_grt(grt::GRT *grt, ModelDiagramForm *view, 
-                                              const mdc::Point &pos, ObjectType type);
+                                              const MySQL::Geometry::Point &pos, ObjectType type);
     
-    RelationshipToolContext *start_relationship(ModelDiagramForm *view, const mdc::Point &pos, RelationshipType type);
+    RelationshipToolContext *start_relationship(ModelDiagramForm *view, const MySQL::Geometry::Point &pos, RelationshipType type);
     void cancel_relationship(ModelDiagramForm *view, RelationshipToolContext *rctx);
 
     bool create_nm_relationship_grt(grt::GRT *grt, ModelDiagramForm *view, workbench_physical_TableFigureRef table1, 
@@ -237,7 +256,7 @@ namespace wb {
                                     bool imandatory, bool fmandatory);
 
     grt::ValueRef place_db_object_grt(grt::GRT *grt, ModelDiagramForm *iew, 
-                                      const mdc::Point &pos, const db_DatabaseObjectRef &object,
+                                      const MySQL::Geometry::Point &pos, const db_DatabaseObjectRef &object,
                                       bool select_figure);
 
   private:
@@ -279,7 +298,7 @@ namespace wb {
 
     void schema_member_changed(const std::string &name, const grt::ValueRef &ovalue, const db_SchemaRef &schema);
 
-    bool handle_button_event(ModelDiagramForm*, mdc::MouseButton, bool, mdc::Point, mdc::EventState, void *data);
+    bool handle_button_event(ModelDiagramForm*, mdc::MouseButton, bool, MySQL::Geometry::Point, mdc::EventState, void *data);
 
   };
 
