@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,6 +32,8 @@
 
 using namespace wb;
 using namespace base;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 WBComponentPhysical::RelationshipToolContext::RelationshipToolContext(WBComponentPhysical *owner, 
                                                                       ModelDiagramForm *form,
@@ -452,7 +454,7 @@ bool WBComponentPhysical::RelationshipToolContext::finish_for_tables()
 }
 
 
-void WBComponentPhysical::RelationshipToolContext::on_figure_crossed(const model_ObjectRef &owner, mdc::CanvasItem *item, bool enter, const mdc::Point &pos)
+void WBComponentPhysical::RelationshipToolContext::on_figure_crossed(const model_ObjectRef &owner, mdc::CanvasItem *item, bool enter, const Point &pos)
 {
   if (owner.is_instance<workbench_physical_TableFigure>())
   {
@@ -514,7 +516,7 @@ void WBComponentPhysical::RelationshipToolContext::leave_table(const workbench_p
 }
 
 
-bool WBComponentPhysical::RelationshipToolContext::button_press(ModelDiagramForm *view, const mdc::Point &pos)
+bool WBComponentPhysical::RelationshipToolContext::button_press(ModelDiagramForm *view, const Point &pos)
 {
   std::string result;
   
