@@ -500,7 +500,8 @@ void WBContextModel::notify_diagram_created(ModelDiagramForm *view)
     connect(sigc::bind(sigc::mem_fun(this, &WBContextModel::diagram_object_changed), view));
   view->change_signal_id(signal_id);
     
-  _wbui->get_physical_overview()->send_refresh_diagram(model_DiagramRef());
+  // now called from wb_component_physical.cpp:model_list_changed
+  //_wbui->get_physical_overview()->send_refresh_diagram(model_DiagramRef());
 }
 
 
@@ -513,7 +514,8 @@ void WBContextModel::notify_diagram_destroyed(ModelDiagramForm *diagram)
     _model_forms.erase(id);
   }
 
-  _wbui->get_physical_overview()->send_refresh_diagram(model_DiagramRef());
+  // now called from wb_component_physical.cpp:model_list_changed
+  //_wbui->get_physical_overview()->send_refresh_diagram(model_DiagramRef());
 }
 
 
