@@ -49,6 +49,8 @@
 using namespace wb;
 using namespace bec;
 using namespace base;
+using namespace MySQL::Drawing;
+using namespace MySQL::Geometry;
 
 static const double zoom_steps[]= {
   2.0,
@@ -489,13 +491,13 @@ bool ModelDiagramForm::is_closed()
 }
 
 
-void ModelDiagramForm::set_button_callback(const sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, mdc::Point, mdc::EventState> &cb)
+void ModelDiagramForm::set_button_callback(const sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, Point, mdc::EventState> &cb)
 {
   _handle_button= cb;
 }
 
 
-void ModelDiagramForm::set_motion_callback(const sigc::slot<bool, ModelDiagramForm*, mdc::Point, mdc::EventState> &cb)
+void ModelDiagramForm::set_motion_callback(const sigc::slot<bool, ModelDiagramForm*, Point, mdc::EventState> &cb)
 {
   _handle_motion= cb;
 }
@@ -594,14 +596,14 @@ void ModelDiagramForm::begin_selection_drag()
       {
         model_FigureRef figure(model_FigureRef::cast_from(sel[i]));
 
-        _old_positions[figure.valueptr()].pos= mdc::Point(figure->left(), figure->top());
+        _old_positions[figure.valueptr()].pos= Point(figure->left(), figure->top());
         _old_positions[figure.valueptr()].layer_id= figure->layer().id();
       }
       else if (sel[i]->is_instance(model_Layer::static_class_name()))
       {
         model_LayerRef layer(model_LayerRef::cast_from(sel[i]));
 
-        _old_positions[layer.valueptr()].pos= mdc::Point(layer->left(), layer->top());
+        _old_positions[layer.valueptr()].pos= Point(layer->left(), layer->top());
       }
     }
   }
@@ -611,7 +613,7 @@ void ModelDiagramForm::begin_selection_drag()
     iter != selection.end(); ++iter)
   {
     // if the layer of the figure is also selected, then leave the figure alone
-    mdc::Point rpos= (*iter)->get_root_position();
+    Point rpos= (*iter)->get_root_position();
 
     if (root != (*iter)->get_parent() && !(*iter)->get_parent()->get_selected())
     {
@@ -640,7 +642,7 @@ void ModelDiagramForm::end_selection_drag()
     {
       model_FigureRef figure(model_FigureRef::cast_from(sel[i]));
       {
-        mdc::Point p= _old_positions[figure.valueptr()].pos;
+        Point p= _old_positions[figure.valueptr()].pos;
         std::string layer_id= _old_positions[figure.valueptr()].layer_id;
 
         if (*figure->left() != p.x || *figure->top() != p.y || layer_id != figure->layer().id())
@@ -657,7 +659,7 @@ void ModelDiagramForm::end_selection_drag()
     {
       model_LayerRef layer(model_LayerRef::cast_from(sel[i]));
       {
-        mdc::Point p= _old_positions[layer.valueptr()].pos;
+        Point p= _old_positions[layer.valueptr()].pos;
 
         if (*layer->left() != p.x || *layer->top() != p.y)
         {
@@ -710,7 +712,7 @@ bool ModelDiagramForm::current_mouse_position(int &x, int &y)
 }
 
 
-bool ModelDiagramForm::current_mouse_position(mdc::Point &pos)
+bool ModelDiagramForm::current_mouse_position(Point &pos)
 {
   int x, y;
   bool inside= current_mouse_position(x, y);
@@ -721,7 +723,7 @@ bool ModelDiagramForm::current_mouse_position(mdc::Point &pos)
 }
 
 
-mdc::CanvasItem *ModelDiagramForm::get_leaf_item_at(const mdc::Point &pos)
+mdc::CanvasItem *ModelDiagramForm::get_leaf_item_at(const Point &pos)
 {
   return _view->get_leaf_item_at(pos);
 }
@@ -732,7 +734,7 @@ void ModelDiagramForm::handle_mouse_button(mdc::MouseButton button, bool press,
 {
   stop_editing();
   
-  mdc::Point pos(_view->window_to_canvas(x, y));
+  Point pos(_view->window_to_canvas(x, y));
   
   if (button == mdc::ButtonRight && !press)
   {
@@ -822,7 +824,7 @@ void ModelDiagramForm::handle_mouse_double_click(mdc::MouseButton button, int x,
 {
   stop_editing();
   
-  mdc::Point pos(_view->window_to_canvas(x, y));
+  Point pos(_view->window_to_canvas(x, y));
   
   if (button != mdc::ButtonLeft && button != mdc::ButtonMiddle)
     return;
@@ -834,7 +836,7 @@ void ModelDiagramForm::handle_mouse_double_click(mdc::MouseButton button, int x,
 
 void ModelDiagramForm::handle_mouse_move(int x, int y, mdc::EventState state)
 {
-  mdc::Point pos(_view->window_to_canvas(x, y));
+  Point pos(_view->window_to_canvas(x, y));
   
   _features->mouse_moved(x, y, state);
   
@@ -1350,8 +1352,8 @@ bool ModelDiagramForm::is_visible(const model_ObjectRef &object, bool partially)
 
   if (!item) return false;
 
-  mdc::Rect bounds= item->get_root_bounds();
-  mdc::Rect viewport= _view->get_viewport();
+  Rect bounds= item->get_root_bounds();
+  Rect viewport= _view->get_viewport();
   
   if (partially)
     return mdc::bounds_intersect(viewport, bounds);    
@@ -1379,24 +1381,24 @@ void ModelDiagramForm::focus_and_make_visible(const model_ObjectRef &object, boo
   if (item)
   {
     mdc::CanvasView *view= item->get_view();
-    mdc::Rect bounds= item->get_root_bounds();
-    mdc::Rect viewport= view->get_viewport();
+    Rect bounds= item->get_root_bounds();
+    Rect viewport= view->get_viewport();
 
     if (!mdc::bounds_contain_bounds(viewport, bounds))
     {
-      mdc::Point offset= viewport.pos;
+      Point offset= viewport.pos;
 
       // get the offset that will move the viewport the least to bring the item inside it
 
-      if (bounds.xmin() < viewport.xmin())
-        offset.x= bounds.xmin() - 20;
-      else if (bounds.xmax() > viewport.xmax())
-        offset.x= bounds.xmax() - viewport.width();
+      if (bounds.left() < viewport.left())
+        offset.x= bounds.left() - 20;
+      else if (bounds.right() > viewport.right())
+        offset.x= bounds.right() - viewport.width();
 
-      if (bounds.ymin() < viewport.ymin())
-        offset.y= bounds.ymin() - 20;
-      else if (bounds.ymax() > viewport.ymax())
-        offset.y= bounds.ymax() - viewport.height();
+      if (bounds.top() < viewport.top())
+        offset.y= bounds.top() - 20;
+      else if (bounds.bottom() > viewport.bottom())
+        offset.y= bounds.bottom() - viewport.height();
 
       view->set_offset(offset);
     }
@@ -1508,7 +1510,7 @@ void ModelDiagramForm::set_cursor(const std::string &cursor)
 
 
 
-model_LayerRef ModelDiagramForm::get_layer_at(const mdc::Point &pos, mdc::Point &offset)
+model_LayerRef ModelDiagramForm::get_layer_at(const Point &pos, Point &offset)
 {
   model_LayerRef layer;
   mdc::AreaGroup *ag= 0;
@@ -1547,7 +1549,7 @@ model_LayerRef ModelDiagramForm::get_layer_at(const mdc::Point &pos, mdc::Point
 }
 
 
-model_LayerRef ModelDiagramForm::get_layer_bounding(const mdc::Rect &rect, mdc::Point &offset)
+model_LayerRef ModelDiagramForm::get_layer_bounding(const Rect &rect, Point &offset)
 {
   grt::ListRef<model_Layer> layers(_model_diagram->layers());
   
@@ -1564,7 +1566,7 @@ model_LayerRef ModelDiagramForm::get_layer_bounding(const mdc::Rect &rect, mdc::
 }
 
 
-model_ObjectRef ModelDiagramForm::get_object_at(const mdc::Point &pos)
+model_ObjectRef ModelDiagramForm::get_object_at(const Point &pos)
 {
   mdc::CanvasItem *item= _view->get_item_at(pos);
 
@@ -1650,10 +1652,10 @@ mdc::Layer *ModelDiagramForm::get_floater_layer()
 
 void ModelDiagramForm::add_floater(Floater *floater)
 {
-  mdc::Point pos;
+  Point pos;
 
-  pos.x= _view->get_viewport().xmax() - 200;
-  pos.y= _view->get_viewport().ymin() + 20;
+  pos.x= _view->get_viewport().right() - 200;
+  pos.y= _view->get_viewport().top() + 20;
 
   floater->move_to(pos);
   _floater_layer->add_item(floater);
@@ -1667,7 +1669,7 @@ WBContext *ModelDiagramForm::get_wb()
 
 
 /* unused
-void ModelDiagramForm::hover_in_figure(mdc::CanvasItem *item, mdc::Point pos)
+void ModelDiagramForm::hover_in_figure(mdc::CanvasItem *item, Point pos)
 {
 }
 
@@ -1682,7 +1684,7 @@ void ModelDiagramForm::hover_out_figure(mdc::CanvasItem *item)
 
 // inline editing
 
-void ModelDiagramForm::begin_editing(const mdc::Rect &rect, const std::string &text, float text_size, bool multiline)
+void ModelDiagramForm::begin_editing(const Rect &rect, const std::string &text, float text_size, bool multiline)
 {
   if (_inline_edit_context)
   {
