@@ -25,10 +25,16 @@
 #include "grt/icon_manager.h"
 #include "base/ui_form.h"
 #include "mini_view.h"
+#include "base/drawing.h"
 
 #include "mforms/menu.h"
 
 namespace mforms { class ToolBarItem; };
+namespace MySQL {
+  namespace Geometry {
+    struct Point;
+  };
+};
 
 namespace wb {
   class Floater;  
@@ -89,7 +95,7 @@ namespace wb {
     void set_closed(bool flag);
     bool is_closed();
     
-    mdc::CanvasItem *get_leaf_item_at(const mdc::Point &pos);
+    mdc::CanvasItem *get_leaf_item_at(const MySQL::Geometry::Point &pos);
     
     bec::Clipboard *get_clipboard();
     
@@ -127,8 +133,8 @@ namespace wb {
     void zoom_in();
     void zoom_out();
 
-    void set_button_callback(const sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, mdc::Point, mdc::EventState> &cb);
-    void set_motion_callback(const sigc::slot<bool, ModelDiagramForm*, mdc::Point, mdc::EventState> &cb);
+    void set_button_callback(const sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, MySQL::Geometry::Point, mdc::EventState> &cb);
+    void set_motion_callback(const sigc::slot<bool, ModelDiagramForm*, MySQL::Geometry::Point, mdc::EventState> &cb);
     void set_reset_tool_callback(const sigc::slot<void, ModelDiagramForm*> &cb);
     
     std::string get_tool() { return _tool; }
@@ -159,7 +165,7 @@ namespace wb {
     bool handle_key(const mdc::KeyInfo &key, bool press, mdc::EventState state);
 
     bool current_mouse_position(int &x, int &y);
-    bool current_mouse_position(mdc::Point &pos);
+    bool current_mouse_position(MySQL::Geometry::Point &pos);
 
     // drag&drop
     std::vector<std::string> get_accepted_drop_types();
@@ -171,9 +177,9 @@ namespace wb {
     bool perform_drop(int x, int y, const std::string &type, const std::string &text);
 
 
-    model_LayerRef get_layer_at(const mdc::Point &pos, mdc::Point &offset);
-    model_LayerRef get_layer_bounding(const mdc::Rect &rect, mdc::Point &offset);
-    model_ObjectRef get_object_at(const mdc::Point &pos);
+    model_LayerRef get_layer_at(const MySQL::Geometry::Point &pos, MySQL::Geometry::Point &offset);
+    model_LayerRef get_layer_bounding(const MySQL::Geometry::Rect &rect, MySQL::Geometry::Point &offset);
+    model_ObjectRef get_object_at(const MySQL::Geometry::Point &pos);
 
 
     mdc::Layer *get_floater_layer();
@@ -189,7 +195,7 @@ namespace wb {
 
 
     // inline editing
-    void begin_editing(const mdc::Rect &rect, const std::string &text, float text_size, bool multiline);
+    void begin_editing(const MySQL::Geometry::Rect &rect, const std::string &text, float text_size, bool multiline);
     void stop_editing();
     sigc::signal<void,std::string,EditFinishReason> signal_editing_done() { return _signal_editing_done; }
 
@@ -207,7 +213,7 @@ namespace wb {
   protected:
     struct OldPosition
     {
-      mdc::Point pos;
+      MySQL::Geometry::Point pos;
       std::string layer_id;
     };
 
@@ -242,8 +248,8 @@ namespace wb {
     
     sigc::signal<void, std::string> _tool_argument_changed;
 
-    sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, mdc::Point, mdc::EventState> _handle_button;
-    sigc::slot<bool, ModelDiagramForm*, mdc::Point, mdc::EventState> _handle_motion;
+    sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, MySQL::Geometry::Point, mdc::EventState> _handle_button;
+    sigc::slot<bool, ModelDiagramForm*, MySQL::Geometry::Point, mdc::EventState> _handle_motion;
     sigc::slot<void, ModelDiagramForm*> _reset_tool;
 
 
@@ -254,8 +260,8 @@ namespace wb {
     std::string _old_tool;
     std::string _old_cursor;
     sigc::slot<void, ModelDiagramForm*> _old_reset_tool;
-    sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, mdc::Point, mdc::EventState> _old_handle_button;
-    sigc::slot<bool, ModelDiagramForm*, mdc::Point, mdc::EventState> _old_handle_motion;
+    sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, MySQL::Geometry::Point, mdc::EventState> _old_handle_button;
+    sigc::slot<bool, ModelDiagramForm*, MySQL::Geometry::Point, mdc::EventState> _old_handle_motion;
 
     void clipboard_changed();
 
@@ -275,7 +281,7 @@ namespace wb {
     void select_dropdown_item(const std::string &option, mforms::ToolBarItem *item);
     void toggle_checkbox_item(const std::string &name, const std::string &option, bool state);
     
-    //void hover_in_figure(mdc::CanvasItem *item, mdc::Point pos);
+    //void hover_in_figure(mdc::CanvasItem *item, MySQL::Geometry::Point pos);
     //void hover_out_figure(mdc::CanvasItem *item);
     private:
       int _update_count; // If > 0 don't refresh depending structures.
