@@ -26,12 +26,12 @@
 
 #include "grt/icon_manager.h"
 #include "grt/clipboard.h"
-#include "ui_form.h"
+#include "base/ui_form.h"
 #include "grt/exceptions.h"
 
 #include "grts/structs.db.h"
 #include "grts/structs.db.mysql.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 /**
  * @file  wb_overview_physical_schema.cpp
