@@ -4,6 +4,8 @@
 #include "sqlide/recordset_data_storage.h"
 #include "grt/common.h"
 #include "base/string_utilities.h"
+#include "base/util_functions.h"
+#include "base/log.h"
 #include "tinyxml.h"
 #include <fstream>
 #include <glib/gstdio.h>
@@ -12,6 +14,8 @@
 #include <fstream>
 #include <mforms/mforms.h>
 
+ENABLE_LOG("sqlide-history")
+
 using namespace bec;
 using namespace grt;
 
@@ -76,6 +80,7 @@ void DbSqlEditorHistory::current_entry(int index)
   if (index == -1)
   {
     _details_model->reset();
+    _details_model->refresh();
   }
   else
   {
@@ -84,7 +89,7 @@ void DbSqlEditorHistory::current_entry(int index)
     _details_model->load_from(details_model);
   }
   _current_entry_index= index;
-  _details_model->refresh();
+  _entries_model->refresh();
 }
 
 
@@ -100,7 +105,7 @@ std::string DbSqlEditorHistory::restore_sql_from_history(int entry_index, std::l
     BOOST_FOREACH (int row, detail_indexes)
     {
       node[0]= row;
-      details_model->get_field(node, 0, statement);
+      details_model->get_field(node, 1, statement);
       sql+= statement + ";\n";
     }
   }
@@ -186,10 +191,20 @@ void DbSqlEditorHistory::EntriesModel::add_entry(const std::list<std::string> &s
   if (statements.empty())
     return;
 
-  insert_entry(local_timestamp());
+  std::tm timestamp = local_timestamp();
+  insert_entry(timestamp);
+
+  std::string time= format_time(timestamp, "%X");
+  std::list<std::string> timed_statements;
+
+  BOOST_FOREACH(std::string statement, statements)
+  {
+    timed_statements.push_back(time);
+    timed_statements.push_back(base::strip_text(statement));
+  }
 
   DetailsModel::Ref details_model= _details_models.back();
-  details_model->add_entries(statements, false);
+  details_model->add_entries(timed_statements);
 
   refresh_ui();
 }
@@ -306,10 +321,13 @@ void DbSqlEditorHistory::DetailsModel::reset()
 
   _loaded= false;
   _last_loaded_row= -1;
+  _last_timestamp = std::string("");
+  _last_statement = std::string("");
   _datestamp= std::tm();
 
   _readonly= true;
 
+  add_column("Time", std::string());
   add_column("SQL", std::string());
 
   boost::shared_ptr<sqlite::connection> data_swap_db= this->data_swap_db();
@@ -326,33 +344,95 @@ std::string DbSqlEditorHistory::DetailsModel::storage_file_path() const
   return storage_file_path;
 }
 
-
 void DbSqlEditorHistory::DetailsModel::load()
 {
   if (_loaded)
     return;
 
   std::string storage_file_path= this->storage_file_path();
-  if (g_file_test(storage_file_path.c_str(), G_FILE_TEST_EXISTS))
+  
+  char *file_name=g_filename_from_utf8(storage_file_path.c_str(), -1, NULL, NULL, NULL);
+  if (file_name)
   {
-    TiXmlDocument history_xml(storage_file_path);
-    if (history_xml.LoadFile())
+    if (g_file_test(file_name, G_FILE_TEST_EXISTS))
     {
-      std::list<std::string> items;
-      TiXmlNode *entry_node= NULL;
-      while ((entry_node= history_xml.IterateChildren(entry_node)))
-        if (TiXmlText *sql_text_node= dynamic_cast<TiXmlText*> (entry_node->FirstChild()))
-          items.push_back(sql_text_node->ValueStr());
-      add_entries(items, true);
+      std::ifstream history_xml(file_name);
+
+      if (history_xml.is_open())
+      {
+        GStaticRecMutexLock data_mutex(_data_mutex);
+        _data.reserve(_data.size() + _column_count);
+
+        std::string line;
+
+        // Skips the first line in the file as is the xml header
+        std::getline(history_xml, line);
+
+        const char *errptr;
+        int erroffs=0;
+        char *pattern = "<ENTRY( timestamp\\=\'(.*)\')?>(.*)<\\/ENTRY>";
+        int patres[64];
+
+        pcre *patre= pcre_compile(pattern, 0, &errptr, &erroffs, NULL);
+        if (!patre)
+          throw std::logic_error("error compiling regex "+std::string(errptr));
+
+        // process the file
+        _row_count = 0;
+        while (history_xml.good())
+        {
+          std::string timestamp;
+          std::string statement;
+          const char *value;
+
+          std::getline(history_xml, line);
+
+          // executes the regexp against the new line
+          int rc = pcre_exec(patre, NULL, line.c_str(), line.length(), 0, 0, patres, sizeof(patres)/sizeof(int));
+
+          if ( rc > 0 )
+          {
+            // gets the values timestamp and 
+            pcre_get_substring(line.c_str(), patres, rc, 2, &value);
+            timestamp = value ? std::string(value) : "";
+
+            pcre_get_substring(line.c_str(), patres, rc, 3, &value);
+            statement = value ? std::string(value) : "";
+
+            // decides whether to use or not the existing data
+            if (timestamp != _last_timestamp.repr() && timestamp != "~")
+              _last_timestamp = timestamp;
+
+            if (statement != _last_statement.repr() && statement != "~")
+              _last_statement = statement;
+
+            _data.push_back(_last_timestamp);
+            _data.push_back(_last_statement);
+        
+            _row_count++;
+          }
+        }
+
+        pcre_free(patre);
+
+        history_xml.close();
+
+        _data_frame_end= _row_count;
+
+        _last_loaded_row= _row_count-1;
+
+        _loaded= true;
+      }
+      else
+        log_error("Can't open SQL history file %s", storage_file_path.c_str());
     }
     else
-    {
-      _grtm->get_grt()->send_error("Can't open SQL history file", storage_file_path);
-    }
+      _loaded = true; //Should be marked as loaded as a new file will be created
   }
-  _loaded= true;
-}
+  else
+    log_error("Error converting file name %s to utf8", storage_file_path.c_str());
 
+}
 
 void DbSqlEditorHistory::DetailsModel::save()
 {
@@ -380,13 +460,31 @@ void DbSqlEditorHistory::DetailsModel::save()
 
   {
     GStaticRecMutexLock data_mutex(_data_mutex);
+    std::string last_saved_timestamp;
+    std::string last_saved_statement;
+    get_field(NodeId(_last_loaded_row), 0, last_saved_timestamp);
+    get_field(NodeId(_last_loaded_row), 1, last_saved_statement);
+
     for (RowId row= _last_loaded_row+1; row < _row_count; ++row)
     {
-      std::string sql;
-      get_field(NodeId(row), 0, sql);
-      std::string str;
-      TiXmlBase::EncodeString(sql, &str); 
-      ofs << "<ENTRY>" << str << "</ENTRY>\n";
+      std::string time, sql;
+      get_field(NodeId(row), 0, time);
+      get_field(NodeId(row), 1, sql);
+
+      if (time == last_saved_timestamp)
+        time = "~";
+      else
+        last_saved_timestamp = time;
+
+      if (sql == last_saved_statement)
+        sql = "~";
+      else
+        last_saved_statement = sql;
+
+      std::string xml_time, xml_sql;
+      TiXmlBase::EncodeString(time, &xml_time); 
+      TiXmlBase::EncodeString(sql, &xml_sql); 
+      ofs << "<ENTRY timestamp=\'" << xml_time << "\'>" << xml_sql << "</ENTRY>\n";
     }
     _last_loaded_row= _row_count - 1;
   }
@@ -394,12 +492,12 @@ void DbSqlEditorHistory::DetailsModel::save()
 }
 
 
-void DbSqlEditorHistory::DetailsModel::add_entries(const std::list<std::string> &statements, bool loading_from_storage_file)
+void DbSqlEditorHistory::DetailsModel::add_entries(const std::list<std::string> &statements)
 {
   if (statements.empty())
     return;
 
-  if (!_loaded && !loading_from_storage_file)
+  if (!_loaded)
     load();
 
   {
@@ -409,8 +507,27 @@ void DbSqlEditorHistory::DetailsModel::add_entries(const std::list<std::string>
 
     try
     {
+      int index=0;
       BOOST_FOREACH (std::string statement, statements)
-        _data.push_back(base::strip_text(statement));
+      {
+        if (index % 2)
+        {
+          // decides whether to use or not the existing data
+          if (statement != _last_statement.repr())
+            _last_statement = statement;
+        
+          _data.push_back(_last_statement);
+        }
+        else
+        {
+          if (statement != _last_timestamp.repr())
+            _last_timestamp = statement;
+
+          _data.push_back(_last_timestamp);
+        }
+      }
+
+      index++;
     }
     catch(...)
     {
@@ -418,11 +535,9 @@ void DbSqlEditorHistory::DetailsModel::add_entries(const std::list<std::string>
       throw;
     }
 
-    _row_count+= statements.size();
+    _row_count+= statements.size()/2;
     _data_frame_end= _row_count;
 
-    if (loading_from_storage_file)
-      _last_loaded_row= _row_count-1;
   }
 
   refresh_ui();
