@@ -747,13 +747,18 @@ static bool cancel_connect_editor()
 Db_sql_editor::Ref WBContextSQLIDE::create_connected_editor(const db_mgmt_ConnectionRef &conn)
 {
   Db_sql_editor::Ref editor(Db_sql_editor::create(this, conn));
-  /*
-  std::string *result;
-  result = (std::string*)mforms::Utilities::run_cancellable_wait_message_task(sigc::bind(sigc::ptr_fun(connect_editor), editor),
-                                                                              sigc::ptr_fun(cancel_connect_editor));
-  if (!result)
-    throw grt::user_cancelled("cancelled");
+
+  void *result_ptr = 0;
+  if (!mforms::Utilities::run_cancelable_task(_("Opening SQL Editor"), 
+                                              strfmt(_("An SQL editor instance for '%s' is opening and should be available in a "
+                                                       "moment.\n\nPlease stand by..."), conn->name().c_str()),
+                                              sigc::bind(sigc::ptr_fun(connect_editor), editor),
+                                              sigc::ptr_fun(cancel_connect_editor),
+                                              result_ptr)
+      || !result_ptr)
+    throw grt::user_cancelled("canceled");
   
+  std::string *result = (std::string*)result_ptr;
   if (result->empty())
     delete result;
   else
@@ -764,7 +769,7 @@ Db_sql_editor::Ref WBContextSQLIDE::create_connected_editor(const db_mgmt_Connec
   }
   
   editor->finish_startup();
-    */
+
   {
     // create entry for grt tree
     db_query_EditorRef object(_wbui->get_wb()->get_grt());
