@@ -134,7 +134,7 @@ void LiveSchemaTree::refresh_ex(bool hard_refresh)
 
 void LiveSchemaTree::refresh_ex(const std::list<std::string> &schema_list, bool hard_refresh)
 {
-  std::map<std::string, SchemaNode> old_schemata;
+  std::map<std::string, SchemaNode> old_schemata; // or expanded nodes, if it's a hard_refresh
   
   pre_refresh_signal.emit();
   
@@ -147,7 +147,23 @@ void LiveSchemaTree::refresh_ex(const std::list<std::string> &schema_list, bool
       old_schemata[iter->name]= *iter;
     }
   }
-
+  else
+  {
+    // save state of the expanded schema nodes
+    for (std::vector<SchemaNode>::iterator iter= _schemata.begin();
+         iter != _schemata.end(); ++iter)
+    {
+      if (iter->expanded)
+      {
+         iter->fetched= false;
+         iter->fetching= false;
+         iter->tables.clear();
+         iter->views.clear();
+         iter->routines.clear();
+         old_schemata[iter->name]= *iter;
+      }
+    }
+  }
   _schemata.clear();
   _schemata.reserve(schema_list.size());
   for (std::list<std::string>::const_iterator iter= schema_list.begin();
@@ -159,6 +175,7 @@ void LiveSchemaTree::refresh_ex(const std::list<std::string> &schema_list, bool
       node.name= *iter;
       node.fetched= false;
       node.fetching= false;
+      node.expanded= false;
       _schemata.push_back(node);
     }
     else
@@ -174,6 +191,31 @@ void LiveSchemaTree::refresh_ex(const std::list<std::string> &schema_list, bool
 }
 
 
+bool LiveSchemaTree::is_expanded(const bec::NodeId &node)
+{
+  if (node.depth() == 1)
+  {
+    if (node[0] >= 0 && node[0] < (int)_schemata.size())
+    {
+      return _schemata[node[0]].expanded;
+    }
+  }
+  else if (node.depth() == 2)
+  {
+    if (node[0] >= 0 && node[0] < (int)_schemata.size())
+    {
+      switch (node[1])
+      {
+        case 0: return _schemata[node[0]].tables_expanded;
+        case 1: return _schemata[node[0]].views_expanded;
+        case 2: return _schemata[node[0]].routines_expanded;
+      }
+    }
+  }
+  return false;
+}
+
+
 int LiveSchemaTree::count_children(const bec::NodeId &node)
 {
   if (node.depth() == 0)
@@ -374,12 +416,16 @@ void LiveSchemaTree::update_live_object_state(ObjectType type, const std::string
     case Schema:
       {
         bool is_new_obj_found= false;
+        bool was_expanded= false;
         for (int n= _schemata.size()-1; n >= 0; --n)
         {
           if (_schemata[n].name == new_obj_name)
             is_new_obj_found= true;
           if (is_obj_dropped && (_schemata[n].name == old_obj_name))
+          {
+            was_expanded = _schemata[n].expanded;
             _schemata.erase(_schemata.begin()+n);
+          }
         }
         if (is_obj_created && !is_new_obj_found)
         {
@@ -387,6 +433,7 @@ void LiveSchemaTree::update_live_object_state(ObjectType type, const std::string
           new_schema_node.name= new_obj_name;
           new_schema_node.fetched= false;
           new_schema_node.fetching= false;
+          new_schema_node.expanded= was_expanded;
           _schemata.push_back(new_schema_node);
           std::sort(_schemata.begin(), _schemata.end(), compare_schema_node);
         }
@@ -435,6 +482,7 @@ void LiveSchemaTree::schema_contents_arrived(const SchemaNode &node, int index,
       {
         iter->fetched= true;
         iter->fetching= false;
+        iter->expanded= true;
         iter->tables= node.tables;
         iter->views= node.views;
         iter->routines= node.routines;
@@ -449,6 +497,7 @@ void LiveSchemaTree::schema_contents_arrived(const SchemaNode &node, int index,
 
     snode.fetched= true;
     snode.fetching= false;
+    snode.expanded= true;
     snode.tables= node.tables;
     snode.views= node.views;
     snode.routines= node.routines;
@@ -525,6 +574,7 @@ bool LiveSchemaTree::expand_node(const bec::NodeId &node)
     SchemaNode &snode(_schemata[node[0]]);
     if (!snode.fetched && !snode.fetching)
     {
+      snode.expanded= true;
       snode.fetching= true;
       fetch_slot(node, snode.name,
         sigc::bind(sigc::mem_fun(this, &LiveSchemaTree::schema_contents_arrived),
@@ -534,6 +584,15 @@ bool LiveSchemaTree::expand_node(const bec::NodeId &node)
   }
   else if (node.depth() == 2)
   {
+    if (node[0] >= 0 && node[0] < (int)_schemata.size())
+    {
+      switch (node[1])
+      {
+        case 0: _schemata[node[0]].tables_expanded = true; break;
+        case 1: _schemata[node[0]].views_expanded = true; break;
+        case 2: _schemata[node[0]].routines_expanded = true; break;
+      }
+    }
     return true;
   }
   else if (node.depth() == 3)
@@ -545,6 +604,28 @@ bool LiveSchemaTree::expand_node(const bec::NodeId &node)
 }
 
 
+void LiveSchemaTree::collapse_node(const bec::NodeId &node)
+{
+  if (node.depth() == 1)
+  {
+    SchemaNode &snode(_schemata[node[0]]);
+    snode.expanded= false;
+  }
+  else if (node.depth() == 2)
+  {
+    if (node[0] >= 0 && node[0] < (int)_schemata.size())
+    {
+      switch (node[1])
+      {
+        case 0: _schemata[node[0]].tables_expanded = false; break;
+        case 1: _schemata[node[0]].views_expanded = false; break;
+        case 2: _schemata[node[0]].routines_expanded = false; break;
+      }
+    }
+  }
+}
+
+
 LiveSchemaTree::ObjectNode * LiveSchemaTree::load_object_details(const NodeId &index_node)
 {
   ObjectType obj_type;
