@@ -45,6 +45,11 @@ namespace wb
       std::vector<ObjectNode> routines;
       bool fetched;
       bool fetching;
+      bool expanded;
+      bool tables_expanded;
+      bool views_expanded;
+      bool routines_expanded;
+      SchemaNode() : fetched(false), fetching(false), expanded(false), tables_expanded(false), views_expanded(false), routines_expanded(false) {}
     };
     
     typedef sigc::signal<void> RefreshSlot;
@@ -95,7 +100,9 @@ namespace wb
     int get_index_of_schema(const std::string &schema_name) const;
 
     virtual bool is_expandable(const bec::NodeId &node);
+    virtual bool is_expanded(const bec::NodeId &node);
     virtual bool expand_node(const bec::NodeId &node);
+    virtual void collapse_node(const bec::NodeId &node);
 
     virtual void refresh();
     virtual void refresh_ex(bool hard_refresh);
