@@ -29,6 +29,7 @@
 #include "cppdbc.h"
 #include "grts/structs.workbench.h"
 #include "grts/structs.db.mgmt.h"
+#include "base/file_utilities.h"
 #include "base/ui_form.h"
 #include "grt/refresh_ui.h"
 #include "grt/action_list.h"
@@ -101,8 +102,10 @@ private:
   mforms::ToolBar *_toolbar;
   grt::DictRef _options;
   std::string _connection_info;
+  base::LockFile *_autosave_lock;
   std::string _autosave_path;
   bool _loading_workspace;
+  bool _close_done;
 
   void activate_command(const std::string &command);
 public:
@@ -165,6 +168,8 @@ public:
 private:
   std::map<std::string, std::string> _connection_details;
 
+  grt::StringRef do_connect(grt::GRT *grt);
+  grt::StringRef do_disconnect(grt::GRT *grt);
 public:
   void connect();
   bool connected() const;
@@ -224,7 +229,8 @@ private:
   enum ExecFlags {
     Retaining = (1<<0), 
     Wrap_with_non_std_delimiter = (1<<1),
-    Dont_add_limit_clause = (1<<2)
+    Dont_add_limit_clause = (1<<2),
+    Show_warnings = (1<<3)
   };
   grt::StringRef do_exec_sql(grt::GRT *grt, Ptr self_ptr, std::string &sql, Sql_editor::Ref editor, ExecFlags flags, Recordsets *result_list);
   void do_explain_sql(const std::string &sql);
@@ -321,6 +327,9 @@ private:
   void apply_object_alter_script(std::string &alter_script, bec::DBObjectEditorBE* obj_editor);
   void refresh_live_object_in_editor(bec::DBObjectEditorBE* obj_editor, bool using_old_name);
   void refresh_live_object_in_overview(wb::LiveSchemaTree::ObjectType type, const std::string schema_name, const std::string old_obj_name, const std::string new_obj_name);
+  
+  bool parse_ddl_into_catalog(db_mgmt_RdbmsRef rdbms, db_CatalogRef client_state_catalog, const std::string &obj_descr, const std::string &ddl_script, std::string sql_mode);
+  
   db_SchemaRef create_new_schema(db_CatalogRef owner);
   db_TableRef create_new_table(db_SchemaRef owner);
   db_ViewRef create_new_view(db_SchemaRef owner);
