@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -363,11 +363,11 @@ void StarterPopup::draw_entry(cairo_t* cr, app_StarterRef starter, int x, int y,
     draw_button(cr, trigger_left, trigger_top, text_extents.width + STARTER_ACTION_BUTTON_PADDING, true);
 
     // Cache the action button bounds to ease hit tests.
-    _action_button_bounds.left= trigger_left;
-    _action_button_bounds.top= trigger_top;
-    _action_button_bounds.width= image_width(_action_button_parts[0]) + text_extents.width +
+    _action_button_bounds.pos.x = trigger_left;
+    _action_button_bounds.pos.y = trigger_top;
+    _action_button_bounds.size.width = image_width(_action_button_parts[0]) + text_extents.width +
       STARTER_ACTION_BUTTON_PADDING + image_width(_action_button_parts[2]);
-    _action_button_bounds.height= button_height;
+    _action_button_bounds.size.height = button_height;
 
     // Draw the button text.
     trigger_top += (button_height - text_extents.height) / 2 - text_extents.y_bearing - 1;
@@ -557,6 +557,7 @@ void StarterPopup::repaint(cairo_t *cr, int x, int y, int w, int h)
   }
 
   // Buttons.
+
   cairo_select_font_face(cr, STARTER_TITLE_FONT, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
   cairo_set_font_size(cr, STARTER_BUTTON_FONT_SIZE);
 
@@ -575,18 +576,18 @@ void StarterPopup::repaint(cairo_t *cr, int x, int y, int w, int h)
   double outer_offset= image_width(_nav_button_parts[0]) + image_width(_nav_button_parts[2]);
   if (button_width < STARTER_MORE_PLUGINS_BUTTON_MIN_WIDTH - outer_offset)
     button_width= STARTER_MORE_PLUGINS_BUTTON_MIN_WIDTH - outer_offset;
-
+/*
   draw_button(cr, button_left, button_top, button_width, false);
-  _more_button_bounds.width= button_width + outer_offset;
-  _more_button_bounds.height= button_height;
-  _more_button_bounds.left= button_left;
-  _more_button_bounds.top= button_top;
+  _more_button_bounds.size.width = button_width + outer_offset;
+  _more_button_bounds.size.height = button_height;
+  _more_button_bounds.pos.x = button_left;
+  _more_button_bounds.pos.y = button_top;
 
   cairo_move_to(cr, current_left, current_top);
   cairo_set_source_rgb(cr, 1, 1, 1);
   cairo_show_text(cr, STARTER_MORE_PLUGINS_TEXT);
   cairo_stroke(cr);
-
+*/
   // Next and back buttons are right aligned, so we need their width first. Both buttons will be set to
   // have the same width, depending on which is larger.
   cairo_text_extents(cr, STARTER_BACK_TEXT, &extents);
@@ -603,12 +604,12 @@ void StarterPopup::repaint(cairo_t *cr, int x, int y, int w, int h)
 
   cairo_push_group(cr);
   draw_button(cr, button_left, button_top, button_width, false);
-  _back_button_bounds.left= button_left;
-  _back_button_bounds.top= button_top;
-  _back_button_bounds.width= button_width + outer_offset;
-  _back_button_bounds.height= button_height;
+  _back_button_bounds.pos.x = button_left;
+  _back_button_bounds.pos.y = button_top;
+  _back_button_bounds.size.width = button_width + outer_offset;
+  _back_button_bounds.size.height = button_height;
 
-  current_left= (int) ceil(button_left + (_back_button_bounds.width - back_width) / 2);
+  current_left= (int) ceil(button_left + (_back_button_bounds.width() - back_width) / 2);
   cairo_set_source_rgb(cr, 1, 1, 1);
   cairo_move_to(cr, current_left, current_top);
   cairo_show_text(cr, STARTER_BACK_TEXT);
@@ -620,12 +621,12 @@ void StarterPopup::repaint(cairo_t *cr, int x, int y, int w, int h)
     cairo_paint_with_alpha(cr, 0.5);
 
   cairo_push_group(cr);
-  button_left += _back_button_bounds.width + STARTER_BUTTON_SPACING;
-  _next_button_bounds.left= button_left;
-  _next_button_bounds.top= button_top;
-  _next_button_bounds.width= button_width + outer_offset;
-  _next_button_bounds.height= button_height;
-  current_left= (int) ceil(button_left + (_next_button_bounds.width - next_width) / 2);
+  button_left += _back_button_bounds.width() + STARTER_BUTTON_SPACING;
+  _next_button_bounds.pos.x = button_left;
+  _next_button_bounds.pos.y = button_top;
+  _next_button_bounds.size.width = button_width + outer_offset;
+  _next_button_bounds.size.height = button_height;
+  current_left= (int) ceil(button_left + (_next_button_bounds.width() - next_width) / 2);
 
   draw_button(cr, button_left, button_top, button_width, false);
 
@@ -642,7 +643,7 @@ void StarterPopup::repaint(cairo_t *cr, int x, int y, int w, int h)
   // Page display.
   std::string page_text= base::strfmt(STARTER_PAGE_TEXT, _current_page + 1, _page_count);
   cairo_text_extents(cr, page_text.c_str(), &extents);
-  current_left= (int) (floor)(_back_button_bounds.left - STARTER_BUTTON_SPACING - extents.width);
+  current_left= (int) (floor)(_back_button_bounds.left() - STARTER_BUTTON_SPACING - extents.width);
   cairo_set_source_rgb(cr, 1, 1, 1);
   cairo_move_to(cr, current_left, current_top);
   cairo_show_text(cr, page_text.c_str());
@@ -693,7 +694,7 @@ void StarterPopup::mouse_click(int button, int x, int y)
         set_needs_repaint();
       }
     }
-
+/*
     if (!handled && _more_button_bounds.contains(x, y))
     {
       handled= true;
@@ -701,13 +702,13 @@ void StarterPopup::mouse_click(int button, int x, int y)
         _callback(StarterPluginCentral, _hot_entry, _user_data);
       set_modal_result(1);
     }
-
+*/
     if (!handled && _action_button_bounds.contains(x, y))
     {
       handled= true;
 
       // See if the user hit the action button and show the action menu if so.
-      _action_menu->popup_at(this, (int) (_action_button_bounds.right() + 5), (int) _action_button_bounds.top);
+      _action_menu->popup_at(this, (int) (_action_button_bounds.right() + 5), (int) _action_button_bounds.top());
     }
 
     if (!handled && _hot_entry.is_valid())
