@@ -8,7 +8,7 @@
 #include "wb_helpers.h"
 #include "workbench/wb_overview.h"
 #include "workbench/wb_find_dialog.h"
-#include "util_functions.h"
+#include "base/util_functions.h"
 #include "wbcanvas/workbench_physical_tablefigure_impl.h"
 
 #include "grtdb/db_object_helpers.h"
@@ -156,7 +156,8 @@ TEST_FUNCTION(4)
 }
 
 
-
+// TODO : Check if this function still valid as the function has been removed from WBContext
+/*
 TEST_FUNCTION(5)
 {
   // test check_plugin_input_available from WBContext
@@ -259,7 +260,7 @@ TEST_FUNCTION(5)
   // test for workbench.physical.Model
   pdef->objectStructName(workbench_physical_Model::static_class_name());
   ensure("workbench.physical.Model", wb->check_plugin_input_available(pdef));
-}
+}*/
 
 
 
