@@ -573,7 +573,7 @@ void CommandUI::add_menu_items_for_context(const std::string &context, mforms::M
       if (item_context.empty())
         item_context= WB_CONTEXT_GLOBAL;
 
-      const mforms::MenuItemType type = mitem->itemType() != "check" ? mforms::NormalMenuItem : mforms::CheckedMenuItem;
+      const mforms::MenuItemType type = (mitem->itemType() != "check" && mitem->itemType() != "radio") ? mforms::NormalMenuItem : mforms::CheckedMenuItem;
 
       if (item_context == WB_CONTEXT_GLOBAL)
       {
@@ -1090,3 +1090,17 @@ void CommandUI::activate_command(const std::string &command)
   }
 }
 
+
+void CommandUI::revalidate_edit_menu_items()
+{
+  if (mforms::Utilities::in_main_thread())
+    signal_validate_edit_menu_items().emit();
+  else
+    _wb->get_grt_manager()->run_when_idle(sigc::bind_return<bool>(sigc::bind_return(sigc::mem_fun(this, &CommandUI::revalidate_edit_menu_items), (void*)0), false));
+    //mforms::Utilities::perform_from_main_thread(sigc::bind_return(sigc::mem_fun(this, &CommandUI::revalidate_edit_menu_items), (void*)0));
+
+  // NOTE : using perform_from_main_thread causes a _grtm reference on the BaseEditor to to get lost in the process, 
+  //        this causes the application to crash while attempting to create AutoUndoUpdate objects.
+  //        Changed to run_when_idle to fix this issue
+} 
+
