@@ -49,8 +49,8 @@
 
 #define APP_MAJOR_NUMBER 5
 #define APP_MINOR_NUMBER 2
-#define APP_RELEASE_NUMBER 33
-#define APP_REVISION_NUMBER 7506
+#define APP_RELEASE_NUMBER 34
+#define APP_REVISION_NUMBER 7780
 
 
 
@@ -307,12 +307,19 @@ namespace wb {
     void request_refresh(RefreshType type, const std::string &str, NativeHandle ptr= (NativeHandle)0);
 
     const std::string &get_user_datadir() const { return _user_datadir; }
+    //TODO: Temoprarly solution need to make ModelFile grt class
+    workbench_DocumentRef openModelFile(const std::string &file);
+    std::string getTempDir();
+    int closeModelFile();
+    std::string getDbFilePath();
 
     bool open_document(const std::string &file);
     void open_script_file(const std::string &file);
     void open_recent_document(int index);
     bool has_unsaved_changes();
     bool save_changes();
+    
+    bool open_file_by_extension(const std::string &path, bool interactive);
 
     bec::PluginManager *get_plugin_manager() { return _plugin_manager; }
     template<class C> C *get_component()
@@ -402,6 +409,7 @@ namespace wb {
   protected:
     friend class WBContextModel; // to access _components
     
+    ModelFile* _model_file;
     bec::GRTManager *_manager;
     bec::PluginManager *_plugin_manager;
 
@@ -505,6 +513,8 @@ namespace wb {
     bool find_connection_password(const db_mgmt_ConnectionRef &conn, std::string &password);
 
     bool do_request_password(const std::string &title, const std::string &service, std::string &account, bool reset_password, std::string *ret_password);
+    bool do_find_connection_password(const std::string &hostId, const std::string &username, std::string *ret_password);
+
     void attempt_options_upgrade(xmlDocPtr xmldoc, const std::string &version);
 
     std::string request_connection_password(const db_mgmt_ConnectionRef &conn, bool force_asking);
