@@ -44,6 +44,8 @@
 #include "mforms/app.h"
 #include "base/string_utilities.h"
 
+#include "plugin_install_window.h"
+
 using namespace wb;
 using namespace bec;
 using namespace base;
@@ -70,6 +72,9 @@ WBContextUI::WBContextUI(bool verbose)
   _active_form= 0;
   _active_main_form= 0;
   
+  _addon_download_window = 0;
+  _plugin_install_window = 0;
+  
   _last_unsaved_changes_state= false;
   _quitting= false;
   
@@ -87,35 +92,53 @@ WBContextUI::~WBContextUI()
 {
   _wb->do_close_document(true);
 
+  delete _addon_download_window;
+  _addon_download_window = 0;
+  delete _plugin_install_window;
+  _plugin_install_window = 0;
   delete _find_dialog;
+  _find_dialog = 0;
   delete _history_tree;
+  _history_tree = 0;
   delete _home_screen;
+  _home_screen = 0;
   delete _shell_window;
+  _shell_window = 0;
 
   delete _wb;
+  _wb = 0;
 }
 
 //--------------------------------------------------------------------------------------------------
 
 bool WBContextUI::init(WBFrontendCallbacks *callbacks, WBOptions *options)
 {
-  // this needs to be created after the search paths have been set
-  // WBContext::init_ will call get_shell_window() at the right time, which 
-  // will trigger the instantiation
-  //_shell_window = new GRTShellWindow(_wb->get_grt_manager());
+  _initializing = true;
+  bool flag = false;
+  try
+  {
+    // this needs to be created after the search paths have been set
+    // WBContext::init_ will call get_shell_window() at the right time, which 
+    // will trigger the instantiation
+    //_shell_window = new GRTShellWindow(_wb->get_grt_manager());
+    flag= _wb->init_(callbacks, options);
 
-  bool flag= _wb->init_(callbacks, options);
+    // has to be called after WBContext is initialized
+    add_backend_builtin_commands();
+
+    // look for auto-save files (must be done at startup to not confuse with autosaves created by ourself)
+    WBContextModel::detect_auto_save_files(_wb->get_auto_save_dir());
+    WBContextSQLIDE::detect_auto_save_files(_wb->get_auto_save_dir());
+
+    // Finally show initial home screen.
+    show_home_screen();
+    _initializing = false;
+  }
+  catch (...)
+  {
+    _initializing = false;
+  }
 
-  // has to be called after WBContext is initialized
-  add_backend_builtin_commands();
-  
-  // look for auto-save files (must be done at startup to not confuse with autosaves created by ourself)
-  WBContextModel::detect_auto_save_files(_wb->get_auto_save_dir());
-  WBContextSQLIDE::detect_auto_save_files(_wb->get_auto_save_dir());
-  
-  // Finally show initial home screen.
-  show_home_screen();
-  
   return flag;
 }
 
@@ -208,6 +231,7 @@ void WBContextUI::history_changed()
   if (_wb->has_unsaved_changes() != _last_unsaved_changes_state)
     _wb->request_refresh(RefreshDocument, "", (NativeHandle)0);
 
+  get_command_ui()->revalidate_edit_menu_items();
   _last_unsaved_changes_state= _wb->has_unsaved_changes();
 }
 
@@ -324,6 +348,12 @@ void WBContextUI::add_backend_builtin_commands()
     sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://bugs.mysql.com/", true));
   _command_ui.add_builtin_command("list_bugs",
     sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://bugs.mysql.com/saved/WB%20bugs", true));
+  _command_ui.add_builtin_command("plugin_site",
+    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://wb.mysql.com/addons/", true));
+  _command_ui.add_builtin_command("check_update",
+    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), 
+               base::strfmt("http://wb.mysql.com/workbench/version-check.php?version=%i.%i.%i&revision=%i", 
+                            APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, APP_REVISION_NUMBER), false));
   _command_ui.add_builtin_command("help_index", sigc::mem_fun(this, &WBContextUI::show_help_index));
 }
 
@@ -373,7 +403,7 @@ void WBContextUI::show_web_page(const std::string& url, bool internal_browser)
 #ifdef WB_USE_INTERNAL_BROWSER
   if (internal_browser)
   {
-    WebBrowserView* browser= mforms::manage(new WebBrowserView());
+    WebBrowserView* browser= mforms::manage(new WebBrowserView(this));
     mforms::App::get()->dock_view(browser, "maintab");
     mforms::App::get()->set_view_title(browser, _("Loading web page..."));
     browser->navigate(url);
@@ -432,6 +462,10 @@ void WBContextUI::form_changed()
     refresh_home_instances(0);
     refresh_home_connections();
   }
+
+  bec::UIForm *form = get_active_main_form();
+  if (form && form->get_menubar())
+    form->get_menubar()->validate();
 }
 
 HistoryTreeBE *WBContextUI::get_history_tree()
@@ -685,30 +719,23 @@ void WBContextUI::set_description_for_selection(const grt::ListRef<GrtObject> &o
     std::string descr_mem_name("description");
     
     grt::AutoUndo undo(_wb->get_grt());
-    
-    if (objList.count()==1)
+
+    for (size_t c= objList.count(), i= 0; i < c; i++)
     {
-      GrtObjectRef obj(objList[0]);
+      GrtObjectRef obj(objList[i]);
       if (obj.is_valid())
       {
         if (obj.has_member(comment_mem_name))
-          obj.set_member(comment_mem_name, grt::StringRef(val));
-        else if (obj.has_member(descr_mem_name))
-          obj.set_member(descr_mem_name, grt::StringRef(val));
-      }
-    }
-    else
-    {
-      for (size_t c= objList.count(), i= 0; i < c; i++)
-      {
-        GrtObjectRef obj(objList[i]);
-        if (obj.is_valid())
         {
-          if (obj.has_member(comment_mem_name))
-            obj.set_member(comment_mem_name, grt::StringRef(val));
-          else if (obj.has_member(descr_mem_name))
-            obj.set_member(descr_mem_name, grt::StringRef(val));
+          obj.set_member(comment_mem_name, grt::StringRef(val));
+          get_physical_overview()->send_refresh_for_schema_object(obj, true);
         }
+        else
+          if (obj.has_member(descr_mem_name))
+          {
+            obj.set_member(descr_mem_name, grt::StringRef(val));
+            get_physical_overview()->send_refresh_for_schema_object(obj, true);
+          }
       }
     }
 
@@ -1043,7 +1070,6 @@ void WBContextUI::set_active_form(bec::UIForm *form)
 {
   if (_active_form == form)
     return;
-    
   // register callbacks to form if needed
   
   if (_active_form && form)
@@ -1118,3 +1144,19 @@ std::string WBContextUI::get_title()
 }
 
 #endif // ___others
+
+
+void WBContextUI::start_plugin_net_install(const std::string &url)
+{
+  if (!_addon_download_window)
+    _addon_download_window = new AddOnDownloadWindow(this);
+  _addon_download_window->install_addon_from_url(url);
+}
+
+
+bool WBContextUI::start_plugin_install(const std::string &path)
+{
+  if (!_plugin_install_window)
+    _plugin_install_window = new PluginInstallWindow(this);
+  return _plugin_install_window->install_plugin(path);
+}
