@@ -84,14 +84,6 @@ std::string get_server_info(db_mgmt_ServerInstanceRef instance)
 
 //--------------------------------------------------------------------------------------------------
 
-static bool on_home_closing(WBContextUI* owner)
-{
-  owner->home_screen_closing();
-  return true;
-}
-
-//--------------------------------------------------------------------------------------------------
-
 static void save_state(WBContext *wb, HomeScreen *home)
 {
   if (!home->get_wb_central_expanded())
@@ -99,8 +91,21 @@ static void save_state(WBContext *wb, HomeScreen *home)
                    strfmt("%i.%i.%i", APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER));
   else
     wb->save_state("WBCentralCollapsedInVersion", "home", std::string(""));  
+  
+  wb->save_state("WBHomeGroupStateAdministration", "home", home->get_collapsed_group_data(HomeScreenAdministrationList));  
+  wb->save_state("WBHomeGroupStateSQLDev", "home", home->get_collapsed_group_data(HomeScreenSQLDevList));  
 }
 
+//--------------------------------------------------------------------------------------------------
+
+static bool on_home_closing(WBContextUI* owner, HomeScreen *home)
+{
+  owner->home_screen_closing();
+  save_state(owner->get_wb(), home);
+  return true;
+}
+
+
 /**
  * Creates the main home screen (Workbench Central, Workspace) if not yet done and docks it to 
  * the main application window.
@@ -110,12 +115,15 @@ void WBContextUI::show_home_screen()
   if (_home_screen == NULL)
   {    
     _home_screen= mforms::manage(new HomeScreen(&_command_ui, _wb->get_grt()));
-    _home_screen->set_on_close(sigc::bind(sigc::ptr_fun(on_home_closing), this));
+    _home_screen->set_on_close(sigc::bind(sigc::ptr_fun(on_home_closing), this, _home_screen));
     _home_screen->set_callback((home_screen_action_callback)&WBContextUI::home_action_callback, this);
     _home_screen->handle_context_menu = sigc::mem_fun(this, &WBContextUI::handle_home_context_menu);
     
+#if defined(__APPLE__) || defined(_WIN32)
+    // in Linux, the Home screen is closed/deleted when the app closes, so state should be
+    // saved when the home screen is closed
     _wb->signal_app_closing().connect(sigc::bind(sigc::ptr_fun(save_state), _wb, _home_screen));
-
+#endif
     // setup context menus
     bec::MenuItemList items, pitems;
     bec::MenuItem item, sep;
@@ -143,6 +151,17 @@ void WBContextUI::show_home_screen()
     }
     if (!items.empty())
       items.push_back(sep);
+
+    item.name= "move_connection_up";
+    item.caption= "Move Up";
+    items.push_back(item);
+    
+    item.name= "move_connection_down";
+    item.caption= "Move Down";
+    items.push_back(item);
+    
+    items.push_back(sep);
+    
     item.name= "delete_connection";
     item.caption= "Delete Connection...";
     items.push_back(item);
@@ -152,6 +171,25 @@ void WBContextUI::show_home_screen()
     items.push_back(item);
 
     _home_screen->set_context_menu_items(HomeScreenSQLDevList, items);
+    _home_screen->set_collapsed_group_data(HomeScreenSQLDevList, _wb->read_state("WBHomeGroupStateSQLDev", "home", std::string()));
+    
+    items.clear();
+
+    item.name= "move_connection_up";
+    item.caption= "Move Up";
+    items.push_back(item);
+    
+    item.name= "move_connection_down";
+    item.caption= "Move Down";
+    items.push_back(item);
+    
+    items.push_back(sep);
+    
+    item.name= "delete_connection_group";
+    item.caption= "Delete Group";
+    items.push_back(item);
+
+    _home_screen->set_context_menu_items(HomeScreenSQLDevList, items, true);
     
     //
     items.clear();
@@ -203,15 +241,46 @@ void WBContextUI::show_home_screen()
     if (!items.empty())
       items.push_back(sep);
 
+    item.name= "move_instance_up";
+    item.caption= "Move Up";
+    items.push_back(item);
+	  
+    item.name= "move_instance_down";
+    item.caption= "Move Down";
+    items.push_back(item);
+
+    items.push_back(sep);
+    
     item.name= "delete_instance";
     item.caption= "Delete Server Instance...";
     items.push_back(item);
-    
+
     item.caption= "Delete All Server Instances...";
     item.name= "delete_instance_all";
     items.push_back(item);
     
     _home_screen->set_context_menu_items(HomeScreenAdministrationList, items);
+    _home_screen->set_collapsed_group_data(HomeScreenAdministrationList, _wb->read_state("WBHomeGroupStateAdministration", "home", std::string()));
+    
+    items.clear();
+    
+    item.name= "move_instance_up";
+    item.caption= "Move Up";
+    items.push_back(item);
+    
+    item.name= "move_instance_down";
+    item.caption= "Move Down";
+    items.push_back(item);
+    
+    items.push_back(sep);
+    
+    item.name= "delete_instance_group";
+    item.caption= "Delete Group";
+    items.push_back(item);
+    
+    _home_screen->set_context_menu_items(HomeScreenAdministrationList, items, true);
+    
+
   }
   mforms::App::get()->dock_view(_home_screen, "maintab");
   mforms::App::get()->set_view_title(_home_screen, "Home");
@@ -285,6 +354,50 @@ void WBContextUI::handle_home_context_menu(HomeScreenListType list, const grt::V
       refresh_home_connections();
     }
   }
+  else if (action == "move_connection_up")
+  {
+    grt::ListRef<db_mgmt_Connection> connections(_wb->get_root()->rdbmsMgmt()->storedConns());
+    
+    bec::move_list_ref_item<db_mgmt_Connection>(MoveUp, connections, object);
+    
+    refresh_home_connections();
+    _home_screen->select_list_entry(HomeScreenSQLDevList, object);
+  }
+  else if (action == "move_connection_down")
+  {
+    grt::ListRef<db_mgmt_Connection> connections(_wb->get_root()->rdbmsMgmt()->storedConns());
+    
+    bec::move_list_ref_item<db_mgmt_Connection>(MoveDown, connections, object);
+    
+    refresh_home_connections();
+    _home_screen->select_list_entry(HomeScreenSQLDevList, object);
+  }
+  else if (action == "delete_connection_group")
+  {
+    std::string group = object.repr();
+    std::string text= strfmt(_("Do you really want to delete all the connections in group: %s?"), group.c_str());
+    int answer= Utilities::show_warning(_("Delete Connection Group"), text,  _("Delete"), _("Cancel"));
+    if (answer == mforms::ResultOk)
+    {
+      group +="/";
+      int group_length = group.length();
+      
+      grt::ListRef<db_mgmt_Connection> connections(_wb->get_root()->rdbmsMgmt()->storedConns());
+
+      int index = connections.count() - 1;
+      while (index >= 0)
+      {
+        std::string name = connections[index]->name();
+        
+        if (name.compare(0, group_length, group) == 0)
+          connections->remove(index);
+
+        index--;
+      }
+
+      refresh_home_connections();
+    }
+  }
   else if (action == "delete_connection_all")
   {
     std::string text= _("Do you really want to delete all defined connections?");
@@ -339,6 +452,51 @@ void WBContextUI::handle_home_context_menu(HomeScreenListType list, const grt::V
       refresh_home_instances();
     }
   }
+  else if (action == "move_instance_up")
+  {
+    grt::ListRef<db_mgmt_ServerInstance> instances(_wb->get_root()->rdbmsMgmt()->storedInstances());
+    
+    bec::move_list_ref_item<db_mgmt_ServerInstance>(MoveUp, instances, object);
+    
+    refresh_home_instances();
+    _home_screen->select_list_entry(HomeScreenAdministrationList, object);
+  }
+  else if (action == "move_instance_down")
+  {
+    grt::ListRef<db_mgmt_ServerInstance> instances(_wb->get_root()->rdbmsMgmt()->storedInstances());
+    
+    bec::move_list_ref_item<db_mgmt_ServerInstance>(MoveDown, instances, object);
+    
+    refresh_home_instances();
+    _home_screen->select_list_entry(HomeScreenAdministrationList, object);
+  }
+  else if (action == "delete_instance_group")
+  {
+    std::string group = object.repr();
+    std::string text= strfmt("Do you really want to delete all the server instances in group : %s?", group.c_str());
+    int answer= Utilities::show_warning(_("Delete Server Instance Group"), text,  _("Delete"), _("Cancel"));
+    if (answer == mforms::ResultOk)
+    {
+      group +="/";
+      int group_length = group.length();
+      
+      grt::ListRef<db_mgmt_ServerInstance> instances(_wb->get_root()->rdbmsMgmt()->storedInstances());
+      
+      int index = instances.count() - 1;
+      while (index >= 0)
+      {
+        std::string name = instances[index]->name();
+        
+        if (name.compare(0, group_length, group) == 0)
+          instances->remove(index);
+        
+        index--;
+      }
+      
+      refresh_home_instances();
+    }
+  }
+  
   else if (action == "delete_instance_all")
   {
     std::string text= _("Do you really want to delete all defined server instances?");
@@ -373,6 +531,7 @@ void WBContextUI::handle_home_context_menu(HomeScreenListType list, const grt::V
   }
 }
 
+
 //--------------------------------------------------------------------------------------------------
 
 void WBContextUI::start_plugin(const std::string& title, const std::string& command, bool force_external)
@@ -456,8 +615,8 @@ void WBContextUI::handle_home_action(HomeScreenAction action, const grt::ValueRe
       if (object.is_valid())
       {
         db_mgmt_ConnectionRef connection(db_mgmt_ConnectionRef::cast_from(object));
-        GUILock lock(_wb, _("Opening SQL Editor"), strfmt(_("An SQL editor instance for '%s' is opening and should be available in a "
-                                                            "moment.\n\nPlease stand by..."), connection->name().c_str()));
+        //GUILock lock(_wb, _("Opening SQL Editor"), strfmt(_("An SQL editor instance for '%s' is opening and should be available in a "
+        //                                                    "moment.\n\nPlease stand by..."), connection->name().c_str()));
         
         _wb->show_status_text("Opening SQL Editor...");          
         _wb->add_new_query_window(connection);
@@ -474,6 +633,7 @@ void WBContextUI::handle_home_action(HomeScreenAction action, const grt::ValueRe
       refresh_home_connections();
       break;
     }
+      
     case ActionAddSchemaObject:
       break;
     case ActionEditTable:
@@ -627,8 +787,9 @@ void WBContextUI::handle_home_action(HomeScreenAction action, const grt::ValueRe
       }
       else
         _wb->show_status_text(_("New server instance creation cancelled"));
-    }
+
       break;
+    }
       
     case ActionDumpRestore:
     {
@@ -770,14 +931,16 @@ void WBContextUI::handle_starter_action(StarterAction action, const app_StarterR
 
 void WBContextUI::refresh_home_instances(int selected)
 {
-  if (!_home_screen) return;
+  if (!_home_screen)
+    return;
+
   grt::ListRef<db_mgmt_ServerInstance> instances(_wb->get_root()->rdbmsMgmt()->storedInstances());
   
   _home_screen->clear_list(HomeScreenAdministrationList);
 
   // If there are no connections defined yet then create entries for all currently installed
-  // local servers.
-  if (instances->count() == 0)
+  // local servers (only if this is the first run, after application start).
+  if (_initializing && (instances->count() == 0))
   {
     grt::GRT* grt = _wb->get_grt();
     grt::Module* module = grt->get_module("Workbench");
@@ -796,14 +959,20 @@ void WBContextUI::refresh_home_instances(int selected)
     _home_screen->add_list_entry(HomeScreenAdministrationList, (*inst)->name(), text, *inst);
   }
   
-  _home_screen->select_list_entry(HomeScreenAdministrationList, selected);
+  grt::ValueRef selected_item = ((int) instances.count() > selected) ? instances[selected] : db_mgmt_ServerInstanceRef();
+
+  _home_screen->select_list_entry(HomeScreenAdministrationList, selected_item);
+
+  _home_screen->refresh_list(HomeScreenAdministrationList);
 }
 
 //--------------------------------------------------------------------------------------------------
 
 void WBContextUI::refresh_home_connections(int selected)
 {
-  if (!_home_screen) return;
+  if (!_home_screen)
+    return;
+
   grt::ListRef<db_mgmt_Connection> connections(_wb->get_root()->rdbmsMgmt()->storedConns());
 
   std::map<std::string, std::string> auto_save_files = WBContextSQLIDE::auto_save_sessions();
@@ -811,8 +980,8 @@ void WBContextUI::refresh_home_connections(int selected)
   _home_screen->clear_list(HomeScreenSQLDevList);
 
   // If there are no connections defined yet then create entries for all currently installed
-  // local servers.
-  if (connections->count() == 0)
+  // local servers (only if this is the first run, after application start).
+  if (_initializing && (connections->count() == 0))
   {
     grt::GRT* grt = _wb->get_grt();
     grt::Module* module = grt->get_module("Workbench");
@@ -844,20 +1013,23 @@ void WBContextUI::refresh_home_connections(int selected)
     
     std::string schema = dict.get_string("schema");
     if (!schema.empty())
-      schema = "Schema: "+schema;
+      schema = "Schema: " + schema;
     
     std::string text = strfmt("User: %s  Host: %s %s  %s", dict.get_string("userName").c_str(), 
                               host_entry.c_str(), tunnel.c_str(), schema.c_str());
     
     if (auto_save_files.find((*inst)->id()) != auto_save_files.end())
-      _home_screen->add_list_entry(HomeScreenSQLDevList, std::string((*inst)->name())+" (autosaved)", text, *inst,
+      _home_screen->add_list_entry(HomeScreenSQLDevList, std::string((*inst)->name())+" (auto saved)", text, *inst,
                                    SQLEDITOR_AUTOSAVED_ICON_FILE);
     else
       _home_screen->add_list_entry(HomeScreenSQLDevList, (*inst)->name(), text, *inst);
   }
   
-  _home_screen->select_list_entry(HomeScreenSQLDevList, selected);
-  
+  grt::ValueRef selected_item = ((int) connections.count() > selected) ? connections[selected] : db_mgmt_ConnectionRef();
+  _home_screen->select_list_entry(HomeScreenSQLDevList, selected_item);
+
+  _home_screen->refresh_list(HomeScreenSQLDevList);
+
   _home_screen->show_autosave_warning((int)WBContextModel::auto_save_files().size(), 
                                       (int)auto_save_files.size());
 }
@@ -983,7 +1155,9 @@ void WBContextUI::refresh_home_models(int selected)
 #endif
   }
 
-  _home_screen->select_list_entry(HomeScreenModellingList, selected);
+  _home_screen->select_list_entry(HomeScreenModellingList, grt::IntegerRef(selected));
+
+  _home_screen->refresh_list(HomeScreenModellingList);
     
   _home_screen->show_autosave_warning((int)WBContextModel::auto_save_files().size(), 
                                       (int)WBContextSQLIDE::auto_save_sessions().size());
