@@ -24,7 +24,7 @@
 
 #include "wb_context.h"
 
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 #include "grts/structs.db.h"
 
