@@ -267,7 +267,13 @@ void ModelFile::open(const std::string &path, GRTManager *grtm)
     if (buffer[0] == 0x50 && buffer[1] == 0x4b && buffer[2] == 0x03 && buffer[3] == 0x04 && buffer[4] == 0x14)
       file_is_zip= true;
     else
-      file_is_zip= false;
+    {
+      //file_is_zip= false;
+      if (strncmp((char*)buffer, "<?xml", c < 5 ? c : 5) == 0) // check if this is a XML, otherwise assume zip
+        file_is_zip = false;
+      else
+        file_is_zip = true;
+    }
   }
 
   gchar *basename= g_path_get_basename(path.c_str());
@@ -440,7 +446,7 @@ retry:
         goto retry;
     throw;
   }
-  catch (std::exception &exc)
+  catch (std::exception)
   {
     if (xmldoc)
       xmlFreeDoc(xmldoc);
@@ -462,8 +468,10 @@ bool ModelFile::semantic_check(workbench_DocumentRef doc)
 
 //--------------------------------------------------------------------------------------------------
 
-void ModelFile::unpack_zip(const std::string &zipfile, const std::string &destdir)
+std::list<std::string> ModelFile::unpack_zip(const std::string &zipfile, const std::string &destdir)
 {
+  std::list<std::string> unpacked_files;
+  
   if (g_mkdir_with_parents(destdir.c_str(), 0700) < 0)
     throw grt::os_error(strfmt(_("Cannot create temporary directory for open document: %s"), destdir.c_str()), errno);
 
@@ -545,6 +553,8 @@ void ModelFile::unpack_zip(const std::string &zipfile, const std::string &destdi
       zip_close(z);
       throw grt::os_error(_("Error creating temporary file while opending document."), errno);
     }
+    
+    unpacked_files.push_back(outpath);
 
     char buffer[4098];
     int c;
@@ -573,6 +583,8 @@ void ModelFile::unpack_zip(const std::string &zipfile, const std::string &destdi
   }
 
   zip_close(z);
+  
+  return unpacked_files;
 }
 
 
