@@ -132,7 +132,7 @@ namespace wb {
     void check_and_fix_inconsistencies(const workbench_DocumentRef &doc, const std::string &version);
 
   public:
-    static void unpack_zip(const std::string &zipfile, const std::string &destdir);
+    static std::list<std::string> unpack_zip(const std::string &zipfile, const std::string &destdir);
     void pack_zip(const std::string &zipfile, const std::string &destdir);
 
   private:
