@@ -370,10 +370,13 @@ bool ModelFile::attempt_xml_document_upgrade(xmlDocPtr xmldoc, const std::string
       xmlNodePtr table= tables[i];
       std::string id= xml.node_prop(table, "id");
       xmlNodePtr inserts= xml.get_object_child(table, "inserts");
-      xmlChar *sql= xmlNodeGetContent(inserts);
-      table_inserts_sql_scripts[id]= (char*)sql;
-      xmlFree(sql);
-      xml.delete_object_item(table, "inserts");
+      if (inserts != NULL)
+      {
+        xmlChar *sql= xmlNodeGetContent(inserts);
+        table_inserts_sql_scripts[id]= (char*)sql;
+        xmlFree(sql);
+        xml.delete_object_item(table, "inserts");
+      }
     }
 
     minor= 3;
@@ -818,7 +821,7 @@ static int fix_duplicate_uuid_bug(xmlNodePtr node,
             remapped_ids[id][object_types[id]] = id;
           }
           remapped_ids[id][sname] = remapped;
-          g_message("changed duplicate %s %s to %s", id.c_str(), sname.c_str(), remapped.c_str());
+          //g_message("changed duplicate %s %s to %s", id.c_str(), sname.c_str(), remapped.c_str());
           xmlSetProp(n, (const xmlChar*)"id", (const xmlChar*)remapped.c_str());
           fixes++;
         }
@@ -865,14 +868,15 @@ static void fix_duplicate_uuid_bug_references(grt::GRT *grt, xmlNodePtr node,
               continue;
             }
           }
-        retry:
+//        retry: not used
           if (it->second.find(sname) == it->second.end())
           {
             bool ok = false;
             std::map<std::string, std::string> structs = it->second;
+            std::string target_key;
             
             // handle refs to owner, which some times have a generic type like GrtObject so they're very ambiguous
-            if (XMLTraverser::node_prop(n, "key") == "owner")
+            if ((target_key = XMLTraverser::node_prop(n, "key")) == "owner")
             {
               if (sname == "GrtObject")
               {
@@ -881,8 +885,8 @@ static void fix_duplicate_uuid_bug_references(grt::GRT *grt, xmlNodePtr node,
                 {
                   if (XMLTraverser::node_prop(gparent, "type") == "object")
                   {
-                    g_message("%s %s -> %s (%s)", id.c_str(), sname.c_str(), XMLTraverser::node_prop(gparent, "struct-name").c_str(),
-                              XMLTraverser::node_prop(gparent, "id").c_str());
+                    //g_message("%s %s -> %s (%s)", id.c_str(), sname.c_str(), XMLTraverser::node_prop(gparent, "struct-name").c_str(),
+                    //          XMLTraverser::node_prop(gparent, "id").c_str());
                     sname = XMLTraverser::node_prop(gparent, "struct-name");
                     break;
                   }
@@ -892,6 +896,7 @@ static void fix_duplicate_uuid_bug_references(grt::GRT *grt, xmlNodePtr node,
             }
             
             // go through the alternatives checking their superclasses
+            int count = 0;
             for (std::map<std::string, std::string>::const_iterator opt = structs.begin();
                  opt != structs.end(); ++opt)
             {
@@ -900,7 +905,9 @@ static void fix_duplicate_uuid_bug_references(grt::GRT *grt, xmlNodePtr node,
               {
                 if (mc->name() == sname)
                 {
-                  g_message("found match %s for %s (%s -> %s)", opt->first.c_str(), sname.c_str(), id.c_str(), opt->second.c_str());
+                  count++;
+                  g_message("found match %i %s for %s:%s (%s -> %s)", count, opt->first.c_str(), sname.c_str(), target_key.c_str(),
+                            id.c_str(), opt->second.c_str());
                   xmlNodeSetContent(n, (xmlChar*)opt->second.c_str());
                   ok = true;
                   break;
@@ -925,7 +932,8 @@ static void fix_duplicate_uuid_bug_references(grt::GRT *grt, xmlNodePtr node,
 
 bool ModelFile::check_and_fix_duplicate_uuid_bug(grt::GRT *grt, xmlDocPtr xmldoc)
 {
-  if (XMLTraverser::node_prop(xmlDocGetRootElement(xmldoc), "version") == "1.4.1")
+  if (XMLTraverser::node_prop(xmlDocGetRootElement(xmldoc), "version") == "1.4.1"
+      || XMLTraverser::node_prop(xmlDocGetRootElement(xmldoc), "version") == "1.4.2")
   {
     // in 5.2.32, the UUID generator was replaced with a boost implementation.
     // for some reason, that caused duplicate UUIDs to be generated, which screws up with saving/loading
@@ -960,8 +968,8 @@ static void check_schema_objects(db_SchemaRef schema, std::list<std::string> &lo
         db_IndexColumnRef column(icolumns[i-1]);
         if (!column->referencedColumn().is_valid())
         {
-          load_warnings.push_back(strfmt("Index %s has an invalid column reference. The reference was removed from the index.",
-                                         (*index)->name().c_str()));
+          load_warnings.push_back(strfmt("Index %s.%s has an invalid column reference. The reference was removed from the index.",
+                                         (*table)->name().c_str(), (*index)->name().c_str()));
           
           icolumns.remove_value(column);
         }
