@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -54,6 +54,7 @@
 using namespace wb;
 using namespace grt;
 using namespace base;
+using namespace MySQL::Geometry;
 
 //--------------------------------------------------------------------------------------------------
 
@@ -756,17 +757,13 @@ int WorkbenchImpl::goToMarker(const std::string &marker)
     
     if (mk.is_valid())
     {
-      ModelDiagramForm *form= _wb->get_model_context()->get_diagram_form_for_diagram_id(mk->diagram()->id());
-      if (form)
-      {
-        form->get_view()->set_zoom((float)mk->zoom());
-        form->get_view()->set_offset(mdc::Point(*mk->x(), *mk->y()));
-        if (form->get_model_diagram() != mk->diagram())
-        {
-          _wb->get_grt_manager()->get_dispatcher()->call_from_main_thread<void>(
-            sigc::bind<model_DiagramRef>(sigc::mem_fun(_wb, &WBContext::switch_diagram), model_DiagramRef::cast_from(mk->diagram())), false, false);
-        }
-      }
+      model_DiagramRef diagram = model_DiagramRef::cast_from(mk->diagram());
+      diagram->zoom(mk->zoom());
+      diagram->x(mk->x());
+      diagram->y(mk->y());
+
+      _wb->get_grt_manager()->get_dispatcher()->call_from_main_thread<void>(
+        sigc::bind<model_DiagramRef>(sigc::mem_fun(_wb, &WBContext::switch_diagram), diagram), false, false);
     }
   }
 
@@ -795,8 +792,8 @@ int WorkbenchImpl::setMarker(const std::string &marker)
     mk->name(marker);
     mk->diagram(form->get_model_diagram());
     mk->zoom(form->get_view()->get_zoom());
-    mk->x(form->get_view()->get_viewport().xmin());
-    mk->y(form->get_view()->get_viewport().ymin());
+    mk->x(form->get_view()->get_viewport().left());
+    mk->y(form->get_view()->get_viewport().top());
 
     model->markers().insert(mk);
   }
@@ -959,6 +956,25 @@ int WorkbenchImpl::exportAttachedFileContents(const std::string &filename,
   return _wb->export_attached_file_contents(filename, export_to);
 }
 
+workbench_DocumentRef WorkbenchImpl::openModelFile(const std::string &path)
+{
+  return _wb->openModelFile(path);
+}
+
+int WorkbenchImpl::closeModelFile()
+{
+  return _wb->closeModelFile();
+}
+
+std::string WorkbenchImpl::getTempDir()
+{
+    return _wb->getTempDir();
+}
+
+std::string WorkbenchImpl::getDbFilePath()
+{
+  return _wb->getDbFilePath();
+}
 
 int WorkbenchImpl::runScriptFile(const std::string &filename)
 {
@@ -1701,6 +1717,7 @@ int WorkbenchImpl::createConnectionsFromLocalServers()
   return 0;
 }
 
+extern std::string get_admin_script_for_os(const std::string &os);
 //--------------------------------------------------------------------------------------------------
 
 /**
@@ -1708,7 +1725,6 @@ int WorkbenchImpl::createConnectionsFromLocalServers()
  */
 int WorkbenchImpl::createInstancesFromLocalServers()
 {
-  extern std::string get_admin_script_for_os(const std::string &os);
 
   try
   {
