@@ -22,7 +22,7 @@
 
 #include "grt/tree_model.h"
 #include "grt/grt_manager.h"
-#include "ui_form.h"
+#include "base/ui_form.h"
 
 #include "wb_command_ui.h"
 
