@@ -257,7 +257,7 @@ sql::TunnelConnection* TunnelManager::create_tunnel(db_mgmt_ConnectionRef connec
     std::string server = parameter_values.get_string("sshHost");
     std::string username = parameter_values.get_string("sshUserName");
     std::string password = parameter_values.get_string("sshPassword");
-    std::string keyfile = bec::expand_tilde(parameter_values.get_string("sshKeyFile"));
+    std::string keyfile = base::expand_tilde(parameter_values.get_string("sshKeyFile"));
     std::string target = parameter_values.get_string("hostName");
     int target_port = parameter_values.get_int("port", 3306);
 
