@@ -185,75 +185,7 @@ namespace bec {
     if (prefix[prefix.size()-1] == '/' || prefix[prefix.size()-1] == '\\')
       return prefix+file;
     return prefix+G_DIR_SEPARATOR+file;
-  }
-
-  /**
-   * Removes all unnecessary path separators as well as "./" combinations.
-   * If there is a parent-dir entry (../) then this as well as the directly prefacing
-   * dir entry is removed.
-   */
-  std::string normalize_path(const std::string path)
-  {
-    // First convert all separators to the one that is used on the platform (no mix)
-    // and ease so at the same time further processing here.
-    std::string result;
-    std::string separator(1, G_DIR_SEPARATOR);
-
-    result= replace_string(path, "\\", separator);
-    result= replace_string(result, "/", separator);
-
-    std::string double_separator = separator + separator;
-    while (result.find(double_separator) != std::string::npos)
-      result= replace_string(result, double_separator, separator);
-
-    // Sanity check. Return *after* we have converted the slashs. This is part of the normalization.
-    if (result.size() < 2)
-      return result;
-
-    std::vector<std::string> parts= base::split(result, separator);
-
-    // Construct result backwards while examining the path parts.
-    result= "";
-    int pending_count= 0;
-    for (int i= parts.size() - 1; i >= 0; i--)
-    {
-      if (parts[i].compare(".") == 0)
-        // References to the current directory can be removed without further change.
-        continue;
-
-      if (parts[i].compare("..") == 0)
-      {
-        // An entry that points back to the parent dir.
-        // Ignore this and keep track for later removal of the parent dir.
-        pending_count++;
-      }
-      else
-        if (pending_count > 0)
-        {
-          // If this is a normal dir entry and we have pending parent-dir redirections
-          // then go one step up by removing (ignoring) this entry.
-          pending_count--;
-        }
-        else
-          result = separator + parts[i] + result;
-    }
-
-    // Don't return the leading separator.
-    return result.substr(1);
-  }
-  
-  std::string expand_tilde(const std::string &path)
-  {
-    if (!path.empty() && path[0] == '~' && (path.size() == 1 || path[1] == G_DIR_SEPARATOR))
-    {
-      const char *homedir = g_getenv("HOME");
-      if (!homedir)
-        homedir = g_get_home_dir();
-
-      return std::string(homedir).append(path.substr(1));
-    }
-    return path;
-  }
+  }  
 
   GStaticMutexLock::GStaticMutexLock(GStaticMutex& mtx) 
   : mutex(mtx) 
