@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,6 +22,8 @@
 
 #include <grtpp_module_cpp.h>
 #include <grtpp_module_lua.h>
+#include <grtpp_module_python.h>
+#include <python_context.h>
 
 #include "grt/grt_manager.h"
 #include "grt/common.h"
@@ -218,16 +220,24 @@ GRTManager::~GRTManager()
   if (_log_file)
     fclose(_log_file);
 
+  _grt->set_message_handler(MessageSlot());
+
   _dispatcher->shutdown();
   _dispatcher.reset();
 
   delete _shell;
+  _shell = 0;
   delete _value_tree;
+  _value_tree = 0;
   delete _structs_tree;
+  _structs_tree = 0;
   delete _modules_tree;
+  _modules_tree = 0;
   delete _messages_list;
+  _messages_list = 0;
 
   delete _grt;
+  _grt = 0;
 
   for (std::list<Timer*>::iterator iter= _timers.begin(); iter != _timers.end(); ++iter)
     delete *iter;
@@ -335,7 +345,7 @@ void GRTManager::set_progress_callback(const sigc::slot<bool,std::string,std::st
 }
 
 
-void GRTManager::push_output_callback(const sigc::slot<void, std::string> &slot)
+void GRTManager::push_output_callback(const sigc::slot<bool, std::string> &slot)
 {
   GMutexLock lock(_tmp_output_cb_stack_mutex);
   _tmp_output_cb_stack.push_back(slot);
@@ -379,8 +389,12 @@ void GRTManager::task_msg_cb(const grt::Message &msg, const std::string &title,
     
     if (!_tmp_output_cb_stack.empty())
     {
-      _tmp_output_cb_stack.back()(msg.text);
-      return;
+      std::list<sigc::slot<bool, std::string> >::reverse_iterator iter = _tmp_output_cb_stack.rbegin();
+      while (iter != _tmp_output_cb_stack.rend())
+      {
+        if ((*iter)(msg.text))
+          return;
+      }
     }
   }
   
@@ -936,11 +950,16 @@ bool GRTManager::init_loaders(const std::string &loader_module_path)
   
   try
   {
-    // temporary code, once the dynamic loading of language support is added, these
-    // should go away
     if (grt::init_python_support(_grt, loader_module_path))
     {
       if (_verbose) _shell->write_line(_("Python loader initialized."));
+
+      PythonModuleLoader *loader = dynamic_cast<PythonModuleLoader*>(_grt->get_module_loader("python"));
+      if (loader)
+      {
+        loader->get_python_context()->push_output_handler = sigc::mem_fun(this, &GRTManager::push_output_callback);
+        loader->get_python_context()->pop_output_handler = sigc::mem_fun(this, &GRTManager::pop_output_callback);
+      }
     }
   }
   catch (std::exception &exc)
@@ -997,6 +1016,8 @@ void GRTManager::scan_modules_grt(grt::GRT *grt, const std::list<std::string> &e
       count+= c;
   }
 
+  _grt->end_loading_modules();
+  
   _shell->writef(_("Registered %i modules (from %i files).\n"),
                  _grt->get_modules().size(), count);
 
@@ -1004,9 +1025,18 @@ void GRTManager::scan_modules_grt(grt::GRT *grt, const std::list<std::string> &e
 }
 
 
-void GRTManager::set_app_option_slot(const sigc::slot<grt::ValueRef,std::string> &slot)
+void GRTManager::set_app_option_slots(const sigc::slot<grt::ValueRef,std::string> &slot,
+                                      const sigc::slot<void, std::string, grt::ValueRef> &set_slot)
 {
   _get_app_option_slot= slot;
+  _set_app_option_slot= set_slot;
+}
+
+
+void GRTManager::set_app_option(const std::string &name, const grt::ValueRef &value)
+{
+  if (_set_app_option_slot)
+    _set_app_option_slot(name, value);
 }
 
 
@@ -1020,10 +1050,21 @@ grt::ValueRef GRTManager::get_app_option(const std::string &name)
 
 std::string GRTManager::get_app_option_string(const std::string &name)
 {
-  return *grt::StringRef::cast_from(get_app_option(name));
+  grt::ValueRef value(get_app_option(name));
+  if (value.is_valid() && grt::StringRef::can_wrap(value))
+    return *grt::StringRef::cast_from(value);
+  return "";  
 }
 
 
+long GRTManager::get_app_option_int(const std::string &name, long default_)
+{
+  grt::ValueRef value(get_app_option(name));
+  if (value.is_valid() && grt::IntegerRef::can_wrap(value))
+    return *grt::IntegerRef::cast_from(value);
+  return default_;
+}
+
 std::string GRTManager::get_tmp_dir()
 {
   std::string res;
