@@ -122,9 +122,14 @@ namespace bec {
     void pop_status_text();
     void set_status_slot(const sigc::slot<void, std::string> &slot);
     
-    void push_output_callback(const sigc::slot<void, std::string> &slot);
+    void push_output_callback(const sigc::slot<bool, std::string> &slot);
     void pop_output_callback();
 
+    void push_cancel_query_callback(const sigc::slot<bool> &slot);
+    void pop_cancel_query_callback();
+
+    void set_canceled();
+  
     void set_message_callback(const sigc::slot<void, grt::Message> &handler);
 
     void set_progress_callback(const sigc::slot<bool,std::string,std::string,float> &cb);
@@ -171,10 +176,13 @@ namespace bec {
     ValueTreeBE *get_shared_value_tree(const std::string &valuespec);
 
     //
-    void set_app_option_slot(const sigc::slot<grt::ValueRef,std::string> &slot);
+    void set_app_option_slots(const sigc::slot<grt::ValueRef,std::string> &slot,
+                              const sigc::slot<void, std::string, grt::ValueRef> &set_slot);
     grt::ValueRef get_app_option(const std::string &name);
     std::string get_app_option_string(const std::string &name);
-
+    long get_app_option_int(const std::string &name, long default_= 0);
+    void set_app_option(const std::string &name, const grt::ValueRef &value);
+    
     // signals are private so that we can properly protect them with mutexes
     void run_when_idle(const sigc::slot<bool> &slot);
     void block_idle_tasks();
@@ -247,7 +255,7 @@ namespace bec {
     
     // stack of text output handlers
     GMutex *_tmp_output_cb_stack_mutex;
-    std::list<sigc::slot<void, std::string> > _tmp_output_cb_stack;
+    std::list<sigc::slot<bool, std::string> > _tmp_output_cb_stack;
 
     sigc::slot<bool,std::string,std::string,float> _progress_cb;
 
@@ -273,6 +281,7 @@ namespace bec {
     std::string _user_script_path;
 
     sigc::slot<grt::ValueRef,std::string> _get_app_option_slot;
+    sigc::slot<void, std::string, grt::ValueRef> _set_app_option_slot;
     
     bool _threaded;
     bool _verbose;
