@@ -20,6 +20,7 @@
 
 #include "stdafx.h"
 
+#include "base/wb_memory.h"
 #include "grt/grt_threaded_task.h"
 
 
@@ -111,6 +112,11 @@ bec::GRTTask * GrtThreadedTask::task()
 }
 
 
+inline void release_task(bec::GRTTask *task)
+{
+  task->release();
+}
+
 void GrtThreadedTask::exec(bool sync, Proc_cb proc_cb)
 {
   if (!_grtm)
@@ -122,7 +128,7 @@ void GrtThreadedTask::exec(bool sync, Proc_cb proc_cb)
 
   bec::GRTDispatcher::Ref dispatcher= this->dispatcher();
 
-  std::auto_ptr<bec::GRTTask> task(new bec::GRTTask(desc(), dispatcher.get(), proc_cb));
+  base::scope_ptr<bec::GRTTask, release_task> task(new bec::GRTTask(desc(), dispatcher.get(), proc_cb));
 
   task->signal_starting_task.connect(sigc::bind(sigc::mem_fun(this, &GrtThreadedTask::on_starting), task.get()));
   task->signal_failing_task.connect(sigc::bind(sigc::mem_fun(this, &GrtThreadedTask::on_failing), task.get()));
@@ -131,13 +137,11 @@ void GrtThreadedTask::exec(bool sync, Proc_cb proc_cb)
   task->signal_message().connect(sigc::bind(sigc::mem_fun(this, &GrtThreadedTask::process_msg), task.get()));
   task->signal_failed().connect(sigc::bind(sigc::mem_fun(this, &GrtThreadedTask::process_fail), task.get()));
   task->signal_finished().connect(sigc::bind(sigc::mem_fun(this, &GrtThreadedTask::process_finish), task.get()));
-
+  task->retain();
   if (sync)
     dispatcher->add_task_and_wait(task.get());
   else
     dispatcher->add_task(task.get());
-
-  task.release();
 }
 
 
