@@ -27,7 +27,7 @@
 #include "grt_value_inspector.h"
 #include <grtpp_util.h>
 #include <grtpp_undo_manager.h>
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 #include <sstream>
 #include <boost/tuple/tuple.hpp>
