@@ -30,7 +30,7 @@
 #ifdef __GNUC__ 
 typedef void* NativeHandle;
 #else
-typedef __int64 NativeHandle;
+typedef uintptr_t NativeHandle;
 #endif
 
 // GUI plugins with native code that are loaded and managed by the Workbench process
