@@ -45,13 +45,12 @@ struct WBPUBLICBACKEND_PUBLIC_FUNC DbObjectMatchRecreateOmf : public Omf
   virtual bool equal(const ValueRef& , const ValueRef&) const;
 };
 
-  template <typename Tgrt>
   class NormalizedComparer
     {
     protected:
-      Tgrt _grt;
+      grt::GRT* _grt;
     public:
-      NormalizedComparer(Tgrt grt):_grt(grt){};
+      NormalizedComparer(grt::GRT* grt):_grt(grt){};
       bool normalizedComparison(const ValueRef obj1, const ValueRef obj2, const std::string name)const
       {
 
@@ -63,45 +62,37 @@ struct WBPUBLICBACKEND_PUBLIC_FUNC DbObjectMatchRecreateOmf : public Omf
           str2 = bec::TableHelper::get_sync_comment(str2);
           if (db_mysql_SchemaRef::can_wrap(obj1))
             return true;
-          return str1 == str2;       
+          return str1 == str2;
         }
         if(name == "tableEngine")
         {
-          std::string str1= ObjectRef::cast_from(obj1).get_string_member(name);
-          std::string str2= ObjectRef::cast_from(obj2).get_string_member(name);
-          base::toupper(str1);
-          base::toupper(str2);
-          return str1 == str2;       
+          std::string str1= base::toupper(ObjectRef::cast_from(obj1).get_string_member(name));
+          std::string str2= base::toupper(ObjectRef::cast_from(obj2).get_string_member(name));
+          return str1 == str2;
         }
 
         if(((name == "name") || (name == "oldName")) && !(db_ColumnRef::can_wrap(obj1)))
         {
-          std::string str1= ObjectRef::cast_from(obj1).get_string_member(name);
-          std::string str2= ObjectRef::cast_from(obj2).get_string_member(name);
-          base::toupper(str1);
-          base::toupper(str2);
-          return str1 == str2;       
+          std::string str1= base::toupper(ObjectRef::cast_from(obj1).get_string_member(name));
+          std::string str2= base::toupper(ObjectRef::cast_from(obj2).get_string_member(name));
+          return str1 == str2;
         }
 
         if (name == "referencedTable")
         {
-          std::string str1 = db_mysql_ForeignKeyRef::cast_from(obj1)->referencedTable()->name();
-          std::string str2 = db_mysql_ForeignKeyRef::cast_from(obj2)->referencedTable()->name();
-          base::toupper(str1);
-          base::toupper(str2);
-          return str1 == str2;              
+          std::string str1 = base::toupper(db_mysql_ForeignKeyRef::cast_from(obj1)->referencedTable()->name());
+          std::string str2 = base::toupper(db_mysql_ForeignKeyRef::cast_from(obj2)->referencedTable()->name());
+          return str1 == str2;
         }
         if ((name == "rowFormat") || (name == "packKeys"))
         {
-          std::string str1= ObjectRef::cast_from(obj1).get_string_member(name);
-          std::string str2= ObjectRef::cast_from(obj2).get_string_member(name);
-          base::toupper(str1);
-          base::toupper(str2);
+          std::string str1= base::toupper(ObjectRef::cast_from(obj1).get_string_member(name));
+          std::string str2= base::toupper(ObjectRef::cast_from(obj2).get_string_member(name));
           if (str1 == "DEFAULT")
             str1 = "";
           if (str2 == "DEFAULT")
             str2 = "";
-          return str1 == str2;       
+          return str1 == str2;
         }
         if ((name == "characterSetName") || (name == "collationName"))
         {
@@ -142,10 +133,8 @@ struct WBPUBLICBACKEND_PUBLIC_FUNC DbObjectMatchRecreateOmf : public Omf
 
         if ((name == "deleteRule") || (name == "updateRule"))
         {
-          std::string sql1= ObjectRef::cast_from(obj1).get_string_member(name);
-          std::string sql2= ObjectRef::cast_from(obj2).get_string_member(name);
-          base::toupper(sql1);
-          base::toupper(sql2);
+          std::string sql1= base::toupper(ObjectRef::cast_from(obj1).get_string_member(name));
+          std::string sql2= base::toupper(ObjectRef::cast_from(obj2).get_string_member(name));
           if (sql1 == "RESTRICT")
             sql1 = "";
           if (sql2 == "RESTRICT")
@@ -169,14 +158,11 @@ struct WBPUBLICBACKEND_PUBLIC_FUNC DbObjectMatchRecreateOmf : public Omf
         if (!parser)
           return false;
         
-        sql1= parser->remove_inter_token_spaces(sql1);
-        sql2= parser->remove_inter_token_spaces(sql2);
-        base::toupper(sql1);
-        base::toupper(sql2);
+        sql1= base::toupper(parser->remove_inter_token_spaces(sql1));
+        sql2= base::toupper(parser->remove_inter_token_spaces(sql2));
 //        if (sql1 != sql2)
 //        std::cout<<"============"<<sql1<<std::endl<<std::endl<<sql2<<"==========================="<<std::endl;
         return sql1 == sql2;
-
         }
         if(name == "sqlDefinition")
         {
@@ -194,10 +180,8 @@ struct WBPUBLICBACKEND_PUBLIC_FUNC DbObjectMatchRecreateOmf : public Omf
           GrtObjectRef::cast_from(obj2)->owner()->name();
         sql1= parser->normalizeSqlStatement(sql1, schema1);
         sql2= parser->normalizeSqlStatement(sql2, schema2);
-        sql1= parser->remove_inter_token_spaces(sql1);
-        sql2= parser->remove_inter_token_spaces(sql2);
-        base::toupper(sql1);
-        base::toupper(sql2);
+        sql1= base::toupper(parser->remove_inter_token_spaces(sql1));
+        sql2= base::toupper(parser->remove_inter_token_spaces(sql2));
 //        sql1.erase(std::remove(sql1.begin(), sql1.end(), '\n'), sql1.end());
 //        sql2.erase(std::remove(sql2.begin(), sql2.end(), '\n'), sql2.end());
 //        if (sql1 != sql2)
@@ -206,8 +190,8 @@ struct WBPUBLICBACKEND_PUBLIC_FUNC DbObjectMatchRecreateOmf : public Omf
         }
         return false; 
       };
-      operator TSlotNormalizerSlot(){return boost::bind(&NormalizedComparer<Tgrt>::normalizedComparison,*this, _1, _2, _3);};
-        //sigc::mem_fun(*this, &NormalizedComparer<Tgrt>::normalizedComparison);};
+      operator TSlotNormalizerSlot(){return boost::bind(&NormalizedComparer::normalizedComparison,*this, _1, _2, _3);};
+        //sigc::mem_fun(*this, &NormalizedComparer<grt::GRT*>::normalizedComparison);};
     };
   
   
