@@ -36,6 +36,23 @@ RoutineGroupEditorBE::RoutineGroupEditorBE(GRTManager *grtm, const db_RoutineGro
 {
 }
 
+std::string RoutineGroupEditorBE::set_routine_newlines(const std::string &routine)
+{
+    // The parser returns existing new lines at the beginning of each routine
+    // This logic ensures at least a blank line ( two new lines ) separate the next routine
+    // from the sql so far
+    std::string final_routine="";
+    int routine_size = routine.length();
+    
+    if (routine_size >= 1 && routine[0]!='\n')
+      final_routine.append("\n");
+
+    if (routine_size >= 2 && routine[1]!='\n')
+      final_routine.append("\n");
+
+    return final_routine.append(routine);
+}
+
 std::string RoutineGroupEditorBE::get_routines_sql()
 {
   std::string sql;
@@ -48,7 +65,7 @@ std::string RoutineGroupEditorBE::get_routines_sql()
   sql.append("-- --------------------------------------------------------------------------------\n");
   sql.append("-- ").append(_group->name().c_str()).append(" Group Routines\n");
   sql.append("-- --------------------------------------------------------------------------------\n");
-  sql.append(strfmt("DELIMITER %s\n\n", _non_std_sql_delimiter.c_str()));
+  sql.append(strfmt("DELIMITER %s", _non_std_sql_delimiter.c_str()));
 
   size_t count= routines.count();
   typedef std::map<int, db_RoutineRef> OrderedRoutines;
@@ -66,11 +83,12 @@ std::string RoutineGroupEditorBE::get_routines_sql()
       unordered_routines.push_back(routine);
   }
 
-  for (OrderedRoutines::iterator i= ordered_routines.begin(), i_end= ordered_routines.end(); i != i_end; ++i)
-    sql.append(i->second->sqlDefinition()).append(_non_std_sql_delimiter).append("\n\n\n\n");
+  for(OrderedRoutines::iterator i_end = ordered_routines.end(), i = ordered_routines.begin(); i != i_end; i++)
+    sql.append(set_routine_newlines(i->second->sqlDefinition().repr())).append(_non_std_sql_delimiter);
+
 
   for (UnorderedRoutines::iterator i= unordered_routines.begin(), i_end= unordered_routines.end(); i != i_end; ++i)
-    sql.append((*i)->sqlDefinition()).append(_non_std_sql_delimiter).append("\n\n\n\n");
+    sql.append(set_routine_newlines((*i)->sqlDefinition().repr())).append(_non_std_sql_delimiter);
 
   return sql;
 }
