@@ -18,12 +18,17 @@
  */
 
 #include "stdafx.h"
+
 #include "editor_table.h"
 #include "sqlide/recordset_table_inserts_storage.h"
+#include "grtui/inserts_export_form.h"
+
 #include "db_object_helpers.h"
-#include <grtpp_util.h>
+#include "grtpp_util.h"
 #include "grt/validation_manager.h"
+
 #include "base/string_utilities.h"
+
 #include "mforms/utilities.h"
 
 using namespace bec;
@@ -2858,6 +2863,7 @@ grt::ValueRef TableEditorBE::parse_triggers_sql(grt::GRT* grt, grt::StringRef sq
   return res;
 }
 
+//--------------------------------------------------------------------------------------------------
 
 Recordset::Ref TableEditorBE::get_inserts_model()
 {
@@ -2872,11 +2878,21 @@ Recordset::Ref TableEditorBE::get_inserts_model()
     _inserts_model= Recordset::create(_grtm);
     _inserts_model->empty_info_message_on_reset(true);
     _inserts_model->data_storage(_inserts_storage);
+    _inserts_model->export_wizard = sigc::mem_fun(this, &TableEditorBE::show_export_wizard);
     _inserts_model->refresh();
   }
   return _inserts_model;
 }
 
+//--------------------------------------------------------------------------------------------------
+
+void TableEditorBE::show_export_wizard()
+{
+  InsertsExportForm exporter(_inserts_model);
+  exporter.run();  
+}
+
+//--------------------------------------------------------------------------------------------------
 
 Sql_editor::Ref TableEditorBE::get_sql_editor()
 {
