@@ -23,7 +23,7 @@
 
 #include "editor_user_role.h"
 #include "db_object_helpers.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 using namespace grt;
 using namespace bec;
