@@ -79,6 +79,11 @@ public:
     return std::vector<std::string>();
   }
 
+  virtual bool check_column_referenceable_by_fk(const db_ColumnRef &column1, const db_ColumnRef &column2)
+  {
+	  // TODO: implement
+    return false;
+  }
 };
 
 
@@ -88,12 +93,16 @@ public:
   GRTManager grtm;
   db_CatalogRef catalog;
   db_TableRef table;
+  db_SchemaRef schema;
   Auto_release autorel;
 
   TestTableEditor *editor;
 TEST_DATA_CONSTRUCTOR(bedb_table_editor)
   : grtm(false)
 {
+  std::string path = "../../Bin/Debug";
+  grtm.set_search_paths(path, path, path);
+  grtm.initialize(path);
 }
 
 TEST_DATA_DESTRUCTOR(bedb_table_editor)
@@ -112,16 +121,23 @@ TEST_FUNCTION(1)
   ensure("load structs", i>0);
   grtm.get_grt()->end_loading_metaclasses();
 
-  grtm.get_grt()->set_root(grtm.get_grt()->unserialize("../../res/grtdata/db_datatype_groups.xml"));
+  //grtm.get_grt()->set_root(grtm.get_grt()->unserialize("../../res/grtdata/db_datatype_groups.xml"));
 
   rdbms= db_mgmt_RdbmsRef::cast_from(grtm.get_grt()->unserialize("../../modules/db.mysql/res/mysql_rdbms_info.xml"));
 
-  table= db_mysql_TableRef(grtm.get_grt());
-  ensure("table ok", table.is_valid());
-
   catalog= db_mysql_CatalogRef(grtm.get_grt());
   ensure("catalog ok", catalog.is_valid());
 
+  schema= db_mysql_SchemaRef(grtm.get_grt());
+  ensure("schema ok", catalog.is_valid());
+  schema->owner(catalog);
+
+  table= db_mysql_TableRef(grtm.get_grt());
+  ensure("table ok", table.is_valid());
+  table->owner(schema);
+
+
+
   editor= new TestTableEditor(&grtm, table, rdbms);
   
   // Don't use the auto releaser here. It conflicts with the static test class leading to 
@@ -842,7 +858,7 @@ static db_TableRef make_inserts_test_table(grt::GRT *grt, const db_mgmt_RdbmsRef
 }
 
 
-#warning disabled std inserts test
+#pragma warning disabled std inserts test
 #if 0 // inserts intreface changed
 TEST_FUNCTION(15)
 {
