@@ -48,12 +48,17 @@ std::string Sql_specifics::query_connection_id()
 }
 
 
-std::string Sql_specifics::query_kill_connection(int connection_id)
+std::string Sql_specifics::query_kill_connection(boost::int64_t connection_id)
 {
   return "";
 }
 
 
+std::string Sql_specifics::query_kill_query(boost::int64_t connection_id)
+{
+  return "";
+}
+
 std::string Sql_specifics::query_variable(const std::string &name)
 {
   return "";
