@@ -10,7 +10,7 @@ public:
   ConnectionPage(grtui::WizardForm *form, const char *name= "connect")
     : WizardPage(form, name), _dbconn(0)
   {
-    set_title(_("Set parameters for connecting to a DBMS"));
+    set_title(_("Set Parameters for Connecting to a DBMS"));
     set_short_title(_("Connection Options"));
 
     add(&_connect, true, true);
@@ -52,4 +52,4 @@ protected:
   grtui::DbConnectPanel _connect;
 };
 
-#endif // _CONNECTION_PAGE_H_
\ No newline at end of file
+#endif // _CONNECTION_PAGE_H_
