@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,6 +21,10 @@
 
 #include "wb_config.h"
 
+#include "base/geometry.h"
+
+using namespace MySQL::Geometry;
+
 #include "grtdb/db_helpers.h"
 #include "db_conn_be.h"
 #include "grtsqlparser/sql_facade.h"
@@ -162,11 +166,10 @@ void DbDriverParam::set_value(const grt::ValueRef &value)
 
 struct LayoutControl
 {
-  LayoutControl(int offset) : param_handle(NULL), type(ctUnknown) { pos.x= offset; }
+  LayoutControl(int offset) : param_handle(NULL), type(ctUnknown) { bounds.left = offset; }
   DbDriverParam *param_handle;
   ControlType type;
-  Position pos;
-  Size size;
+  ControlBounds bounds;
   std::string caption;
 };
 
@@ -193,8 +196,8 @@ public:
   void insert(LayoutControl &control)
   {
     _controls.push_back(control);
-    _offset+= control.size.width + _hmargin;
-    _max_height= std::max(_max_height, control.size.height);
+    _offset += control.bounds.width + _hmargin;
+    _max_height= std::max(_max_height, control.bounds.height);
   }
   void add_desc(const std::string &desc)
   {
@@ -234,7 +237,7 @@ void DbDriverParams::init(
   const db_mgmt_ConnectionRef &stored_conn,
   const sigc::slot<void,bool> &suspend_layout,
   const sigc::slot<void> &clear_param_controls,
-  const sigc::slot<void, DbDriverParam*, ControlType, const Position &, const Size &, const std::string &> &create_control,
+  const sigc::slot<void, DbDriverParam*, ControlType, const ControlBounds&, const std::string &> &create_control,
   bool skip_schema,
   int first_row_label_width,
   int hmargin,
@@ -307,8 +310,8 @@ void DbDriverParams::init(
           ctrl.type= ctLabel;
           ctrl.caption= param->caption();
           if (row.empty())
-            ctrl.size.width= first_row_label_width;
-          ctrl.pos.y= y_offset;
+            ctrl.bounds.width = first_row_label_width;
+          ctrl.bounds.top = y_offset;
           //create_control(ctrl.param_handle, ctrl.type, ctrl.pos, ctrl.size, ctrl.caption);
           row.insert(ctrl);
         }
@@ -318,8 +321,8 @@ void DbDriverParams::init(
           LayoutControl ctrl(row.offset());
           ctrl.param_handle= param_handle;
           ctrl.type= param_handle->get_control_type();
-          ctrl.size.width= param->layoutWidth();
-          ctrl.pos.y= y_offset;
+          ctrl.bounds.width= param->layoutWidth();
+          ctrl.bounds.top = y_offset;
           if (param_handle->get_control_type() == ctCheckBox)
             ctrl.caption= param->caption();
           //create_control(ctrl.param_handle, ctrl.type, ctrl.pos, ctrl.size, ctrl.caption);
@@ -343,16 +346,16 @@ void DbDriverParams::init(
       LayoutRow::LayoutControls *controls= r->controls();
       for (LayoutRow::LayoutControls::iterator c= controls->begin(); c != controls->end(); ++c)
       {
-        c->pos.y= row_index;
-        create_control(c->param_handle, c->type, c->pos, c->size, c->caption);
+        c->bounds.top = row_index;
+        create_control(c->param_handle, c->type, c->bounds, c->caption);
       }
 
       // row description control
       {
         LayoutControl ctrl= r->desc_control();
-        ctrl.pos.y= row_index;
+        ctrl.bounds.top = row_index;
 
-        create_control(ctrl.param_handle, ctrl.type, ctrl.pos, ctrl.size, ctrl.caption);
+        create_control(ctrl.param_handle, ctrl.type, ctrl.bounds, ctrl.caption);
       }
       row_index++;
     }
@@ -427,7 +430,7 @@ void DbConnection::init(const db_mgmt_ManagementRef &mgmt, bool skip_schema)
 void DbConnection::set_control_callbacks(
   const sigc::slot<void,bool> &suspend_layout,
   const sigc::slot<void> &clear_param_controls,
-  const sigc::slot<void, DbDriverParam*, ControlType, const Position &, const Size &, const std::string &> &create_control)
+  const sigc::slot<void, DbDriverParam*, ControlType, const ControlBounds&, const std::string &> &create_control)
 {
   _suspend_layout = suspend_layout;
   _clear_param_controls= clear_param_controls;
