@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,25 +27,12 @@
 #include <map>
 
 #include "wbpublic_public_interface.h"
+#include "base/geometry.h"
 
 class DbDriverParam;
 class DbDriverParams;
 class DbConnection;
 
-struct Position {
-  Position() : x(0), y(0) {}
-  int x;
-  int y;
-};
-
-
-struct Size {
-  Size() : width(0), height(0) {}
-  int width;
-  int height;
-};
-
-
 enum ControlType {
   ctUnknown,
   ctLabel,
@@ -124,7 +111,8 @@ public:
     const db_mgmt_ConnectionRef &stored_conn,
     const sigc::slot<void,bool> &suspend_layout,
     const sigc::slot<void> &clear_param_controls,
-    const sigc::slot<void, DbDriverParam*, ControlType, const Position &, const Size &, const std::string &> &create_control,
+    const sigc::slot<void, DbDriverParam*, ControlType, const MySQL::Geometry::ControlBounds&,
+      const std::string &> &create_control,
     bool skip_schema=false,
     int first_row_label_width= 100,
     int hmargin= 10,
@@ -148,7 +136,8 @@ private:
   
   sigc::slot<void> _clear_param_controls;
   sigc::slot<void,bool> _suspend_layout;
-  sigc::slot<void, DbDriverParam*, ControlType, const Position &, const Size &, const std::string &> _create_control;
+  sigc::slot<void, DbDriverParam*, ControlType, const MySQL::Geometry::ControlBounds&,
+    const std::string &> _create_control;
 
   db_mgmt_DriverRef get_active_driver() { return _rdbms->drivers().get(_active_db_driver_index); }
   
@@ -163,7 +152,8 @@ public:
   void set_control_callbacks(
     const sigc::slot<void,bool> &suspend_layout,
     const sigc::slot<void> &clear_param_controls,
-    const sigc::slot<void, DbDriverParam*, ControlType, const Position &, const Size &, const std::string &> &create_control);
+    const sigc::slot<void, DbDriverParam*, ControlType, const MySQL::Geometry::ControlBounds&,
+      const std::string &> &create_control);
 
   DbDriverParams *get_db_driver_param_handles() { return &_db_driver_param_handles; }
   
