@@ -35,9 +35,10 @@ class WBPUBLICBACKEND_PUBLIC_FUNC FileCharsetDialog : public mforms::Form
 public:
   std::string run();
   
-  static bool ensure_filedata_utf8(const char *data, size_t length, 
+  static bool ensure_filedata_utf8(const char *data, size_t length, const std::string &encoding,
                                    const std::string &filename,
-                                   std::string &output_str);
+                                   std::string &output_str,
+                                   std::string *original_encoding = 0);
 };
 
 #endif /* _FILE_CHARSET_DIALOG_H_ */
