@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-
-
 #include "stdafx.h"
 
 #include "grtdb_connect_panel.h"
@@ -29,6 +27,7 @@
 #include <grt/common.h>
 #include "base/string_utilities.h"
 
+using namespace MySQL::Geometry;
 using namespace grtui;
 using namespace mforms;
 
@@ -584,7 +583,7 @@ void DbConnectPanel::set_keychain_password(DbDriverParam *param, bool clear)
 
 
 void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::ControlType ctrl_type, 
-                                    const ::Position &pos, const ::Size &size, const std::string &caption)
+                                    const ControlBounds& bounds, const std::string &caption)
 {
   bool is_new_line= false;
   Table *table= NULL;
@@ -594,29 +593,32 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
   {
   case 0:
     {
-      if (pos.y >= (int)_param_rows.size())
+      if (bounds.top >= (int)_param_rows.size())
       {
         is_new_line= true;
 
         _params_table.set_row_count(_param_rows.size() + 1);
         _param_rows.push_back(box= new Box(true));
+
+        mforms::TableItemFlags flags;
 #ifdef __APPLE__ // HExpand is messing layout in mac
-        _params_table.add(mforms::manage(box), 1, 2, pos.y, pos.y + 1, mforms::HFillFlag);
+        flags = mforms::HFillFlag;
 #else
-        _params_table.add(mforms::manage(box), 1, 2, pos.y, pos.y + 1, mforms::HExpandFlag|mforms::HFillFlag);
+        flags = mforms::HExpandFlag | mforms::HFillFlag;
 #endif
+        _params_table.add(mforms::manage(box), 1, 2, bounds.top, bounds.top + 1, flags);
         box->set_spacing(4);
         _views.push_back(box);
       }
       else
-        box= _param_rows[pos.y];
+        box= _param_rows[bounds.top];
 
       table= &_params_table;
       break;
     }
   case 1:
     {
-      if (pos.y >= (int)_advanced_rows.size())
+      if (bounds.top >= (int)_advanced_rows.size())
       {
         is_new_line= true;
 
@@ -633,13 +635,13 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
         }
         _views.push_back(box);
 #ifdef __APPLE__ // TODO: HExpand is messing layout in mac, needs fix
-        _advanced_table.add(mforms::manage(box), 1, 2, pos.y, pos.y + 1, mforms::HFillFlag);
+        _advanced_table.add(mforms::manage(box), 1, 2, bounds.top, bounds.top + 1, mforms::HFillFlag);
 #else
-        _advanced_table.add(mforms::manage(box), 1, 2, pos.y, pos.y + 1, mforms::HExpandFlag|mforms::HFillFlag);
+        _advanced_table.add(mforms::manage(box), 1, 2, bounds.top, bounds.top + 1, mforms::HExpandFlag|mforms::HFillFlag);
 #endif
       }
       else
-        box= _advanced_rows[pos.y];
+        box= _advanced_rows[bounds.top];
 
       table= &_advanced_table;
       break;
@@ -657,7 +659,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
       label->set_text_align(mforms::MiddleRight);
 
       if (is_new_line)
-        table->add(mforms::manage(label), 0, 1, pos.y, pos.y + 1, mforms::HFillFlag | mforms::VFillFlag);
+        table->add(mforms::manage(label), 0, 1, bounds.top, bounds.top + 1, mforms::HFillFlag | mforms::VFillFlag);
       else
         box->add(mforms::manage(label), false, true);
       _views.push_back(label);
@@ -668,7 +670,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
       Label *label= new Label();
       label->set_text(caption);
       label->set_style(mforms::SmallHelpTextStyle);
-      table->add(mforms::manage(label), 2, 3, pos.y, pos.y + 1, mforms::HFillFlag | mforms::VFillFlag);
+      table->add(mforms::manage(label), 2, 3, bounds.top, bounds.top + 1, mforms::HFillFlag | mforms::VFillFlag);
       _views.push_back(label);
       break;
     }
@@ -738,7 +740,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
           ctrl->set_value(*value);
       }
 
-      ctrl->set_size(size.width, -1);
+      ctrl->set_size(bounds.width, -1);
 
       ctrl->signal_changed().connect(sigc::bind(sigc::mem_fun(this, &DbConnectPanel::param_value_changed), ctrl));
 
