@@ -22,7 +22,7 @@
 #include "grtdb_object_filter.h"
 #include "grt/grt_string_list_model.h"
 #include "text_input_dialog.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 using namespace grtui;
 using namespace base;
@@ -76,7 +76,7 @@ DBObjectFilterFrame::DBObjectFilterFrame(bec::GRTManager *grtm)
   _show_button.set_text(_("Show Filter"));
   _show_button.signal_clicked().connect(sigc::mem_fun(this, &DBObjectFilterFrame::toggle_detailed));
   
-  _summary_table.add(&_show_button, 2, 3, 0, 2, 0);
+  _summary_table.add(&_show_button, 2, 3, 0, 2, mforms::HFillFlag);
   
   
   // detailed view
