@@ -20,7 +20,7 @@
 #include "stdafx.h"
 #include "grt/common.h"
 #include "string_list_editor.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 using namespace grtui;
 
