@@ -21,7 +21,7 @@
 
 #include <grts/structs.db.h>
 
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 #include <grtpp_undo_manager.h>
 
 #include "grt/common.h"
