@@ -1,20 +1,20 @@
 /* 
- * (c) 2007-2008 MySQL AB, 2008-2010 Sun Microsystems, Inc.
+ * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 #include "stdafx.h"
@@ -27,7 +27,7 @@
 
 #include "objimpl/db.query/db_query_EditableResultset.h"
 
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 #include <grtpp_undo_manager.h>
 
 #include "grt/common.h"
@@ -47,6 +47,10 @@ static void table_list_changed(grt::internal::OwnedList *list, bool added, const
   {
     table->signal_refreshDisplay().emit("index");
   }
+  else if (table->triggers().valueptr() == list)
+  {
+    table->signal_refreshDisplay().emit("trigger");
+  }
   else if (table->foreignKeys().valueptr() == list)
   {
     table->signal_refreshDisplay().emit("foreignKey");
@@ -107,7 +111,8 @@ db_query_EditableResultsetRef db_Table::createInsertsEditor()
 void db_Table::addColumn(const db_ColumnRef &column)
 {
   _columns.insert(column);
-  
+  if (column->owner().valueptr() != this)
+    column->owner(db_TableRef(this));
 }
 
 
@@ -127,6 +132,8 @@ db_ForeignKeyRef db_Table::createForeignKey(const std::string &name)
 void db_Table::addIndex(const db_IndexRef &index)
 {
   _indices.insert(index);
+  if (index->owner().valueptr() != this)
+    index->owner(db_TableRef(this));
 }
 
 
@@ -139,6 +146,9 @@ void db_Table::addPrimaryKeyColumn(const db_ColumnRef &column)
 
   grt::AutoUndo undo(get_grt(), !is_global());
 
+  if (_columns.get_index(column) == grt::BaseListRef::npos)
+    addColumn(column);
+
   std::string strname;
   
   pkindex= primaryKey();
@@ -330,7 +340,7 @@ void db_Table::removeForeignKey(const db_ForeignKeyRef &fk, long removeColumns)
   grt::AutoUndo undo(get_grt(), !is_global());
 
   foreignKeys().remove_value(fk);
-  if (fk->index().is_valid())
+  if (fk->index().is_valid() && !fk->index()->isPrimary())
     indices().remove_value(fk->index());
   
   if (removeColumns > 0)
