@@ -694,7 +694,9 @@ void Recordset::sort_by(ColumnId column, int direction, bool retaining)
     _sort_columns.clear();
     if (!(direction))
     {
-      refresh_ui();
+      boost::shared_ptr<sqlite::connection> data_swap_db= this->data_swap_db();
+      rebuild_data_index(data_swap_db.get(), true, true);
+      //refresh_ui();
       return;
     }
   }
@@ -1422,7 +1424,7 @@ class DataEditorSelector : public boost::static_visitor<BinaryDataEditor*>
 {
 public:
   DataEditorSelector(bec::GRTManager *grtm, bool read_only) : _grtm(grtm), _read_only(read_only) {}
-  DataEditorSelector(bec::GRTManager *grtm, bool read_only, const std::string &encoding) : _grtm(grtm), _read_only(read_only), _encoding(encoding) {}
+  DataEditorSelector(bec::GRTManager *grtm, bool read_only, const std::string &encoding) : _grtm(grtm), _encoding(encoding), _read_only(read_only) {}
   const std::string & encoding() const { return _encoding; }
   void encoding(const std::string &value) { _encoding= value; }
 private:
