@@ -247,7 +247,7 @@ void Recordset_cdbc_storage::do_unserialize(Recordset *recordset, sqlite::connec
   for (ColumnId n= column_types.size(); editable_col_count > n; ++n)
   {
     std::string type_name= rs_meta->getColumnTypeName(n+1);
-    base::toupper(type_name);
+    type_name = base::toupper(type_name);
     std::string::size_type tne= type_name.find(' ');
     type_name= type_name.substr(0, tne);
     column_types.push_back(known_types[type_name]);
@@ -322,8 +322,8 @@ void Recordset_cdbc_storage::do_unserialize(Recordset *recordset, sqlite::connec
         row_values[editable_col_count+n]= row_values[_pkey_columns[n]];
       add_data_swap_record(insert_commands, row_values);
 
-      if (_dbms_conn->is_disconnection_requested)
-        throw std::runtime_error(_("The DBMS connection was dropped"));
+      if (_dbms_conn->is_stop_query_requested)
+        throw std::runtime_error(_("Query execution has been stopped, the connection to the DB server was not restarted, any open transaction remains open"));
     }
 
     transaction_guarder.commit();
