@@ -471,7 +471,7 @@ void Recordset_sql_storage::generate_sql_script(const Recordset *recordset, sqli
               if (!values.empty())
                 values.resize(values.size()-2);
 
-              sql= strfmt("INSERT INTO %s (%s) VALUES (%s)", _omit_schema_qualifier ? table_name().c_str() : full_table_name.c_str(), col_names.c_str(), values.c_str());
+              sql= strfmt("INSERT INTO %s (%s) VALUES (%s)", _omit_schema_qualifier ? (std::string("`")+table_name()+std::string("`")).c_str() : full_table_name.c_str(), col_names.c_str(), values.c_str());
             }
           }
           break;
@@ -562,7 +562,7 @@ void Recordset_sql_storage::generate_sql_script(const Recordset *recordset, sqli
         }
         if (!values.empty())
           values.resize(values.size()-2);
-        std::string sql= strfmt("INSERT INTO %s (%s) VALUES (%s)", _omit_schema_qualifier ? table_name().c_str() : full_table_name.c_str(), col_names.c_str(), values.c_str());
+        std::string sql= strfmt("INSERT INTO %s (%s) VALUES (%s)", _omit_schema_qualifier ? (std::string("`")+table_name()+std::string("`")).c_str() : full_table_name.c_str(), col_names.c_str(), values.c_str());
         sql_script.statements.push_back(sql);
 
         BOOST_FOREACH (boost::shared_ptr<sqlite::result> &data_rs, data_results)
@@ -635,7 +635,7 @@ void Recordset_sql_storage::generate_inserts(const Recordset *recordset, sqlite:
         }
         if (!values.empty())
           values.resize(values.size()-2);
-        std::string sql= strfmt("INSERT INTO %s (%s) VALUES (%s)", _omit_schema_qualifier ? table_name().c_str() : full_table_name.c_str(), col_names.c_str(), values.c_str());
+        std::string sql= strfmt("INSERT INTO %s (%s) VALUES (%s)", _omit_schema_qualifier ? (std::string("`")+table_name()+std::string("`")).c_str() : full_table_name.c_str(), col_names.c_str(), values.c_str());
         sql_script.statements.push_back(sql);
 
         BOOST_FOREACH (boost::shared_ptr<sqlite::result> &data_rs, data_results)
