@@ -149,13 +149,7 @@ bool SqlScriptApplyPage::execute_sql_script()
 
 std::string SqlScriptApplyPage::next_button_caption()
 {
-#ifdef __APPLE__
-  return _("Close");
-#elif defined(_WIN32)
-  return _("Finish");
-#else
-  return _("_Close");
-#endif
+  return finish_button_caption();
 }
 
 
