@@ -1,27 +1,27 @@
 /* 
  * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 
 #include "stdafx.h"
 
 #include "var_grid_model_be.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 #include "sqlide_generics_private.h"
 #include <sqlite/execute.hpp>
 #include <sqlite/query.hpp>
@@ -118,6 +118,7 @@ void VarGridModel::reset()
   reinit(_column_names);
   reinit(_column_types);
   reinit(_real_column_types);
+  reinit(_column_quoting);
 
   _column_count= 0;
   _row_count= 0;
@@ -157,23 +158,13 @@ boost::shared_ptr<sqlite::connection> VarGridModel::create_data_swap_db_connecti
 }
 
 
-bool VarGridModel::call_refresh_ui()
-{
-  refresh_ui_cb();
-  return false;
-}
-
-
 int VarGridModel::refresh_ui()
 {
   if (_grtm->in_main_thread())
     return refresh_ui_cb();
   else
   {
-    //_grtm->run_when_idle(sigc::bind_return(sigc::hide_return(refresh_ui_cb), false));
-    // this method is better because it will auto-invalidate the scheduled slot when the object
-    // is deleted and also reduce call stack size from sigc wrappers
-    _grtm->run_when_idle(sigc::mem_fun(this, &VarGridModel::call_refresh_ui));
+    _grtm->run_when_idle(sigc::bind_return(sigc::hide_return(refresh_ui_cb), false));
     return 0;
   }
 }
@@ -279,7 +270,7 @@ IconId VarGridModel::get_field_icon(const NodeId &node, int column, IconSize siz
 
   Cell cell;
   static const sqlite::Variant null_value= sqlite::Null();
-  if ((column < 0) || (column + 1 >= _column_types.size()))
+  if ((column < 0) || (column + 1 >= (int) _column_types.size()))
     return 0;
   const sqlite::Variant &var= get_cell(cell, node, column, false) ? *cell : null_value;
   return boost::apply_visitor(*_icon_for_val, _column_types[column], var);
