@@ -82,7 +82,7 @@ public:
   typedef std::vector<std::string> Column_names;
   typedef std::vector<sqlite::Variant> Column_types;
   typedef Data::const_iterator Cell_const;
-  typedef std::vector<bool> Column_quoting;
+  typedef std::vector<int> Column_quoting; // was bool, but it had some wierd effects where returned value was random
 
 protected:
   typedef Data::iterator Cell;
