@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,12 +32,12 @@ class WBPUBLICBACKEND_PUBLIC_FUNC BadgeFigure : public mdc::Figure
   mdc::FontSpec _font;
   std::string _badge_id;
   std::string _text;
-  mdc::Color _fill_color2;
-  mdc::Color _text_color;
+  MySQL::Drawing::Color _fill_color2;
+  MySQL::Drawing::Color _text_color;
   cairo_pattern_t *_gradient;
-  mdc::Size _text_size;
+  MySQL::Geometry::Size _text_size;
   
-  virtual mdc::Size calc_min_size();
+  virtual MySQL::Geometry::Size calc_min_size();
 public:
   BadgeFigure(mdc::Layer *layer);
   virtual ~BadgeFigure();
@@ -47,9 +47,9 @@ public:
   std::string badge_id() const { return _badge_id; }
   
   void set_text(const std::string &text);
-  void set_gradient_from_color(const mdc::Color &color);
-  void set_fill_color2(const mdc::Color &color);
-  void set_text_color(const mdc::Color &color);
+  void set_gradient_from_color(const MySQL::Drawing::Color &color);
+  void set_fill_color2(const MySQL::Drawing::Color &color);
+  void set_text_color(const MySQL::Drawing::Color &color);
   
   sigc::connection updater_connection;
 };
