@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,6 +22,9 @@
 #include "figure_common.h"
 #include "base/string_utilities.h"
 
+using namespace wbfig;
+using namespace MySQL::Drawing;
+using namespace MySQL::Geometry;
 
 mdc::FontSpec parse_font_spec(const std::string &font)
 {
@@ -59,12 +62,6 @@ mdc::FontSpec parse_font_spec(const std::string &font)
   return fs;
 }
 
-
-
-
-using namespace wbfig;
-
-
 Titlebar::Titlebar(mdc::Layer *layer, FigureEventHub *hub, BaseFigure *owner, bool expander)
   : mdc::Box(layer, mdc::Box::Horizontal), _hub(hub), _owner(owner), _icon_text(layer)
 {
@@ -72,8 +69,8 @@ Titlebar::Titlebar(mdc::Layer *layer, FigureEventHub *hub, BaseFigure *owner, bo
   set_spacing(6);
 
   _corners= mdc::CNone;
-  _back_color= mdc::Color(1, 1, 1);
-  _border_color= mdc::Color(0.7, 0.7, 0.7);
+  _back_color= Color(1, 1, 1);
+  _border_color= Color(0.7, 0.7, 0.7);
 
   _icon_text.set_allow_shrinking(true);
   //_icon_text.set_auto_sizing(false);
@@ -84,7 +81,7 @@ Titlebar::Titlebar(mdc::Layer *layer, FigureEventHub *hub, BaseFigure *owner, bo
   {
     _expander= new mdc::Button(layer, mdc::ExpanderButton);
     _expander->signal_activate().connect(sigc::mem_fun(this, &Titlebar::expand_toggled));
-    _expander->set_pen_color(mdc::Color(0.4, 0.4, 0.4));
+    _expander->set_pen_color(Color(0.4, 0.4, 0.4));
     
     add(_expander, false, false);
   }
@@ -100,7 +97,7 @@ Titlebar::~Titlebar()
 }
 
 
-bool Titlebar::on_button_press(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool Titlebar::on_button_press(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub || !_hub->figure_button_press(_owner->represented_object(), target, point, button, state))
     return super::on_button_press(target, point, button, state);
@@ -108,7 +105,7 @@ bool Titlebar::on_button_press(mdc::CanvasItem *target, const mdc::Point &point,
 }
 
 
-bool Titlebar::on_button_release(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool Titlebar::on_button_release(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub || !_hub->figure_button_release(_owner->represented_object(), target, point, button, state))
     return super::on_button_release(target, point, button, state);
@@ -116,7 +113,7 @@ bool Titlebar::on_button_release(mdc::CanvasItem *target, const mdc::Point &poin
 }
 
 
-bool Titlebar::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
+bool Titlebar::on_enter(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub || !_hub->figure_enter(_owner->represented_object(), target, point))
     return super::on_enter(target, point);
@@ -124,7 +121,7 @@ bool Titlebar::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
 }
 
 
-bool Titlebar::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
+bool Titlebar::on_leave(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub || !_hub->figure_leave(_owner->represented_object(), target, point))
     return super::on_leave(target, point);
@@ -133,7 +130,7 @@ bool Titlebar::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
 
 //--------------------------------------------------------------------------------------------------
 
-bool Titlebar::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool Titlebar::on_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub || !_hub->figure_click(_owner->represented_object(), target, point, button, state))
     return super::on_click(target, point, button, state);
@@ -142,7 +139,7 @@ bool Titlebar::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::M
 
 //--------------------------------------------------------------------------------------------------
 
-bool Titlebar::on_double_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool Titlebar::on_double_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub || !_hub->figure_double_click(_owner->represented_object(), target, point, button, state))
     return super::on_double_click(target, point, button, state);
@@ -182,20 +179,20 @@ void Titlebar::expand_toggled()
 }
 
 
-void Titlebar::set_color(const mdc::Color &color)
+void Titlebar::set_color(const Color &color)
 {
   _back_color= color;
   set_needs_render();
 }
 
 
-void Titlebar::set_text_color(const mdc::Color &color)
+void Titlebar::set_text_color(const Color &color)
 {
   _icon_text.set_pen_color(color);
 }
 
 
-void Titlebar::set_border_color(const mdc::Color &color)
+void Titlebar::set_border_color(const Color &color)
 {
   _border_color= color;
 }
@@ -248,7 +245,7 @@ FigureItem::FigureItem(mdc::Layer *layer, FigureEventHub *hub, BaseFigure *owner
 }
 
 
-bool FigureItem::on_button_press(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool FigureItem::on_button_press(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (target!= this || !_hub->figure_button_press(_owner->represented_object(), target, point, button, state))
     return super::on_button_press(target, point, button, state);
@@ -256,7 +253,7 @@ bool FigureItem::on_button_press(mdc::CanvasItem *target, const mdc::Point &poin
 }
 
 
-bool FigureItem::on_button_release(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool FigureItem::on_button_release(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (target!= this || !_hub->figure_button_release(_owner->represented_object(), target, point, button, state))
     return super::on_button_release(target, point, button, state);
@@ -264,7 +261,7 @@ bool FigureItem::on_button_release(mdc::CanvasItem *target, const mdc::Point &po
 }
 
 
-bool FigureItem::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
+bool FigureItem::on_enter(mdc::CanvasItem *target, const Point &point)
 {
   if (target!= this || !_hub->figure_enter(_owner->represented_object(), target, point))
     return super::on_enter(target, point);
@@ -272,7 +269,7 @@ bool FigureItem::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
 }
 
 
-bool FigureItem::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
+bool FigureItem::on_leave(mdc::CanvasItem *target, const Point &point)
 {
   if (target!= this || !_hub->figure_leave(_owner->represented_object(), target, point))
     return super::on_leave(target, point);
@@ -281,7 +278,7 @@ bool FigureItem::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
 
 //--------------------------------------------------------------------------------------------------
 
-bool FigureItem::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool FigureItem::on_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (target!= this || !_hub->figure_click(_owner->represented_object(), target, point, button, state))
     return super::on_click(target, point, button, state);
@@ -290,7 +287,7 @@ bool FigureItem::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc:
 
 //--------------------------------------------------------------------------------------------------
 
-bool FigureItem::on_double_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool FigureItem::on_double_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (target!= this || !_hub->figure_double_click(_owner->represented_object(), target, point, button, state))
     return super::on_double_click(target, point, button, state);
@@ -299,23 +296,23 @@ bool FigureItem::on_double_click(mdc::CanvasItem *target, const mdc::Point &poin
 
 //--------------------------------------------------------------------------------------------------
 
-mdc::Point FigureItem::get_intersection_with_line_to(const mdc::Point &p)
+Point FigureItem::get_intersection_with_line_to(const Point &p)
 {
-  mdc::Point point(mdc::CanvasItem::get_intersection_with_line_to(p));
-  mdc::Rect bounds(get_root_bounds());
+  Point point(mdc::CanvasItem::get_intersection_with_line_to(p));
+  Rect bounds(get_root_bounds());
 
-  if (point.x-bounds.xmin() < bounds.width()/2)
-    point.x= bounds.xmin();
+  if (point.x-bounds.left() < bounds.width()/2)
+    point.x= bounds.left();
   else
-    point.x= bounds.xmax();
+    point.x= bounds.right();
 
-  point.y= (bounds.ymax()+bounds.ymin())/2;
+  point.y= (bounds.bottom()+bounds.top())/2;
   
   return point;
 }
 
 
-mdc::Rect FigureItem::get_root_bounds() const
+Rect FigureItem::get_root_bounds() const
 {
   if (!get_visible() || !get_parents_visible())
     return get_toplevel()->get_root_bounds();
@@ -361,7 +358,7 @@ BaseFigure::BaseFigure(mdc::Layer *layer, FigureEventHub *hub, const model_Objec
 }
 
 
-bool BaseFigure::on_button_press(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool BaseFigure::on_button_press(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (target!= this || !_hub->figure_button_press(represented_object(), target, point, button, state))
     return super::on_button_press(target, point, button, state);
@@ -369,7 +366,7 @@ bool BaseFigure::on_button_press(mdc::CanvasItem *target, const mdc::Point &poin
 }
 
 
-bool BaseFigure::on_button_release(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool BaseFigure::on_button_release(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (target!= this || !_hub->figure_button_release(represented_object(), target, point, button, state))
     return super::on_button_release(target, point, button, state);
@@ -377,7 +374,7 @@ bool BaseFigure::on_button_release(mdc::CanvasItem *target, const mdc::Point &po
 }
 
 
-bool BaseFigure::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
+bool BaseFigure::on_enter(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub->figure_enter(represented_object(), target, point))
     return super::on_enter(target, point);
@@ -385,7 +382,7 @@ bool BaseFigure::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
 }
 
 
-bool BaseFigure::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
+bool BaseFigure::on_leave(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub->figure_leave(represented_object(), target, point))
     return super::on_leave(target, point);
@@ -393,14 +390,14 @@ bool BaseFigure::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
 }
 
 
-bool BaseFigure::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool BaseFigure::on_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (target!= this || !_hub->figure_click(represented_object(), target, point, button, state))
     return super::on_click(target, point, button, state);
   return false;
 }
 
-bool BaseFigure::on_double_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool BaseFigure::on_double_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (target!= this || !_hub->figure_double_click(represented_object(), target, point, button, state))
     return super::on_double_click(target, point, button, state);
@@ -413,14 +410,14 @@ void BaseFigure::unset_color()
 }
 
 
-void BaseFigure::set_color(const mdc::Color &color)
+void BaseFigure::set_color(const Color &color)
 {
   set_background_color(color);
   set_draw_background(true);
 }
 
 
-void BaseFigure::highlight(const mdc::Color *color)
+void BaseFigure::highlight(const Color *color)
 {
   set_highlight_color(color);
   set_highlighted(true);
@@ -440,7 +437,7 @@ void BaseFigure::set_allow_manual_resizing(bool flag)
   _manual_resizing= flag;
   invalidate_min_sizes();
   if (!flag)
-    set_fixed_size(mdc::Size(-1,-1));
+    set_fixed_size(Size(-1,-1));
 }
 
 
@@ -458,7 +455,7 @@ void BaseFigure::invalidate_min_sizes()
 }
 
 
-bool BaseFigure::on_drag_handle(mdc::ItemHandle *handle, const mdc::Point &pos, bool dragging)
+bool BaseFigure::on_drag_handle(mdc::ItemHandle *handle, const Point &pos, bool dragging)
 {
   if (!_manual_resizing)
     set_allow_manual_resizing(true);
@@ -628,11 +625,11 @@ void BaseFigure::end_sync(mdc::Box &box, ItemList &list, ItemList::iterator iter
 
     if (_manual_resizing)
     {
-      mdc::Size size= get_min_size();
-      mdc::Size fsize= get_fixed_size();
+      Size size= get_min_size();
+      Size fsize= get_fixed_size();
 
       if (size.height > fsize.height)
-        set_fixed_size(mdc::Size(fsize.width, size.height));
+        set_fixed_size(Size(fsize.width, size.height));
     }
   }
   get_layer()->get_view()->unlock_redraw();
@@ -648,7 +645,7 @@ CaptionFigure::CaptionFigure(mdc::Layer *layer, FigureEventHub *hub, model_Objec
 }
 
 
-bool CaptionFigure::on_button_press(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool CaptionFigure::on_button_press(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub->figure_button_press(_owner_object, target, point, button, state))
     return super::on_button_press(target, point, button, state);
@@ -656,7 +653,7 @@ bool CaptionFigure::on_button_press(mdc::CanvasItem *target, const mdc::Point &p
 }
 
 
-bool CaptionFigure::on_button_release(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool CaptionFigure::on_button_release(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub->figure_button_release(_owner_object, target, point, button, state))
     return super::on_button_release(target, point, button, state);
@@ -664,7 +661,7 @@ bool CaptionFigure::on_button_release(mdc::CanvasItem *target, const mdc::Point
 }
 
 
-bool CaptionFigure::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
+bool CaptionFigure::on_enter(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub->figure_enter(_owner_object, target, point))
     return super::on_enter(target, point);
@@ -672,7 +669,7 @@ bool CaptionFigure::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
 }
 
 
-bool CaptionFigure::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
+bool CaptionFigure::on_leave(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub->figure_leave(_owner_object, target, point))
     return super::on_leave(target, point);
@@ -681,7 +678,7 @@ bool CaptionFigure::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
 
 //--------------------------------------------------------------------------------------------------
 
-bool CaptionFigure::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool CaptionFigure::on_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub->figure_click(_owner_object, target, point, button, state))
     return super::on_click(target, point, button, state);
@@ -690,7 +687,7 @@ bool CaptionFigure::on_click(mdc::CanvasItem *target, const mdc::Point &point, m
 
 //--------------------------------------------------------------------------------------------------
 
-bool CaptionFigure::on_double_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool CaptionFigure::on_double_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub->figure_double_click(_owner_object, target, point, button, state))
     return super::on_double_click(target, point, button, state);
@@ -706,15 +703,15 @@ ShrinkableBox::ShrinkableBox(mdc::Layer *layer, mdc::Box::Orientation orientatio
   _limit_item_count= 0;
 }
 
-mdc::Size ShrinkableBox::calc_min_size()
+Size ShrinkableBox::calc_min_size()
 {
   if (_manual_resizing)
   {
     if (_children.empty())
-      return mdc::Size(0,0);//Box::calc_min_size();
+      return Size(0,0);//Box::calc_min_size();
     else
     {
-      mdc::Size min_size= Box::calc_min_size();
+      Size min_size= Box::calc_min_size();
       min_size.height= _children.front().item->get_min_size().height;
       
       return min_size;
@@ -722,8 +719,8 @@ mdc::Size ShrinkableBox::calc_min_size()
   }
   else if (_limit_item_count > 0 && _limit_item_count+1 < (int) _children.size())
   {
-    mdc::Size min_item_size= _children.front().item->get_min_size();
-    mdc::Size min_size= Box::calc_min_size();
+    Size min_item_size= _children.front().item->get_min_size();
+    Size min_size= Box::calc_min_size();
 
     min_size.height= min_item_size.height * (_limit_item_count+1) + _spacing * (_limit_item_count);
     
@@ -738,15 +735,15 @@ mdc::Size ShrinkableBox::calc_min_size()
 #define EXTRA_LABEL_SIZE 10
 #define EXTRA_LABEL_PADDING 2
 
-void ShrinkableBox::resize_to(const mdc::Size &size)
+void ShrinkableBox::resize_to(const Size &size)
 {  
   if (!_children.empty() && (_manual_resizing || (_limit_item_count > 0 && _limit_item_count < (int) _children.size())))
   {
-    mdc::Size used_size;
+    Size used_size;
     int number_of_items_that_fit= 0;
     int i;
     // hide items that won't fit
-    mdc::Size min_item_size= _children.front().item->get_min_size();
+    Size min_item_size= _children.front().item->get_min_size();
     
     if (_orientation == mdc::Box::Horizontal)
     {
@@ -819,7 +816,7 @@ void ShrinkableBox::render(mdc::CairoCtx *cr)
   {
     char text[100];
     sprintf(text, "%i more...", _hidden_item_count);
-    mdc::Point pos= get_position();
+    Point pos= get_position();
     
     cr->save();
     
