@@ -21,6 +21,7 @@
 #include "image_figure.h"
 
 using namespace wbfig;
+using namespace MySQL::Geometry;
 
 Image::Image(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &self) 
 : BaseFigure(layer, hub, self), _image(layer)
@@ -38,7 +39,7 @@ Image::Image(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &self
 }
 
 
-static void constrain_aspect_ratio(mdc::ItemHandle *handle, mdc::Size &size, double ratio)
+static void constrain_aspect_ratio(mdc::ItemHandle *handle, Size &size, double ratio)
 {
   if ((handle->get_tag() & (HDL_LEFT|HDL_RIGHT)) != 0)
     size.height= size.width/ratio;
@@ -68,19 +69,19 @@ void Image::keep_aspect_ratio(bool flag)
       double new_height= width / aspect;
 
       if (fabs(_image.get_size().height-new_height) > 1)
-        set_fixed_size(mdc::Size(width, new_height));
+        set_fixed_size(Size(width, new_height));
 
       set_drag_handle_constrainer(sigc::bind<double>(sigc::ptr_fun(constrain_aspect_ratio), aspect));
     }
   }
   else
-    set_drag_handle_constrainer(sigc::slot<void,mdc::ItemHandle*,mdc::Size&>());
+    set_drag_handle_constrainer(sigc::slot<void,mdc::ItemHandle*,Size&>());
 }
 
 
 double Image::get_aspect_ratio()
 {
-  mdc::Size size= _image.get_image_size();
+  Size size= _image.get_image_size();
 
   return size.width / size.height;
 }
@@ -114,7 +115,7 @@ void Image::set_allow_manual_resizing(bool flag)
 
 //--------------------------------------------------------------------------------------------------
 
-bool Image::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool Image::on_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub->figure_click(represented_object(), target, point, button, state))
     return super::on_click(target, point, button, state);
@@ -123,7 +124,7 @@ bool Image::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::Mous
 
 //--------------------------------------------------------------------------------------------------
 
-bool Image::on_double_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool Image::on_double_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub->figure_double_click(represented_object(), target, point, button, state))
     return super::on_double_click(target, point, button, state);
