@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,6 +24,8 @@
 
 using namespace std;
 using namespace wbfig;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 #define MIN_LAYER_TITLE_WIDTH 120.0
 #define MIN_LAYER_SIZE 10.0
@@ -44,8 +46,8 @@ LayerAreaGroup::LayerAreaGroup(mdc::Layer *layer, FigureEventHub *hub, model_Obj
   _font= layer->get_view()->get_default_font();
   _font.weight= mdc::WBold;
 
-  _title_fore= mdc::Color::Black();
-  _title_back= mdc::Color(0.85, 0.85, 0.85);
+  _title_fore= Color::Black();
+  _title_back= Color(0.85, 0.85, 0.85);
 
   _min_size.width= MIN_LAYER_SIZE;
   _min_size.height= MIN_LAYER_SIZE;
@@ -87,35 +89,35 @@ void LayerAreaGroup::set_font(const mdc::FontSpec &font)
 }
 
 
-static void get_bounding_area(mdc::CanvasItem *item, mdc::Point *maxpos)
+static void get_bounding_area(mdc::CanvasItem *item, Point *maxpos)
 {
-  mdc::Rect bounds= item->get_bounds();
+  Rect bounds= item->get_bounds();
 
-  maxpos->x= max(maxpos->x, bounds.xmax());
-  maxpos->y= max(maxpos->y, bounds.ymax());
+  maxpos->x= max(maxpos->x, bounds.right());
+  maxpos->y= max(maxpos->y, bounds.bottom());
 }
 
 
-void LayerAreaGroup::move_item(mdc::CanvasItem *item, const mdc::Point &pos)
+void LayerAreaGroup::move_item(mdc::CanvasItem *item, const Point &pos)
 {
   item->move_to(pos);
 }
 
 
-bool LayerAreaGroup::on_drag_handle(mdc::ItemHandle *handle, const mdc::Point &pos, bool dragging)
+bool LayerAreaGroup::on_drag_handle(mdc::ItemHandle *handle, const Point &pos, bool dragging)
 {
-  //mdc::Point offset= pos - get_view()->snap_to_grid(handle->get_position());
-  mdc::Point npos= get_position();
-  mdc::Size nsize= get_size();
+  //Point offset= pos - get_view()->snap_to_grid(handle->get_position());
+  Point npos= get_position();
+  Size nsize= get_size();
 
   if (!_resizing)
   {
-    mdc::Point maxpos;
+    Point maxpos;
 
     _initial_bounds= get_root_bounds();
     _resizing= true;
 
-    foreach(sigc::bind<mdc::Point*>(sigc::ptr_fun(get_bounding_area), &maxpos));
+    foreach(sigc::bind<Point*>(sigc::ptr_fun(get_bounding_area), &maxpos));
 
     _min_size.width= max(maxpos.x, MIN_LAYER_SIZE);
     _min_size.height= max(maxpos.y, MIN_LAYER_SIZE);
@@ -138,7 +140,7 @@ bool LayerAreaGroup::on_drag_handle(mdc::ItemHandle *handle, const mdc::Point &p
 }
 
 
-bool LayerAreaGroup::on_button_press(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool LayerAreaGroup::on_button_press(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (mdc::bounds_contain_point(get_title_bounds(), point.x, point.y))
   {
@@ -152,7 +154,7 @@ bool LayerAreaGroup::on_button_press(mdc::CanvasItem *target, const mdc::Point &
 }
 
 
-bool LayerAreaGroup::on_button_release(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool LayerAreaGroup::on_button_release(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   bool ret= false;
   
@@ -166,7 +168,7 @@ bool LayerAreaGroup::on_button_release(mdc::CanvasItem *target, const mdc::Point
 
 //--------------------------------------------------------------------------------------------------
 
-bool LayerAreaGroup::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool LayerAreaGroup::on_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub || !_hub->figure_click(_represented_object, target, point, button, state))
     return mdc::AreaGroup::on_click(target, point, button, state);
@@ -176,7 +178,7 @@ bool LayerAreaGroup::on_click(mdc::CanvasItem *target, const mdc::Point &point,
 
 //--------------------------------------------------------------------------------------------------
 
-bool LayerAreaGroup::on_double_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool LayerAreaGroup::on_double_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub || !_hub->figure_double_click(_represented_object, target, point, button, state))
     return mdc::AreaGroup::on_double_click(target, point, button, state);
@@ -186,7 +188,7 @@ bool LayerAreaGroup::on_double_click(mdc::CanvasItem *target, const mdc::Point &
 
 //--------------------------------------------------------------------------------------------------
 
-bool LayerAreaGroup::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
+bool LayerAreaGroup::on_enter(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub || !_hub->figure_enter(_represented_object, target, point))
     return super::on_enter(target, point);
@@ -194,7 +196,7 @@ bool LayerAreaGroup::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
 }
 
 
-bool LayerAreaGroup::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
+bool LayerAreaGroup::on_leave(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub || !_hub->figure_leave(_represented_object, target, point))
     return super::on_leave(target, point);
@@ -213,22 +215,22 @@ void LayerAreaGroup::render(mdc::CairoCtx *cr)
     _extents_invalid= false;
   }
 
-  mdc::Size size= get_title_bounds().size;
+  Size size= get_title_bounds().size;
 
   cr->save();
   cr->translate(get_position());
   cr->set_color(_title_back);
   cr->new_path();
-  cr->move_to(mdc::Point(0, 0));
-  cr->line_to(mdc::Point(size.width, 0));
-  cr->line_to(mdc::Point(size.width, size.height-5));
-  cr->line_to(mdc::Point(size.width-5, size.height));
-  cr->line_to(mdc::Point(0, size.height));
+  cr->move_to(Point(0, 0));
+  cr->line_to(Point(size.width, 0));
+  cr->line_to(Point(size.width, size.height-5));
+  cr->line_to(Point(size.width-5, size.height));
+  cr->line_to(Point(0, size.height));
   cr->close_path();
   cr->fill();
 
   cr->set_color(_title_fore);
-  cr->move_to(mdc::Point(TEXT_PADDING + _extents.x_bearing, TEXT_PADDING - _extents.y_bearing));
+  cr->move_to(Point(TEXT_PADDING + _extents.x_bearing, TEXT_PADDING - _extents.y_bearing));
   cr->set_font(_font);
   cr->show_text(_title);
   
@@ -247,14 +249,14 @@ void LayerAreaGroup::render_gl(mdc::CairoCtx *cr)
     _extents_invalid= false; 
   } 
  
-  mdc::Size size= get_title_bounds().size; 
-  mdc::Point text_position= mdc::Point(_extents.x_bearing, -_extents.y_bearing);
+  Size size= get_title_bounds().size; 
+  Point text_position= Point(_extents.x_bearing, -_extents.y_bearing);
  
   // Render caption for the layer figure. This is done via Cairo and a texture.
   bool generate_display_list= _display_list == 0;
 
   // Check if we need to regenerate the cache. if so, do it and load it as a texture.
-  mdc::Size texture_size= get_texture_size(size);
+  Size texture_size= get_texture_size(size);
   if (_needs_render || _text_texture == 0)
   {
     generate_display_list= true;
@@ -307,7 +309,7 @@ void LayerAreaGroup::render_gl(mdc::CairoCtx *cr)
 
     glNewList(_display_list, GL_COMPILE);
 
-    gl_setcolor(_title_back); 
+    mdc::gl_setcolor(_title_back); 
    
     glBegin(GL_POLYGON); 
       glVertex2f(0.0, 0.0); 
@@ -354,15 +356,15 @@ void LayerAreaGroup::render_gl(mdc::CairoCtx *cr)
   glPopMatrix();
 } 
 
-mdc::Rect LayerAreaGroup::get_title_bounds() const
+Rect LayerAreaGroup::get_title_bounds() const
 {
-  mdc::Rect rect;
+  Rect rect;
   
   double width= _extents.width + 10;
   if (width < MIN_LAYER_TITLE_WIDTH)
     width= MIN_LAYER_TITLE_WIDTH;
   
-  mdc::Size size= get_size();
+  Size size= get_size();
 
   if (width > size.width - _extents.height - 2 * TEXT_PADDING)
     width= size.width - _extents.height - 2 * TEXT_PADDING;
