@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,12 +33,12 @@ class LayerAreaGroup : public mdc::AreaGroup
   typedef mdc::AreaGroup super;
   model_Object *_represented_object;
   FigureEventHub *_hub;
-  mdc::Rect _initial_bounds;
+  MySQL::Geometry::Rect _initial_bounds;
   
   mdc::FontSpec _font;
   std::string _title;
-  mdc::Color _title_fore;
-  mdc::Color _title_back;
+  MySQL::Drawing::Color _title_fore;
+  MySQL::Drawing::Color _title_back;
 
   cairo_text_extents_t _extents;
   bool _resizing;
@@ -48,23 +48,23 @@ class LayerAreaGroup : public mdc::AreaGroup
   GLuint _text_texture;
   GLuint _display_list; // OpenGL's rendering list for this item.
 
-  sigc::signal<void, mdc::Rect> _resize_signal;
+  sigc::signal<void, MySQL::Geometry::Rect> _resize_signal;
 
-  virtual bool on_drag_handle(mdc::ItemHandle *handle, const mdc::Point &pos, bool dragging);
+  virtual bool on_drag_handle(mdc::ItemHandle *handle, const MySQL::Geometry::Point &pos, bool dragging);
   
-  virtual bool on_button_press(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state);
-  virtual bool on_button_release(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state);
-  virtual bool on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state);
-  virtual bool on_double_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state);
-  virtual bool on_enter(mdc::CanvasItem *target, const mdc::Point &point);
-  virtual bool on_leave(mdc::CanvasItem *target, const mdc::Point &point);
+  virtual bool on_button_press(mdc::CanvasItem *target, const MySQL::Geometry::Point &point, mdc::MouseButton button, mdc::EventState state);
+  virtual bool on_button_release(mdc::CanvasItem *target, const MySQL::Geometry::Point &point, mdc::MouseButton button, mdc::EventState state);
+  virtual bool on_click(mdc::CanvasItem *target, const MySQL::Geometry::Point &point, mdc::MouseButton button, mdc::EventState state);
+  virtual bool on_double_click(mdc::CanvasItem *target, const MySQL::Geometry::Point &point, mdc::MouseButton button, mdc::EventState state);
+  virtual bool on_enter(mdc::CanvasItem *target, const MySQL::Geometry::Point &point);
+  virtual bool on_leave(mdc::CanvasItem *target, const MySQL::Geometry::Point &point);
 
-  virtual void move_item(mdc::CanvasItem *item, const mdc::Point &pos);
+  virtual void move_item(mdc::CanvasItem *item, const MySQL::Geometry::Point &pos);
 
   virtual void render(mdc::CairoCtx *cr);
   virtual void render_gl(mdc::CairoCtx *cr); 
 
-  mdc::Rect get_title_bounds() const;
+  MySQL::Geometry::Rect get_title_bounds() const;
 
 public:
   LayerAreaGroup(mdc::Layer *layer, FigureEventHub *hub, model_Object *represented_object);
@@ -73,7 +73,7 @@ public:
   void set_title(const std::string &title);
   void set_font(const mdc::FontSpec &font);
   
-  sigc::signal<void, mdc::Rect> signal_interactive_resize() { return _resize_signal; }
+  sigc::signal<void, MySQL::Geometry::Rect> signal_interactive_resize() { return _resize_signal; }
   
   bool in_user_resize() const { return _resizing; }
 };
