@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -34,6 +34,8 @@
 #include "base/string_utilities.h"
 
 using namespace grt;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 // this subclass allows repainting to happen in 3 steps, layer only, connection only and figure only
 // to follow a repaint ordering that's independent from logical ordering
@@ -42,7 +44,7 @@ class RootAreaGroup : public mdc::AreaGroup
 public:
   RootAreaGroup(mdc::Layer *owner) : mdc::AreaGroup(owner) {}
 
-  virtual void repaint(const mdc::Rect &clipArea, bool direct)
+  virtual void repaint(const Rect &clipArea, bool direct)
   {
     mdc::CairoCtx *cr= _layer->get_view()->cairoctx();
 
@@ -89,7 +91,7 @@ public:
     // 4th paint figures inside area groups
     for (std::list<mdc::AreaGroup*>::iterator end= layers.end(), iter= layers.begin(); iter != end; ++iter)
     {
-      mdc::Rect localClipArea(clipArea);
+      Rect localClipArea(clipArea);
       localClipArea.pos= localClipArea.pos - (*iter)->get_position();
       (*iter)->repaint_contents(localClipArea, direct);
     }
@@ -127,7 +129,7 @@ bool model_Diagram::ImplData::is_realizable()
 
 void model_Diagram::ImplData::set_page_counts(int x, int y)
 {
-  mdc::Size pageSize(get_size_for_page(_self->owner()->get_data()->get_page_settings()));
+  Size pageSize(get_size_for_page(_self->owner()->get_data()->get_page_settings()));
 
   _self->width(pageSize.width * x);
   _self->height(pageSize.height * y);
@@ -153,9 +155,9 @@ mdc::CanvasView* model_Diagram::ImplData::get_canvas_view()
 
 //--------------------------------------------------------------------------------------------------
 
-mdc::Size model_Diagram::ImplData::get_size_for_page(const app_PageSettingsRef &page)
+Size model_Diagram::ImplData::get_size_for_page(const app_PageSettingsRef &page)
 {
-  mdc::Size size;
+  Size size;
 
   if (page.is_valid() && page->paperType().is_valid())
   {
@@ -192,11 +194,17 @@ void model_Diagram::ImplData::notify_object_realize(const model_ObjectRef &objec
 }
 
 
+void model_Diagram::ImplData::notify_object_will_unrealize(const model_ObjectRef &object)
+{
+  _will_unrealize_object_signal.emit(object);
+}
+
+
 void model_Diagram::ImplData::update_from_page_size()
 {
   if (_canvas_view)
   {
-    mdc::Size pageSize(get_size_for_page(_self->owner()->get_data()->get_page_settings()));
+    Size pageSize(get_size_for_page(_self->owner()->get_data()->get_page_settings()));
     _canvas_view->set_page_size(pageSize);
 
     mdc::Count xc, yc;
@@ -215,7 +223,7 @@ void model_Diagram::ImplData::update_size()
 {
   if (_canvas_view)
   {
-    mdc::Size pageSize(get_size_for_page(_self->owner()->get_data()->get_page_settings()));
+    Size pageSize(get_size_for_page(_self->owner()->get_data()->get_page_settings()));
 
     if (!is_main_thread())
       run_later(sigc::bind(sigc::mem_fun(_canvas_view, &mdc::CanvasView::set_page_size), pageSize));
@@ -248,7 +256,7 @@ void model_Diagram::ImplData::update_size()
 void model_Diagram::ImplData::realize_selection()
 {
   // apply selection state that was previously saved
-  _updating_selection++;
+  begin_selection_update();  
 
   for (size_t i= _self->_selection.count(); i > 0; --i)
   {
@@ -285,9 +293,7 @@ void model_Diagram::ImplData::realize_selection()
       g_warning("Unknown object in selection %s", object.class_name().c_str());
   }
 
-  _updating_selection--;
-
-  _selection_changed_signal.emit(model_DiagramRef(_self));
+  end_selection_update();  
   
   if (_canvas_view)
     g_return_if_fail(_canvas_view->get_selection()->get_contents().size() == _self->_selection.count());
@@ -422,14 +428,20 @@ void model_Diagram::ImplData::member_changed(const std::string &name, const grt:
     if (_canvas_view)
       _canvas_view->set_zoom((float)*_self->_zoom);
   }
-  else if (name == "pageSettings")
-  {
-    update_size();
-  }
-  else if (name == "width" || name == "height")
-  {
-    update_size();
-  }
+  else
+    if (name == "x" || name == "y")
+    {
+      if (_canvas_view)
+        _canvas_view->set_offset(MySQL::Geometry::Point(_self->_x, _self->_y));
+    }
+    else if (name == "pageSettings")
+    {
+      update_size();
+    }
+    else if (name == "width" || name == "height")
+    {
+      update_size();
+    }
 }
 
 
@@ -528,7 +540,7 @@ void model_Diagram::ImplData::select_object(const model_ObjectRef &object)
   {
     model_Figure::ImplData *elem= dynamic_cast<model_Figure::ImplData*>(object->get_data());
 
-    _updating_selection++;
+    begin_selection_update();  
     if (elem && elem->get_canvas_item())
       _canvas_view->get_selection()->add(elem->get_canvas_item());
 
@@ -540,7 +552,7 @@ void model_Diagram::ImplData::select_object(const model_ObjectRef &object)
   {
     model_Connection::ImplData *conn= dynamic_cast<model_Connection::ImplData*>(object->get_data());
 
-    _updating_selection++;
+    begin_selection_update();  
     if (conn && conn->get_canvas_item())
       _canvas_view->get_selection()->add(conn->get_canvas_item());
 
@@ -552,7 +564,7 @@ void model_Diagram::ImplData::select_object(const model_ObjectRef &object)
   {
     model_Layer::ImplData *layer= dynamic_cast<model_Layer::ImplData*>(object->get_data());
 
-    _updating_selection++;
+    begin_selection_update();  
     if (layer && layer->get_area_group())
       _canvas_view->get_selection()->add(layer->get_area_group());
 
@@ -562,10 +574,8 @@ void model_Diagram::ImplData::select_object(const model_ObjectRef &object)
   }
   else
     throw std::runtime_error("trying to select invalid object");
-
-  _updating_selection--;
   
-  _selection_changed_signal.emit(model_DiagramRef(_self));
+  end_selection_update();
 }
 
 
@@ -575,7 +585,7 @@ void model_Diagram::ImplData::unselect_object(const model_ObjectRef &object)
   {
     model_Figure::ImplData *elem= dynamic_cast<model_Figure::ImplData*>(object->get_data());
 
-    _updating_selection++;
+    begin_selection_update();
     if (elem && elem->get_canvas_item())
       _canvas_view->get_selection()->remove(elem->get_canvas_item());
     
@@ -587,7 +597,7 @@ void model_Diagram::ImplData::unselect_object(const model_ObjectRef &object)
   {
     model_Connection::ImplData *conn= dynamic_cast<model_Connection::ImplData*>(object->get_data());
     
-    _updating_selection++;
+    begin_selection_update();
     if (conn && conn->get_canvas_item())
       _canvas_view->get_selection()->remove(conn->get_canvas_item());
 
@@ -599,7 +609,7 @@ void model_Diagram::ImplData::unselect_object(const model_ObjectRef &object)
   {
     model_Layer::ImplData *layer= dynamic_cast<model_Layer::ImplData*>(object->get_data());
 
-    _updating_selection++;
+    begin_selection_update();
     if (layer && layer->get_area_group())
       _canvas_view->get_selection()->remove(layer->get_area_group());
 
@@ -610,15 +620,13 @@ void model_Diagram::ImplData::unselect_object(const model_ObjectRef &object)
   else
     throw std::runtime_error("trying to deselect invalid object");
   
-  _updating_selection--;
-  
-  _selection_changed_signal.emit(model_DiagramRef(_self));
+  end_selection_update();
 }
 
 
 void model_Diagram::ImplData::unselect_all()
 {
-  _updating_selection++;
+  begin_selection_update();
 
   _canvas_view->get_selection()->clear();
 
@@ -627,66 +635,78 @@ void model_Diagram::ImplData::unselect_all()
     _self->_selection.remove(0);
   _self->get_grt()->get_undo_manager()->enable();
 
-  _updating_selection--;
-  
-  _selection_changed_signal.emit(model_DiagramRef(_self));
+  end_selection_update();  
 }
 
+/**
+ * Increases the selection lock count and returns true if the caller can continue.
+ */
+bool model_Diagram::ImplData::begin_selection_update()
+{
+  return ++_updating_selection == 1;
+}
+
+/**
+ * Removes one lock level from the selection lock and triggers the change event if
+ * it reaches 0.
+ */
+void model_Diagram::ImplData::end_selection_update()
+{
+  _updating_selection--;
+  if (_updating_selection == 0)
+    _selection_changed_signal.emit(model_DiagramRef(_self));
+}
 
 void model_Diagram::ImplData::canvas_selection_changed(bool added, mdc::CanvasItem *item)
 {
-  if (_updating_selection)
-    return;
-  
-  _updating_selection++;
-  if (added)
+  if (begin_selection_update())
   {
-    model_ObjectRef object;
-
-    if (item)
+    if (added)
     {
-      object= find_object_in_list(_self->_figures, item->get_tag());
-      if (!object.is_valid())
-        object= find_object_in_list(_self->_connections, item->get_tag());
-      if (!object.is_valid())
-        object= find_object_in_list(_self->_layers, item->get_tag());
+      model_ObjectRef object;
 
-      if (object.is_valid())
+      if (item)
+      {
+        object= find_object_in_list(_self->_figures, item->get_tag());
+        if (!object.is_valid())
+          object= find_object_in_list(_self->_connections, item->get_tag());
+        if (!object.is_valid())
+          object= find_object_in_list(_self->_layers, item->get_tag());
+
+        if (object.is_valid())
+        {
+          _self->get_grt()->get_undo_manager()->disable();
+          if (!find_object_in_list(_self->_selection, item->get_tag()).is_valid())
+            _self->_selection.insert(object);
+          _self->get_grt()->get_undo_manager()->enable();
+        }
+      }
+      else abort();
+    }
+    else // removed
+    {
+      if (item)
+      {
+        model_ObjectRef object(find_object_in_list(_self->_selection, item->get_tag()));
+
+        _self->get_grt()->get_undo_manager()->disable();
+        if (object.is_valid())
+          _self->_selection.remove_value(object);
+        _self->get_grt()->get_undo_manager()->enable();
+      }
+      else
       {
         _self->get_grt()->get_undo_manager()->disable();
-        if (!find_object_in_list(_self->_selection, item->get_tag()).is_valid())
-          _self->_selection.insert(object);
+        while (_self->_selection.count() > 0)
+          _self->_selection.remove(0);
         _self->get_grt()->get_undo_manager()->enable();
       }
     }
-    else abort();
   }
-  else // removed
-  {
-    if (item)
-    {
-      model_ObjectRef object(find_object_in_list(_self->_selection, item->get_tag()));
 
-      _self->get_grt()->get_undo_manager()->disable();
-      if (object.is_valid())
-        _self->_selection.remove_value(object);
-      _self->get_grt()->get_undo_manager()->enable();
-    }
-    else
-    {
-      _self->get_grt()->get_undo_manager()->disable();
-      while (_self->_selection.count() > 0)
-        _self->_selection.remove(0);
-      _self->get_grt()->get_undo_manager()->enable();
-    }
-  }
-  _updating_selection--;
-
-  _selection_changed_signal.emit(model_DiagramRef(_self));
+  end_selection_update();
 }
 
-
-
 static mdc::CanvasItem *get_first_realized_layer_under(const grt::ListRef<model_Layer> &list,
                                                 const model_LayerRef &layer)
 {
@@ -791,7 +811,7 @@ void model_Diagram::ImplData::stack_figure(const model_FigureRef &figure, mdc::C
 
 model_LayerRef model_Diagram::ImplData::get_layer_under_figure(const model_FigureRef &figure)
 {
-  mdc::Rect bounds;
+  Rect bounds;
 
   mdc::CanvasItem *item= figure->get_data()->get_canvas_item();
   if (item)
@@ -816,7 +836,7 @@ model_LayerRef model_Diagram::ImplData::get_layer_under_figure(const model_Figur
   for (grt::ListRef<model_Layer>::const_reverse_iterator it= _self->layers().rbegin(); it != _self->layers().rend(); ++it)
   {
     model_LayerRef layer(*it);
-    mdc::Rect layerBounds;
+    Rect layerBounds;
 
     layerBounds.pos.x= layer->left();
     layerBounds.pos.y= layer->top();
@@ -856,7 +876,7 @@ bool model_Diagram::ImplData::update_layer_of_figure(const model_FigureRef &figu
       // if figure stays in same layer as before, make sure that it has correct canvas parent
       if (item && parent && item->get_parent() != parent)
       {
-        mdc::Point pos= item->get_root_position() - parent->get_root_position();
+        Point pos= item->get_root_position() - parent->get_root_position();
         parent->add(item);
         item->move_to(pos);
       }
@@ -887,7 +907,7 @@ bool model_Diagram::ImplData::update_layer_of_figure(const model_FigureRef &figu
 //--------------------------------------------------------------------------------------------------
 
 bool model_Diagram::ImplData::figure_click(const model_ObjectRef &owner, mdc::CanvasItem *target,
-                                           const mdc::Point &point, mdc::MouseButton button,
+                                           const Point &point, mdc::MouseButton button,
                                            mdc::EventState state)
 {
   _item_click_signal.emit(owner, target, point, button, state);
@@ -898,7 +918,7 @@ bool model_Diagram::ImplData::figure_click(const model_ObjectRef &owner, mdc::Ca
 //--------------------------------------------------------------------------------------------------
 
 bool model_Diagram::ImplData::figure_double_click(const model_ObjectRef &owner, mdc::CanvasItem *target,
-                                                  const mdc::Point &point, mdc::MouseButton button,
+                                                  const Point &point, mdc::MouseButton button,
                                                   mdc::EventState state)
 {
   _item_double_click_signal.emit(owner, target, point, button, state);
@@ -908,7 +928,7 @@ bool model_Diagram::ImplData::figure_double_click(const model_ObjectRef &owner,
 
 //--------------------------------------------------------------------------------------------------
 
-bool model_Diagram::ImplData::figure_button_press(const model_ObjectRef &owner, mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool model_Diagram::ImplData::figure_button_press(const model_ObjectRef &owner, mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   _item_mouse_button_signal.emit(owner, target, true, point, button, state);
   
@@ -916,7 +936,7 @@ bool model_Diagram::ImplData::figure_button_press(const model_ObjectRef &owner,
 }
 
 
-bool model_Diagram::ImplData::figure_button_release(const model_ObjectRef &owner, mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool model_Diagram::ImplData::figure_button_release(const model_ObjectRef &owner, mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   _item_mouse_button_signal.emit(owner, target, false, point, button, state);
   
@@ -924,7 +944,7 @@ bool model_Diagram::ImplData::figure_button_release(const model_ObjectRef &owner
 }
 
 
-bool model_Diagram::ImplData::figure_enter(const model_ObjectRef &owner, mdc::CanvasItem *target, const mdc::Point &point)
+bool model_Diagram::ImplData::figure_enter(const model_ObjectRef &owner, mdc::CanvasItem *target, const Point &point)
 {
   _item_crossed_signal.emit(owner, target, true, point);
   
@@ -932,7 +952,7 @@ bool model_Diagram::ImplData::figure_enter(const model_ObjectRef &owner, mdc::Ca
 }
 
 
-bool model_Diagram::ImplData::figure_leave(const model_ObjectRef &owner, mdc::CanvasItem *target, const mdc::Point &point)
+bool model_Diagram::ImplData::figure_leave(const model_ObjectRef &owner, mdc::CanvasItem *target, const Point &point)
 {
   _item_crossed_signal.emit(owner, target, false, point);
   
@@ -948,7 +968,7 @@ static void update_badge(const std::string &name, const ValueRef& ovalue, const
   }
   else if (name == "color")
   {
-    badge->set_gradient_from_color(mdc::Color::parse(tag->color()));
+    badge->set_gradient_from_color(Color::parse(tag->color()));
   }
 }
 
@@ -959,8 +979,8 @@ void model_Diagram::ImplData::add_tag_badge_to_figure(const model_FigureRef &fig
 
   badge->set_badge_id(tag->id());
   badge->set_text(tag->label());
-  badge->set_gradient_from_color(mdc::Color::parse(*tag->color()));
-  badge->set_text_color(mdc::Color::parse("#ffffff"));
+  badge->set_gradient_from_color(Color::parse(*tag->color()));
+  badge->set_text_color(Color::parse("#ffffff"));
 
   badge->updater_connection=
     tag->signal_changed().connect(sigc::bind(sigc::ptr_fun(&update_badge), tag, badge));
