@@ -69,7 +69,7 @@ void model_Model::ImplData::option_changed(grt::internal::OwnedDict *dict,
   if (!_reset_pending && bec::has_suffix(option, "Font"))
   {
     _reset_pending= true;
-    run_later(sigc::mem_fun(this, &model_Model::ImplData::reset_figures));
+//    run_later(sigc::mem_fun(this, &model_Model::ImplData::reset_figures));
     run_later(sigc::mem_fun(this, &model_Model::ImplData::reset_layers));
     run_later(sigc::mem_fun(this, &model_Model::ImplData::reset_connections));
   }
