@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,6 +21,8 @@
 #include "routine_group_figure.h"
 
 using namespace wbfig;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 RoutineGroup::RoutineGroup(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &self)
 : BaseFigure(layer, hub, self), _title(layer, hub, this, true), _footer(layer, hub, this, false),
@@ -34,9 +36,9 @@ RoutineGroup::RoutineGroup(mdc::Layer *layer, FigureEventHub *hub, const model_O
   set_accepts_focus(true);
   set_accepts_selection(true);
 
-  set_border_color(mdc::Color(0.5, 0.5, 0.5));
+  set_border_color(Color(0.5, 0.5, 0.5));
   set_draw_background(true);
-  set_background_color(mdc::Color::White());
+  set_background_color(Color::White());
   set_background_corners(mdc::CAll, 8.0);
 
   _title.set_rounded(mdc::CTop);
@@ -45,7 +47,7 @@ RoutineGroup::RoutineGroup(mdc::Layer *layer, FigureEventHub *hub, const model_O
   _title.set_has_shadow(true);
   _title.set_title("View");
   _title.set_font(mdc::FontSpec("Helvetica", mdc::SNormal, mdc::WBold, 12));
-  _title.set_color(mdc::Color(0.59, 0.85, 0.59));
+  _title.set_color(Color(0.59, 0.85, 0.59));
   add(&_title, false, false, true);
 
   _content_box.set_spacing(1);
@@ -57,8 +59,8 @@ RoutineGroup::RoutineGroup(mdc::Layer *layer, FigureEventHub *hub, const model_O
   _footer.set_has_shadow(true);
   _footer.set_title("0 routines");
   _footer.set_font(mdc::FontSpec("Helvetica", mdc::SNormal, mdc::WNormal, 9));
-  _footer.set_text_color(mdc::Color(0.5, 0.5, 0.5));
-  _footer.set_color(mdc::Color(0.59, 0.85, 0.59));
+  _footer.set_text_color(Color(0.5, 0.5, 0.5));
+  _footer.set_color(Color(0.59, 0.85, 0.59));
   add(&_footer, false, false, true);
 }
 
@@ -92,7 +94,7 @@ void RoutineGroup::set_content_font(const mdc::FontSpec &font)
 }
 
 
-void RoutineGroup::set_color(const mdc::Color &color)
+void RoutineGroup::set_color(const Color &color)
 {
   _title.set_color(color);
   _footer.set_color(color);
