@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,7 +28,8 @@
  */
 
 using namespace wbfig;
-
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 ItemMagnet::ItemMagnet(mdc::CanvasItem *owner)
 : mdc::Magnet(owner)
@@ -44,41 +45,41 @@ double ItemMagnet::constrain_angle(double angle) const
 }
 
 
-void ItemMagnet::owner_parent_bounds_changed(mdc::CanvasItem *item, const mdc::Rect &obounds)
+void ItemMagnet::owner_parent_bounds_changed(mdc::CanvasItem *item, const Rect &obounds)
 {
   /*
   if (_owner->get_parents_visible())
   {
-    mdc::Rect bounds(_owner->get_root_bounds());
+    Rect bounds(_owner->get_root_bounds());
 
-    set_position(mdc::Point(bounds.xmin()+bounds.width()/2,
+    set_position(Point(bounds.xmin()+bounds.width()/2,
                             bounds.ymin()+bounds.height()/2));
   }
   else
   {
-    mdc::Rect bounds(_owner->get_toplevel()->get_root_bounds());
+    Rect bounds(_owner->get_toplevel()->get_root_bounds());
 
-    set_position(mdc::Point(bounds.xmin()+bounds.width()/2,
+    set_position(Point(bounds.xmin()+bounds.width()/2,
                             bounds.ymin()+bounds.height()/2));
   }*/
   notify_connected();
 }
 
 
-void ItemMagnet::owner_bounds_changed(const mdc::Rect &obounds)
+void ItemMagnet::owner_bounds_changed(const Rect &obounds)
 {/*
   if (_owner->get_parents_visible())
   {
-    mdc::Rect bounds(_owner->get_root_bounds());
+    Rect bounds(_owner->get_root_bounds());
 
-    set_position(mdc::Point(bounds.xmin()+bounds.width()/2,
+    set_position(Point(bounds.xmin()+bounds.width()/2,
                             bounds.ymin()+bounds.height()/2));
   }
   else
   {
-    mdc::Rect bounds(_owner->get_toplevel()->get_root_bounds());
+    Rect bounds(_owner->get_toplevel()->get_root_bounds());
 
-    set_position(mdc::Point(bounds.xmin()+bounds.width()/2,
+    set_position(Point(bounds.xmin()+bounds.width()/2,
                             bounds.ymin()+bounds.height()/2));
   }*/
   notify_connected();
@@ -105,9 +106,9 @@ void TableColumnItem::set_column_flags(ColumnFlags flags)
 }
 
 
-mdc::Size TableColumnItem::calc_min_size()
+Size TableColumnItem::calc_min_size()
 {
-  mdc::Size size= FigureItem::calc_min_size();
+  Size size= FigureItem::calc_min_size();
   cairo_text_extents_t extents;
   mdc::CairoCtx *cr= get_layer()->get_view()->cairoctx();
 
@@ -137,9 +138,9 @@ void TableColumnItem::draw_contents(mdc::CairoCtx *cr)
   FigureItem::draw_contents(cr);
 
   cairo_text_extents_t extents;
-  mdc::Size text_size(get_text_size());
-  mdc::Point pos(get_position());
-  mdc::Size size(get_size());
+  Size text_size(get_text_size());
+  Point pos(get_position());
+  Size size(get_size());
   float max_x;
 
   if (text_size.width >= size.width - 2*_xpadding)
@@ -246,7 +247,7 @@ bool Table::compare_connection_position(mdc::Connector *a, mdc::Connector *b,
                                         mdc::BoxSideMagnet::Side side)
 {
   wbfig::ConnectionLineLayouter *layouter;
-  mdc::Point a_pos, b_pos;
+  Point a_pos, b_pos;
   mdc::CanvasItem *item;
   mdc::Connector *a_conn, *b_conn;
 
