@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,6 +22,8 @@
 
 using namespace mdc;
 using namespace wbfig;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 void Separator::draw_contents(mdc::CairoCtx *cr)
 {
@@ -38,19 +40,19 @@ void Separator::draw_contents(mdc::CairoCtx *cr)
     cr->line_to(get_size().width, 0.5);
   }
   cr->set_line_width(1);
-  cr->set_color(mdc::Color::Black());
+  cr->set_color(Color::Black());
   cr->stroke();
 }
 
 
-mdc::Size Separator::calc_min_size()
+Size Separator::calc_min_size()
 {
   if (_top_empty && _bottom_empty)
-    return mdc::Size(80, 40);
+    return Size(80, 40);
   else if (_top_empty || _bottom_empty)
-    return mdc::Size(80, 20);
+    return Size(80, 20);
   else
-    return mdc::Size(80, 2);
+    return Size(80, 2);
 }
 
 
@@ -84,18 +86,18 @@ Idef1xTable::Idef1xTable(mdc::Layer *layer, FigureEventHub *hub, const model_Obj
   
   _column_box.set_spacing(1);
   
-  _column_box.set_border_color(mdc::Color::Black());
-  _column_box.set_background_color(mdc::Color::White());
+  _column_box.set_border_color(Color::Black());
+  _column_box.set_background_color(Color::White());
   _column_box.set_draw_background(true);
   
-  set_background_color(mdc::Color::White());
+  set_background_color(Color::White());
   set_draw_background(true);
   
   add(&_column_box, true, true, true);
 }
 
 
-void Idef1xTable::set_color(const mdc::Color &color)
+void Idef1xTable::set_color(const Color &color)
 {
   _column_box.set_background_color(color);
   set_background_color(color);
