@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,7 +22,8 @@
 
 using namespace wbfig;
 using namespace mdc;
-
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 SimpleTable::SimpleTable(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &self)
   : Table(layer, hub, self, false), _column_box(layer, mdc::Box::Vertical)
@@ -33,15 +34,15 @@ SimpleTable::SimpleTable(mdc::Layer *layer, FigureEventHub *hub, const model_Obj
   magnetize_bounds();
   
   add(&_title, false, true, true);
-  _title.set_border_color(mdc::Color::Black());
+  _title.set_border_color(Color::Black());
   _title.set_font(mdc::FontSpec(_title.get_font().family, mdc::SNormal, mdc::WNormal, 12));
   
   _column_box.set_spacing(1);
   
   //_column_box.set_fixed_min_size(mdc::Size(-1, 20));
 
-  set_border_color(mdc::Color::Black());
-  set_background_color(mdc::Color::White());
+  set_border_color(Color::Black());
+  set_background_color(Color::White());
   set_draw_background(true);
 
   _barker= false;
@@ -50,7 +51,7 @@ SimpleTable::SimpleTable(mdc::Layer *layer, FigureEventHub *hub, const model_Obj
 }
 
 
-void SimpleTable::set_color(const mdc::Color &color)
+void SimpleTable::set_color(const Color &color)
 {
   set_background_color(color);
   set_needs_render();
