@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,9 +22,9 @@
 
 #include "table_figure_wb.h"
 
-
 using namespace wbfig;
-
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 WBTable::WBTable(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &self)
   : Table(layer, hub, self, true), 
@@ -36,8 +36,8 @@ WBTable::WBTable(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &
 {
   _title.signal_expand_toggle().connect(sigc::mem_fun(this, &WBTable::toggle));
 
-  _index_title.signal_expand_toggle().connect(sigc::mem_fun(this, &WBTable::toggle_indexes));
-  _trigger_title.signal_expand_toggle().connect(sigc::mem_fun(this, &WBTable::toggle_triggers));
+//  _index_title.signal_expand_toggle().connect(sigc::mem_fun(this, &WBTable::toggle_indexes));
+//  _trigger_title.signal_expand_toggle().connect(sigc::mem_fun(this, &WBTable::toggle_triggers));
 
   _title.set_icon(mdc::ImageManager::get_instance()->get_image("workbench.physical.TableFigure.16x16.png"));
 
@@ -50,8 +50,8 @@ WBTable::WBTable(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &
   
   set_draw_background(true);
   set_background_corners(mdc::CAll, 8.0);
-  set_background_color(mdc::Color::White());
-  set_border_color(mdc::Color(0.5, 0.5, 0.5));
+  set_background_color(Color::White());
+  set_border_color(Color(0.5, 0.5, 0.5));
 
 
   _title.set_rounded(mdc::CTop);
@@ -59,23 +59,23 @@ WBTable::WBTable(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &
   _title.set_expanded(true);
   _title.set_title("Table");
   _title.set_font(mdc::FontSpec("Helvetica", mdc::SNormal, mdc::WBold, 12));
-  _title.set_color(mdc::Color(0.59, 0.75, 0.85));
+  _title.set_color(Color(0.59, 0.75, 0.85));
 
   _index_title.set_title("Indexes");
-  _index_title.set_color(mdc::Color(0.77, 0.77, 0.77));
-  _index_title.set_text_color(mdc::Color::White());
+  _index_title.set_color(Color(0.77, 0.77, 0.77));
+  _index_title.set_text_color(Color::White());
   _index_title.set_font(mdc::FontSpec("Helvetica", mdc::SNormal, mdc::WBold, 11));
 
   _trigger_title.set_title("Triggers");
-  _trigger_title.set_color(mdc::Color(0.77, 0.77, 0.77));
-  _trigger_title.set_text_color(mdc::Color::White());
+  _trigger_title.set_color(Color(0.77, 0.77, 0.77));
+  _trigger_title.set_text_color(Color::White());
   _trigger_title.set_font(mdc::FontSpec("Helvetica", mdc::SNormal, mdc::WBold, 11));
 
   _index_title.set_visible(false);
   _trigger_title.set_visible(false);
 
-  _footer.set_fixed_min_size(mdc::Size(-1, 8));
-  _footer.set_color(mdc::Color(0.59, 0.75, 0.85));
+  _footer.set_fixed_min_size(Size(-1, 8));
+  _footer.set_color(Color(0.59, 0.75, 0.85));
   _footer.set_rounded(mdc::CBottom);
 
   add(&_title, false, false, true);
@@ -106,7 +106,7 @@ WBTable::~WBTable()
 }
 
 
-void WBTable::set_color(const mdc::Color &color)
+void WBTable::set_color(const Color &color)
 {
   _title.set_color(color);
   _footer.set_color(color);
@@ -174,7 +174,7 @@ void WBTable::toggle(bool flag)
 
     if (_manual_resizing)
     {
-      mdc::Size size(get_size());
+      Size size(get_size());
 
       size.height= size.height - _column_box.get_size().height + _original_column_box_height;
 
@@ -228,8 +228,8 @@ void WBTable::toggle_indexes(bool flag)
   _index_title.set_expanded(flag);
   if (!_hide_indexes)
   {
-    mdc::Size size(get_size());
-    mdc::Size index_size(_index_box.get_size());
+    Size size(get_size());
+    Size index_size(_index_box.get_size());
 
     _index_box.set_visible(flag);
 
@@ -238,7 +238,6 @@ void WBTable::toggle_indexes(bool flag)
       if (flag)
       {
         relayout();
-
         size.height+= _index_box.get_size().height;
       }
       else
@@ -254,8 +253,8 @@ void WBTable::toggle_triggers(bool flag)
   _trigger_title.set_expanded(flag);
   if (!_hide_triggers)
   {
-    mdc::Size size(get_size());
-    mdc::Size trigger_size(_trigger_box.get_size());
+    Size size(get_size());
+    Size trigger_size(_trigger_box.get_size());
 
     _trigger_box.set_visible(flag);
 
