@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,6 +24,8 @@
 #include "model_model_impl.h"
 #include "model_diagram_impl.h"
 
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 workbench_model_ImageFigure::ImplData::ImplData(workbench_model_ImageFigure *self)
   : super(self), _figure(0), _thumbnail(0)
@@ -100,7 +102,7 @@ void workbench_model_ImageFigure::ImplData::set_keep_aspect_ratio(bool flag)
     if (__height < 1)
       __height= 1;
 
-    _figure->set_fixed_size(mdc::Size(__width, __height));
+    _figure->set_fixed_size(Size(__width, __height));
   }
   else if (_figure && name == "height" && *__keepAspectRatio!=0)
   {
@@ -111,12 +113,14 @@ void workbench_model_ImageFigure::ImplData::set_keep_aspect_ratio(bool flag)
     if (__width < 1)
       __width= 1;
 
-    _figure->set_fixed_size(mdc::Size(__width, __height));
+    _figure->set_fixed_size(Size(__width, __height));
   }*/
 
 
 void workbench_model_ImageFigure::ImplData::unrealize()
 {
+  notify_will_unrealize();
+  
   super::unrealize();
   
   delete _figure;
@@ -130,8 +134,8 @@ void workbench_model_ImageFigure::ImplData::unrealize()
 
 bool workbench_model_ImageFigure::ImplData::shrink_if_needed()
 {
-  mdc::Size size(_figure->calc_min_size());
-  mdc::Size max_size(get_canvas_view()->get_total_view_size());
+  Size size(_figure->calc_min_size());
+  Size max_size(get_canvas_view()->get_total_view_size());
   bool resized= false;
 
   max_size.width-= 20;
@@ -219,7 +223,7 @@ void workbench_model_ImageFigure::ImplData::render_mini(mdc::CairoCtx *cr)
 {
   if (!_thumbnail && _figure && _figure->get_image())
   {
-    mdc::Size image_size= _figure->get_size();
+    Size image_size= _figure->get_size();
     
     // Create a thumbnail and remember the scale used.
     if (image_size.width > 256)
@@ -234,7 +238,7 @@ void workbench_model_ImageFigure::ImplData::render_mini(mdc::CairoCtx *cr)
       _thumbnail= cairo_surface_create_similar(_figure->get_image(), CAIRO_CONTENT_COLOR_ALPHA, w, h);
       mdc::CairoCtx cr(_thumbnail);
       
-      cr.set_color(mdc::Color(1.0, 1.0, 1.0), 0.0);
+      cr.set_color(Color(1.0, 1.0, 1.0), 0.0);
       cr.paint();
       cr.scale(image_size.width/w, image_size.height/h);
       cr.set_source_surface(_figure->get_image(), 0.0, 0.0);
