@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,6 +30,8 @@
 
 #include "model_diagram_impl.h"
 
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 /*
 
@@ -284,7 +286,7 @@ void workbench_physical_Connection::ImplData::fk_member_changed(const std::strin
 }
 
 
-void workbench_physical_Connection::ImplData::caption_bounds_changed(const mdc::Rect &obounds, mdc::TextFigure *figure)
+void workbench_physical_Connection::ImplData::caption_bounds_changed(const Rect &obounds, mdc::TextFigure *figure)
 {
   if (!figure->is_dragging())
     return;
@@ -495,11 +497,16 @@ bool workbench_physical_Connection::ImplData::realize()
 
 void workbench_physical_Connection::ImplData::unrealize()
 {
-  if (_highlighting)
-    set_highlighted(false);
-
-  if (_table_changed_conn)
-    _table_changed_conn.disconnect();
-
-  super::unrealize();
+  if (_line)
+  {
+    notify_will_unrealize();
+    
+    if (_highlighting)
+      set_highlighted(false);
+    
+    if (_table_changed_conn)
+      _table_changed_conn.disconnect();
+    
+    super::unrealize();
+  }
 }
