@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -55,7 +55,7 @@ protected:
   virtual mdc::CanvasItem *get_start_canvas_item();
   virtual mdc::CanvasItem *get_end_canvas_item();
 
-  virtual void caption_bounds_changed(const mdc::Rect &obounds, mdc::TextFigure *figure);
+  virtual void caption_bounds_changed(const MySQL::Geometry::Rect &obounds, mdc::TextFigure *figure);
 
   void fk_member_changed(const std::string &member, const grt::ValueRef &ovalue);
 
