@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,6 +28,8 @@
 #include "base/string_utilities.h"
 
 using namespace base;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 workbench_physical_RoutineGroupFigure::ImplData::ImplData(workbench_physical_RoutineGroupFigure *self)
   : super(self), _figure(0)
@@ -144,6 +146,9 @@ bool workbench_physical_RoutineGroupFigure::ImplData::is_realizable()
 void workbench_physical_RoutineGroupFigure::ImplData::unrealize()
 {
   workbench_physical_ModelRef model(workbench_physical_ModelRef::cast_from(self()->owner()->owner()));
+  
+  notify_will_unrealize();
+  
   // remove tag badges
   std::list<meta_TagRef> tags(model->get_data()->get_tags_for_dbobject(self()->_routineGroup));
   for (std::list<meta_TagRef>::const_iterator end= tags.end(), tag= tags.begin();
@@ -185,7 +190,7 @@ bool workbench_physical_RoutineGroupFigure::ImplData::realize()
     
     view->get_current_layer()->add_item(_figure, agroup);
     
-    _figure->set_color(mdc::Color::parse(*self()->_color));
+    _figure->set_color(Color::parse(*self()->_color));
 
     _figure->set_title(*self()->_name, strfmt("%i routines", (int) self()->_routineGroup->routines().count()));
 
