@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -34,6 +34,8 @@
 #include "base/string_utilities.h"
 
 using namespace base;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 workbench_physical_TableFigure::ImplData::ImplData(workbench_physical_TableFigure *self)
   : super(self), _figure(0)
@@ -414,6 +416,9 @@ bool workbench_physical_TableFigure::ImplData::is_realizable()
 void workbench_physical_TableFigure::ImplData::unrealize()
 {
   workbench_physical_ModelRef model(workbench_physical_ModelRef::cast_from(self()->owner()->owner()));
+  
+  notify_will_unrealize();
+  
   // remove tag badges
   std::list<meta_TagRef> tags(model->get_data()->get_tags_for_dbobject(self()->_table));
   for (std::list<meta_TagRef>::const_iterator end= tags.end(), tag= tags.begin();
@@ -456,7 +461,7 @@ bool workbench_physical_TableFigure::ImplData::realize()
 
     view->get_current_layer()->add_item(_figure, agroup);
 
-    _figure->set_color(mdc::Color::parse(*self()->_color));
+    _figure->set_color(Color::parse(*self()->_color));
     
     _figure->get_title()->set_title(*self()->_table->name());
 
@@ -567,7 +572,7 @@ db_IndexRef workbench_physical_TableFigure::ImplData::get_index_at(mdc::CanvasIt
 }
 
 
-void workbench_physical_TableFigure::ImplData::set_column_highlighted(const db_ColumnRef &column, const mdc::Color *color)
+void workbench_physical_TableFigure::ImplData::set_column_highlighted(const db_ColumnRef &column, const Color *color)
 {
   if (_figure)
   {
