@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -89,7 +89,7 @@ public:
   db_ColumnRef get_column_at(mdc::CanvasItem *item);
   db_IndexRef get_index_at(mdc::CanvasItem *item);
   
-  void set_column_highlighted(const db_ColumnRef &column, const mdc::Color *color= 0);
+  void set_column_highlighted(const db_ColumnRef &column, const MySQL::Drawing::Color *color= 0);
   void set_column_unhighlighted(const db_ColumnRef &column);
   
   virtual mdc::CanvasItem* get_canvas_item() const { return _figure; }
