@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,6 +25,8 @@
 #include "workbench_physical_model_impl.h"
 #include "workbench_physical_diagram_impl.h"
 
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 workbench_physical_ViewFigure::ImplData::ImplData(workbench_physical_ViewFigure *owner)
   : super(owner), _figure(0)
@@ -139,6 +141,9 @@ bool workbench_physical_ViewFigure::ImplData::is_realizable()
 void workbench_physical_ViewFigure::ImplData::unrealize()
 {
   workbench_physical_ModelRef model(workbench_physical_ModelRef::cast_from(self()->owner()->owner()));
+  
+  notify_will_unrealize();
+  
   // remove tag badges
   std::list<meta_TagRef> tags(model->get_data()->get_tags_for_dbobject(self()->_view));
   for (std::list<meta_TagRef>::const_iterator end= tags.end(), tag= tags.begin();
@@ -183,7 +188,7 @@ bool workbench_physical_ViewFigure::ImplData::realize()
 
     view->get_current_layer()->add_item(_figure, agroup);
     
-    _figure->set_color(mdc::Color::parse(*self()->_color));
+    _figure->set_color(Color::parse(*self()->_color));
 
     _figure->set_title(*self()->_view->name());
     
