@@ -38,6 +38,9 @@ namespace SysUtils {
     static void Copy(ComboBox^ box);
     static void Paste(ComboBox^ box);
     static bool CanUndo(ComboBox^ box);
+
+    static bool UnblockWorkbenchFiles(String^ folder);
+    static bool UnblockFile(String^ file);
   };
 
 } // SysUtilits
