@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,14 +25,20 @@
 #include <vector>
 #include <list>
 
+#include "base/drawing.h"
+
 using namespace System;
 using namespace System::Text;
 using namespace System::Collections::Generic;
+using namespace System::Drawing;
 
 namespace MySQL {
   
 static String^ CppStringToNative(const std::string &str)
 {
+  if (str.length() == 0)
+    return "";
+
   if (str.find('\r') == std::string::npos)
   {
     // convert from \n to \r\n (but don't double-convert \r\n to \r\r\n)
@@ -45,13 +51,16 @@ static String^ CppStringToNative(const std::string &str)
 
 static String^ CppStringToNativeRaw(const std::string &str)
 {
+  if (str.length() == 0)
+    return "";
+
   return gcnew String(str.c_str(), 0, (int) str.size(), Encoding::UTF8);
 }
 
 
 static std::string NativeToCppString(String^ str)
 {
-  if (str == nullptr)
+  if (str == nullptr || str->Length == 0)
     return "";
 
   array<unsigned char>^ chars= Encoding::UTF8->GetBytes(str->Replace("\r\n", "\n"));
@@ -65,7 +74,7 @@ static std::string NativeToCppString(String^ str)
 
 static std::string NativeToCppStringRaw(String^ str)
 {
-  if (str == nullptr)
+  if (str == nullptr || str->Length == 0)
     return "";
 
   array<unsigned char>^ chars= Encoding::UTF8->GetBytes(str);
@@ -144,6 +153,14 @@ static std::vector<int> IntListToCppVector(List<int>^ input)
   return result;
 }
 
+//--------------------------------------------------------------------------------------------------
+
+static MySQL::Drawing::Color NativeToColor(System::Drawing::Color^ color)
+{
+  return MySQL::Drawing::Color(color->R / 255.0, color->G / 255.0, color->B / 255.0, color->A / 255.0);
+}
+//--------------------------------------------------------------------------------------------------
+
 } // namespace MySQL
 
 #endif // __CONV_UTILS_H__
