@@ -20,6 +20,7 @@ static NSCursor* waitCursor;
 #define INPUT_INDICATOR INDIC_MAX - 1
 
 NSString *SCIUpdateUINotification = @"SCIUpdateUI";
+NSString *SCIMarginClickNotification = @"SCIMarginClick";
 
 @implementation InnerView
 
@@ -288,6 +289,9 @@ NSString *SCIUpdateUINotification = @"SCIUpdateUI";
     currentPosition = mMarkedTextRange.location;
   }
 
+  // Keep Scintilla from collecting undo actions for the composition task.
+  [mOwner setGeneralProperty: SCI_SETUNDOCOLLECTION value: 0];
+  
   // Note: Scintilla internally works almost always with bytes instead chars, so we need to take
   //       this into account when determining selection ranges and such.
   std::string raw_text = [newText UTF8String];
@@ -296,12 +300,18 @@ NSString *SCIUpdateUINotification = @"SCIUpdateUI";
   mMarkedTextRange.location = currentPosition;
   mMarkedTextRange.length = raw_text.size();
     
-  // Mark the just inserted text. Keep the marked range for later reset.
-  [mOwner setGeneralProperty: SCI_SETINDICATORCURRENT value: INPUT_INDICATOR];
-  [mOwner setGeneralProperty: SCI_INDICATORFILLRANGE
-                   parameter: mMarkedTextRange.location
-                       value: mMarkedTextRange.length];
-  
+  if (mMarkedTextRange.length > 0)
+  {
+    // Mark the just inserted text. Keep the marked range for later reset.
+    [mOwner setGeneralProperty: SCI_SETINDICATORCURRENT value: INPUT_INDICATOR];
+    [mOwner setGeneralProperty: SCI_INDICATORFILLRANGE
+                     parameter: mMarkedTextRange.location
+                         value: mMarkedTextRange.length];
+  }
+  else
+    // Re-enable undo action collection if composition ended (indicated by an empty mark string).
+    [mOwner setGeneralProperty: SCI_SETUNDOCOLLECTION value: range.length == 0];
+ 
   // Select the part which is indicated in the given range. It does not scroll the caret into view.
   if (range.length > 0)
   {
@@ -323,6 +333,9 @@ NSString *SCIUpdateUINotification = @"SCIUpdateUI";
                      parameter: mMarkedTextRange.location
                          value: mMarkedTextRange.length];
     mMarkedTextRange = NSMakeRange(NSNotFound, 0);
+
+    // Reenable undo action collection, after we are done with text composition.    
+    [mOwner setGeneralProperty: SCI_SETUNDOCOLLECTION value: 1];
   }
 }
 
@@ -342,6 +355,9 @@ NSString *SCIUpdateUINotification = @"SCIUpdateUI";
                      value: mMarkedTextRange.location + mMarkedTextRange.length];
     mOwner.backend->InsertText(@"");
     mMarkedTextRange = NSMakeRange(NSNotFound, 0);
+
+    // Reenable undo action collection, after we are done with text composition.
+    [mOwner setGeneralProperty: SCI_SETUNDOCOLLECTION value: 1];
   }
 }
 
@@ -616,6 +632,17 @@ NSString *SCIUpdateUINotification = @"SCIUpdateUI";
 
 //--------------------------------------------------------------------------------------------------
 
+/**
+ * Sends a new notification of the given type and user info to the default notification center.
+ */
+- (void) sendNotification: (NSString*) notificationName withUserInfo: (NSDictionary*) userInfo
+{
+  NSNotificationCenter* center = [NSNotificationCenter defaultCenter];
+  [center postNotificationName: notificationName object: self userInfo: userInfo];
+}
+
+//--------------------------------------------------------------------------------------------------
+
 /**
  * Called by a connected compontent (usually the info bar) if something changed there.
  *
@@ -683,20 +710,31 @@ static void notification(intptr_t windowid, unsigned int iMessage, uintptr_t wPa
       {
         case SCN_MARGINCLICK:
         {
+          int line = [editor getGeneralProperty: SCI_LINEFROMPOSITION parameter: scn->position];
           if (scn->margin == 2)
           {
             // Click on the folder margin. Toggle the current line if possible.
-            int line = [editor getGeneralProperty: SCI_LINEFROMPOSITION parameter: scn->position];
             [editor setGeneralProperty: SCI_TOGGLEFOLD value: line];
           }
+          
+          NSMutableDictionary* info = [NSMutableDictionary dictionary];
+          [info setValue: [NSNumber numberWithInt: line] forKey: @"line"];
+          [info setValue: [NSNumber numberWithInt: scn->modifiers] forKey: @"modifiers"];
+          [info setValue: [NSNumber numberWithInt: scn->margin] forKey: @"margin"];
+          [editor sendNotification: SCIMarginClickNotification withUserInfo: info];
           break;
           };
         case SCN_MODIFIED:
         {
+          int line = [editor getGeneralProperty: SCI_LINEFROMPOSITION parameter: scn->position];
+          NSMutableDictionary* info = [NSMutableDictionary dictionary];
+          [info setValue: [NSNumber numberWithInt: line] forKey: @"line"];
+          [info setValue: [NSNumber numberWithInt: scn->linesAdded] forKey: @"linesAdded"];
+
           // Decide depending on the modification type what to do.
           // There can be more than one modification carried by one notification.
           if (scn->modificationType & (SC_MOD_INSERTTEXT | SC_MOD_DELETETEXT))
-            [editor sendNotification: NSTextDidChangeNotification];
+            [editor sendNotification: NSTextDidChangeNotification withUserInfo: info];
           break;
         }
         case SCN_ZOOM:
@@ -713,11 +751,19 @@ static void notification(intptr_t windowid, unsigned int iMessage, uintptr_t wPa
           // Triggered whenever changes in the UI state need to be reflected.
           // These can be: caret changes, selection changes etc.
           NSPoint caretPosition = editor->mBackend->GetCaretPosition();
+          
           [editor->mInfoBar notify: IBNCaretChanged message: nil location: caretPosition value: 0];
-          [editor sendNotification: SCIUpdateUINotification];
           [editor sendNotification: NSTextViewDidChangeSelectionNotification];
+
+          // For the UI notification we also need the caret location, but as global position,
+          // not in row/column format.
+          int position = [editor getGeneralProperty: SCI_GETCURRENTPOS];
+          NSMutableDictionary* info = [NSMutableDictionary dictionary];
+          [info setValue: [NSNumber numberWithInt: position] forKey: @"currentPosition"];
+          [editor sendNotification: SCIUpdateUINotification withUserInfo: info];
+
           break;
-      }
+        }
       }
       break;
     }
@@ -1237,12 +1283,30 @@ static void notification(intptr_t windowid, unsigned int iMessage, uintptr_t wPa
 
 //--------------------------------------------------------------------------------------------------
 
+/**
+ * Specialized property setter for colors without additional parameter.
+ */
+- (void) setColorProperty: (int) property value: (NSColor*) value
+{
+  if ([value colorSpaceName] != NSDeviceRGBColorSpace)
+    value = [value colorUsingColorSpaceName: NSDeviceRGBColorSpace];
+  long red = [value redComponent] * 255;
+  long green = [value greenComponent] * 255;
+  long blue = [value blueComponent] * 255;
+  
+  long color = (blue << 16) + (green << 8) + red;
+  mBackend->WndProc(property, color, 0);
+}
+
+//--------------------------------------------------------------------------------------------------
+
 /**
  * Another color property setting, which allows to specify the color as string like in HTML
  * documents (i.e. with leading # and either 3 hex digits or 6).
  */
 - (void) setColorProperty: (int) property parameter: (long) parameter fromHTML: (NSString*) fromHTML
 {
+  // HTML hex code of the form #rgb or #rrggbb.
   if ([fromHTML length] > 3 && [fromHTML characterAtIndex: 0] == '#')
   {
     bool longVersion = [fromHTML length] > 6;
@@ -1279,6 +1343,27 @@ static void notification(intptr_t windowid, unsigned int iMessage, uintptr_t wPa
     long color = (rawBlue << 16) + (rawGreen << 8) + rawRed;
     mBackend->WndProc(property, parameter, color);
   }
+  else
+  {
+    // A color name. Scan all available color catalogs for that.
+    // Unfortunately the color comparison in those lists is case-sensitive, which forces us
+    // to do an extra (time costly) roundtrip.
+    NSArray* colorLists = [NSColorList availableColorLists];
+    for (int i = 0; i < [colorLists count]; i++)
+    {
+      NSArray* keys = [[colorLists objectAtIndex: i] allKeys];
+      for (int j = 0; j < [keys count]; j++)
+      {
+        if ([[keys objectAtIndex: j] caseInsensitiveCompare: fromHTML] == NSOrderedSame)
+        {
+          [self setColorProperty: property
+                       parameter: parameter
+                           value: [[colorLists objectAtIndex: i] colorWithKey: [keys objectAtIndex: j]]];
+          return;
+        }
+      }
+    }
+  }
 }
 
 //--------------------------------------------------------------------------------------------------
