@@ -482,7 +482,7 @@ static void FoldMySQLDoc(unsigned int startPos, int length, int initStyle, WordL
         break;
         
       default:
-        if (!isspace(currentChar) && endPending)
+        if ((((unsigned) currentChar >= 128) || !isspace(currentChar)) && endPending)
         {
           // END followed by a non-whitespace character (not covered by other cases like identifiers)
           // also should end a folding block. Typical case: END followed by self defined delimiter.
@@ -512,7 +512,7 @@ static void FoldMySQLDoc(unsigned int startPos, int length, int initStyle, WordL
       visibleChars = 0;
     }
 
-    if (!isspacechar(currentChar))
+    if (((unsigned) currentChar >= 128) || !isspacechar(currentChar))
       visibleChars++;
   }
 }
