@@ -20,16 +20,20 @@
 #include "stdafx.h"
 
 #include "grts/structs.db.mgmt.h"
-#include "advanced_sidebar.h"
 
 #include "base/string_utilities.h"
 #include "base/geometry.h"
+#include "base/drawing.h"
+
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
+
+#include "advanced_sidebar.h"
 
 #include <math.h>
 
 using namespace std;
 
-using namespace MySQL::Geometry;
 using namespace wb;
 using namespace mforms;
 
@@ -56,7 +60,7 @@ using namespace mforms;
 
 //----------------- SidebarSection -----------------------------------------------------------------
 
-SidebarEntry::SidebarEntry(const string& title, const string& icon, const std::string& command, bool as_link)
+SidebarEntry::SidebarEntry(const string& title, const string& icon, const string& command, bool as_link)
 {
   _title = title;
   _icon = Utilities::load_icon(icon);
@@ -74,23 +78,23 @@ SidebarEntry::~SidebarEntry()
 
 //--------------------------------------------------------------------------------------------------
 
-void SidebarEntry::paint(cairo_t* cr, Rect bounds, bool hot, bool active)
+void SidebarEntry::paint(cairo_t* cr, Rect bounds, bool hot, bool active, const Color& selection_color)
 {
-  // Fill a blue background if the item is active.
+  // Fill background if the item is active.
   if (active)
   {
-    cairo_set_source_rgb(cr, 0x33 / 255.0, 0x99 / 255.0, 0xff / 255.0);
-    cairo_rectangle(cr, 2, bounds.top, bounds.left + bounds.width - 4, bounds.height);
+    cairo_set_source_rgb(cr, selection_color.red, selection_color.green, selection_color.blue);
+    cairo_rectangle(cr, 2, bounds.top(), bounds.left() + bounds.width() - 4, bounds.height());
     cairo_fill(cr);
   }
 
-  cairo_move_to(cr, bounds.left, bounds.top);
+  cairo_move_to(cr, bounds.left(), bounds.top());
 
   double offset;
   if (_icon != NULL)
   {
-    offset = (bounds.height - cairo_image_surface_get_height(_icon)) / 2;
-    cairo_set_source_surface(cr, _icon, bounds.left, bounds.top + offset);
+    offset = (bounds.height() - cairo_image_surface_get_height(_icon)) / 2;
+    cairo_set_source_surface(cr, _icon, bounds.left(), bounds.top() + offset);
     cairo_paint(cr);
     cairo_rel_move_to(cr, cairo_image_surface_get_width(_icon) + SECTION_ENTRY_ICON_SPACING, 0);
   }
@@ -102,7 +106,7 @@ void SidebarEntry::paint(cairo_t* cr, Rect bounds, bool hot, bool active)
     cairo_set_source_rgb(cr, 1, 1, 1);
   else
     cairo_set_source_rgb(cr, 0, 0, 0);
-  cairo_rel_move_to(cr, 0, (bounds.height + SIDEBAR_ENTRY_FONT_SIZE) / 2 - 2);
+  cairo_rel_move_to(cr, 0, (bounds.height() + SIDEBAR_ENTRY_FONT_SIZE) / 2 - 2);
   cairo_show_text(cr, _title.c_str());
 
   if (hot)
@@ -129,7 +133,8 @@ bool SidebarEntry::contains(double x, double y)
 
 //----------------- SidebarSection -----------------------------------------------------------------
 
-SidebarSection::SidebarSection(AdvancedSidebar* owner, const std::string& title)
+SidebarSection::SidebarSection(AdvancedSidebar* owner, const std::string& title, bool expandable,
+  bool refreshable)
   : DrawBox()
 {
   _owner = owner;
@@ -140,9 +145,21 @@ SidebarSection::SidebarSection(AdvancedSidebar* owner, const std::string& title)
   _layout_width = 0;
   _layout_height = 0;
   _expanded = true;
+  _expandable = expandable;
   _expand_text_visible = false;
   _expand_text_width = 0;
   _expand_text_active = false;
+
+  if (refreshable)
+  {
+#ifdef __APPLE__
+    _refresh_icon = Utilities::load_icon("refresh_sidebar_mac.png");
+#else
+    _refresh_icon = Utilities::load_icon("refresh_sidebar.png");
+#endif
+  }
+  else
+    _refresh_icon = NULL;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -150,6 +167,8 @@ SidebarSection::SidebarSection(AdvancedSidebar* owner, const std::string& title)
 SidebarSection::~SidebarSection()
 {
   clear();
+  if (_refresh_icon != NULL)
+    cairo_surface_destroy(_refresh_icon);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -163,6 +182,8 @@ void SidebarSection::set_selected(SidebarEntry* entry)
   {
     _selected_entry= entry;
     set_needs_repaint();
+    if (entry)
+      _owner->on_section_command().emit(entry->command());
   }
 }
 
@@ -173,6 +194,7 @@ void SidebarSection::set_selected(SidebarEntry* entry)
 #define SECTION_BOTTOM_SPACING 7 // Vertical distance from the content to the bottom.
 #define SECTION_HEADER_SPACING 6 // Vertical distance between the heading bottom line and the content top.
 #define SECTION_HEADER_HEIGHT 12 // Height of the section heading.
+#define SECTION_HEADER_REFRESH_SPACING 4 // Horizontal distance between collapse text and refresh button.
 
 void SidebarSection::layout(cairo_t* cr)
 {
@@ -318,11 +340,18 @@ bool SidebarSection::select(const std::string& title)
 
 //--------------------------------------------------------------------------------------------------
 
+//void SidebarSection::set_selection_color(const Color* color)
+//{
+//  _selection_color = color;
+//}
+
+//--------------------------------------------------------------------------------------------------
+
 void draw_header_text(cairo_t* cr, Rect &bounds, const std::string& text, bool active)
 {
   // Draw heading twice. Once like a white shadow and once normal.
   cairo_set_source_rgb(cr, 1, 1, 1);
-  cairo_move_to(cr, bounds.left, bounds.top + 1);
+  cairo_move_to(cr, bounds.left(), bounds.top() + 1);
   cairo_show_text(cr, text.c_str());
   cairo_stroke(cr);
 
@@ -330,7 +359,7 @@ void draw_header_text(cairo_t* cr, Rect &bounds, const std::string& text, bool a
     cairo_set_source_rgb(cr, 0x04 / 255.0, 0x7c / 255.0, 0xf2 / 255.0);
   else
     cairo_set_source_rgb(cr, 0x61 / 255.0, 0x70 / 255.0, 0x80 / 255.0);
-  cairo_move_to(cr, bounds.left, bounds.top);
+  cairo_move_to(cr, bounds.left(), bounds.top());
   cairo_show_text(cr, text.c_str());
   cairo_stroke(cr);
 }
@@ -350,6 +379,15 @@ void SidebarSection::repaint(cairo_t *cr, int areax, int areay, int areaw, int a
   cairo_set_font_size(cr, SIDEBAR_TITLE_FONT_SIZE);
   draw_header_text(cr, bounds, _title, false);
 
+  if (_refresh_icon != NULL)
+  {
+    int image_width = cairo_image_surface_get_width(_refresh_icon);
+    cairo_set_source_surface(cr, _refresh_icon, bounds.size.width - image_width, SECTION_TOP_SPACING);
+    cairo_paint(cr);
+
+    width -= image_width + SECTION_HEADER_REFRESH_SPACING;
+  }
+
   if (_expand_text_visible)
   {
     cairo_select_font_face(cr, SIDEBAR_FONT, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
@@ -357,21 +395,22 @@ void SidebarSection::repaint(cairo_t *cr, int areax, int areay, int areaw, int a
 
     std::string expand_text = _expanded ? _("Hide") : _("Show");
     Rect text_bounds = bounds;
-    text_bounds.left = width - _expand_text_width - SECTION_SIDE_SPACING;
-    text_bounds.width = _expand_text_width;
+    text_bounds.pos.x = width - _expand_text_width - SECTION_SIDE_SPACING;
+    text_bounds.size.width = _expand_text_width;
     draw_header_text(cr, text_bounds, expand_text, _expand_text_active);
   }
 
   if (_expanded)
   {
-    bounds.left += SECTION_ENTRY_INDENT;
-    bounds.width -= SECTION_ENTRY_INDENT;
-    bounds.top += SECTION_HEADER_SPACING;
-    bounds.height = SECTION_ENTRY_HEIGHT;
+    bounds.pos.x += SECTION_ENTRY_INDENT;
+    bounds.size.width -= SECTION_ENTRY_INDENT;
+    bounds.pos.y += SECTION_HEADER_SPACING;
+    bounds.size.height = SECTION_ENTRY_HEIGHT;
+    const Color& selection_color = _owner->selection_color();
     for (std::vector<SidebarEntry*>::const_iterator iterator= _entries.begin(); iterator != _entries.end(); iterator++)
     {
-      (*iterator)->paint(cr, bounds, *iterator == _hot_entry, (*iterator == _selected_entry));
-      bounds.top += SECTION_ENTRY_HEIGHT + SECTION_ENTRY_SPACING;
+      (*iterator)->paint(cr, bounds, *iterator == _hot_entry, (*iterator == _selected_entry), selection_color);
+      bounds.pos.y += SECTION_ENTRY_HEIGHT + SECTION_ENTRY_SPACING;
     }
   }
 }
@@ -395,7 +434,7 @@ void SidebarSection::mouse_move(int x, int y)
 {
   bool need_refresh = false;
   
-  if (_expand_text_visible != y < SECTION_TOP_SPACING + SECTION_HEADER_HEIGHT)
+  if (_expandable && (_expand_text_visible != (y < SECTION_TOP_SPACING + SECTION_HEADER_HEIGHT)))
   {
     _expand_text_visible = y < SECTION_TOP_SPACING + SECTION_HEADER_HEIGHT;
     _hot_entry= NULL;
@@ -426,7 +465,10 @@ void SidebarSection::mouse_down(int button, int x, int y)
 {
   if (button == MouseButtonLeft)
   {
-    if (_expand_text_visible && x >= (get_width() - _expand_text_width - SECTION_SIDE_SPACING))
+    int width = get_width() - SECTION_SIDE_SPACING;
+    if (_refresh_icon != NULL)
+      width -= cairo_image_surface_get_width(_refresh_icon) + SECTION_HEADER_REFRESH_SPACING;
+    if (_expand_text_visible && x >= (width - _expand_text_width) && x < width)
     {
       _expand_text_active = true;
       set_needs_repaint();
@@ -448,15 +490,36 @@ void SidebarSection::mouse_click(int button, int x, int y)
   {
   case MouseButtonLeft:
     {
-      if (_expand_text_visible && _expand_text_active)
-        toggle_expand();
-      else
+      bool handled = false;
+
+      // _expand_text_visible implicitly indicates that the mouse is in the header area.
+      if (_expand_text_visible)
+      {
+        if (_expand_text_active)
+        {
+          handled = true;
+          toggle_expand();
+          _expand_text_active = false;
+          set_needs_repaint();
+        }
+        else
+          if (_refresh_icon != NULL)
+          {
+            int width = get_width() - SECTION_SIDE_SPACING;
+            if (x >= (width - cairo_image_surface_get_width(_refresh_icon)) && x < width)
+            {
+              handled = true;
+              _owner->refresh_clicked(this);
+            }
+          }
+      }
+
+      if (!handled)
       {
         SidebarEntry* entry = entry_from_point(x, y);
         if (entry && ((entry == _hot_entry) || (entry == _selected_entry)))
           _owner->on_section_command().emit(entry->command());
       }
-      _expand_text_active = false;
     }
     break;
 
@@ -501,7 +564,7 @@ void SidebarSection::clear_selection()
 
 AdvancedSidebar::AdvancedSidebar()
   : _schema_tree(TreeNoColumns | TreeNoBorder | TreeSidebar | TreeNoHeader), _is_model_owner(false),
-    _schema_box(false)
+    _schema_box(false), _schema_tree_heading(NULL)
 {
   setup_schema_tree();
 
@@ -567,11 +630,11 @@ void AdvancedSidebar::setup_schema_tree()
   _tree_context_menu.set_handler(sigc::mem_fun(this, &AdvancedSidebar::handle_menu_command));
 
   // Add the tree itself and its section caption to the container.
-  SidebarSection* schema_heading = new SidebarSection(this, "SCHEMAS");
-  schema_heading->expanded_changed().connect(sigc::mem_fun(this, &AdvancedSidebar::on_expand_changed));
-  _sections.push_back(schema_heading);
+  _schema_tree_heading = new SidebarSection(this, _("SCHEMAS"), true, true);
+  _schema_tree_heading->expanded_changed().connect(sigc::mem_fun(this, &AdvancedSidebar::on_expand_changed));
+  _sections.push_back(_schema_tree_heading);
   _schema_box.set_back_color("#d9e2ef");
-  _schema_box.add(schema_heading, false, true);
+  _schema_box.add(_schema_tree_heading, false, true);
   _schema_box.add(&_schema_tree, true, true);
 
   _schema_box.show(false);
@@ -608,9 +671,20 @@ void AdvancedSidebar::handle_menu_command(const std::string& command)
 
 //--------------------------------------------------------------------------------------------------
 
+void AdvancedSidebar::refresh_clicked(SidebarSection* section)
+{
+  if (section == _schema_tree_heading)
+  {
+    std::vector<bec::NodeId> nodes;
+    _schema_model->activate_popup_item_for_nodes("refresh", nodes);
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void AdvancedSidebar::refresh_model()
 {
-  _schema_tree.refresh(bec::NodeId());
+  _schema_model->refresh();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -643,7 +717,7 @@ int AdvancedSidebar::add_section(const string& title)
   if (result > -1)
     return result;
 
-  SidebarSection* box = new SidebarSection(this, title);
+  SidebarSection* box = new SidebarSection(this, title, true, false);
   box->set_back_color("#d9e2ef");
   _sections.push_back(box);
   add(box, false, true);
@@ -689,6 +763,47 @@ void AdvancedSidebar::remove_section_entry(const std::string& section, const std
 
 //--------------------------------------------------------------------------------------------------
 
+void AdvancedSidebar::set_collapse_states(const std::string& data)
+{
+  std::vector<std::string> collapsed_sections = base::split(data, ",");
+  for (std::vector<std::string>::const_iterator iter = collapsed_sections.begin();
+       iter != collapsed_sections.end(); ++iter)
+  {
+    int section;
+    int state;
+    const char *ptr = strrchr(iter->c_str(), '=');
+    if (ptr)
+    {
+      section = find_section(iter->substr(0, ptr-iter->c_str()));
+      if (section < 0)
+        continue;
+      
+      state = atoi(ptr+1);
+    }
+    else
+      continue;
+    
+    if ((state!=0) == _sections[section]->expanded())
+      _sections[section]->toggle_expand();
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
+std::string AdvancedSidebar::get_collapse_states()
+{
+  std::string states;
+  for (int i = 0; i < (int)_sections.size(); i++)
+  {
+    if (i > 0)
+      states.append(",");
+    states.append(base::strfmt("%s=%i", _sections[i]->title().c_str(), !_sections[i]->expanded()));
+  }
+  return states;
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void AdvancedSidebar::clear_sections()
 {
   SidebarSection* schema_heading = _sections[0]; // A special section. We wanna keep it.
@@ -716,11 +831,31 @@ void AdvancedSidebar::clear_section(const std::string& section)
 
 //--------------------------------------------------------------------------------------------------
 
+void AdvancedSidebar::set_selection_color(const std::string& color)
+{
+  _selection_color = Color::parse(color);
+  //for (int i = 0; i < (int) _sections.size(); i++)
+  //  _sections[i]->set_selection_color(_selection_color);
+  set_needs_repaint();
+}
+
+//--------------------------------------------------------------------------------------------------
+
+void AdvancedSidebar::set_selection_color(const mforms::SystemColor color)
+{
+  mforms::App* app = mforms::App::get();
+  if (app)
+    set_selection_color(app->get_system_color(color).to_html());
+}
+
+//--------------------------------------------------------------------------------------------------
+
 /**
  * Expands the schema node with the given index. A schema node is a top level node.
  */
 void AdvancedSidebar::expand_schema(int schema_index)
 {
+  _schema_tree.set_expanded(schema_index, true);
 }
 
 //--------------------------------------------------------------------------------------------------
