@@ -21,7 +21,7 @@
 
 #include "document_properties_form.h"
 #include "workbench/wb_context_ui.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 DocumentPropertiesForm::DocumentPropertiesForm(wb::WBContextUI *wbui)
   : Form(NULL, mforms::FormResizable), _bottom_box(true), _text(mforms::VerticalScrollBar)
