@@ -20,7 +20,7 @@
 #include "stdafx.h"
 
 #include "grt_code_editor.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 #include "grt_shell_window.h"
 #include "grt_python_debugger.h"
 
