@@ -22,7 +22,7 @@
 #define __GRT_PLUGIN_WIZARD_H__
 
 #include "mforms/mforms.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 #include "workbench/wb_context.h"
 #include "grt/common.h"
 
