@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
  */
 
 #include "stdafx.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 #include "grt_python_debugger.h"
 #include "grt_shell_window.h"
 #include "grt_code_editor.h"
@@ -238,7 +238,7 @@ PythonDebugger *PythonDebugger::from_cobject(PyObject *cobj)
 PythonDebugger::PythonDebugger(GRTShellWindow *shell, mforms::TabView *tabview)
 : _shell(shell), _lower_tabs(tabview), _stack_position_editor(0), _stack_position_line(0)
 {
-  _breakpoint_list= manage(new TreeView(TreeShowHeader));
+  _breakpoint_list= manage(new TreeView(TreeDefault));
 //  _breakpoint_list->add_column(CheckColumnType, " ", 30, true);
   _breakpoint_list->add_column(StringColumnType, "Breakpoint", 200, false);
   _breakpoint_list->add_column(StringColumnType, "Location", 200, false);
@@ -251,7 +251,7 @@ PythonDebugger::PythonDebugger(GRTShellWindow *shell, mforms::TabView *tabview)
   
   _lower_tabs->add_page(spl, _("Debug Info"));
 
-  _stack_list= manage(new TreeView(TreeShowHeader));
+  _stack_list= manage(new TreeView(TreeDefault));
   _stack_list->add_column(StringColumnType, "#", 30, false);
   _stack_list->add_column(StringColumnType, "Stack Location", 300, false);
   _stack_list->add_column(StringColumnType, "File", 300, false);
@@ -260,7 +260,7 @@ PythonDebugger::PythonDebugger(GRTShellWindow *shell, mforms::TabView *tabview)
   _stack_list->signal_changed().connect(sigc::mem_fun(this, &PythonDebugger::stack_selected));
   //_stack_list->signal_row_activated().connect();
   
-  _variable_list= manage(new TreeView(TreeShowHeader));
+  _variable_list= manage(new TreeView(TreeDefault));
   _variable_list->add_column(StringColumnType, "Variable", 200, false);
   _variable_list->add_column(StringColumnType, "Value", 400, false);
   _variable_list->end_columns();
@@ -599,7 +599,7 @@ const char *PythonDebugger::ui_program_stopped(const char *file, int line, int r
       break;
       
     case 5: // heartbeat
-      if (action == -1) // timeout
+      if (action < 0) // timeout
         action = BP_ACTION_CONTINUE;            
       break;
   }
