@@ -926,7 +926,7 @@ void GRTShellWindow::run_snippet()
 
     handle_output("Running snippet...\n");
     // redirect snippet output to the shell
-    grtm()->push_output_callback(sigc::mem_fun(this, &GRTShellWindow::handle_output));
+    grtm()->push_output_callback(sigc::bind_return(sigc::mem_fun(this, &GRTShellWindow::handle_output), true));
     
     try
     {
@@ -1099,8 +1099,18 @@ void GRTShellWindow::open_file_in_editor(const std::string &path, bool is_script
     if (g_str_has_suffix(path.c_str(), ".lua"))
       language = "lua"; // Lua script
     else
-      if (g_str_has_suffix(path.c_str(), ".sql"))
+      if (g_str_has_suffix(path.c_str(), ".sql") || g_str_has_suffix(path.c_str(), ".qbquery"))
         language = "sql";
+
+  // Show warning messages if applicable...
+  if (language == "")
+  {
+    std::string text= base::strfmt(_("The file %s has an unsupported extension for this script editor."), path.c_str());
+    Utilities::show_message_and_remember(_("Unsupported File Format"), text, _("OK"), _(""), _(""),  "ShellWindowUnknownLanguageFile", _("") );
+  }
+  else if (language == "sql")
+    Utilities::show_message_and_remember(_("Unsupported Execution"), _("This script editor is meant for developing Workbench plugins and scripts. SQL scripts should be opened and executed in the SQL Editor."), _("OK"), _(""), _(""),  "ShellWindowSqlLanguageFile", _("") );
+
   GRTCodeEditor *editor= add_editor(is_script, language);
   if (!editor->load(path))
   {
@@ -1150,9 +1160,10 @@ void GRTShellWindow::add_new_script()
 }
 
 
-void GRTShellWindow::add_output(const std::string &text)
+bool GRTShellWindow::add_output(const std::string &text)
 {
   _output_text.append_text(text, true);
+  return true;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1374,12 +1385,15 @@ void GRTShellWindow::on_tab_closed(int index)
 
 void GRTShellWindow::on_tab_changed()
 {
-  if (get_active_editor())
+  GRTCodeEditor *editor = get_active_editor();
+  if (editor)
   {
+    bool exec_enabled = (editor->get_language() == "python" || editor->get_language() == "lua");
+
     _save_button->set_enabled(true);
     _save_as_button->set_enabled(true);
-    _run_button->set_enabled(true);
-    _step_button->set_enabled(true);
+    _run_button->set_enabled(exec_enabled);
+    _step_button->set_enabled(exec_enabled);
     
     _right_splitter.set_expanded(false, true);
   }
