@@ -56,7 +56,7 @@ public:
 
   bool request_quit();
   
-  void add_output(const std::string &text);  
+  bool add_output(const std::string &text);  
   void activate_output_tab();
 
   GRTCodeEditor* get_editor_for(const std::string& path, bool select_tab);
