@@ -59,8 +59,10 @@ OutputView::OutputView(bec::MessageListStorage *storage)
 
 OutputView::~OutputView()
 {
+  _storage->set_output_handler(sigc::slot<void, std::string>());
   _message_list.set_model(0);
   delete _messages;
+  _messages = 0;
 }
 
 //--------------------------------------------------------------------------------------------------
