@@ -22,7 +22,9 @@
 #include "mforms/mforms.h"
 #include "mforms/widgets.h"
 #include "mforms/sectionbox.h"
+
 #include "base/string_utilities.h"
+#include "base/util_functions.h"
 
 #if defined(_WIN32) || defined(__APPLE__)
 #define HAVE_BUNDLED_MYSQLDUMP
@@ -71,11 +73,23 @@ public:
   {
     _table.set_row_count(++_rows);
    
-    _table.add(new_label(caption, true), 0, 1, _rows-1, _rows, mforms::HFillFlag|mforms::HExpandFlag);
-    _table.add(control, 1, 2, _rows-1, _rows, mforms::HFillFlag);
+#ifdef _WIN32
+    TableItemFlags descriptionFlags = mforms::HFillFlag;
+    TableItemFlags helpFlags = mforms::HFillFlag | mforms::HExpandFlag;
+    bool right_aligned = false;
+#else
+    TableItemFlags descriptionFlags = mforms::HFillFlag | mforms::HExpandFlag;
+    TableItemFlags helpFlags = mforms::HFillFlag;
+    bool right_aligned = true;
+#endif
 
-    mforms::Label *l;
-    _table.add(l = new_label(help, false, true), 2, 3, _rows-1, _rows, mforms::HFillFlag);
+    mforms::Label* label = new_label(caption, right_aligned);
+    _table.add(label, 0, 1, _rows-1, _rows, descriptionFlags);
+    label->set_size(170, -1);
+    _table.add(control, 1, 2, _rows-1, _rows, mforms::HFillFlag | mforms::HExpandFlag);
+    control->set_size(150, -1);
+
+    _table.add(new_label(help, false, true), 2, 3, _rows-1, _rows, helpFlags);
   }
   
 
@@ -86,7 +100,17 @@ public:
     mforms::TextEntry *entry = _owner->new_entry_option(option, false);
     entry->set_tooltip(tooltip);
     
-    _table.add(new_label(caption, true), 0, 1, _rows-1, _rows, mforms::HFillFlag|mforms::HExpandFlag);
+#ifdef _WIN32
+    TableItemFlags descriptionFlags = mforms::HFillFlag;
+    bool right_aligned = false;
+#else
+    TableItemFlags descriptionFlags = mforms::HFillFlag | mforms::HExpandFlag;
+    bool right_aligned = true;
+#endif
+
+    mforms::Label* label = new_label(caption, right_aligned);
+    _table.add(label, 0, 1, _rows-1, _rows, descriptionFlags);
+    label->set_size(170, -1);
     _table.add(entry, 1, 2, _rows-1, _rows, mforms::HFillFlag);
   }
   
@@ -98,7 +122,12 @@ public:
     cb->set_text(caption);
     cb->set_tooltip(tooltip);
     
-    _table.add(cb, 1, 2, _rows-1, _rows, mforms::HFillFlag);
+#ifdef _WIN32
+    int start_column = 0;
+#else
+    int start_column = 1;
+#endif
+    _table.add(cb, start_column, 2, _rows - 1, _rows, mforms::HFillFlag);
   }
 };
 
@@ -292,7 +321,15 @@ void PreferencesForm::show_checkbox_option(const std::string &option_name, mform
 
 void PreferencesForm::update_checkbox_option(const std::string &option_name, mforms::CheckBox *checkbox)
 {
-  _wbui->set_wb_options_value(_model_id, option_name, checkbox->get_active() ? "1" : "0", grt::IntegerType);
+  std::string value = checkbox->get_active() ? "1" : "0";
+  _wbui->set_wb_options_value(_model_id, option_name, value, grt::IntegerType);
+
+#ifdef _WIN32
+  // On Windows we have to write the following value also to the registry as our options are not
+  // available yet when we need that value.
+  if (option_name == "SingleInstance")
+    set_value_to_registry(HKEY_CURRENT_USER, "Software\\Oracle\\MySQL Workbench", "SingleInstance", value.c_str());
+#endif
 }
 
 
@@ -545,11 +582,11 @@ void PreferencesForm::create_sqlide_page()
       tbox->set_spacing(4);
       vbox->add(tbox, false);
       
-      tbox->add(new_label(_("SQL Delimiter:"), true), false, false);
+      tbox->add(new_label(_("Non-Standard SQL Delimiter:"), true), false, false);
       mforms::TextEntry *entry= new_entry_option("SqlDelimiter", false);
       entry->set_size(50, -1);
       entry->set_tooltip(_(
-        "SQL statement delimiter."));
+        "SQL statement delimiter different from the normally used one (ie, shouldn't be ;). Change this only if the delimiter you normally use, specially in stored routines, happens to be the current setting."));
       tbox->add(entry, false, false);
     }
   }
@@ -598,12 +635,14 @@ void PreferencesForm::create_sqlide_page()
     
     {
       mforms::CheckBox *check= new_checkbox_option("DbSqlEditor:SafeUpdates");
-      check->set_text(_("Forbid UPDATE and DELETE statements without a WHERE clause (safe updates). Requires a reconnection."));
+      check->set_text(_("\"Safe Updates\". Forbid UPDATEs and DELETEs with no key in WHERE clause or no LIMIT clause. Requires a reconnection."));
       check->set_tooltip(_(
-                           "Enables the SQL_SAFE_UPDATES option for the session, "
-                           "preventing UPDATE and DELETE statements to be executed if a WHERE "
-                           "clause is not present. That will avoid some dangerous commands that "
-                           "would update or delete all rows in a table by accident.\n"
+                           "Enables the SQL_SAFE_UPDATES option for the session.\n"
+                           "If enabled, MySQL aborts UPDATE or DELETE statements\n"
+                           "that do not use a key in the WHERE clause or a LIMIT clause.\n"
+                           "This makes it possible to catch UPDATE or DELETE statements\n"
+                           "where keys are not used properly and that would probably change\n"
+                           "or delete a large number of rows. \n"
                            "Changing this option requires a reconnection (Query -> Reconnect to Server)"));
       vbox->add(check, false);
     }    
@@ -652,6 +691,35 @@ void PreferencesForm::create_sqlide_page()
                            "Set to 0 to not send keep-alive messages."));
       tbox->add(entry, false, false);
     }    
+
+    {
+      mforms::Box *tbox= mforms::manage(new mforms::Box(true));
+      tbox->set_spacing(4);
+      vbox->add(tbox, false);
+      
+      tbox->add(new_label(_("DBMS connection read time out (in seconds):"), true), false, false);
+      mforms::TextEntry *entry= new_entry_option("DbSqlEditor:ReadTimeOut", false);
+      entry->set_max_length(5);
+      entry->set_size(50, -1);
+      entry->set_tooltip(_(
+                           "Max time the a query can take to return data from the DBMS"));
+      tbox->add(entry, false, false);
+    }    
+
+    {
+      mforms::Box *tbox= mforms::manage(new mforms::Box(true));
+      tbox->set_spacing(4);
+      vbox->add(tbox, false);
+      
+      tbox->add(new_label(_("Max. query length to store in history (in bytes):"), true), false, false);
+      mforms::TextEntry *entry= new_entry_option("DbSqlEditor:MaxQuerySizeToHistory", false);
+      entry->set_size(50, -1);
+      entry->set_tooltip(_(
+        "Queries beyond specified size will not be saved in the history when executed.\n"
+        "Set to 0 to save any executed query or script"));
+      tbox->add(entry, false, false);
+    }
+
   }
 
   {
@@ -794,6 +862,10 @@ void PreferencesForm::create_general_page()
                                _("Whether to place sidebar on the left or right side in module windows.\n"
                                  "Clear this checbox to place sidebar on the left side."));
     
+    table->add_checkbox_option("SingleInstance", _("Only allow one instance of MySQL Workbench to run"), 
+      _("Determines if only one or multiple instances of MySQL Workbench can run at the same time for "
+      "a single user."));
+
     mforms::Selector *combo= new_selector_option("grtshell:ShellLanguage");
     table->add_option(combo, _("Interactive GRT Shell language:"), 
                       _("Select the language to use in the interactive GRT shell.\n"
@@ -1214,58 +1286,27 @@ void PreferencesForm::create_test_page()
 {
   Box* content= manage(new Box(false));
 
-  TextEntry* file_name = manage(new TextEntry());
-  file_name->set_value("dummy entry");
-  file_name->set_size(300, -1);
-  Selector* section = manage(new Selector());
-  section->set_enabled(false);
-  section->set_size(150, -1);
-  
-  Box* bottom_box = manage(new Box(true));
-  content->add(bottom_box, false, false);
-  
-  Button* accept_btn = manage(new Button());
-  accept_btn->set_text("Apply ...");
-  accept_btn->set_size(80, -1);
-  
-  Button* discard_btn = manage(new Button());
-  discard_btn->set_text("Discard");
-  discard_btn->set_size(80, -1);
-  
-  Label* search_label = manage(new Label("Locate option:"));
-  TextEntry* option_lookup_entry = manage(new TextEntry());
-  Button* search_btn = manage(new Button());
-  search_btn->set_text("Find ...");
-  
-  Box* search_box = manage(new Box(true));
-  search_box->set_padding(2);
-  search_box->set_spacing(4);
-  search_box->set_size(300, -1);
-  search_box->add(search_label, false, false);
-  search_box->add(option_lookup_entry, true, false);
-  search_box->add(search_btn, false, false);
-  Panel* search_panel = manage(new Panel(mforms::BorderedPanel));
-  search_panel->set_size(300, -1);
-  //search_panel->add(search_box);
+  Box* file_path = manage(new Box(true));
+  file_path->set_spacing(4);
+  Label* labelfile = manage(new Label("   File Path"));
+  TextEntry* file_te = manage(new TextEntry());
+  file_te->set_value("asdlkjasfd");  
+  file_path->add(labelfile, false, false);
+  file_path->add(file_te, true, true);
 
-  bottom_box->add(manage(new Label("Configuration File:")), false, false);
-  bottom_box->add(file_name, true, false);
-  bottom_box->add(section, false, false);
-  bottom_box->add(search_box, false, false);
+  Button* file_btn = manage(new Button());
+  file_btn->set_text("...");
+  file_btn->enable_internal_padding(false);
+  file_btn->signal_clicked().connect(sigc::mem_fun(this, &PreferencesForm::test_clicked));
+  file_path->add(file_btn, false, false);
   
-  Utilities::add_end_ok_cancel_buttons(bottom_box, accept_btn, discard_btn);
-  
-  bottom_box->set_spacing(8);
-  bottom_box->set_padding(12);
-  bottom_box->set_back_color("#FFFFFF");
-
+  content->add(file_path, false, true);
   _tabview.add_page(content, _("Test page"));
 }
 
 void PreferencesForm::test_clicked()
 {
-  mforms::Utilities::show_wait_message("Time consuming operation", "Wait for this operation to complete\n\nIt might take a few hours."
-    "\n\nPlease stand by...");
+  //Utilities::move_to_trash("D:\\New Text Document.txt");
 }
 
 #endif
