@@ -292,9 +292,9 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
   {
     Panel* remote_admin_panel = manage(new Panel(TitledGroupPanel)); // For border and title.
     remote_admin_panel->set_title(_("Remote Management"));
-    remote_admin_panel->set_padding(20);
 
     Box* remote_admin_box = manage(new Box(false));                 // For the content.
+    remote_admin_box->set_padding(MF_PANEL_PADDING);
     remote_admin_box->set_spacing(4);
     mforms::Table* remote_param_table = NewTable(6, 2);
     
