@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,14 +20,14 @@
 #include "stdafx.h"
 #include "user_defined_type_editor.h"
 #include "grtui/string_list_editor.h"
-#include "util_functions.h"
-#include "string_utilities.h"
+#include "base/util_functions.h"
+#include "base/string_utilities.h"
 
 using namespace base;
 
 UserDefinedTypeEditor::UserDefinedTypeEditor(wb::WBContextUI *wbui, const workbench_physical_ModelRef &model)
 : mforms::Form(0, mforms::FormResizable), _wbui(wbui), _model(model),
-_vbox(false), _type_list((mforms::TreeOptions)(mforms::TreeShowHeader|mforms::TreeAllowReorderRows)), _args_box(true), _flags_box(false), _button_box(true)
+_vbox(false), _type_list(mforms::TreeAllowReorderRows), _args_box(true), _flags_box(false), _button_box(true)
 {
   set_title(_("User Defined Types"));
   
