@@ -21,7 +21,7 @@ public:
 
   virtual bec::UIForm *get_form() const= 0;
   
-  virtual bool will_close() { return true; }
+  virtual bool on_close() { return true; }
 
   virtual void toggle_sidebar() {}
   
@@ -30,6 +30,9 @@ public:
   virtual bool close_focused_tab();
 
   virtual void find_text(const std::string &text) {}
+
+  virtual void dispose() {}
+
 private:
   bool close_plugin_tab(PluginEditorBase *editor);
   
