@@ -38,7 +38,6 @@ Gtk::HBox &create_icon_label(const std::string &icon, const std::string &label);
 Gtk::Widget *create_closeable_tab(const Glib::ustring &title, const sigc::slot<void> &close_callback,
                                   Gtk::Label **title_label);
 
-void open_url(const std::string &url);
 
 void swap_panned_children(Gtk::Paned *paned, bool fixed_size1);
 
@@ -49,6 +48,7 @@ void recreate_model_from_string_list(Glib::RefPtr<Gtk::ListStore>, const std::ve
 void setup_combo_for_string_list(Gtk::ComboBox *combo);
 
 std::string get_selected_combo_item(Gtk::ComboBox *combo);
+bool set_selected_combo_item(Gtk::ComboBox *combo, const std::string &value);
 
 //! Wrapper to set string values to a Glib::ValueBase
 //! Used in ListModelWrapper
@@ -57,7 +57,7 @@ void set_glib_int(Glib::ValueBase& value, const int i);
 void set_glib_bool(Glib::ValueBase& value, const bool b);
 void set_glib_double(Glib::ValueBase& value, const double d);
 
-void fill_combo_from_string_list(Gtk::ComboBoxText* combo, const std::vector<std::string>& list);
+void fill_combo_from_string_list(Gtk::ComboBox* combo, const std::vector<std::string>& list);
 void fill_combo_from_string_list(Gtk::ComboBoxEntryText* combo, const std::vector<std::string>& list);
 
 //! get_mainwindow is declared here as extern while it is implemented in frontend/linux/workbench/Program.cpp
