@@ -4,9 +4,6 @@
 #include <gtkmm/icontheme.h>
 #include "custom_renderers.h"
 #include "grt/common.h"
-#ifndef NO_MENU_MANAGER
-#include "menu_manager.h"
-#endif
 
 //#define DEBUG
 #undef DEBUG
@@ -18,6 +15,172 @@
 #endif
 
 
+static void process_menu_actions(const std::string &command
+                                , bec::ListModel* model
+                                , const std::vector<bec::NodeId>& nodes
+                                , const sigc::slot<void, const std::string&, const std::vector<bec::NodeId>&> fe_menu_handler
+                                )
+{
+  if (!model->activate_popup_item_for_nodes(command, nodes) && !fe_menu_handler.empty())
+    fe_menu_handler(command, nodes);
+}
+
+//------------------------------------------------------------------------------
+static void run_menu_and_forward_action(const bec::MenuItemList& items
+                                        ,const int x
+                                        ,const int y
+                                        ,const int time
+                                        ,bec::ListModel* model
+                                        ,const std::vector<bec::NodeId>& nodes
+                                        ,const sigc::slot<void, const std::string&, const std::vector<bec::NodeId>&> fe_menu_handler
+                                        )
+{
+  if (items.size() > 0)
+  {
+    run_popup_menu(items
+                   ,time
+                   ,sigc::bind(sigc::ptr_fun(process_menu_actions), model, nodes, fe_menu_handler)
+                   );
+  }
+}
+
+
+
+Index::ExternalMap Index::_ext_map;
+
+//------------------------------------------------------------------------------
+Index::Index(GtkTreeIter* it, const bec::NodeId& node)
+      : _raw_data((char *)it)
+      , _ext(0)
+{
+  //memset(_raw_data, 0xff, sizeof(*it));
+  //*_raw_data = 0;
+  reset_iter(it);
+
+  const int depth = node.depth();
+
+  const Mode m = (depth < MaxDepth) ? (depth == 1 ? ListNode : Internal) : External;
+  mode(m);
+
+  if (m == External)
+  {
+    const std::string nrepr = node.repr();
+    std::pair<ExternalMap::iterator, bool> res = _ext_map.insert(nrepr);
+    _ext = const_cast<std::string*>(&(*(res.first)));
+    it->user_data = (void*)_ext;
+  }
+  else if (m == Internal)
+  {
+    for (int i = 0; i < depth; ++i)
+      word(i, node[i]);
+  }
+  else if (m == ListNode)
+  {
+    it->user_data = (void*)(node[0]);
+  }
+}
+
+//------------------------------------------------------------------------------
+Index::Index(const GtkTreeIter* it)
+      : _raw_data((char *)it)
+      , _ext(0)
+{
+  if (mode() == External)
+    _ext = reinterpret_cast<std::string*>(((GtkTreeIter*)_raw_data)->user_data);
+}
+
+//------------------------------------------------------------------------------
+void Index::stamp(const int st)
+{
+  ((Info*)_raw_data)->stamp = st % StampMax;
+}
+
+//------------------------------------------------------------------------------
+int Index::stamp() const
+{
+  return ((Info*)_raw_data)->stamp;
+}
+
+//------------------------------------------------------------------------------
+bool Index::cmp_stamp(const int st) const
+{
+  return ((Info*)_raw_data)->stamp == (st % StampMax);
+}
+
+//------------------------------------------------------------------------------
+int Index::word(const int w) const
+{
+  int ret = 0;
+
+  if (mode() == Internal)
+  {
+    char* dest = (char*)&ret;
+    const int start_byte = (w * K) + 1;
+
+    memcpy(dest, _raw_data + start_byte, K);
+  }
+
+  return ret;
+}
+
+//------------------------------------------------------------------------------
+void Index::word(const int w, const int v)
+{
+  if (mode() == Internal)
+  {
+    int start_byte = (w * K) + 1;
+    char* dest = _raw_data + start_byte;
+    char* src = (char*)&v;
+
+    memcpy(dest, src, K);
+  }
+  else
+  {
+    throw std::logic_error("Can't change external Node ref\n");
+  }
+}
+
+//------------------------------------------------------------------------------
+bec::NodeId Index::to_node() const
+{
+  bec::NodeId node;
+  if (mode() == Internal)
+  {
+    int v;
+    char* dst = (char*)&v;
+    char* src = _raw_data + 1;
+
+    for (int i = 0; i < MaxDepth; ++i)
+    {
+      v = MaxValue;
+      memcpy(dst, src, K);
+      src += K;
+      if (v != MaxValue)
+        node.append(v);
+      else
+        break;
+    }
+  }
+  else if (mode() == External)
+  {
+    if (_ext)
+      node = bec::NodeId(*_ext);
+  }
+  else if (mode() == ListNode)
+    node.append((long)(((GtkTreeIter*)_raw_data)->user_data));
+
+  return node;
+}
+
+//------------------------------------------------------------------------------
+void Index::reset_iter(GtkTreeIter* it)
+{
+  memset(it, 0xff, sizeof(*it));
+  *((char*)it) = 0;
+}
+
+
+
 //------------------------------------------------------------------------------
 Gtk::TreeModel::Path node2path(const ::bec::NodeId& node)
 {
@@ -353,32 +516,38 @@ ListModelWrapper::ListModelWrapper(bec::ListModel* tm, Gtk::TreeView *treeview,
                     , _stamp(1)
                     , _columns(this, treeview)
                     , _icon_size(bec::Icon16)
+                    , _self_ref(new ListModelWrapper*(this))
                     , _name(name)
 {
   tm->tree_changed_signal().connect(sigc::mem_fun(*this, &::ListModelWrapper::model_changed));
-  tm->add_destroy_notify_callback(this, &ListModelWrapper::on_bec_model_destroyed);
+  tm->add_destroy_notify_callback(_self_ref, &ListModelWrapper::on_bec_model_destroyed);
   #ifndef NO_MENU_MANAGER
   if (_treeview)
     _treeview->signal_event().connect(sigc::mem_fun(this, &ListModelWrapper::handle_popup_event));
   #endif
 }
 
-ListModelWrapper::~ListModelWrapper()
-{
-  if (_tm)
-    _tm->remove_destroy_notify_callback(this);
-}
 
 void* ListModelWrapper::on_bec_model_destroyed(void* data)
 {
-  ListModelWrapper* self = (ListModelWrapper*)(data);
-  if (self)
+  ListModelWrapper** self = (ListModelWrapper**)data;
+  if (self && *self)
   {
-    self->_tm = 0;
+    (*self)->_tm = 0;
   }
+  delete self;
   return 0;
 }
 
+ListModelWrapper::~ListModelWrapper()
+{
+  if (_tm)
+    _tm->remove_destroy_notify_callback(_self_ref);
+  *_self_ref= 0;
+
+  _tm= 0;
+}
+
 void ListModelWrapper::set_iconview(Gtk::IconView* iv)
 {
   _iconview = iv;
@@ -414,7 +583,11 @@ ListModelWrapper::NodeIdArray ListModelWrapper::get_selection() const
 
 void ListModelWrapper::set_be_model(bec::ListModel* tm)
 {
+  if (_tm)
+    _tm->remove_destroy_notify_callback(_self_ref);
   _tm = tm;
+  if (_tm)
+    _tm->add_destroy_notify_callback(_self_ref, &ListModelWrapper::on_bec_model_destroyed);
 }
 
 #ifndef NO_MENU_MANAGER
@@ -472,7 +645,7 @@ void ListModelWrapper::handle_popup(const int x, const int y, const int time)
       list.push_back(node);
     }
 
-    MenuManager::run_and_forward_action(_tm->get_popup_items_for_nodes(list), x, y, time, _tm, list, _fe_menu_handler);
+    run_menu_and_forward_action(_tm->get_popup_items_for_nodes(list), x, y, time, _tm, list, _fe_menu_handler);
   }
 }
 
@@ -503,37 +676,31 @@ bec::NodeId ListModelWrapper::get_node_for_path(const Gtk::TreeModel::Path &path
 }
 
 //------------------------------------------------------------------------------
-bool ListModelWrapper::init_gtktreeiter(GtkTreeIter *it, const bec::NodeId &node) const throw()
+bool ListModelWrapper::init_gtktreeiter(GtkTreeIter *it, const bec::NodeId &node) const
 {
   if ( _tm && it && node.is_valid() )
   {
-    it->stamp      = _stamp;
-    it->user_data  = _tm;
-    it->user_data2 = _tm->nodeid_to_uid(node);
+    Index id(it, node);
+    id.stamp(_stamp);
   }
   return it && node.is_valid();
 }
 
 
-bec::NodeId ListModelWrapper::node_for_iter(const iterator &iter) const throw()
+//------------------------------------------------------------------------------
+bec::NodeId ListModelWrapper::node_for_iter(const iterator &iter) const
 {
   const GtkTreeIter* it = iter.gobj();
-  bec::ListModel   *tm = reinterpret_cast<bec::ListModel*>(it->user_data);
-  bec::NodeId::uid uid = reinterpret_cast<bec::NodeId::uid>(it->user_data2);
+  bec::NodeId  node;
 
-  if ( tm && tm == _tm && uid )
+  if ( it )
   {
-    try
-    {
-      if (it->stamp == _stamp)
-        return bec::NodeId(tm->nodeuid_to_path(uid));
-      else
-        g_warning("reference to invalid iter in grt list/tree model");
-    }
-    catch (...)
-    {}
+    const Index id(it);
+    if (id.cmp_stamp(_stamp))
+      node = id.to_node();
   }
-  return bec::NodeId();
+
+  return node;
 }
 
 //------------------------------------------------------------------------------
@@ -572,8 +739,7 @@ void ListModelWrapper::set_fake_column_value_setter(FakeColumnValueSetter fake_s
 void ListModelWrapper::reset_iter(iterator& iter) const throw()
 {
   GtkTreeIter *it = iter.gobj();
-  it->stamp = 0;
-  it->user_data = it->user_data2 = 0;
+  Index::reset_iter(it);
 }
 
 //------------------------------------------------------------------------------
