@@ -23,6 +23,66 @@
 #include "wbdbg.h"
 #include <sstream>
 
+//==============================================================================
+//
+//==============================================================================
+template <int T>
+struct Pow
+{
+  enum {Value = 256  *  Pow<T - 1>::Value};
+};
+
+template <>
+struct Pow<0>
+{
+  enum {Value=1};
+};
+
+//==============================================================================
+//
+//==============================================================================
+struct Index
+{
+    struct Info
+    {
+      unsigned int mode : 2;
+      unsigned int stamp : 6;
+    };
+  public:
+    typedef std::set<std::string>     ExternalMap;
+    enum {K = 3, StampMax = 0x3f, ModeMask = 0xC0, MaxDepth = (sizeof(GtkTreeIter) - 1) / K, MaxValue = Pow<K>::Value - 1};
+    enum Mode {Internal = 0x01, External = 0x02, ListNode = 0x03};
+
+    Index(GtkTreeIter* it, const bec::NodeId& node);
+    Index(const GtkTreeIter* it);
+
+    int stamp() const;
+    void stamp(const int st);
+    bool cmp_stamp(const int st) const;
+
+    Mode mode() const
+    {
+      return (Mode)(((Info*)_raw_data)->mode);
+    }
+    void mode(const Mode m)
+    {
+      ((Info*)_raw_data)->mode = m;
+    }
+
+    bec::NodeId to_node() const;
+    static void reset_iter(GtkTreeIter* it);
+
+  private:
+    int  word(const int w) const;
+    void word(const int w, const int v);
+
+    char*                   _raw_data;
+    static ExternalMap      _ext_map;
+    std::string            *_ext;
+};
+
+
+
 //! \brief if a column created by TreeModelWrapper should be read only or editable
 enum {READONLY_COLUMN = 0, EDITABLE_COLUMN = 1};
 
@@ -239,7 +299,7 @@ class ListModelWrapper : public Glib::Object, public Gtk::TreeModel,
       return _icon_size;
     }
 
-    bec::NodeId node_for_iter(const iterator &iter) const throw();
+    bec::NodeId node_for_iter(const iterator &iter) const;
 
     virtual bec::NodeId get_node_for_path(const Gtk::TreeModel::Path &path) const;
   
@@ -461,7 +521,7 @@ class ListModelWrapper : public Glib::Object, public Gtk::TreeModel,
     virtual bool drag_data_received_vfunc(const Gtk::TreeModel::Path& dest, const Gtk::SelectionData& selection_data);
 
   protected:
-    bool init_gtktreeiter(GtkTreeIter* it, const bec::NodeId &uid= bec::NodeId()) const throw();
+    virtual bool init_gtktreeiter(GtkTreeIter* it, const bec::NodeId &uid= bec::NodeId()) const;
     void reset_iter(iterator& iter) const throw();
 
     bec::ListModel  *_tm;
@@ -470,6 +530,7 @@ class ListModelWrapper : public Glib::Object, public Gtk::TreeModel,
     int              _stamp;              //!< stamp to check if an iterator is invalid
     ColumnsModel     _columns;            //!< Generic model of columns
     bec::IconSize    _icon_size;          //!< icon size to set by mode view changed buttons
+    ListModelWrapper** _self_ref; // hack to workaround a crash.. 
 
     std::string      _name;
 
