@@ -1,5 +1,4 @@
 #include <gtkmm.h>
-#include "MGGladeXML.h"
 #include "toolbar_manager.h"
 #include "workbench/wb_command_ui.h"
 #include "image_cache.h"
@@ -31,7 +30,7 @@ static Gtk::ComboBox *create_color_combo(const std::vector<std::string> &colors,
   }
 
   Glib::RefPtr<Gtk::ListStore> model= Gtk::ListStore::create(*color_combo_columns);
-  Gtk::ComboBox *combo= new Gtk::ComboBox(model);
+  Gtk::ComboBox *combo= new Gtk::ComboBox(Glib::RefPtr<Gtk::TreeModel>(model));
 
   combo->pack_start(color_combo_columns->image);
 
