@@ -72,13 +72,15 @@ class SqlEditorFE : public sigc::trackable
     void paste();
     bool has_selection();
     bool is_editable();
-    void find_text(const std::string &text, bool match_case=false, bool match_whole_word=false);
+    bool find_text(const std::string &text, bool match_case=false, bool match_whole_word=false);
   
     bool can_undo();
     bool can_redo();
     void undo();
     void redo();
-  
+
+    void toggle_wrap_lines();
+
   private:
     void init_lexer();
 
