@@ -7,8 +7,7 @@
 #define _DIAGRAM_SIZE_FORM_H_
 
 #include <gtkmm/dialog.h>
-
-class MGGladeXML;
+#include <gtkmm/builder.h>
 
 namespace wb
 {
@@ -24,17 +23,17 @@ namespace mdc
 
 class DiagramSizeForm : public Gtk::Dialog
 {
-  MGGladeXML *_xml;
+  Glib::RefPtr<Gtk::Builder> _xml;
   mdc::GtkCanvas *_canvas;
   wb::DiagramOptionsBE *_be;
 
   void realize_be(wb::WBContextUI *wbui);
-  void init(wb::WBContextUI *wb, MGGladeXML *xml);
+  void init(wb::WBContextUI *wb);
   void spin_changed();
   void changed();
   void ok_clicked();
 public:
-  DiagramSizeForm(GtkDialog *gobj);
+  DiagramSizeForm(GtkDialog *gobj, Glib::RefPtr<Gtk::Builder> xml);
   virtual ~DiagramSizeForm();
 
   static DiagramSizeForm *create(wb::WBContextUI *wb);
