@@ -36,6 +36,9 @@
 #include "mforms/../gtk/lf_menubar.h"
 #include "mforms/../gtk/lf_toolbar.h"
 
+#include <base/log.h>
+ENABLE_LOG("linux.ui")
+
 using base::strfmt;
 
 
@@ -60,6 +63,8 @@ static void set_window_icons(Gtk::Window *window)
   window->set_icon_list(icons);
 }
 
+static Gtk::Window *_dummy_window = 0;
+static Gdk::Color _sys_selection_color;
 
 //------------------------------------------------------------------------------
 // @ctx is passed from Program class, see Program::Program
@@ -67,11 +72,25 @@ MainForm::MainForm(wb::WBContextUI* ctx)
   : _wbui_context(ctx),
     _exiting(false)
 {
+  _dummy_window = new Gtk::Window(Gtk::WINDOW_TOPLEVEL);
+  gtk_widget_realize(GTK_WIDGET(_dummy_window->gobj()));
+
   setup_mforms_app();
   
   bec::GRTManager *grtm= _wbui_context->get_wb()->get_grt_manager();
-  _ui= new MGGladeXML(grtm->get_data_file_path("wb.glade").c_str(), "", "");
-  _toolbar_manager = new ToolbarManager(ctx->get_command_ui());
+  _ui= Gtk::Builder::create_from_file(grtm->get_data_file_path("wb.glade"));
+
+ {
+    Gtk::TreeView dummy_treeview;
+    _dummy_window->add(dummy_treeview);
+    dummy_treeview.show();
+// There is some bug in Fedora 14 where this code causes other stuff later to crash
+// The same code works just fine in Ubuntu, where the exact same version of gtk is shipped
+//    _sys_selection_color= Gtk::RC::get_style(dummy_treeview)->get_bg(Gtk::STATE_SELECTED);
+    GtkStyle *style = gtk_rc_get_style(GTK_WIDGET(dummy_treeview.gobj()));
+    if (style)
+      _sys_selection_color = Gdk::Color(&style->bg[GTK_STATE_SELECTED]);
+  }
 
   _accel_group = get_mainwindow()->get_accel_group();
   if (!_accel_group)
@@ -87,7 +106,6 @@ MainForm::MainForm(wb::WBContextUI* ctx)
   get_mainwindow()->set_title("MySQL Workbench");
   
   //_accel_group= Gtk::AccelGroup::create();
-  _menu_manager = new MenuManager(ctx->get_command_ui(), _accel_group);
   //get_mainwindow()->add_accel_group(_accel_group);
 
   _model_panel= 0;
@@ -95,9 +113,9 @@ MainForm::MainForm(wb::WBContextUI* ctx)
   _find_panel= 0;
 
   get_upper_note()->signal_switch_page().connect(sigc::mem_fun(*this, &MainForm::switch_page));
-  
+
   Gtk::Statusbar *status = 0;
-  _ui->get("statusbar1", &status);
+  _ui->get_widget("statusbar1", status);
   if (status)
   {
     status->pack_end(_progress_bar, false, false);
@@ -114,14 +132,7 @@ MainForm::~MainForm()
 {
   notify_callbacks(); // disconnect all signals
   
-
-  delete _menu_manager;
-  _menu_manager= 0;
-  delete _toolbar_manager;
   delete _model_panel;
-
-  delete _ui;
-  _ui= 0;
 }
 
 //------------------------------------------------------------------------------
@@ -205,7 +216,7 @@ void MainForm::show()
 Gtk::Window* MainForm::get_mainwindow() const
 {
   Gtk::Window *win = 0;
-  _ui->get("wb_main_window", &win);
+  _ui->get_widget("wb_main_window", win);
 
   return win;
 }
@@ -214,7 +225,7 @@ Gtk::Window* MainForm::get_mainwindow() const
 Gtk::Notebook *MainForm::get_upper_note() const
 {
   Gtk::Notebook *note= 0;
-  _ui->get("model_tabs", &note);
+  _ui->get_widget("model_tabs", note);
   return note;
 }
 
@@ -232,7 +243,7 @@ void MainForm::show_status_text_becb(const std::string& text)
 {
   Gtk::Statusbar *status = 0;
 
-  _ui->get("statusbar1", &status);
+  _ui->get_widget("statusbar1", status);
 
   if (_wbui_context->get_wb()->get_grt_manager()->in_main_thread())
     change_status(status, text);
@@ -242,6 +253,18 @@ void MainForm::show_status_text_becb(const std::string& text)
 }
 
 
+//------------------------------------------------------------------------------
+void MainForm::quit_app_becb()
+{
+  Gtk::Notebook *note = get_upper_note();
+  while (note->get_n_pages() > 0)
+  {
+    close_tab(note, note->get_nth_page(0));
+  }
+
+  Gtk::Main::quit();
+}
+
 //------------------------------------------------------------------------------
 bool MainForm::show_progress_becb(const std::string& title, const std::string& status, float pct)
 {
@@ -371,9 +394,17 @@ void MainForm::call_find()
       call_find_replace();
   }
 
-  Gtk::Box *box;
- // _toolbar_manager->focus_searchbox(_ui->get("main_toolbar", &box));
-#warning missing here
+  bec::UIForm *form = _wbui_context->get_active_main_form();
+  if (form)
+  {
+    mforms::ToolBar *toolbar = form->get_toolbar();
+    if (toolbar)
+    {
+      Gtk::Entry *entry = dynamic_cast<Gtk::Entry*>(mforms::gtk::widget_for_toolbar_item_named(toolbar, "searchbox"));
+      if (entry)
+        entry->grab_focus();
+    }
+  }
 }
 
 
@@ -538,7 +569,15 @@ void MainForm::call_search()
 {
   FormViewBase *form = reinterpret_cast<FormViewBase*>(get_upper_note()->get_nth_page(get_upper_note()->get_current_page())->get_data("FormViewBase"));
   if (form)
-    form->find_text(_toolbar_manager->get_search_text());
+  {
+    mforms::ToolBar *toolbar = form->get_form()->get_toolbar();
+    if (toolbar)
+    {
+      Gtk::Entry *entry = dynamic_cast<Gtk::Entry*>(mforms::gtk::widget_for_toolbar_item_named(toolbar, "searchbox"));
+      if (entry)
+        form->find_text(entry->get_text());
+    }
+  }
 }
 
 
@@ -1367,26 +1406,30 @@ void MainForm::close_active_tab()
       if (panel)
       {
         if (!panel->close_focused_tab())
-          close_tab(upper, page, sigc::mem_fun(panel, &FormViewBase::will_close));
+          close_tab(upper, page);
       }
       else
-        close_tab(upper, page, sigc::slot<bool>());
+        close_tab(upper, page);
     }
   }
 }
 
 
-void MainForm::close_tab(Gtk::Notebook *note, Gtk::Widget *page, const sigc::slot<bool> &on_close)
+void MainForm::close_tab(Gtk::Notebook *note, Gtk::Widget *page)
 {
   // on_close should return true if the form should be closed/removed
-  if (on_close)
+  mforms::AppView *app_view = reinterpret_cast<mforms::AppView*>(page->get_data("AppView"));
+  FormViewBase *form = reinterpret_cast<FormViewBase*>(page->get_data("FormViewBase"));
+
+  if (app_view || form)
   {
-    if (on_close())
+    if ((app_view && app_view->on_close()) || (form && form->on_close()))
     {
-      bool is_appview = page->get_data("AppView") != 0;
       page->hide();
+      if (form)
+        form->dispose();
       note->remove_page(*page);
-      if (!is_appview)
+      if (app_view == 0)
         page->unreference();
     }
     else
@@ -1412,7 +1455,6 @@ void MainForm::close_tab(Gtk::Notebook *note, Gtk::Widget *page, const sigc::slo
 
 void MainForm::append_tab_page(Gtk::Notebook *note, Gtk::Widget *widget, const std::string &title,
                                bool auto_switch,
-                               const sigc::slot<bool> &on_close,
                                Gtk::Label **title_label_ret)
 {
   // Make a lookup of existing page with the same content
@@ -1430,7 +1472,7 @@ void MainForm::append_tab_page(Gtk::Notebook *note, Gtk::Widget *widget, const s
   {
     Gtk::Widget *tab= 
       create_closeable_tab(title, sigc::bind(sigc::mem_fun(this, &MainForm::close_tab),
-                                             note, widget, on_close),
+                                             note, widget),
                            title_label_ret);
 
     note->append_page(*widget, *tab);
@@ -1484,8 +1526,7 @@ void MainForm::add_form_pane(FormViewBase *panel, bool opened)
   panel->get_panel()->set_data("FormViewBase", panel);
   panel->get_panel()->set_data("uiform", dynamic_cast<bec::UIForm*>(panel->get_form()));
 
-  append_tab_page(get_upper_note(), panel->get_panel(), panel->get_title(), opened,
-                  sigc::mem_fun(panel, &FormViewBase::will_close));
+  append_tab_page(get_upper_note(), panel->get_panel(), panel->get_title(), opened);
   if (!opened)
     panel->get_panel()->hide();
 
@@ -1590,19 +1631,19 @@ void MainForm::show_diagram_options()
 void MainForm::show_find()
 {
   if (!_find_panel)
-  {
+  {/*
     _find_panel= FindPanel::create(_wbui_context);
 
     Gtk::VBox *vbox;
-    _ui->get("inner_vbox", &vbox);
+    _ui->get_widget("inner_vbox", vbox);
 
     vbox->pack_start(*_find_panel, false, false);
     vbox->reorder_child(*_find_panel, 0);
     _find_panel->unreference();
-
+*/
   }
 
-  _find_panel->show();
+  //_find_panel->show();
 }
 
 
@@ -1653,6 +1694,41 @@ void MainForm::set_status_text(mforms::App* app, const std::string &text)
   self->show_status_text_becb(text);
 }
 
+//------------------------------------------------------------------------------
+static MySQL::Drawing::Color gdk_color_to_mforms(const Gdk::Color& c)
+{
+  return MySQL::Drawing::Color(c.get_red_p(), c.get_green_p(), c.get_blue_p(), 1);
+}
+
+
+//------------------------------------------------------------------------------
+static MySQL::Drawing::Color get_system_color(mforms::SystemColor type)
+{
+  typedef std::map<mforms::SystemColor, MySQL::Drawing::Color*> Colors;
+  static Colors     colors;
+
+  MySQL::Drawing::Color ret;
+
+  switch (type)
+  {
+    case mforms::SystemHighlight:
+    {
+      Colors::const_iterator it = colors.find(type);
+      if (it != colors.end())
+        ret = *(it->second);
+      else
+      {
+        MySQL::Drawing::Color* new_color = new MySQL::Drawing::Color(gdk_color_to_mforms(_sys_selection_color));
+        colors[type] = new_color;
+        ret = *new_color;
+      }
+      break;
+    }
+  }
+
+  return ret;
+}
+
 
 static void begin_thread_loop()
 {
@@ -1663,12 +1739,53 @@ static void end_thread_loop()
 }
 
 
-static std::list<std::pair<int,int> > event_loop_exit_codes;
+struct EventLoopFrame
+{
+  int exit_code;
+  bool timedout;
+  bool ended;
+};
+
+static std::list<EventLoopFrame*> event_loop_exit_codes;
+
+static bool event_loop_timeout()
+{
+  if (!event_loop_exit_codes.empty())
+  {
+    EventLoopFrame *frame = event_loop_exit_codes.back();
+    if (!frame->timedout && !frame->ended)
+    {
+      frame->timedout = true;
+      Gtk::Main::quit();
+    }
+  }
+  return false;
+}
 
 static int begin_event_loop(mforms::App*,float timeout)
 {
+  EventLoopFrame frame;
+
+  frame.exit_code = -1;
+  frame.timedout = false;
+  frame.ended = false;
+
+  sigc::connection timeout_conn;
+  if (timeout > 0.0)
+    timeout_conn = Glib::signal_timeout().connect(sigc::ptr_fun(event_loop_timeout), (unsigned int)(timeout * 1000)); 
+
+  event_loop_exit_codes.push_back(&frame);
+
   Gtk::Main::run();
-  if (event_loop_exit_codes.empty() || event_loop_exit_codes.back().first != (int)Gtk::Main::level())
+
+  timeout_conn.disconnect();
+  if (event_loop_exit_codes.empty() || event_loop_exit_codes.back() != &frame)
+  {
+    g_warning("Internal inconsistency in begin_event_loop");
+    return -1;
+  }
+
+  if (!frame.ended && !frame.timedout)
   {
     // means something other than end_event_loop() called quit(), could mean the app is being quit.. 
     Gtk::Main::quit();
@@ -1676,7 +1793,7 @@ static int begin_event_loop(mforms::App*,float timeout)
   }
   else
   {
-    int rc = event_loop_exit_codes.back().second;
+    int rc = event_loop_exit_codes.back()->exit_code;
     event_loop_exit_codes.pop_back();
     return rc;
   }
@@ -1684,8 +1801,17 @@ static int begin_event_loop(mforms::App*,float timeout)
 
 static void end_event_loop(mforms::App *,int rc)
 {
-  Gtk::Main::quit();
-  event_loop_exit_codes.push_back(std::make_pair(Gtk::Main::level()-1, rc));
+  if (event_loop_exit_codes.empty())
+  {
+    g_warning("Attempt to exit unexisting event loop");
+    return;
+  }
+    
+  if (!event_loop_exit_codes.back()->timedout)
+  {
+    event_loop_exit_codes.back()->exit_code = rc;
+    Gtk::Main::quit();
+  }
 }
 
 void MainForm::setup_mforms_app()
@@ -1706,6 +1832,7 @@ void MainForm::setup_mforms_app()
   cf->_app_impl.end_thread_loop= &end_thread_loop;
   cf->_app_impl.enter_event_loop= &begin_event_loop;
   cf->_app_impl.exit_event_loop= &end_event_loop;
+  cf->_app_impl.get_system_color= &get_system_color;
 }
 
 
@@ -1719,6 +1846,7 @@ Gtk::Widget *MainForm::decorate_widget(Gtk::Widget *panel, bec::UIForm *form)
   if (menu)
   {
     Gtk::Widget *w = mforms::gtk::widget_for_menubar(menu);
+    w->set_name(form->get_form_context_name());
     top_box->pack_start(*w, false, true);
     w->show();
   }
@@ -1771,8 +1899,7 @@ void MainForm::dock_view(mforms::App *app, mforms::AppView *view, const std::str
     
     if (!view->get_menubar())
     {
-      view->set_menubar(self->_wbui_context->get_command_ui()->create_menubar_for_context(""));
-      view->get_menubar()->set_managed();
+      view->set_menubar(mforms::manage(self->_wbui_context->get_command_ui()->create_menubar_for_context("")));
       view->get_menubar()->release();
     }
 
@@ -1794,7 +1921,6 @@ void MainForm::dock_view(mforms::App *app, mforms::AppView *view, const std::str
     {
       Gtk::Label *label= 0;
       self->append_tab_page(self->get_upper_note(), decorated, "", true,
-                            sigc::mem_fun(view, &mforms::AppView::on_close),
                             &label);    
       w->set_data("tablabel", label);
     }
@@ -1806,7 +1932,6 @@ void MainForm::dock_view(mforms::App *app, mforms::AppView *view, const std::str
     Gtk::Label *label= 0;
     
 ///    self->append_tab_page(self->get_lower_note(), w, "", true,
-///                          sigc::mem_fun(view, &mforms::AppView::on_close),
 ///                          &label);
     w->set_data("tablabel", label);
 ///    w->set_data("containerNote", self->get_lower_note());
