@@ -2,7 +2,6 @@
 #include "sqlide/utils_fe.h"
 #include "linux_utilities/gtk_helpers.h"
 #include "sql_snippets_view.h"
-#include "workbench/menu_manager.h"
 #include "mforms/utilities.h"
 #include <boost/foreach.hpp>
 #include <fstream>
@@ -52,37 +51,43 @@ void DbSqlEditorView::refresh_ui(const int what)
 
 DbSqlEditorView *DbSqlEditorView::create(Db_sql_editor::Ref editor_be)
 {
-  MGGladeXML *xml = new MGGladeXML(editor_be->grt_manager()->get_data_file_path("db_sql_editor_view.glade"));
-  GtkVBox *vbox = GTK_VBOX(xml->get_unwrapped("db_sql_editor_view"));
-  g_object_ref_sink(vbox);
-  gtk_widget_unparent(GTK_WIDGET(vbox));
+  Glib::RefPtr<Gtk::Builder> xml = Gtk::Builder::create_from_file(editor_be->grt_manager()->get_data_file_path("db_sql_editor_view.glade"));
   
-  DbSqlEditorView *v = Gtk::manage(new DbSqlEditorView(editor_be, vbox, xml));
+  DbSqlEditorView *v = 0;
+  xml->get_widget_derived<DbSqlEditorView>("db_sql_editor_view", v);
+  v = Gtk::manage(v);
+  v->post_construct(editor_be);
   
   return v;
 }
 
 
-DbSqlEditorView::DbSqlEditorView(Db_sql_editor::Ref editor_be, GtkVBox *vbox, MGGladeXML *xml)
+DbSqlEditorView::DbSqlEditorView(GtkVBox *vbox, Glib::RefPtr<Gtk::Builder> xml)
 :
 Gtk::VBox(vbox),
 FormViewBase(),
 _xml(xml),
-_live_physical_overview(0),
-_closing(false)
+_closing(false),
+_live_physical_overview(0)
 {
+}
+
+
+void DbSqlEditorView::post_construct(Db_sql_editor::Ref editor_be)
+{
+  Gtk::Widget *v = this;
   _be= editor_be;
 
   if (editor_be->wbsql()->get_wbui()->get_wb()->get_wb_options().get_int("Sidebar:RightAligned", 0))
   {
     Gtk::Paned *paned;
-    _xml->get("hpaned1", &paned);
+    _xml->get_widget("hpaned1", paned);
     swap_panned_children(paned, true);
   }
 
   {
     Gtk::Container *placeholder;
-    _xml->get("sql_snippets_placeholder", &placeholder);
+    _xml->get_widget("sql_snippets_placeholder", placeholder);
 
     wb::WBContextUI *wbui= editor_be->wbsql()->get_wbui();
     _sql_snippets_view= Gtk::manage(new SqlSnippetsView(wbui, _xml));
@@ -103,7 +108,7 @@ _closing(false)
   mforms::View *sbview = _be->get_sidebar();
   Gtk::Widget *sidebar = mforms::gtk::ViewImpl::get_widget_for_view(sbview);
   Gtk::Container *place;
-  _xml->get("sidebar_placeholder", &place);
+  _xml->get_widget("sidebar_placeholder", place);
   place->add(*sidebar);
   sidebar->show();
   
@@ -111,8 +116,7 @@ _closing(false)
   
   // setup toolbar and menubar
   {
-    Gtk::VBox *vbox;
-    _xml->get("db_sql_editor_view", &vbox);
+    Gtk::VBox *vbox = this;
     
     Gtk::Widget *w;
     mforms::ToolBar *tbar = _be->get_toolbar();
@@ -135,12 +139,18 @@ _closing(false)
 
 
 DbSqlEditorView::~DbSqlEditorView()
+{
+}
+
+//------------------------------------------------------------------------------
+void DbSqlEditorView::dispose()
 {
   if (_live_physical_overview)
-  _live_physical_overview->reset();
+    _live_physical_overview->reset();
   delete _live_physical_overview;
   _be->close();
-  delete _xml;
+  _be.reset();
+  _xml.clear();
 }
 
 //------------------------------------------------------------------------------
@@ -153,7 +163,7 @@ bool DbSqlEditorView::toolbar_action(const std::string& item)
 //------------------------------------------------------------------------------
 void DbSqlEditorView::init()
 {
-  _xml->get("editor_note", &_editor_note);
+  _xml->get_widget("editor_note", _editor_note);
   _editor_note->signal_switch_page().connect(sigc::mem_fun(this, &DbSqlEditorView::editor_page_switched));
     
   _be->sql_editor_new_ui.connect(sigc::bind_return(sigc::hide(sigc::mem_fun(this, &DbSqlEditorView::add_editor_tab)), 0));
@@ -162,19 +172,19 @@ void DbSqlEditorView::init()
         sigc::mem_fun(this, &DbSqlEditorView::explain_sql),
         sigc::mem_fun(this, &DbSqlEditorView::validate_explain_sql));
 
-  _xml->get("output_text", &_output_text);
+  _xml->get_widget("output_text", _output_text);
   {
     Pango::FontDescription font(_output_text->get_style()->get_font());
     font.set_family("Bitstream Vera Sans Mono");
     _output_text->modify_font(font);
   }
   Gtk::Button *clear_button;
-  _xml->get("output_clear_button", &clear_button);
+  _xml->get_widget("output_clear_button", clear_button);
   clear_button->signal_clicked().connect(sigc::mem_fun(this, &DbSqlEditorView::clear_output));
 
   // tab control
-  _xml->get("db_sql_editor_tab_pages", &_tab_pages);
-  _xml->get("log_page", &_log_page);
+  _xml->get_widget("db_sql_editor_tab_pages", _tab_pages);
+  _xml->get_widget("log_page", _log_page);
 
   // this is the lower tabview
   _tab_pages->signal_switch_page().connect(sigc::mem_fun(this, &DbSqlEditorView::lower_page_switched));
@@ -186,14 +196,16 @@ void DbSqlEditorView::init()
     Glib::RefPtr<Gtk::AccelGroup> _accel_group= Gtk::AccelGroup::create();//!
     _live_physical_overview= new OverviewPanel(_be->wbsql()->get_wbui(), _be->live_physical_overview(), true);
 
-    Gtk::HBox *live_physical_overview_toolbar = _xml->get("live_physical_overview_toolbar", &live_physical_overview_toolbar);
+    Gtk::HBox *live_physical_overview_toolbar = 0;
+    _xml->get_widget("live_physical_overview_toolbar", live_physical_overview_toolbar);
     ToolbarManager::rebuild_toolbar(live_physical_overview_toolbar,
                                     _be->live_physical_overview()->get_toolbar_items(bec::NodeId(0)),
                                     sigc::slot<Gtk::Widget*,bec::ToolbarItem>(),
                                     sigc::mem_fun(this, &DbSqlEditorView::toolbar_action)
                                    );
 
-    Gtk::Viewport *live_physical_overview_placeholder = _xml->get("live_physical_overview_placeholder", &live_physical_overview_placeholder);
+    Gtk::Viewport *live_physical_overview_placeholder = 0;
+    _xml->get_widget("live_physical_overview_placeholder", live_physical_overview_placeholder);
     live_physical_overview_placeholder->add(*_live_physical_overview);
     _live_physical_overview->set_data("FormViewBase", _live_physical_overview);
     _live_physical_overview->set_data("uiform", dynamic_cast<bec::UIForm*>(get_form())); //!_live_physical_overview->get_form()
@@ -204,7 +216,7 @@ void DbSqlEditorView::init()
     if (!_be->is_physical_overview_enabled())
     {
       Gtk::Container *live_physical_overview_page;
-      _xml->get("live_physical_overview_page", &live_physical_overview_page);
+      _xml->get_widget("live_physical_overview_page", live_physical_overview_page);
       int tab_page_index= _tab_pages->page_num(*live_physical_overview_page);
       _tab_pages->remove_page(tab_page_index);
     }
@@ -212,7 +224,8 @@ void DbSqlEditorView::init()
 
   // log panel
   //WIDGET_DEF (_xml, Container, log_placeholder) // auto-replaced
-  Gtk::Container *log_placeholder = _xml->get("log_placeholder", &log_placeholder);
+  Gtk::Container *log_placeholder = 0;
+  _xml->get_widget("log_placeholder", log_placeholder);
   _log_view= GridView::create(_be->log());
   log_placeholder->add(*_log_view);
   _log_view->row_numbers_visible(false);
@@ -220,33 +233,35 @@ void DbSqlEditorView::init()
     sigc::bind<bool>(sigc::mem_fun(_log_view, &GridView::refresh), false);
   _log_view->refresh(true);
 
-  //Gtk::HBox *output_toolbar = _xml->get("output_toolbar", &output_toolbar);
+  //Gtk::HBox *output_toolbar = _xml->get_widget("output_toolbar", output_toolbar);
   //ToolbarManager::rebuild_toolbar(output_toolbar,
   //                                _be->log()->get_toolbar_items(bec::NodeId(0)),
   //                                sigc::mem_fun(this, &DbSqlEditorView::output_toolbar_action)
   //                               );
 
 
-  _xml->get("log_event_detail_action_text_view", &_log_event_detail_action_text_view);
-  _xml->get("log_event_detail_message_text_view", &_log_event_detail_message_text_view);
+  _xml->get_widget("log_event_detail_action_text_view", _log_event_detail_action_text_view);
+  _xml->get_widget("log_event_detail_message_text_view", _log_event_detail_message_text_view);
 
-  _xml->get("output_note", &_output_note);
+  _xml->get_widget("output_note", _output_note);
   
   Gtk::RadioButton *radio;
-  _xml->get("output_radio1", &radio);
+  _xml->get_widget("output_radio1", radio);
   radio->signal_toggled().connect(sigc::bind(sigc::mem_fun(_output_note, &Gtk::Notebook::set_current_page), 0));
-  _xml->get("output_radio2", &radio);
+  _xml->get_widget("output_radio2", radio);
   _output_text_radio= radio;
   radio->signal_toggled().connect(sigc::bind(sigc::mem_fun(_output_note, &Gtk::Notebook::set_current_page), 1));
-  _xml->get("output_radio3", &radio);
+  _xml->get_widget("output_radio3", radio);
   radio->signal_toggled().connect(sigc::bind(sigc::mem_fun(_output_note, &Gtk::Notebook::set_current_page), 2));
   
   _log_view->get_selection()->signal_changed().connect(sigc::mem_fun(this, &DbSqlEditorView::on_log_view_selection_changed));
   on_log_view_selection_changed();
 
   // history panels
-  Gtk::Container *history_entries_placeholder = _xml->get("history_entries_placeholder", &history_entries_placeholder);
-  Gtk::Container *history_details_placeholder = _xml->get("history_details_placeholder", &history_details_placeholder);
+  Gtk::Container *history_entries_placeholder = 0;
+  _xml->get_widget("history_entries_placeholder", history_entries_placeholder);
+  Gtk::Container *history_details_placeholder = 0;
+  _xml->get_widget("history_details_placeholder", history_details_placeholder);
   _history_entries_view= GridView::create(_be->history()->entries_model());
   _history_details_view= GridView::create(_be->history()->details_model());
   history_entries_placeholder->add(*_history_entries_view);
@@ -258,7 +273,7 @@ void DbSqlEditorView::init()
   _history_entries_view->refresh(true);
   _history_details_view->refresh(true);
 
-  //Gtk::HBox *history_toolbar = _xml->get("history_toolbar", &history_toolbar);
+  //Gtk::HBox *history_toolbar = _xml->get_widget("history_toolbar", history_toolbar);
   //ToolbarManager::rebuild_toolbar(history_toolbar,
   //                                _be->history()->get_toolbar_items(bec::NodeId(0)),
   //                                sigc::mem_fun(this, &DbSqlEditorView::output_toolbar_action)
@@ -270,13 +285,15 @@ void DbSqlEditorView::init()
   _on_history_entries_selection_changed_cb= sigc::mem_fun(this, &DbSqlEditorView::on_history_entries_selection_changed);
   _history_entries_view->get_selection()->signal_changed().connect(_on_history_entries_selection_changed_cb);
   _history_details_view->signal_event().connect(sigc::mem_fun(this, &DbSqlEditorView::on_history_details_view_event));
-  _xml->get("history_details_popup_menu", &_history_details_popup_menu);
+  _xml->get_widget("history_details_popup_menu", _history_details_popup_menu);
   {
-    Gtk::MenuItem *w = _xml->get("append_to_sql_script_menuitem", &w);
+    Gtk::MenuItem *w = 0;
+    _xml->get_widget("append_to_sql_script_menuitem", w);
     w->signal_activate().connect(sigc::mem_fun(this, &DbSqlEditorView::on_append_to_sql_script_menuitem_activate));
   }
   {
-    Gtk::MenuItem *w = _xml->get("replace_sql_script_menuitem", &w);
+    Gtk::MenuItem *w = 0;
+    _xml->get_widget("replace_sql_script_menuitem", w);
     w->signal_activate().connect(sigc::mem_fun(this, &DbSqlEditorView::on_replace_sql_script_menuitem_activate));
   }
   
@@ -288,7 +305,7 @@ void DbSqlEditorView::init()
   }
 }
 
-bool DbSqlEditorView::will_close()
+bool DbSqlEditorView::on_close()
 {
   if (_be->can_close())
   {
@@ -760,7 +777,7 @@ void DbSqlEditorView::toggle_sidebar()
 {
   Gtk::Widget *sidebar;
   
-  _xml->get("sidebar_placeholder", &sidebar);
+  _xml->get_widget("sidebar_placeholder", sidebar);
   
   if (sidebar->is_visible())
     sidebar->hide();
