@@ -1,7 +1,6 @@
 #ifndef __DB_SQL_EDITOR_VIEW_H__
 #define __DB_SQL_EDITOR_VIEW_H__
 
-#include "linux_utilities/MGGladeXML.h"
 #include "sqlide/wb_sql_editor_form.h"
 #include "sqlide/sql_editor_fe.h"
 #include "sqlide/recordset_view.h"
@@ -13,13 +12,15 @@ class ToolbarManager;
 
 class DbSqlEditorView : public Gtk::VBox, public FormViewBase
 {
-  DbSqlEditorView(Db_sql_editor::Ref editor_be, GtkVBox *vbox, MGGladeXML *xml);
 public:
+  DbSqlEditorView(GtkVBox *vbox, Glib::RefPtr<Gtk::Builder> xml);
+  void post_construct(Db_sql_editor::Ref editor_be);
   static DbSqlEditorView *create(Db_sql_editor::Ref editor_be);
   virtual ~DbSqlEditorView();
 
   virtual void init();
-  virtual bool will_close();
+  virtual bool on_close();
+  virtual void dispose();
 
   virtual bec::BaseEditor* get_be() { return NULL; }
   virtual std::string get_title() { return _be->caption(); }
@@ -34,7 +35,7 @@ private:
 
   Glib::Dispatcher _dispatch_rset_update;
   Db_sql_editor::Ref _be;
-  MGGladeXML *_xml;
+  Glib::RefPtr<Gtk::Builder> _xml;
   std::vector<boost::shared_ptr<SqlEditorFE> > _sql_editors;
   Gtk::Container *_view;
   Gtk::Notebook *_tab_pages;
