@@ -118,15 +118,30 @@
 
 - (void) doCustomize;
 {
-	mTabPlacement = WBTabPlacementTop;
-	mTabDirection = WBTabDirectionUp;
-	mTabSize = WBTabSizeLarge;
-	
-	[super doCustomize];
+  mTabPlacement = WBTabPlacementTop;
+  mTabDirection = WBTabDirectionUp;
+  mTabSize = WBTabSizeLarge;
+  
+  
+  [super doCustomize];
+  
+  NSRect r = [mTabView frame];
+  r.size.height -= 5;
+  [mTabView setFrame: r];
+}
+
+@end
+
+
+@implementation WBPaddedGrayTabView
+
+
+- (void) doCustomize
+{
+  [super doCustomize];
   
   NSRect r = [mTabView frame];
   r = NSInsetRect(r, 5, 0);
-  r.size.height -= 5;
   [mTabView setFrame: r];
 }
 
