@@ -52,7 +52,7 @@ static NSImage *descendingSortIndicator= nil;
     
     [column setDataCell: [[[MQResultSetCell alloc] init] autorelease]];
     [[column dataCell] setEditable: YES];
-    [[column dataCell] setLineBreakMode: NSLineBreakByClipping];
+    [[column dataCell] setLineBreakMode: NSLineBreakByTruncatingTail];
     
     [mTableView addTableColumn: column];
   }
@@ -612,20 +612,29 @@ static int onRefresh(MResultsetViewer *self)
 - (void) tableView: (NSTableView *) tableView
   didClickTableColumn: (NSTableColumn *) tableColumn
 {
-  int column_index= [[tableColumn identifier] intValue];  
-  ::bec::GridModel::SortColumns sort_columns= (*mData)->sort_columns();
-  int sort_order= 1; // ascending (1) on first click, descending (-1) on second, then toggling
-  for (::bec::GridModel::SortColumns::const_iterator i= sort_columns.begin(), end= sort_columns.end(); i != end; ++i)
+  if ([tableColumn identifier])
   {
-    if (i->first == column_index)
+    int column_index= [[tableColumn identifier] intValue];  
+    ::bec::GridModel::SortColumns sort_columns= (*mData)->sort_columns();
+    int sort_order= 1; // ascending (1) on first click, descending (-1) on second, then toggling
+    for (::bec::GridModel::SortColumns::const_iterator i= sort_columns.begin(), end= sort_columns.end(); i != end; ++i)
     {
-      sort_order= (1 == i->second) ? -1 : 0;
-      break;
+      if (i->first == column_index)
+      {
+        sort_order= (1 == i->second) ? -1 : 0;
+        break;
+      }
     }
+    if (0 == sort_order)
+      [mTableView setIndicatorImage:nil inTableColumn:tableColumn];
+    (*mData)->sort_by(column_index, sort_order, true);
+  }
+  else
+  {
+    // reset sorting if clicked the dummy column - change this to Select All, to match behaviour in Windows
+    //[mTableView setIndicatorImage:nil inTableColumn:tableColumn];
+    //(*mData)->sort_by(0, 0, false);
   }
-  if (0 == sort_order)
-    [mTableView setIndicatorImage:nil inTableColumn:tableColumn];
-  (*mData)->sort_by(column_index, sort_order, true);
 }
 
 @end
