@@ -60,6 +60,12 @@
           else
             enabled= false;
         }
+        else
+          if (iter->name == "toggle_wrap_lines")
+          {
+            int wrap_mode = [self getGeneralProperty: SCI_GETWRAPMODE]; // None=0, Word=1, Char=2
+            iter->checked = (wrap_mode == 1);
+          }
         iter->enabled= enabled;
       }
 
@@ -108,17 +114,26 @@
       [[self content] selectAll:nil];
     }
     else
-    {
-      try
+      if (action == "toggle_wrap_lines")
       {
-        mBackEnd->activate_context_menu_item(action); 
+        int wrap_mode = [self getGeneralProperty: SCI_GETWRAPMODE]; // None=0, Word=1, Char=2
+        if (wrap_mode == 1)
+          [self setGeneralProperty: SCI_SETWRAPMODE value: 0];
+        else
+          [self setGeneralProperty: SCI_SETWRAPMODE value: 1];
       }
-      catch (const std::exception &exc)
+      else
       {
-        NSRunAlertPanel(@"Error", @"Could not execute plugin: %s", @"OK", nil, nil,
-                        exc.what());
+        try
+        {
+          mBackEnd->activate_context_menu_item(action); 
+        }
+        catch (const std::exception &exc)
+        {
+          NSRunAlertPanel(@"Error", @"Could not execute plugin: %s", @"OK", nil, nil,
+                          exc.what());
+        }
       }
-    }
   }
 }
 
