@@ -284,7 +284,7 @@ objectValueForTableColumn: (NSTableColumn*) aTableColumn
   
   for (NSUInteger row= [selection firstIndex]; row != NSNotFound; row= [selection indexGreaterThanIndex:row])
   {
-    mBackEnd->history()->details_model()->get_field(row, 0, text);
+    mBackEnd->history()->details_model()->get_field(row, 1, text);
     query.append("\n").append(text);
   }
 
@@ -454,7 +454,7 @@ static void addTextToOutput(const std::string &text, bool bring_to_front, WBSQLQ
   
   [mLowerTabView selectTabViewItemWithIdentifier: @"messages"];
   
-  mBackEnd->exec_sql(text, [[self activeEditor] backEnd], false, currentStatementOnly);
+  mBackEnd->exec_sql(text, [[self activeEditor] backEnd], false, currentStatementOnly);  
 }
 
 
@@ -725,7 +725,7 @@ static void refreshUIPartial(const int what, WBSQLQueryPanel *panel)
       if (i != NSNotFound)
       {
         bec::NodeId node(bec::NodeId(0).append(i));
-        
+        panel->mBackEnd->live_physical_overview()->focus_node(node); // refocus the node
         for (int j= 0; j < 3; j++)
         {
           // this might not be the node that needs to be refreshed. this callback needs an extra argument
@@ -908,10 +908,9 @@ static int editorCreated(int editor_index, WBSQLQueryPanel *panel)
     
     DbSqlEditorSnippets::get_instance()->select_category([[categories objectAtIndex: 0] UTF8String]);
     [snippetTable reloadData];
-
     
     // realize pre-existing editors
-    while ([mUpperTabView numberOfTabViewItems] < mBackEnd->sql_editor_count())
+    for (int i = 0; i < mBackEnd->sql_editor_count(); i++)
     {
       [self addEditorTabWithBackEndIndex: [mUpperTabView numberOfTabViewItems]];
     }
