@@ -788,14 +788,15 @@ static void flush_main_thread()
 
 - (BOOL)application:(NSApplication *)theApplication openFile:(NSString *)filename
 {
+  std::string path = [filename fileSystemRepresentation];
   if (_initFinished)
   {
-    if (_wb->open_document([filename fileSystemRepresentation]))
+    if (_wb->open_file_by_extension(path, true))
       return YES;
   }
   else
   {
-    _options->open_at_startup= [filename fileSystemRepresentation];
+    _options->open_at_startup= path;
     return YES;
   }
   return NO;
@@ -820,6 +821,7 @@ static void flush_main_thread()
 - (void)applicationDidFinishLaunching:(NSNotification*)notification
 {
   _wb->get_ui()->init_finish(_options);
+
   _initFinished= YES;
   [[NSNotificationCenter defaultCenter] addObserver: self
                                            selector: @selector(windowDidBecomeKey:)
@@ -903,37 +905,40 @@ static NSString *applicationSupportFolder()
     _options->user_data_dir= [[applicationSupportFolder() stringByAppendingString: @"/MySQL/Workbench"] fileSystemRepresentation];
  
     // handle some command line options
-    // --model <modelfile>
-    // --query <connection>
-    // --admin <admin>
-    // --script <scriptfile>
-    // --run <script>
-    // --run-python <script>
-    // --run-lua <script>
+    // --model=<modelfile>
+    // --query=<connection>
+    // --admin=<admin>
+    // --script=<scriptfile>
+    // --run=<script>
+    // --run-python=<script>
+    // --run-lua=<script>
     // --quit-when-done
     {
       int argc= *_NSGetArgc();
       char **argv= *_NSGetArgv();
       for (int i= 1; i < argc; i++)
       {
-        if (strcmp(argv[i], "--model") == 0
-            || strcmp(argv[i], "--query") == 0
-            || strcmp(argv[i], "--admin") == 0
-            || strcmp(argv[i], "--script") == 0)
+        if (strncmp(argv[i], "--model=", strlen("--model=")) == 0
+            || strncmp(argv[i], "--query=", strlen("--query=")) == 0
+            || strncmp(argv[i], "--admin=", strlen("--admin=")) == 0
+            || strncmp(argv[i], "--script=", strlen("--script=")) == 0)
         {
-          _options->open_at_startup_type= argv[i]+2;
-          if (i+1 < argc)
-            _options->open_at_startup= argv[++i];
+          char *eq = strchr(argv[i], '=');
+          _options->open_at_startup_type= std::string(argv[i]+2, eq);
+          
+          if (strlen(eq+1) > 0)
+            _options->open_at_startup= eq+1;
           else
           {
             NSLog(@"Missing argument for %s option", argv[i]);
             exit(1);
           }
         }
-        else if (strcmp(argv[i], "--run") == 0)
+        else if (strncmp(argv[i], "--run=", strlen("--run=")) == 0)
         {
-          if (i+1 < argc)
-            _options->run_at_startup= argv[++i];
+          char *eq = strchr(argv[i], '=');
+          if (strlen(eq+1) > 0)
+            _options->run_at_startup= eq+1;
           else
           {
             NSLog(@"Missing argument for --run option");
@@ -942,23 +947,46 @@ static NSString *applicationSupportFolder()
         }
         else if (strncmp(argv[i], "--run-", strlen("--run-")) == 0)
         {
-          _options->run_language= argv[i]+strlen("--run-");
-          
-          if (i+1 < argc)
-            _options->run_at_startup= argv[++i];
-          else
+          char *eq = strchr(argv[i], '=');
+          if (!eq || strlen(eq+1) == 0)
           {
             NSLog(@"Missing argument for %s option", argv[i-1]);
             exit(1);
           }
+          
+          _options->run_language= std::string(argv[i]+strlen("--run-"), eq);
+          _options->run_at_startup= eq+1;
         }        
         else if (strcmp(argv[i], "--quit-when-done") == 0)
           _options->quit_when_done= true;
+        else if (strcmp(argv[i], "--help") == 0)
+        {
+          NSLog(@"%s [<options>] [<model file>]", argv[0]);
+          NSLog(@"--model=<model file>             Open a model file at startup");
+          NSLog(@"--query=<connection name>        Starts a query tab to the named connection");
+          NSLog(@"--admin=<instance name>          Starts the administrator for the named instance");
+          NSLog(@"--script=<script file>           Executes the script file");
+          NSLog(@"--run=<script code>              Executes the script code, in the default scripting language");
+          NSLog(@"--run-python=<python code>       Executes the given Python code");
+          NSLog(@"--run-lua=<lua code>             Executes the given Lua code");
+          NSLog(@"--quit-when-done                 Quits Workbench when the script finished executing");
+          NSLog(@"--version                        Print version information and exit");
+          NSLog(@"--help                           Print this message and exit");
+          exit(0);
+        }
+        else if (strcmp(argv[i], "--version") == 0)
+        {
+#ifdef EDITION_SE
+          NSLog(@"MySQL Workbench SE %i.%i.%i rev %i", APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, APP_REVISION_NUMBER);
+#else
+          NSLog(@"MySQL Workbench CE %i.%i.%i rev %i", APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, APP_REVISION_NUMBER);
+#endif
+          exit(0);
+        }
       }
     }
-
     //wboptions.open_at_startup = "";
-    
+
     // add shipped python module search path to PYTHONPATH
     // also include mysql utilities module zip
     {
@@ -979,7 +1007,7 @@ static NSString *applicationSupportFolder()
       // we ship 32bit binary python modules, so python needs to be started as 32bit as well
       putenv((char*)"VERSIONER_PYTHON_PREFER_32_BIT=yes");
     }
-    
+
     _wbui->init(&wbcallbacks, _options);
     
     _wb->flush_idle_tasks();
