@@ -1,5 +1,5 @@
 /* 
- * Copyright © 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  * 
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,10 +21,7 @@
 #import "WBModelSidebarController.h"
 
 @class WBMainController;
-@class WBToolbarTabView;
 @class WBQuerySidebarController;
-@class WBMenuManager;
-@class WBToolbarManager;
 @class WBBasePanel;
 @class WBModelOverviewPanel;
 @class WBSplitView;
@@ -50,6 +47,8 @@
 
   IBOutlet NSMenu *contextMenu;
   
+  IBOutlet NSView *tabSwitcher;
+  
   NSMutableDictionary *_panels;
   
   NSTimer *_backendTimer;
@@ -59,9 +58,8 @@
   
   WBMainController *_mainController;
   
-  WBMenuManager *_menuManager;
-  WBToolbarManager *_toolbarManager;
-
+  NSMenu *_defaultMainMenu;
+  
   WBModelOverviewPanel *_physicalOverview;
 
   int _eventLoopRetCode;
@@ -86,9 +84,6 @@
 
 - (WBMainController*)owner;
 
-- (WBMenuManager*)menuManager;
-- (WBToolbarManager*)toolbarManager;
-
 - (WBBasePanel*)selectedTopPanel;
 
 - (IBAction)showMySQLOverview:(id)sender;
@@ -98,8 +93,6 @@
 
 - (void)blockGUI:(BOOL)lock;
 
-- (void)popupDiagramMenu:(bec::MenuItemList*)items atPoint:(NSPoint)pos;
-
 - (void)switchToDiagramWithIdentifier:(const char*)identifier;
 - (void)reopenEditor:(id)editor;
 
@@ -120,6 +113,7 @@
 
 - (BOOL)closePanel:(WBBasePanel*)panel;
 - (void)closeTopPanelWithIdentifier:(id)identifier;
+- (void)closeTopPanelWithIdentifier:(id)identifier hideOnly:(BOOL)hideOnly;
 - (void)closeBottomPanelWithIdentifier:(id)identifier;
 - (void)closeEditorsMatching: (NSString*)identifier;
 
