@@ -1221,6 +1221,18 @@ static void exit_event_loop(mforms::App *app, int retcode)
   }
 }
 
+static MySQL::Drawing::Color get_system_color(mforms::SystemColor color)
+{
+  switch (color)
+  {
+    case mforms::SystemHighlight:
+    {
+      NSColor *c = [[NSColor alternateSelectedControlColor] colorUsingColorSpaceName: NSCalibratedRGBColorSpace];
+      return MySQL::Drawing::Color([c redComponent], [c greenComponent], [c blueComponent]);
+    }
+  }
+  return MySQL::Drawing::Color::Color(1, 0, 0);
+}
 
 void setup_mforms_app(WBMainWindow *mwin)
 {
@@ -1228,7 +1240,7 @@ void setup_mforms_app(WBMainWindow *mwin)
   g_assert(cf);
   
   mforms::App::get()->set_data(mwin);
-  
+
   cf->_app_impl.dock_view= dock_view;
   cf->_app_impl.select_view= select_view;
   cf->_app_impl.undock_view= undock_view;
@@ -1240,6 +1252,7 @@ void setup_mforms_app(WBMainWindow *mwin)
   cf->_app_impl.end_thread_loop= free_ar_pool;
   cf->_app_impl.enter_event_loop= enter_event_loop;
   cf->_app_impl.exit_event_loop= exit_event_loop;
+  cf->_app_impl.get_system_color= get_system_color;
 }
 
 //--------------------------------------------------------------------------------------------------
