@@ -81,9 +81,18 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
 
 - (void)reuseShareableDataSourcesFrom:(WBModelSidebarController*)sidebar
 {
-  catalogDS = sidebar->catalogDS;
-  historyDS = sidebar->historyDS;
-  userTypeDS = sidebar->userTypeDS;
+  if (sidebar)
+  {
+    catalogDS = sidebar->catalogDS;
+    historyDS = sidebar->historyDS;
+    userTypeDS = sidebar->userTypeDS;
+  }
+  else
+  {
+    catalogDS = nil;
+    historyDS = nil;
+    userTypeDS = nil;
+  }
   
   [catalogOutline setDataSource: catalogDS];
   [catalogOutline setDelegate: self];
@@ -97,13 +106,27 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
 
 
 - (void)dealloc
-{
+{ 
+  _wbui= 0;
+  
+  if (_historyRefresh)
+    _historyRefresh->disconnect();
   delete _historyRefresh;
+  if (_userTypesRefresh)
+    _userTypesRefresh->disconnect();
   delete _userTypesRefresh;
   [[NSNotificationCenter defaultCenter] removeObserver: self];
   [super dealloc];
 }
 
+
+- (void)invalidate
+{
+  // since performSelectorOnMainThread could have pending refreshes, set _wbui to nil
+  _wbui= 0;
+}
+
+
 - (void)setZoom:(id)x
 {
   NSLog(@"here");
@@ -181,10 +204,13 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
 
 - (void)refreshUserTypeList
 {
-  if ([userTypeDS listModel])
-    [userTypeDS listModel]->refresh();
+  if (_wbui)
+  {
+    if ([userTypeDS listModel])
+      [userTypeDS listModel]->refresh();
   
-  [userTypeTable reloadData];
+    [userTypeTable reloadData];
+  }
 }
 
 
@@ -346,6 +372,13 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
 
 //--------------------------------------------------------------------------------------------------
 
+- (GRTListDataSource*) userTypeDS
+{
+  return userTypeDS;
+}
+
+//--------------------------------------------------------------------------------------------------
+
 static void refresh_history(const bec::NodeId &parent, int orow, WBModelSidebarController *self)
 {
   [self performSelectorOnMainThread:@selector(refreshHistory)
