@@ -637,7 +637,13 @@ namespace MySQL.Controls
 
           Brush brush;
           if (tabStyle == TabStyleType.TopTransparent)
-            brush = new SolidBrush(Color.Black);
+          {
+            // In Aero we always draw a black caption.
+            if (ControlUtilities.IsCompositionEnabled() || isSelected)
+              brush = new SolidBrush(Color.Black);
+            else
+              brush = new SolidBrush(Color.White);
+          }
           else
             if (isSelected)
             {
