@@ -740,8 +740,11 @@ namespace MySQL.GUI.Workbench
           if (activeControl is Scintilla)
             (activeControl as Scintilla).Clipboard.Copy();
           else
-            if (wbContext.edit_can_copy())
-              wbContext.edit_copy();
+            if (activeControl is GridView)
+              (activeControl as GridView).Copy();
+            else
+              if (wbContext.edit_can_copy())
+                wbContext.edit_copy();
     }
 
     private bool EditCanCopy()
@@ -753,7 +756,10 @@ namespace MySQL.GUI.Workbench
         if (activeControl is Scintilla)
           return (activeControl as Scintilla).Selection.Length > 0;
         else
-          return wbContext.edit_can_copy();
+          if (activeControl is GridView)
+            return (activeControl as GridView).CanCopy();
+          else
+            return wbContext.edit_can_copy();
     }
 
     private void EditCut()
@@ -806,7 +812,7 @@ namespace MySQL.GUI.Workbench
     private bool EditCanPaste()
     {
       Control activeControl = ControlUtilities.GetLeafActiveControl(this);
-      if (activeControl is TextBoxBase || activeControl is ComboBox)
+      if (activeControl is TextBoxBase || activeControl is ComboBox || activeControl is GridView)
         return false;
       else
         if (activeControl is Scintilla)
@@ -1421,20 +1427,37 @@ namespace MySQL.GUI.Workbench
         info += "FullText = " + o.ToString();
       }
 
-      ExceptionDialog dialog = new ExceptionDialog(message, info);
-      dialog.ShowDialog();
+      // Check for blocked files (Windows "security" feature).
+      if (info.Contains("0x80131515"))
+      {
+        MessageBox.Show("A blocked library could not be loaded. You probably downloaded MySQL Workbench " +
+          "as no-installation zip package. Windows has locked this preventing so its full operation.\n\n" +
+          "When you click \"OK\" MySQL Workbench will try to automatically unblock all its files. Restart the application " +
+          "for this change to take effect!\n\nThis operation might fail " +
+          "e.g. on read-only volumes or for other reasons. If that is the case then manually unblock the zip package " +
+          "(see its Properties in Explorer) and unzip it again.",
+          "Blocked DLL Detected", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
+
+        Win32Api.UnblockWorkbenchFiles(System.IO.Directory.GetCurrentDirectory());
+      }
+      else
+      {
+          ExceptionDialog dialog = new ExceptionDialog(message, info);
+          dialog.ShowDialog();
+      }
     }
 
     private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
     {
       shuttingDown = true;
+      Hide();
 
       e.Cancel = !wbContext.request_quit();
+      ITabDocument[] documents = contentTabControl.DocumentsToArray();
 
       /* This code is doing work which is already done in request_quit(), so it can be 
        * removed once we can be sure that works in any circumstance.
        *
-      ITabDocument[] documents = contentTabControl.DocumentsToArray();
       if (!e.Cancel)
       {
         foreach (ITabDocument document in documents)
@@ -1473,7 +1496,6 @@ namespace MySQL.GUI.Workbench
       RemoveFocusChangeHandlers(this);
       SaveFormState();
 
-      /*
       // Go through each workbench document and close it unconditionally.
       contentTabControl.SuspendLayout();
       try
@@ -1481,13 +1503,22 @@ namespace MySQL.GUI.Workbench
         // Close all documents (editors implement the document interface too, so we get them
         // with that loop as well).
         for (int i = documents.Length - 1; i >= 0; i--)
-          documents[i].Close();
+        {
+          // WBA is closed via the appview's DocumentClosing() function not by normal closing.
+          if (documents[i] is MySQL.Forms.AppViewDockContent)
+          {
+            MySQL.Forms.AppViewDockContent content = documents[i] as MySQL.Forms.AppViewDockContent;
+            content.GetAppView().DocumentClosing();
+          }
+          else
+            documents[i].Close();
+        }
       }
       finally
       {
         contentTabControl.ResumeLayout();
       }
-      */
+      
       wbContext.perform_quit();
     }
 
@@ -1640,7 +1671,6 @@ namespace MySQL.GUI.Workbench
       e.canClose = true;
 
       ITabDocument document = (sender as FlatTabControl).DocumentFromPage(e.page);
-      RemoveFocusChangeHandlers(document as Control);
       if (document is DbSqlEditor)
         e.canClose = (document as DbSqlEditor).Backend.can_close();
       if (document is Plugins.DockablePlugin)
@@ -1655,9 +1685,12 @@ namespace MySQL.GUI.Workbench
           if (document is MySQL.Forms.AppViewDockContent)
           {
             MySQL.Forms.AppViewDockContent content = document as MySQL.Forms.AppViewDockContent;
-            content.GetAppView().DocumentClosing(sender, e);
+            e.canClose = content.GetAppView().DocumentClosing();
           }
 
+      if (e.canClose)
+        RemoveFocusChangeHandlers(document as Control);
+
       // Because of the order of processing in the UI we have to anticipate notification handling.
       // It is too late when the regular messages come in (then the page for which they are meant
       // is already gone, leaving so for instance plugins registered, which don't exist anymore).
