@@ -294,7 +294,7 @@ namespace MySQL.GUI.Workbench
         if (document is MySQL.Forms.AppViewDockContent)
         {
           MySQL.Forms.AppViewDockContent content = document as MySQL.Forms.AppViewDockContent;
-          content.GetAppView().DocumentClosing(sender, e);
+          e.canClose = content.GetAppView().DocumentClosing();
         }
     }
 
@@ -356,12 +356,11 @@ namespace MySQL.GUI.Workbench
         if (nodeType == (int)Overview.NodeType.Item)
         {
           // find the object in its container
-          if (listsByNode.ContainsKey(wbOverview.get_parent(node).repr()))
+          NodeId parent = wbOverview.get_parent(node);
+          if (listsByNode.ContainsKey(parent.repr()))
           {
-            ListView list = listsByNode[wbOverview.get_parent(node).repr()];
-
-            //XXX would be good if it updated only the required node instead of everything
-            PopulateListView(wbOverview.get_parent(node), list);
+            ListView list = listsByNode[parent.repr()];
+            UpdateListViewNode(node, list);
           }
         }
         else
@@ -1216,6 +1215,43 @@ namespace MySQL.GUI.Workbench
       };
     }
 
+    /// <summary>
+    /// Updates all fields of the given node.
+    /// </summary>
+    private void UpdateListViewNode(NodeId nodeId, ListView listView)
+    {
+      // Find the listview item that corresponds to the given node id and update it.
+      // Don't wrap this with BeginUpdate/EndUpdate. That will produce more flicker than
+      // just updating the item.
+      String objectId = wbOverview.get_node_unique_id(nodeId);
+      foreach (ListViewItem item in listView.Items)
+      {
+        String currentObjectId = (item.Tag as Identifier).objectId;
+        if (currentObjectId != null && currentObjectId == objectId)
+        {
+          string caption;
+
+          wbOverview.get_field(nodeId, (int)Overview.Columns.Label, out caption);
+          item.Text = caption;
+          item.ToolTipText = caption;
+
+          // Note: the first sub item is the same as the main item.
+          int offset = -1;
+          foreach (ListViewItem.ListViewSubItem subItem in item.SubItems)
+          {
+            if (offset > -1)
+            {
+              String detailText;
+              wbOverview.get_field(nodeId, (int)Overview.Columns.FirstDetailField + offset, out detailText);
+              subItem.Text = detailText.Replace(Environment.NewLine, " / ");
+            }
+            offset++;
+          }
+          break;
+        }
+      }
+    }
+
     void PopupActionHandler(object sender, EventArgs e)
     {
       ToolStripItem item = sender as ToolStripItem;
