@@ -21,6 +21,8 @@ using System;
 using System.Reflection;
 using System.Threading;
 using System.Windows.Forms;
+using System.IO;
+using Microsoft.Win32;
 
 using MySQL.Grt;
 using MySQL.Utilities;
@@ -67,10 +69,36 @@ namespace MySQL.GUI.Workbench
     [STAThread]
     static void Main(string[] Args)
     {
-      // First check if this is the first instance of Workbench.
-      if (!ApplicationInstanceManager.CreateSingleInstance(
-        Assembly.GetExecutingAssembly().GetName().Name,  Args, SingleInstanceCallback))
-        return;
+      Application.EnableVisualStyles();
+      Application.SetCompatibleTextRenderingDefault(false);
+
+      // First check if this is the first instance of Workbench (if enabled).
+      // The setting for single-instance is stored in the registry as it is Windows-only
+      // and loading of the application settings happens later.
+      bool singleInstance = true;
+      RegistryKey wbKey = Registry.CurrentUser;
+      try
+      {
+        wbKey = wbKey.OpenSubKey(@"Software\Oracle\MySQL Workbench", false);
+        if (wbKey != null)
+          singleInstance = wbKey.GetValue("SingleInstance", 0).ToString() == "1";
+      }
+      catch (Exception)
+      {
+        // Ignore errors.
+      }
+      finally
+      {
+        if (wbKey != null)
+          wbKey.Close();
+      }
+
+      if (singleInstance)
+      {
+        if (!ApplicationInstanceManager.CreateSingleInstance(
+          Assembly.GetExecutingAssembly().GetName().Name, Args, SingleInstanceCallback))
+          return;
+      }
 
       // Give the main thread a proper name, so we can later check for it when needed.
       Thread.CurrentThread.Name = "mainthread";
@@ -87,19 +115,21 @@ namespace MySQL.GUI.Workbench
       // for WBA to find the needed commands
       String systemdir = Environment.GetFolderPath(Environment.SpecialFolder.System);
       String syspath = Environment.GetEnvironmentVariable("PATH");
+
       String []paths= syspath.Split(new char[]{';'});
       syspath = "";
       // strip all python related dirs from PATH to avoid conflicts with other Python installations
       foreach (String path in paths)
       {
-        if (!path.Contains("Python") && !path.Contains("python"))
+        if (!path.ToLower().Contains("python"))
           syspath = syspath+";"+path;
       }
       Environment.SetEnvironmentVariable("PATH", systemdir + syspath);
 
       // Clear PYTHONPATH environment variable, as we do not need it but our python impl
       // seriously gets confused with it.
-      Environment.SetEnvironmentVariable("PYTHONPATH", "");
+      Environment.SetEnvironmentVariable("PYTHONPATH", workdir + "\\python\\Lib;" + workdir + "\\python\\DLLs;" + workdir + "\\python");
+      Environment.SetEnvironmentVariable("PYTHONHOME", workdir + "\\python");
 
       // Initialize forms stuff.
       MySQL.Forms.Manager formsManager = new MySQL.Forms.Manager();
@@ -128,7 +158,7 @@ namespace MySQL.GUI.Workbench
       CommandLine.AddOptionName("-script", false);
       CommandLine.AddOptionName("-run", false);
       CommandLine.AddOptionName("-run-python", false);
-      CommandLine.AddOptionName("-run-script", false);
+      CommandLine.AddOptionName("-run-lua", false);
       CommandLine.AddOptionName("-quit-when-done", true);
 
       CommandLine.Parse(Args);
@@ -142,9 +172,6 @@ namespace MySQL.GUI.Workbench
 
       #endregion
 
-      Application.EnableVisualStyles();
-      Application.SetCompatibleTextRenderingDefault(false);
-
       #region Runtime path check
 
       // Currently WB has trouble running from a path containing non-ASCII characters.
@@ -286,10 +313,25 @@ namespace MySQL.GUI.Workbench
           if (CommandLine.Leftovers.Count > 0)
             openAtStartup = CommandLine.Leftovers[CommandLine.Leftovers.Count-1];
         }
-        if (openAtStartup != null && openAtStartup != "" && (openAtStartupType == "" || openAtStartupType == "model" || openAtStartupType == "script"))
+        if (!string.IsNullOrEmpty(openAtStartup) && (openAtStartupType == "" || openAtStartupType == "model" || openAtStartupType == "script"))
         {
           if (!System.IO.Path.IsPathRooted(openAtStartup))
             openAtStartup = System.IO.Path.Combine(workdir, openAtStartup);
+
+          // Since manually assigning an application to a file type does not automatically add
+          // our self defined keywords (like script) to the command line we better check what
+          // file type we got to open, based on the extension.
+          if (string.IsNullOrEmpty(openAtStartupType))
+          {
+            switch (Path.GetExtension(openAtStartup).ToLowerInvariant())
+            {
+              case ".sql":
+              case ".txt":
+              case ".bak":
+                openAtStartupType = "query";
+                break;
+            }
+          }
         }
 
         String runScript = "";
@@ -375,7 +417,7 @@ namespace MySQL.GUI.Workbench
 
       Win32.ReleaseConsole();
     }
-     
+
     //----------------------------------------------------------------------------------------------
 
     #region Application handlers
@@ -445,7 +487,7 @@ namespace MySQL.GUI.Workbench
         CommandLine.AddOptionName("-script", false);
         CommandLine.AddOptionName("-run", false);
         CommandLine.AddOptionName("-run-python", false);
-        CommandLine.AddOptionName("-run-script", false);
+        CommandLine.AddOptionName("-run-lua", false);
         CommandLine.AddOptionName("-quit-when-done", true);
 
         CommandLine.Parse(args.CommandLineArgs);
@@ -476,7 +518,7 @@ namespace MySQL.GUI.Workbench
             fileToOpen = System.IO.Path.Combine(System.IO.Directory.GetCurrentDirectory(), fileToOpen);
         }
 
-        if (!wbContext.get_filename().Equals(fileToOpen))
+        if (!string.IsNullOrEmpty(fileToOpen) && !wbContext.get_filename().Equals(fileToOpen))
           wbContext.open_document(fileToOpen);
       };
       mainForm.Invoke(d, true);
@@ -566,16 +608,33 @@ namespace MySQL.GUI.Workbench
           GetApplicationMetaInfo(ApplicationMetaInfo.Copyright),
           GetApplicationMetaInfo(ApplicationMetaInfo.Company));
         Console.WriteLine("Usage: MySQLWorkbench [options] [model file]" + Environment.NewLine);
+        CommandLine.AddOptionName("-query", false);
+        CommandLine.AddOptionName("-model", false);
+        CommandLine.AddOptionName("-admin", false);
+        CommandLine.AddOptionName("-script", false);
+        CommandLine.AddOptionName("-run", false);
+        CommandLine.AddOptionName("-run-python", false);
+        CommandLine.AddOptionName("-run-lua", false);
+        CommandLine.AddOptionName("-quit-when-done", true);
+
 
         Console.WriteLine("Options" + Environment.NewLine
-          + "  -help (-h) ...... Print this output" + Environment.NewLine
-          + "  -open filename .. Open the given filename at startup" + Environment.NewLine
-          + "  -nologo ......... Do not display the splash screen" + Environment.NewLine
-          + "  -verbose (-v) ... Print verbose output in the GRT Shell" + Environment.NewLine
-          + "  -version ........ Print the version information" + Environment.NewLine
-          + "  -grtversion ..... Print the GRT version information" + Environment.NewLine
-          + "  -swrendering .... Force the canvas to use software rendering instead of OpenGL" + Environment.NewLine
-          + "  -log ............ Instruction to save messages (other debug info) to file" + Environment.NewLine);
+          + "  -admin instance .... Open an admin tab to the named server instance at startup" + Environment.NewLine
+          + "  -open filename ..... Open the given filename at startup" + Environment.NewLine
+          + "  -query server ...... Open a DB query tab to the named server connection at startup" + Environment.NewLine
+          + "  -run script ........ Executes the given Workbench script at startup"  + Environment.NewLine
+          + "  -run-python script . Executes the given Workbench Python script at startup"  + Environment.NewLine
+          + "  -run-lua script .... Executes the given Workbench Lua script at startup"  + Environment.NewLine
+          + "  -script scriptfile . Executes the given Workbench script file at startup"  + Environment.NewLine
+          + "  -quit-when-done .... Quits Workbench once the given script finishes executing"  + Environment.NewLine
+          + "  -swrendering ....... Force the canvas to use software rendering instead of OpenGL" + Environment.NewLine
+          + "  -nologo ............ Do not display the splash screen" + Environment.NewLine
+          + "  -log ............... Instruction to save messages (other debug info) to file" + Environment.NewLine
+          + "  -verbose (-v) ...... Print verbose output in the GRT Shell" + Environment.NewLine
+          + "  -version ........... Print the version information" + Environment.NewLine
+          + "  -grtversion ........ Print the GRT version information" + Environment.NewLine
+          + "  -help (-h) ......... Print this output" + Environment.NewLine
+        );
 
         /*Console.WriteLine("GRT Options" + Environment.NewLine
           + "{0}",
@@ -623,4 +682,4 @@ namespace MySQL.GUI.Workbench
     #endregion
 
   }
-}
\ No newline at end of file
+}
