@@ -1,15 +1,33 @@
-﻿using System;
+﻿/* 
+ * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
+ */
+
+using System;
 using System.Collections.Generic;
-using System.Text;
-using System.Windows;
-using System.Windows.Forms;
 using System.Drawing;
-using System.Text.RegularExpressions;
 using System.IO;
+using System.Text;
+using System.Text.RegularExpressions;
+using System.Windows.Forms;
+
+using MySQL.Utilities;
 
 using ScintillaNet;
-using MySQL.Utilities;
-using MySQL.Workbench;
 
 namespace MySQL.Grt.Db.Sql
 {
@@ -67,6 +85,8 @@ namespace MySQL.Grt.Db.Sql
         sqlEditorBE.set_replace_selected_text_delegate(DoReplaceSelectedText);
         sqlEditorBE.set_do_search_delegate(DoTextSeach);
         sqlEditorBE.set_current_statement_delegate(GetCurrentSqlStatement);
+        sqlEditorBE.set_change_selected_range_delegate(ChangeSelectedRange);
+        sqlEditorBE.set_change_cursor_pos_delegate(ChangeCursorPos);
 
         SelectionChanged += new EventHandler(TextSelectionChanged);
 
@@ -178,7 +198,7 @@ namespace MySQL.Grt.Db.Sql
         if (items.Count > 0)
         {      
           foreach (MySQL.Grt.MenuItem item in items)
-          {        
+          {
             bool enabled = item.get_enabled();
             switch (item.get_name())
             {
@@ -198,6 +218,9 @@ namespace MySQL.Grt.Db.Sql
                 enabled = iData.GetDataPresent(DataFormats.Text);
                 break;
               }
+              case "toggle_wrap_lines":
+                item.set_checked(LineWrap.Mode == WrapMode.Word);
+                break;
             }
             item.set_enabled(enabled);
           }
@@ -236,6 +259,12 @@ namespace MySQL.Grt.Db.Sql
           case "select_all":
             Selection.SelectAll();
             break;
+          case "toggle_wrap_lines":
+            if (LineWrap.Mode == WrapMode.Word)
+              this.LineWrap.Mode = WrapMode.None;
+            else
+              this.LineWrap.Mode = WrapMode.Word;
+            break;
           default:
             sqlEditorBE.activate_context_menu_item(item.Name);
             break;
@@ -423,6 +452,26 @@ namespace MySQL.Grt.Db.Sql
       }
     }
 
+    /// <summary>
+    /// Called by the backend if the selection in the editor must be changed.
+    /// </summary>
+    /// <param name="start"></param>
+    /// <param name="stop"></param>
+    private void ChangeSelectedRange(int start, int stop)
+    {
+      Selection.Start = start;
+      Selection.End = stop;
+    }
+
+    /// <summary>
+    /// Called by the backend if the caret position must be changed.
+    /// </summary>
+    /// <param name="position"></param>
+    private void ChangeCursorPos(int position)
+    {
+      Caret.Position = position;
+    }
+
     void OnDwellStart(object sender, ScintillaMouseEventArgs e)
     {
       if (!Visible || !ClientRectangle.Contains(PointToClient(MousePosition)))
@@ -469,13 +518,17 @@ namespace MySQL.Grt.Db.Sql
 
     int DoInsertText(String text)
     {
-      NativeInterface.AddText(Encoding.UTF8.GetByteCount(text), text);
+      NativeInterface.AddText(text.Length, text);
       return 0;
     }
 
     public void ShowFindReplaceDialog()
     {
-      sqlEditorBE.show_find_replace_dialog();
+      // Scintilla.NET already has an implementation of the search/replace dialog and all the
+      // usual features (including search/replace in the current selection etc.). So we use that
+      // instead of our own dialog.
+      //sqlEditorBE.show_find_replace_dialog();
+      Commands.Execute(BindableCommand.ShowReplace);
     }
 
     bool DoTextSeach(String searchText, String replaceText, int flags)
