@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,14 +30,23 @@
   #define BASELIBRARY_PUBLIC_FUNC
 #endif
 
+#include <string>
+#include <math.h>
+
 #ifdef _WIN32
   #define WIN32_LEAN_AND_MEAN 
   #include <windows.h>
 
   #ifndef strcasecmp
-  #define strcasecmp _stricmp
-  #define strncasecmp strnicmp
+    #define strcasecmp _stricmp
+    #define strncasecmp strnicmp
   #endif
+
+  #ifndef snprintf
+    #define HAVE_SNPRINTF // For python libs.
+    #define snprintf _snprintf_s
+  #endif
+
 #endif // _WIN32
 
 #endif // _COMMON_H_
