@@ -26,16 +26,11 @@
 #include <stdarg.h>
 #include <float.h>
 
-#ifdef WIN32
-  #include <windows.h>
-#endif
-
 #include "base/config_file.h"
 #include "base/util_functions.h"
 #include "base/string_utilities.h"
 
 #ifdef WIN32
-  #define snprintf  _snprintf
   #define vsnprintf _vsnprintf
 #endif
 
