@@ -106,6 +106,51 @@ std::string string_to_path(const std::string &s)
 #endif
 }
 
+//--------------------------------------------------------------------------------------------------
+  
+inline bool is_invalid_filesystem_char(int ch)
+{
+  static const char invalids[] = "/?<>\\:*|\"^";
+  
+  return memchr(invalids, ch, sizeof(invalids)-1) != NULL;
+}
+  
+std::string sanitize_file_name(const std::string &s)
+{
+  static const char *invalid_filenames[] = {
+    "com1", "com2", "com3", "com4", "com5", "com6",
+    "com7", "com8", "com9", "lpt1", "lpt2", "lpt3", "lpt4", 
+    "lpt5", "lpt6", "lpt7", "lpt8", "lpt9", "con", "nul", "prn",
+    ".", "..", 
+    NULL
+  };
+  std::string out;
+  
+  for (std::string::const_iterator c = s.begin(); c != s.end(); ++c)
+  {
+    // utf-8 has the high-bit = 1, so we just copy those verbatim
+    if (isalnum(*c) || (unsigned char)*c >= 128 || (ispunct(*c) && !is_invalid_filesystem_char(*c)))
+      out.push_back(*c);
+    else
+      out.push_back('_');
+  }
+  
+  // not valid under windows
+  if (!out.empty() && (out[out.size()-1] == ' ' || out[out.size()-1] == '.'))
+    out[out.size()-1] = '_';
+  
+  for (const char **fn = invalid_filenames; *fn; ++fn)
+  {
+    if (strcmp(out.c_str(), *fn) == 0)
+    {
+      out.append("_");
+      break;
+    }
+  }
+  
+  return out;
+}
+
 //--------------------------------------------------------------------------------------------------
 
 string trim_right(const string& s, const string& t)
@@ -136,16 +181,6 @@ string trim(const string& s, const string& t)
 
 //--------------------------------------------------------------------------------------------------
 
-/**
- * Simple case conversion routine, which does in-place conversion. Works well only for ANSI characters.
- */
-void tolower(string& s)
-{
-  std::transform(s.begin(), s.end(), s.begin(), ::tolower);
-}
-
-//--------------------------------------------------------------------------------------------------
-
 /**
  * Simple case conversion routine, which returns a new string. Works well only for ANSI characters.
  */
@@ -158,13 +193,6 @@ string tolower(const string& s)
 
 //--------------------------------------------------------------------------------------------------
 
-void toupper(string& s)
-{
-  std::transform(s.begin(), s.end(), s.begin(), ::toupper);
-}
-
-//--------------------------------------------------------------------------------------------------
-
 string toupper(const string& s)
 {
   std::string result = s;
@@ -218,6 +246,22 @@ std::vector<std::string> split(const std::string &s, const std::string &sep, int
 
   return parts;
 }
+
+//--------------------------------------------------------------------------------------------------
+  
+bool partition(const std::string &s, const std::string &sep, std::string &left, std::string &right)
+{
+  std::string::size_type p = s.find(sep);
+  if (p != std::string::npos)
+  {
+    left = s.substr(0, p);
+    right = s.substr(p + sep.size());
+    return true;
+  }
+  left = s;
+  right = "";
+  return false;
+}
   
 //--------------------------------------------------------------------------------------------------
   
@@ -464,6 +508,75 @@ std::string normalize_path_extension(std::string filename, std::string extension
   return filename;
 }
 
+/**
+ * Removes all unnecessary path separators as well as "./" combinations.
+ * If there is a parent-dir entry (../) then this as well as the directly prefacing
+ * dir entry is removed.
+ */
+std::string normalize_path(const std::string path)
+{
+  // First convert all separators to the one that is used on the platform (no mix)
+  // and ease so at the same time further processing here.
+  std::string result;
+  std::string separator(1, G_DIR_SEPARATOR);
+  
+  result= path;
+  replace(result, "\\", separator);
+  replace(result, "/", separator);
+  
+  std::string double_separator = separator + separator;
+  while (result.find(double_separator) != std::string::npos)
+    replace(result, double_separator, separator);
+  
+  // Sanity check. Return *after* we have converted the slashs. This is part of the normalization.
+  if (result.size() < 2)
+    return result;
+  
+  std::vector<std::string> parts= split(result, separator);
+  
+  // Construct result backwards while examining the path parts.
+  result= "";
+  int pending_count= 0;
+  for (int i= parts.size() - 1; i >= 0; i--)
+  {
+    if (parts[i].compare(".") == 0)
+      // References to the current directory can be removed without further change.
+      continue;
+    
+    if (parts[i].compare("..") == 0)
+    {
+      // An entry that points back to the parent dir.
+      // Ignore this and keep track for later removal of the parent dir.
+      pending_count++;
+    }
+    else
+      if (pending_count > 0)
+      {
+        // If this is a normal dir entry and we have pending parent-dir redirections
+        // then go one step up by removing (ignoring) this entry.
+        pending_count--;
+      }
+      else
+        result = separator + parts[i] + result;
+  }
+  
+  // Don't return the leading separator.
+  return result.substr(1);
+}
+
+std::string expand_tilde(const std::string &path)
+{
+  if (!path.empty() && path[0] == '~' && (path.size() == 1 || path[1] == G_DIR_SEPARATOR))
+  {
+    const char *homedir = g_getenv("HOME");
+    if (!homedir)
+      homedir = g_get_home_dir();
+    
+    return std::string(homedir).append(path.substr(1));
+  }
+  return path;
+}
+  
 //--------------------------------------------------------------------------------------------------
 
 /**
