@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2005, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2005, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -1934,6 +1934,7 @@ int get_str_index(char **string_list, unsigned int string_list_num, const char *
 
 //----------------------------------------------------------------------------------------------------------------------
 
+// XXX: use glib function instead.
 /** @brief checks if filename really exists
     @param filename path to file
     @return 0 if the file doesn't exist else 1
@@ -1955,110 +1956,6 @@ int check_file_exists(const char *filename)
   }
 }
 
-#if 0 // not used, delete this
-//----------------------------------------------------------------------------------------------------------------------
-
-/**
- * Scans the given string and duplicates it to result while inserting a back slash character in front of each
- * character that must be masked.
- *
- * @param source The source string to examine.
- * @param special_chars All characters that must be masked.
- *
- * @return A new copy of source with all special characters escaped. This string must be freed by the caller (using g_free).
- * @note covered by unit tests
- */
-char* internal_escape_string(const char* source, const char* special_chars)
-{
-  int i;
-  int j;
-  char* result= NULL;
-
-  if (source != NULL)
-  {
-    // Do a first loop to determine how many characters must be escaped.
-    int count= 0;
-    i= 0;
-    while (source[i] != '\0')
-    {
-      if (strchr(special_chars, source[i++]) != NULL)
-        count++;
-    };
-
-    // If no special char was found then just duplicate the string otherwise do a second round.
-    if (count == 0)
-    {
-      result= g_strdup(source);
-    }
-    else
-    {
-      result= (char*) g_malloc0(i + count + 1);
-      i= 0;
-      j= 0;
-      
-      while (source[i] != '\0')
-      {
-        if (strchr(special_chars, source[i]) != NULL)
-        {
-          result[j++]= '\\';
-          switch (source[i])
-          {
-            case '\n':
-              result[j++]= 'n';
-              break;
-            case '\r':
-              result[j++]= 'r';
-              break;
-            case '\b':
-              result[j++]= 'b';
-              break;
-            case '\t':
-              result[j++]= 't';
-              break;
-            case '\x1a':
-              result[j++]= 'Z';
-              break;
-          default:
-            result[j++]= source[i];
-          };
-        }
-        else
-          result[j++]= source[i];
-        ++i;
-      };
-      result[j]= '\0';
-    };
-  };
-
-  return result;
-}
-
-//----------------------------------------------------------------------------------------------------------------------
-
-/**
- * Scans the given string and duplicates it to result while inserting a back slash character in front of each
- * character that must be masked.
- *
- * @param source The source string to examine.
- *
- * @return A new copy of source with all special characters escaped. This string must be freed by the caller (using g_free).
- * @note This function does not escape % and _ as they are used only with pattern matching. Use escape_string_for_search
- *       if you need these characters escaped too.
- * @note covered by unit tests
- */
-char * escape_string(const char* source)
-{
-  return internal_escape_string(source, "'\"\x8\n\r\t\x1a\\");
-}
-
-//----------------------------------------------------------------------------------------------------------------------
-
-char * escape_string_for_search(const char* source)
-{
-  return internal_escape_string(source, "'\"\x8\n\r\t\x1a\\%_");
-}
-#endif // unused
-
 //----------------------------------------------------------------------------------------------------------------------
 
 /**
@@ -2128,6 +2025,7 @@ const char *stristr(const char *haystack, const char *needle)
 
 //----------------------------------------------------------------------------------------------------------------------
 
+// TODO: move to file_functions
 /**
  * Copies a file whose name is given by source to target. File names are expected to be encoded
  * as UTF-8.
@@ -2187,6 +2085,7 @@ int copy_file(const char* source, const char* target)
 
 //----------------------------------------------------------------------------------------------------------------------
 
+// TODO: move to file_functions
 /**
  * Copies all files non-recursively from source to target. Target will be created on the fly.
  */
@@ -2230,7 +2129,6 @@ int copy_folder(const char *source_folder, const char *target_folder)
 }
 
 //------------------------------------------------------------------------------
-
 bool html_color_to_triplet(const char* color, double *red, double *green, double *blue)
 {
   int tred   = 0;
