@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -40,7 +40,8 @@
 #define MAGNET_STICK_DISTANCE 5
 
 using namespace mdc;
-
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 int mdc_live_item_count = 0;
 
@@ -178,13 +179,13 @@ void CanvasItem::set_size(const Size &size)
 }
 
 
-mdc::Rect CanvasItem::get_root_bounds() const
+Rect CanvasItem::get_root_bounds() const
 {
   return Rect(get_root_position(), get_size());
 }
 
 
-mdc::Rect CanvasItem::get_padded_root_bounds() const
+Rect CanvasItem::get_padded_root_bounds() const
 {
   Rect bounds(get_root_bounds());
 
@@ -197,7 +198,7 @@ mdc::Rect CanvasItem::get_padded_root_bounds() const
 }
 
 
-mdc::Rect CanvasItem::get_bounds() const
+Rect CanvasItem::get_bounds() const
 {
   return Rect(get_position(), get_size());
 }
@@ -228,13 +229,13 @@ void CanvasItem::set_fixed_min_size(const Size &size)
 }
 
 
-mdc::Size CanvasItem::calc_min_size()
+Size CanvasItem::calc_min_size()
 {
   return Size(_xpadding*2, _ypadding*2);
 }
 
 
-mdc::Size CanvasItem::get_min_size()
+Size CanvasItem::get_min_size()
 {
   if (_min_size_invalid)
   {
@@ -401,13 +402,13 @@ void CanvasItem::set_highlighted(bool flag)
 }
 
 
-void CanvasItem::set_highlight_color(const mdc::Color *color)
+void CanvasItem::set_highlight_color(const Color *color)
 {
   if (_highlight_color)
     delete _highlight_color;
   
   if (color)
-    _highlight_color= new mdc::Color(*color);
+    _highlight_color= new Color(*color);
   else
     _highlight_color= 0;
   
@@ -720,12 +721,12 @@ void CanvasItem::draw_outline_ring(CairoCtx *cr, const Color &color)
 {
   cr->save();
   
-  cr->set_color(color, color.a);
+  cr->set_color(color, color.alpha);
   cr->set_line_width(2);
   stroke_outline(cr, 1);
   cr->stroke();
   
-  cr->set_color(color, color.a * 0.3);
+  cr->set_color(color, color.alpha * 0.3);
   cr->set_line_width(4);
   stroke_outline(cr, 2);
   cr->stroke();
@@ -741,7 +742,7 @@ void CanvasItem::draw_outline_ring_gl(const Color &color)
   glLineWidth(2);
   stroke_outline_gl(1);
   
-  Color blended= Color(color.r, color.g, color.b, 0.3 * color.a);
+  Color blended= Color(color.red, color.green, color.blue, 0.3 * color.alpha);
   gl_setcolor(blended);
   glLineWidth(4);
   stroke_outline_gl(1);
@@ -836,14 +837,14 @@ void CanvasItem::repaint_gl(const Rect &clipArea)
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
 
-  mdc::Rect bounds(get_bounds());
+  Rect bounds(get_bounds());
 
   bounds.pos.x-= LEFT_OUTER_PAD;
   bounds.pos.y-= TOP_OUTER_PAD;
   bounds.size.width+= RIGHT_OUTER_PAD+LEFT_OUTER_PAD;
   bounds.size.height+= BOTTOM_OUTER_PAD+TOP_OUTER_PAD;
 
-  glTranslated(bounds.xmin(), bounds.ymin(), 0);
+  glTranslated(bounds.left(), bounds.top(), 0);
 
   if (generate_display_list)
   {
@@ -1032,7 +1033,7 @@ CanvasItem *CanvasItem::get_common_ancestor(CanvasItem *item) const
 }
 
 
-mdc::Point CanvasItem::convert_point_from(const Point &pt, CanvasItem *item) const
+Point CanvasItem::convert_point_from(const Point &pt, CanvasItem *item) const
 {
   CanvasItem *ancestor= 0;
   const CanvasItem *it;
@@ -1055,7 +1056,7 @@ mdc::Point CanvasItem::convert_point_from(const Point &pt, CanvasItem *item) con
 }
 
 
-mdc::Point CanvasItem::convert_point_to(const Point &pt, CanvasItem *item) const
+Point CanvasItem::convert_point_to(const Point &pt, CanvasItem *item) const
 {  
   CanvasItem *ancestor= item ? get_common_ancestor(item) : 0;
   const CanvasItem *it;
@@ -1241,7 +1242,7 @@ bool CanvasItem::on_drag_handle(ItemHandle *handle, const Point &pos, bool dragg
   {
     if ((handle->get_tag() & HDL_LR_MASK) == HDL_RIGHT)
     {
-      nsize.width= pos.x - oframe.xmin();
+      nsize.width= pos.x - oframe.left();
       if (min_size.width > 0 && nsize.width < min_size.width)
         nsize.width= min_size.width;
       else if (nsize.width > max_size.width - npos.x)
@@ -1252,7 +1253,7 @@ bool CanvasItem::on_drag_handle(ItemHandle *handle, const Point &pos, bool dragg
     else if ((handle->get_tag() & HDL_LR_MASK) == HDL_LEFT)
     {
       npos.x= local_pos.x;
-      nsize.width= oframe.width() + (oframe.xmin() - pos.x);
+      nsize.width= oframe.width() + (oframe.left() - pos.x);
       
       if (min_size.width > 0 && nsize.width < min_size.width)
       {
@@ -1271,7 +1272,7 @@ bool CanvasItem::on_drag_handle(ItemHandle *handle, const Point &pos, bool dragg
   {
     if ((handle->get_tag() & HDL_TB_MASK) == HDL_BOTTOM)
     {
-      nsize.height= pos.y - oframe.ymin();
+      nsize.height= pos.y - oframe.top();
       if (min_size.height > 0 && nsize.height < min_size.height)
         nsize.height= min_size.height;
       else if (nsize.height > max_size.height - npos.y)
@@ -1282,7 +1283,7 @@ bool CanvasItem::on_drag_handle(ItemHandle *handle, const Point &pos, bool dragg
     else if ((handle->get_tag() & HDL_TB_MASK) == HDL_TOP)
     {
       npos.y= local_pos.y;
-      nsize.height= oframe.height() + (oframe.ymin() - pos.y);
+      nsize.height= oframe.height() + (oframe.top() - pos.y);
       if (min_size.height > 0 && nsize.height < min_size.height)
       {
         double dy= min_size.height - nsize.height;
