@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,15 +20,13 @@
 #ifndef _MDC_CANVAS_ITEM_H_
 #define _MDC_CANVAS_ITEM_H_
 
+#include "mdc_common.h"
 #include "mdc_canvas_public.h"
 
-#include "mdc_common.h"
 #include "mdc_events.h"
 
-
 BEGIN_MDC_DECLS
 
-
 class CanvasView;
 class Layer;
 class InteractionLayer;
@@ -79,36 +77,36 @@ public:
 
   // geometry
   
-  virtual Rect get_bounds() const;
-  virtual Rect get_root_bounds() const;
-  virtual Rect get_padded_root_bounds() const;
-  virtual bool intersects(const Rect &bounds) const;
-  virtual bool contains_point(const Point &point) const;
+  virtual MySQL::Geometry::Rect get_bounds() const;
+  virtual MySQL::Geometry::Rect get_root_bounds() const;
+  virtual MySQL::Geometry::Rect get_padded_root_bounds() const;
+  virtual bool intersects(const MySQL::Geometry::Rect &bounds) const;
+  virtual bool contains_point(const MySQL::Geometry::Point &point) const;
 
-  virtual void resize_to(const Size &size);
-  virtual void move_to(const Point &pos);
-  void set_position(const Point &pos);
-  void set_size(const Size &size); 
-  void set_bounds(const Rect &rect);
+  virtual void resize_to(const MySQL::Geometry::Size &size);
+  virtual void move_to(const MySQL::Geometry::Point &pos);
+  void set_position(const MySQL::Geometry::Point &pos);
+  void set_size(const MySQL::Geometry::Size &size); 
+  void set_bounds(const MySQL::Geometry::Rect &rect);
   
-  Point get_root_position() const;
-  inline Point get_position() const { return _pos; };
+  MySQL::Geometry::Point get_root_position() const;
+  inline MySQL::Geometry::Point get_position() const { return _pos; };
 
-  virtual void set_fixed_min_size(const Size &size);
-  Size get_min_size();
-  virtual Size calc_min_size();
-  inline Size get_size() const { return _size; }
-  inline Size get_fixed_size() const { return _fixed_size; }
-  virtual void set_fixed_size(const Size &size);
+  virtual void set_fixed_min_size(const MySQL::Geometry::Size &size);
+  MySQL::Geometry::Size get_min_size();
+  virtual MySQL::Geometry::Size calc_min_size();
+  inline MySQL::Geometry::Size get_size() const { return _size; }
+  inline MySQL::Geometry::Size get_fixed_size() const { return _fixed_size; }
+  virtual void set_fixed_size(const MySQL::Geometry::Size &size);
   virtual void set_auto_sizing(bool flag);
   bool auto_sizing() const { return _auto_sizing; }
 
   virtual void set_padding(double xpad, double ypad);
 
-  Point convert_point_from(const Point &pt, CanvasItem *item) const;
-  Point convert_point_to(const Point &pt, CanvasItem *item) const;
+  MySQL::Geometry::Point convert_point_from(const MySQL::Geometry::Point &pt, CanvasItem *item) const;
+  MySQL::Geometry::Point convert_point_to(const MySQL::Geometry::Point &pt, CanvasItem *item) const;
 
-  virtual Point get_intersection_with_line_to(const Point &p);
+  virtual MySQL::Geometry::Point get_intersection_with_line_to(const MySQL::Geometry::Point &p);
   
   // structure
   
@@ -136,9 +134,9 @@ public:
 
   virtual void auto_size();
   void relayout();
-  virtual void repaint(const mdc::Rect &clipRect, bool direct);
+  virtual void repaint(const MySQL::Geometry::Rect &clipRect, bool direct);
   virtual void render(CairoCtx *cr);
-  void repaint_gl(const mdc::Rect &clipRect);
+  void repaint_gl(const MySQL::Geometry::Rect &clipRect);
   virtual void render_gl(mdc::CairoCtx *cr);
   void render_to_surface(cairo_surface_t *surf, bool use_padding= true);
   
@@ -146,8 +144,8 @@ public:
 
   virtual void draw_state(CairoCtx *cr);
   virtual void draw_state_gl();
-  virtual void draw_outline_ring(CairoCtx *cr, const Color &color);
-  virtual void draw_outline_ring_gl(const Color &color);
+  virtual void draw_outline_ring(CairoCtx *cr, const MySQL::Drawing::Color &color);
+  virtual void draw_outline_ring_gl(const MySQL::Drawing::Color &color);
 
   State get_state();
   virtual void stroke_outline(CairoCtx *, float offset= 0) {}
@@ -167,7 +165,7 @@ public:
   bool accepts_focus() const { return _accepts_focus; };
   void set_draws_hover(bool flag= true);
   void set_highlighted(bool flag= true);
-  void set_highlight_color(const mdc::Color *color); // NULL unsets the color
+  void set_highlight_color(const MySQL::Drawing::Color *color); // NULL unsets the color
   
   void set_draggable(bool flag);
   bool is_draggable() { return _draggable; }
@@ -190,14 +188,14 @@ public:
   void add_magnet(Magnet *magnet);
 
   BoundsMagnet *get_bounds_magnet();
-  Magnet *get_closest_magnet(const Point &point);
+  Magnet *get_closest_magnet(const MySQL::Geometry::Point &point);
 
-  void set_drag_handle_constrainer(const sigc::slot<void,ItemHandle*,Size&> &slot);
+  void set_drag_handle_constrainer(const sigc::slot<void,ItemHandle*,MySQL::Geometry::Size&> &slot);
 
   // signals
 
-  sigc::signal<void,const Rect&> signal_bounds_changed() { return _bounds_changed_signal; }
-  sigc::signal<void,CanvasItem*,const Rect&> signal_parent_bounds_changed() { return _parent_bounds_changed_signal; }
+  sigc::signal<void,const MySQL::Geometry::Rect&> signal_bounds_changed() { return _bounds_changed_signal; }
+  sigc::signal<void,CanvasItem*,const MySQL::Geometry::Rect&> signal_parent_bounds_changed() { return _parent_bounds_changed_signal; }
 
   sigc::signal<void> signal_reparent() { return _reparent_signal; }
 
@@ -211,15 +209,15 @@ public:
   virtual CanvasItem *find_item_with_tag(const std::string &tag);
   
 private:
-  Point _pos;
-  Size _size;
-  Rect _old_bounds;
+  MySQL::Geometry::Point _pos;
+  MySQL::Geometry::Size _size;
+  MySQL::Geometry::Rect _old_bounds;
 
   sigc::connection _parent_bounds_con;
   sigc::connection _grand_parent_bounds_con;
 
-  void parent_bounds_changed(const Rect &obounds, CanvasItem *item);
-  void grand_parent_bounds_changed(CanvasItem *item, const Rect &obounds);
+  void parent_bounds_changed(const MySQL::Geometry::Rect &obounds, CanvasItem *item);
+  void grand_parent_bounds_changed(CanvasItem *item, const MySQL::Geometry::Rect &obounds);
 
   static void *parent_destroyed(void *data);
   
@@ -233,22 +231,22 @@ protected:
 
   std::string _tag;
 
-  Size _fixed_size;
-  Size _min_size;
-  Size _fixed_min_size;
+  MySQL::Geometry::Size _fixed_size;
+  MySQL::Geometry::Size _min_size;
+  MySQL::Geometry::Size _fixed_min_size;
   double _xpadding;
   double _ypadding;
-  Point _button_press_pos;
+  MySQL::Geometry::Point _button_press_pos;
   
-  mdc::Color *_highlight_color;
+  MySQL::Drawing::Color *_highlight_color;
 
   std::vector<ItemHandle*> _handles;
   std::vector<Magnet*> _magnets;
 
-  sigc::slot<void,ItemHandle*,Size&> _drag_handle_constrainer;
+  sigc::slot<void,ItemHandle*,MySQL::Geometry::Size&> _drag_handle_constrainer;
   
-  sigc::signal<void,const Rect &> _bounds_changed_signal;
-  sigc::signal<void,CanvasItem*,const Rect&> _parent_bounds_changed_signal;
+  sigc::signal<void,const MySQL::Geometry::Rect &> _bounds_changed_signal;
+  sigc::signal<void,CanvasItem*,const MySQL::Geometry::Rect&> _parent_bounds_changed_signal;
   sigc::signal<void,bool> _focus_changed_signal;
   sigc::signal<void> _reparent_signal;
 
@@ -280,27 +278,27 @@ protected:
   unsigned int _disable_state_drawing:1;
   
 
-  Size get_texture_size(Size size);
+  MySQL::Geometry::Size get_texture_size(MySQL::Geometry::Size size);
   void repaint_direct();
   void repaint_cached();
-  void regenerate_cache(Size size);
+  void regenerate_cache(MySQL::Geometry::Size size);
   
-  //virtual bool can_drag_handle_to(const Point &pos);
-  //virtual void end_drag_handle_to(const Point &pos);
+  //virtual bool can_drag_handle_to(const MySQL::Geometry::Point &pos);
+  //virtual void end_drag_handle_to(const MySQL::Geometry::Point &pos);
 
   
-  virtual bool on_button_press(CanvasItem *target, const Point &point, MouseButton button, EventState state);
-  virtual bool on_button_release(CanvasItem *target, const Point &point, MouseButton button, EventState state);
+  virtual bool on_button_press(CanvasItem *target, const MySQL::Geometry::Point &point, MouseButton button, EventState state);
+  virtual bool on_button_release(CanvasItem *target, const MySQL::Geometry::Point &point, MouseButton button, EventState state);
   // drag event is received when the item is dragged with ButtonLeft pressed
-  virtual bool on_drag(CanvasItem *target, const Point &point, EventState state);
+  virtual bool on_drag(CanvasItem *target, const MySQL::Geometry::Point &point, EventState state);
 
-  virtual bool on_enter(CanvasItem *target, const Point &point);
-  virtual bool on_leave(CanvasItem *target, const Point &point);
+  virtual bool on_enter(CanvasItem *target, const MySQL::Geometry::Point &point);
+  virtual bool on_leave(CanvasItem *target, const MySQL::Geometry::Point &point);
 
-  virtual bool on_click(CanvasItem *target, const Point &point, MouseButton button, EventState state);
-  virtual bool on_double_click(CanvasItem *target, const Point &point, MouseButton button, EventState state);
+  virtual bool on_click(CanvasItem *target, const MySQL::Geometry::Point &point, MouseButton button, EventState state);
+  virtual bool on_double_click(CanvasItem *target, const MySQL::Geometry::Point &point, MouseButton button, EventState state);
 
-  virtual bool on_drag_handle(ItemHandle *handle, const Point &pos, bool dragging);
+  virtual bool on_drag_handle(ItemHandle *handle, const MySQL::Geometry::Point &pos, bool dragging);
 };
 
 
