@@ -1,3 +1,21 @@
+/* 
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
+ */
 
 #include "stdafx.h"
 
@@ -23,7 +41,10 @@
 #include "mdc_line.h"
 
 using namespace mdc;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
+// XXX: use the values defined by the platform!
 #define DOUBLE_CLICK_TIME 0.5
 
 #include <stdio.h>
@@ -217,19 +238,19 @@ void CanvasView::unlock_redraw()
 // Geometry Handling
 
 
-mdc::Size CanvasView::get_total_view_size() const
+Size CanvasView::get_total_view_size() const
 {
   return Size(_x_page_num * _page_size.width, _y_page_num * _page_size.height);
 }
 
 
-mdc::Rect CanvasView::get_viewport_range() const
+Rect CanvasView::get_viewport_range() const
 {
   return Rect(0, 0, _x_page_num * _page_size.width, _y_page_num * _page_size.height);
 }
 
 
-mdc::Rect CanvasView::get_viewport() const
+Rect CanvasView::get_viewport() const
 {
   Rect rect= window_to_canvas(0, 0, _view_width, _view_height);
   Size size= get_total_view_size();
@@ -246,7 +267,7 @@ mdc::Rect CanvasView::get_viewport() const
 }
 
 
-mdc::Size CanvasView::get_viewable_size() const
+Size CanvasView::get_viewable_size() const
 {
   return window_to_canvas(0, 0, _view_width, _view_height).size;
 }
@@ -621,7 +642,7 @@ void CanvasView::remove_item(mdc::CanvasItem *item)
 // Coordinate Transformation
 
 
-mdc::Point CanvasView::window_to_canvas(int x, int y) const
+Point CanvasView::window_to_canvas(int x, int y) const
 {
   cairo_matrix_t mtx;
   Point pt;
@@ -640,7 +661,7 @@ mdc::Point CanvasView::window_to_canvas(int x, int y) const
 }
 
 
-mdc::Rect CanvasView::window_to_canvas(int x, int y, int w, int h) const
+Rect CanvasView::window_to_canvas(int x, int y, int w, int h) const
 {
   cairo_matrix_t mtx;
   Rect rect;
@@ -682,8 +703,8 @@ void CanvasView::canvas_to_window(const Point &pt, int &x, int &y) const
 void CanvasView::canvas_to_window(const Rect &rect, int &x, int &y, int &w, int &h) const
 {
   cairo_matrix_t mtx;
-  double xx= rect.xmin();
-  double yy= rect.ymin();
+  double xx= rect.left();
+  double yy= rect.top();
   double ww= rect.width();
   double hh= rect.height();
 
@@ -815,11 +836,11 @@ void CanvasView::repaint_area(const Rect &aBounds, int wx, int wy, int ww, int w
   if (_blayer->visible())
     _blayer->repaint(bounds);
 
-  clip.set_xmin(std::max(vrect.xmin(), bounds.xmin()));
-  clip.set_ymin(std::max(vrect.ymin(), bounds.ymin()));
+  clip.set_xmin(std::max(vrect.left(), bounds.left()));
+  clip.set_ymin(std::max(vrect.top(), bounds.top()));
 
-  clip.set_xmax(std::min(vrect.xmax(), bounds.xmax()));
-  clip.set_ymax(std::min(vrect.ymax(), bounds.ymax()));
+  clip.set_xmax(std::min(vrect.right(), bounds.right()));
+  clip.set_ymax(std::min(vrect.bottom(), bounds.bottom()));
 
   clip= bounds;
 
@@ -903,10 +924,10 @@ Rect CanvasView::get_content_bounds() const
       Rect rect = (*iter)->get_bounds_of_item_list((*iter)->get_root_area_group()->get_contents());
       if (rect.width() > 0 && rect.height() > 0)
       {
-        minx = std::min(minx, rect.xmin());
-        miny = std::min(miny, rect.ymin());
-        maxx = std::max(maxx, rect.xmax());
-        maxy = std::max(maxy, rect.ymax());
+        minx = std::min(minx, rect.left());
+        miny = std::min(miny, rect.top());
+        maxx = std::max(maxx, rect.right());
+        maxy = std::max(maxy, rect.bottom());
       }
     }
   }
@@ -964,7 +985,7 @@ void CanvasView::export_png(const std::string &filename, bool crop)
 }
 
 
-void CanvasView::export_pdf(const std::string &filename, const mdc::Size &size_in_pt)
+void CanvasView::export_pdf(const std::string &filename, const Size &size_in_pt)
 {
   CanvasAutoLock lock(this);
 
@@ -976,7 +997,7 @@ void CanvasView::export_pdf(const std::string &filename, const mdc::Size &size_i
     CairoCtx ctx(surface);
     ctx.check_state();
 
-    ctx.scale(mdc::Point(size_in_pt.width/vsize.width, size_in_pt.width/vsize.width));
+    ctx.scale(Point(size_in_pt.width/vsize.width, size_in_pt.width/vsize.width));
 
     render_for_export(Rect(Point(0,0), vsize), &ctx);
 
@@ -993,7 +1014,7 @@ void CanvasView::export_pdf(const std::string &filename, const mdc::Size &size_i
 }
 
 
-void CanvasView::export_ps(const std::string &filename, const mdc::Size &size_in_pt)
+void CanvasView::export_ps(const std::string &filename, const Size &size_in_pt)
 {
   CanvasAutoLock lock(this);
 
@@ -1005,7 +1026,7 @@ void CanvasView::export_ps(const std::string &filename, const mdc::Size &size_in
     CairoCtx ctx(surface);
     ctx.check_state();
 
-    ctx.scale(mdc::Point(size_in_pt.width/vsize.width, size_in_pt.width/vsize.width));
+    ctx.scale(Point(size_in_pt.width/vsize.width, size_in_pt.width/vsize.width));
     
     render_for_export(Rect(Point(0,0), vsize), &ctx);
 
@@ -1022,7 +1043,7 @@ void CanvasView::export_ps(const std::string &filename, const mdc::Size &size_in
 }
 
 
-void CanvasView::export_svg(const std::string &filename, const mdc::Size &size_in_pt)
+void CanvasView::export_svg(const std::string &filename, const Size &size_in_pt)
 {
   CanvasAutoLock lock(this);
 
@@ -1034,7 +1055,7 @@ void CanvasView::export_svg(const std::string &filename, const mdc::Size &size_i
     CairoCtx ctx(surface);
     ctx.check_state();
 
-    ctx.scale(mdc::Point(size_in_pt.width/vsize.width, size_in_pt.width/vsize.width));
+    ctx.scale(Point(size_in_pt.width/vsize.width, size_in_pt.width/vsize.width));
     
     render_for_export(Rect(Point(0,0), vsize), &ctx);
 
@@ -1062,7 +1083,7 @@ void CanvasView::render_for_export(const Rect &bounds, CairoCtx *ctx)
 
   _cairo->save();
   
-  _cairo->translate(-bounds.xmin(), -bounds.ymin());
+  _cairo->translate(-bounds.left(), -bounds.top());
 
   _cairo->rectangle(bounds);
   _cairo->clip();
@@ -1152,8 +1173,8 @@ void CanvasView::select_items_inside(const Rect &rect, SelectType type, Group *g
       for (std::list<Layer*>::iterator it= _layers.begin(); it != _layers.end(); ++it)
       {
         std::list<CanvasItem*> selection((*it)->get_items_bounded_by(rect, mdc::Layer::ItemCheckFunc(), group));
-
-        _selection->add(selection);
+        if (selection.size() > 0)
+          _selection->add(selection);
       }
     }
   }
@@ -1250,14 +1271,14 @@ void CanvasView::set_event_callbacks(const sigc::slot<bool, CanvasView*, MouseBu
 
 
 static bool propagate_event(mdc::CanvasItem *item, 
-                            const sigc::mem_functor2<bool, mdc::CanvasItem, mdc::CanvasItem*, const mdc::Point&> &functor,
-                            const mdc::Point &pos)
+                            const sigc::mem_functor2<bool, mdc::CanvasItem, mdc::CanvasItem*, const Point&> &functor,
+                            const Point &pos)
 {
   mdc::CanvasItem *target= item;
 
   while (item)
   {
-    mdc::Point p;
+    Point p;
     
     // convert pos to the item's local coordinate system
     p= item->convert_point_from(pos, 0);
@@ -1278,14 +1299,14 @@ static bool propagate_event(mdc::CanvasItem *item,
 
 template<class T_arg1>
 static bool propagate_event(mdc::CanvasItem *item, 
-                            const sigc::mem_functor3<bool, mdc::CanvasItem, mdc::CanvasItem*, const mdc::Point&, T_arg1> &functor,
-                            const mdc::Point &pos, T_arg1 arg1)
+                            const sigc::mem_functor3<bool, mdc::CanvasItem, mdc::CanvasItem*, const Point&, T_arg1> &functor,
+                            const Point &pos, T_arg1 arg1)
 {
   mdc::CanvasItem *target= item;
   
   while (item)
   {
-    mdc::Point p;
+    Point p;
     
     // convert pos to the item's local coordinate system
     p= item->convert_point_from(pos, 0);
@@ -1305,14 +1326,14 @@ static bool propagate_event(mdc::CanvasItem *item,
 
 template<class T_arg1, class T_arg2>
 static bool propagate_event(mdc::CanvasItem *item, 
-                            const sigc::mem_functor4<bool, mdc::CanvasItem, mdc::CanvasItem*, const mdc::Point&, T_arg1, T_arg2> &functor,
-                            const mdc::Point &pos, T_arg1 arg1, T_arg2 arg2)
+                            const sigc::mem_functor4<bool, mdc::CanvasItem, mdc::CanvasItem*, const Point&, T_arg1, T_arg2> &functor,
+                            const Point &pos, T_arg1 arg1, T_arg2 arg2)
 {
   mdc::CanvasItem *target= item;
   
   while (item)
   {
-    mdc::Point p;
+    Point p;
     
     // convert pos to the item's local coordinate system
     p= item->convert_point_from(pos, 0);
@@ -1338,26 +1359,26 @@ bool CanvasView::perform_auto_scroll(const Point &mouse_pos)
   
   Rect vp= get_viewport();
   
-  if (mouse_pos.x < vp.xmin())
+  if (mouse_pos.x < vp.left())
   {
-    dx= mouse_pos.x - vp.xmin();
+    dx= mouse_pos.x - vp.left();
     if (dx < -100) dx= -100;
   }
-  else if (mouse_pos.x > vp.xmax())
+  else if (mouse_pos.x > vp.right())
   {
-    dx= mouse_pos.x - vp.xmax();
+    dx= mouse_pos.x - vp.right();
     if (dx > 100) dx= 100;
   }
   dx= ceil(dx / 10);
   
-  if (mouse_pos.y < vp.ymin())
+  if (mouse_pos.y < vp.top())
   {
-    dy= mouse_pos.y - vp.ymin();
+    dy= mouse_pos.y - vp.top();
     if (dy < -100) dy= -100;
   }
-  else if (mouse_pos.y > vp.ymax())
+  else if (mouse_pos.y > vp.bottom())
   {
-    dy= mouse_pos.y - vp.ymax();
+    dy= mouse_pos.y - vp.bottom();
     if (dy > 100) dy= 100;
   }
   dy= ceil(dy / 10);
