@@ -1,10 +1,20 @@
-/*
- *  mdc_connector.h
- *  mdcanvas
- *
- *  Created by Alfredo Kojima on 07/May/2.
- *  Copyright 2007 MySQL AB. All rights reserved.
+/* 
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 #ifndef __MDC_CONNECTOR_H__
@@ -41,8 +51,8 @@ public:
   CanvasItem *get_connected_item();
   CanvasItem *get_owner() { return _owner; }
 
-  Point get_position(const Point &srcpos);
-  Point get_position();
+  MySQL::Geometry::Point get_position(const MySQL::Geometry::Point &srcpos);
+  MySQL::Geometry::Point get_position();
 
 
   // callback for Magnet
