@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -43,28 +43,28 @@ namespace mdc {
   
 MYSQLCANVAS_PUBLIC_FUNC void cairo_image_surface_blur(cairo_surface_t* surface, double radius);
 
-MYSQLCANVAS_PUBLIC_FUNC void draw_shadow(CairoCtx *cr, const Rect &around_rect, const Color &color);
-MYSQLCANVAS_PUBLIC_FUNC void draw_shadow_gl(const Rect &bounds, const Color &color);
+MYSQLCANVAS_PUBLIC_FUNC void draw_shadow(CairoCtx *cr, const MySQL::Geometry::Rect &around_rect, const MySQL::Drawing::Color &color);
+MYSQLCANVAS_PUBLIC_FUNC void draw_shadow_gl(const MySQL::Geometry::Rect &bounds, const MySQL::Drawing::Color &color);
 
-MYSQLCANVAS_PUBLIC_FUNC void draw_glow(CairoCtx *cr, const Rect &around_rect, const Color &color);
+MYSQLCANVAS_PUBLIC_FUNC void draw_glow(CairoCtx *cr, const MySQL::Geometry::Rect &around_rect, const MySQL::Drawing::Color &color);
 
-MYSQLCANVAS_PUBLIC_FUNC void fill_hollow_rectangle(CairoCtx *cr, const Rect &outer_rect,
-                           const Rect &inner_rect);
+MYSQLCANVAS_PUBLIC_FUNC void fill_hollow_rectangle(CairoCtx *cr, const MySQL::Geometry::Rect &outer_rect,
+                           const MySQL::Geometry::Rect &inner_rect);
 
 MYSQLCANVAS_PUBLIC_FUNC void stroke_rounded_rectangle(CairoCtx *cr,
-                              const Rect &bounds, CornerMask corners,
+                              const MySQL::Geometry::Rect &bounds, CornerMask corners,
                               float corner_radius, float offset= 0);
-MYSQLCANVAS_PUBLIC_FUNC void stroke_rounded_rectangle_gl(const Rect &rect, CornerMask corners,
+MYSQLCANVAS_PUBLIC_FUNC void stroke_rounded_rectangle_gl(const MySQL::Geometry::Rect &rect, CornerMask corners,
                                                         float corner_radius, float offset);
 
-MYSQLCANVAS_PUBLIC_FUNC void gl_setcolor(const Color &color);
-MYSQLCANVAS_PUBLIC_FUNC void gl_setcolor(const Color &color, double alpha);
+MYSQLCANVAS_PUBLIC_FUNC void gl_setcolor(const MySQL::Drawing::Color &color);
+MYSQLCANVAS_PUBLIC_FUNC void gl_setcolor(const MySQL::Drawing::Color &color, double alpha);
 MYSQLCANVAS_PUBLIC_FUNC void gl_rectangle(double x, double y, double w, double h, bool filled);
-MYSQLCANVAS_PUBLIC_FUNC void gl_rectangle(const Rect &rect, bool filled);
-MYSQLCANVAS_PUBLIC_FUNC void gl_box(const Rect &rect, Color& border_color, Color& fill_color);
-MYSQLCANVAS_PUBLIC_FUNC void gl_polygon(const Point vertices[], int size,  bool filled);
-MYSQLCANVAS_PUBLIC_FUNC void gl_polygon(const Point vertices[], int size, const Color& border_color,
-                                        const Color& fill_color);
+MYSQLCANVAS_PUBLIC_FUNC void gl_rectangle(const MySQL::Geometry::Rect &rect, bool filled);
+MYSQLCANVAS_PUBLIC_FUNC void gl_box(const MySQL::Geometry::Rect &rect, MySQL::Drawing::Color& border_color, MySQL::Drawing::Color& fill_color);
+MYSQLCANVAS_PUBLIC_FUNC void gl_polygon(const MySQL::Geometry::Point vertices[], int size,  bool filled);
+MYSQLCANVAS_PUBLIC_FUNC void gl_polygon(const MySQL::Geometry::Point vertices[], int size, const MySQL::Drawing::Color& border_color,
+                                        const MySQL::Drawing::Color& fill_color);
 MYSQLCANVAS_PUBLIC_FUNC void gl_arc(double x, double y, double radius, double start, double end, bool filled);
 };
 
