@@ -242,8 +242,8 @@ retry:
       _cachedPassword.clear();
     }
   
-    std::string key = connectionProperties.repr();
-    if (key == _cacheKey)
+    std::string key = connectionProperties->hostIdentifier();
+    if (key == _cacheKey && !key.empty()) // hostIdentifier will be "" if it's a temporary connection
       properties["password"] = _cachedPassword;
     else
     {
