@@ -18,7 +18,7 @@
  */
 
 #include <mforms/mforms.h>
-#import "string_utilities.h"
+#include "base/string_utilities.h"
 
 #import "MFCodeEditor.h"
 #import "NSString_extras.h"
@@ -662,7 +662,7 @@ static void ce_set_read_only(CodeEditor* self, bool flag)
 {
   ScintillaView *editor = self->get_data();
   if (editor)
-    [editor setEditable: flag];
+    [editor setEditable: !flag];
 }
 
 static void ce_show_markup(CodeEditor* self, LineMarkup markup, int line)
