@@ -133,6 +133,13 @@
 
 //--------------------------------------------------------------------------------------------------
 
+- (void)setEnabled:(BOOL)flag
+{
+  [[self documentView] setEnabled: flag];
+}
+
+//--------------------------------------------------------------------------------------------------
+
 static bool scrollpanel_create(::mforms::ScrollPanel *self, mforms::ScrollPanelFlags flags)
 {
   [[[MFScrollPanelImpl alloc] initWithObject:self 
