@@ -121,16 +121,21 @@ static NSImage *descendingSortIndicator=nil;
   [column setResizingMask: NSTableColumnUserResizingMask];
   switch (type)
   {
-      case mforms::CheckColumnType:
-      {
-        NSButtonCell *cell = [[[NSButtonCell alloc] init] autorelease];
-        [column setDataCell: cell];
-        [cell setTitle: @""];
-        [cell setButtonType: NSSwitchButton];
-        break;
-      }
-      case mforms::StringColumnType:
-        break;
+    case mforms::CheckColumnType:
+    {
+      NSButtonCell *cell = [[[NSButtonCell alloc] init] autorelease];
+      [column setDataCell: cell];
+      [cell setTitle: @""];
+      [cell setButtonType: NSSwitchButton];
+      break;
+    }
+    case mforms::StringColumnType:
+      break;
+    case mforms::IconColumnType:
+      NSImageCell *cell = [[[NSImageCell alloc] init] autorelease];
+      [column setDataCell: cell];
+      editable = NO;
+      break;
   }
   [[column dataCell] setEditable: editable];
   [[column dataCell] setTruncatesLastVisibleLine: YES];
@@ -462,8 +467,19 @@ static void treeview_set_string(mforms::TreeView *self, int row, int column, con
   if (tree)
   {
     id item= [tree->mOutline itemAtRow: row];
-    [item setObject: [NSString stringWithUTF8String: value.c_str()]
-             forKey: [NSString stringWithFormat:@"%i", column]];
+    if ([[[tree->mOutline tableColumnWithIdentifier: [NSString stringWithFormat:@"%i", column]] dataCell] 
+         isKindOfClass: [NSImageCell class]])
+    {
+      NSImage *image = [[[NSImage alloc] initWithContentsOfFile: wrap_nsstring(value)] autorelease];
+      if (!image)
+        NSLog(@"Can't load icon %s", value.c_str());
+      else
+        [item setObject: image
+                 forKey: [NSString stringWithFormat:@"%i", column]];
+    }
+    else      
+      [item setObject: [NSString stringWithUTF8String: value.c_str()]
+               forKey: [NSString stringWithFormat:@"%i", column]];
     if (tree->mFreezeCount == 0)
       [tree->mOutline reloadItem: item];
   }
@@ -569,6 +585,13 @@ static int treeview_get_selected(mforms::TreeView *self)
 }
 
 
+static void treeview_set_row_height(mforms::TreeView *self, int height)
+{
+  MFTreeViewImpl *tree= self->get_data();
+  if (tree)
+    [tree->mOutline setRowHeight: height];
+}
+
 static void treeview_set_selected(mforms::TreeView *self, const int idx)
 {
   MFTreeViewImpl *tree= self->get_data();
@@ -638,6 +661,8 @@ void cf_treeview_init()
   f->_treeview_impl.get_selected= &treeview_get_selected;
   f->_treeview_impl.set_selected= &treeview_set_selected;
 
+  f->_treeview_impl.set_row_height= &treeview_set_row_height;
+  
   f->_treeview_impl.count= &treeview_count;
 
   f->_treeview_impl.set_row_tag= &treeview_set_row_tag;
