@@ -235,6 +235,22 @@ static void util_show_wait_message(const std::string &title, const std::string &
                     andDescription: [NSString stringWithUTF8String: message.c_str()]];
 }
 
+
+static bool util_run_cancelable_wait_message(const std::string &title, const std::string &text,
+                                             const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_task)
+{
+  start_task();
+  return [MHudController runModalHudWithTitle: [NSString stringWithUTF8String: title.c_str()]
+                               andDescription: [NSString stringWithUTF8String: text.c_str()]
+                                 cancelAction: cancel_task];
+}
+
+
+static void util_stop_cancelable_wait_message()
+{
+  [MHudController stopModalHud];
+}
+
 //--------------------------------------------------------------------------------------------------
 
 static bool util_hide_wait_message()
@@ -244,6 +260,71 @@ static bool util_hide_wait_message()
 
 //--------------------------------------------------------------------------------------------------
 
+static bool util_move_to_trash(const std::string &path)
+{
+  FSRef ref;
+  if (FSPathMakeRefWithOptions((const UInt8 *)[wrap_nsstring(path) fileSystemRepresentation], 
+                               kFSPathMakeRefDoNotFollowLeafSymlink,
+                               &ref,
+                               NULL) != 0)
+    return false;
+  
+  if (FSMoveObjectToTrashSync(&ref, NULL, kFSFileOperationDefaultOptions) != 0)
+    return false;
+  return true;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+@interface MainThreadRunner : NSObject
+{
+  sigc::slot<void*> slot;
+@public
+  void *result;
+}
+
+- (id)initWithSlot:(const sigc::slot<void*>&)slot;
+
+@end
+
+@implementation MainThreadRunner
+
+- (id)initWithSlot:(const sigc::slot<void*>&)aSlot
+{
+  self = [super init];
+  if (self)
+  {
+    slot= aSlot;
+  }
+  return self;
+}
+
+- (void)perform
+{
+  result = slot();
+}
+
+@end
+
+
+static void *util_perform_from_main_thread(const sigc::slot<void*> &slot)
+{
+  if ([NSThread isMainThread])
+    return slot();
+  else
+  {
+    MainThreadRunner *tmp = [[MainThreadRunner alloc] init];
+    [tmp performSelectorOnMainThread: @selector(perform) 
+                          withObject: nil
+                       waitUntilDone: YES];
+    void *result = tmp->result;
+    [tmp release];
+    return result;
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void cf_util_init()
 {
   ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();
@@ -251,8 +332,11 @@ void cf_util_init()
   f->_utilities_impl.show_message= &util_show_message;
   f->_utilities_impl.show_error= &util_show_message;
   f->_utilities_impl.show_warning= &util_show_message;
+  f->_utilities_impl.show_message_with_checkbox= &util_show_message_with_checkbox;
   f->_utilities_impl.show_wait_message= &util_show_wait_message;
   f->_utilities_impl.hide_wait_message= &util_hide_wait_message;
+  f->_utilities_impl.run_cancelable_wait_message= &util_run_cancelable_wait_message;
+  f->_utilities_impl.stop_cancelable_wait_message= &util_stop_cancelable_wait_message;
   f->_utilities_impl.set_clipboard_text= &util_set_clipboard_text;
   f->_utilities_impl.get_clipboard_text= &util_get_clipboard_text;
   f->_utilities_impl.open_url= &util_open_url;
@@ -261,4 +345,6 @@ void cf_util_init()
   f->_utilities_impl.store_password= &util_store_password;
   f->_utilities_impl.find_password= &util_find_password;
   f->_utilities_impl.forget_password= &util_forget_password;
+  f->_utilities_impl.move_to_trash= &util_move_to_trash;
+  f->_utilities_impl.perform_from_main_thread= &util_perform_from_main_thread;
 }
