@@ -20,7 +20,7 @@
 
 #import "MFView.h"
 #import <mforms/mforms.h>
-#import "string_utilities.h"
+#include "base/string_utilities.h"
 
 #import "MFContainerBase.h" // to get forw declaration of setFreezeRelayout:
 #import "NSColor_extras.h"
@@ -35,7 +35,6 @@ enum ViewFlags
 @class MFCheckBoxImpl;
 @implementation NSView(MForms)
 
-
 - (id)innerView
 {
   return self;
@@ -215,7 +214,8 @@ static void view_set_enabled(::mforms::View *self, bool flag)
   id view = self->get_data();
   if (view)
   {
-    [view setEnabled:flag?YES:NO];
+    if ([view respondsToSelector: @selector(setEnabled:)])
+      [view setEnabled:flag?YES:NO];
   }
 }
 
@@ -359,7 +359,11 @@ static void view_set_front_color(::mforms::View *self, const std::string &color)
 static void view_set_back_color(::mforms::View *self, const std::string &color)
 {
   if ([self->get_data() respondsToSelector: @selector(setBackgroundColor:)])
+  {
     [self->get_data() setBackgroundColor: [NSColor colorFromHexString: [NSString stringWithUTF8String: color.c_str()]]];
+    if ([self->get_data() respondsToSelector: @selector(setDrawsBackground:)])
+      [self->get_data() setDrawsBackground: !color.empty()];
+  }
 }
 
 
