@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,12 +23,12 @@
 using namespace mforms;
 
   
-
-GRTTreeView::GRTTreeView(bool border)
+GRTTreeView::GRTTreeView(TreeOptions options)
+  : _context_menu(0)
 {
   _grttreeview_impl= &ControlFactory::get_instance()->_grttreeview_impl;
 
-  _grttreeview_impl->create(this, border);
+  _grttreeview_impl->create(this, options);
 }
 
 void GRTTreeView::set_context_menu(Menu *menu)
@@ -60,9 +60,9 @@ void GRTTreeView::refresh(const bec::NodeId &node)
 }
 
 
-void GRTTreeView::row_count_changed(int old_count)
+void GRTTreeView::row_count_changed(const bec::NodeId &parent, int old_count)
 {
-  _grttreeview_impl->row_count_changed(this, old_count);
+  _grttreeview_impl->row_count_changed(this, parent, old_count);
 }
 
 
@@ -89,15 +89,25 @@ void GRTTreeView::set_allow_multi_selection(bool flag)
   _grttreeview_impl->set_allow_multi_selection(this, flag);
 }
 
+//--------------------------------------------------------------------------------------------------
 
 bool GRTTreeView::get_selected_node(bec::NodeId &node)
 {
   return _grttreeview_impl->get_selected_node(this, node);
 }
 
+//--------------------------------------------------------------------------------------------------
 
 int GRTTreeView::get_selection(std::vector<bec::NodeId> &nodes)
 {
   return _grttreeview_impl->get_selection(this, nodes);
 }
 
+//--------------------------------------------------------------------------------------------------
+
+void GRTTreeView::set_expanded(const bec::NodeId& node, bool expanded)
+{
+  _grttreeview_impl->set_expanded(this, node, expanded);
+}
+
+//--------------------------------------------------------------------------------------------------
