@@ -31,7 +31,7 @@ namespace gtk {
     ~GtkAutoLock() {gdk_threads_leave();}
   };
 
-  class ObjectImpl
+  class ObjectImpl : public sigc::trackable
   {
   protected:
     ::mforms::Object *owner;
@@ -39,14 +39,18 @@ namespace gtk {
     ObjectImpl(::mforms::Object *object)
       : owner(object)
     {
-      object->set_data(this);
+      object->set_data(this, &free_object);
     }
 
     virtual ~ObjectImpl()
     {
-      puts("FREE OBJECT");
       //TODO: Check if we need to free memory here?
     }
+
+    static void free_object(void* obj)
+    {
+      delete (ObjectImpl*)obj;
+    }
   };
 };
 };
