@@ -21,6 +21,7 @@
 
 
 #include "mforms/panel.h"
+#include "base/drawing.h"
 
 #include "lfi_container.h"
 
@@ -45,13 +46,13 @@ protected:
   PanelImpl(::mforms::Panel *self, ::mforms::PanelType type)
     : ContainerImpl(self), _frame(0), _evbox(0), _radio_group_set(false)
   {
-    static Gdk::Color sel_color;
-    static bool initialized = false;
-    if (!initialized)
-    {
-      sel_color = Gtk::RC::get_style(Gtk::TreeView())->get_bg(Gtk::STATE_SELECTED);
-      initialized = true;
-    }
+    //static Gdk::Color sel_color;
+    //static bool initialized = false;
+    //if (!initialized)
+    //{
+    //  sel_color = Gtk::RC::get_style(Gtk::TreeView())->get_bg(Gtk::STATE_SELECTED);
+    //  initialized = true;
+    //}
 
     _title_check= 0;
 
@@ -61,9 +62,22 @@ protected:
       _frame= Gtk::manage(new Gtk::Frame());
       break;
     case StyledHeaderPanel:      // just a container with color filled background
-      _evbox= Gtk::manage(new Gtk::EventBox());
-      _evbox->modify_bg(Gtk::STATE_NORMAL, sel_color);
+    {
+      _evbox = Gtk::manage(new Gtk::EventBox());
+
+      mforms::App                 *app      = mforms::App::get();
+      Glib::RefPtr<Gdk::Colormap>  colormap = _evbox->get_colormap();
+      if (app && colormap)
+      {
+        MySQL::Drawing::Color sclr = app->get_system_color(mforms::SystemHighlight);
+        Gdk::Color clr;
+        clr.set_rgb_p(sclr.red, sclr.green, sclr.blue);
+        if (colormap->alloc_color(clr))
+          _evbox->modify_bg(Gtk::STATE_NORMAL, clr);
+      }
+
       break;
+    }
     case FilledPanel:      // just a container with color filled background
       _evbox= Gtk::manage(new Gtk::EventBox());
       break;
