@@ -689,22 +689,21 @@ void mforms::gtk::CodeEditorImpl::notify(SCNotification *event)
   switch (event->nmhdr.code)
   {
     case SCN_MODIFIED:
-/*
       {
       const int mod_type = event->modificationType;
       if (mod_type & SC_MOD_INSERTTEXT || mod_type & SC_MOD_DELETETEXT)
       {
-        set_dirty(true);
+        //set_dirty(true);
         
-        _background_action_timer_conn.disconnect();
-        _background_action_timer_conn= Glib::signal_timeout().connect(
-          sigc::mem_fun(this, &SqlEditorFE::on_background_action_timer),
-          2000); //! get value from wb options
-        _text_changed_signal.emit();
+        //_background_action_timer_conn.disconnect();
+        //_background_action_timer_conn= Glib::signal_timeout().connect(
+        //  sigc::mem_fun(this, &SqlEditorFE::on_background_action_timer),
+        //  2000); //! get value from wb options
+        _owner->text_changed(event->line, event->linesAdded);
+      }
+     // if (mod_type & SC_MOD_CHANGEFOLD)
+     //   fold_changed(event->line, event->foldLevelNow, event->foldLevelPrev);
       }
-      if (mod_type & SC_MOD_CHANGEFOLD)
-        fold_changed(event->line, event->foldLevelNow, event->foldLevelPrev);
-      }*/
       break;
 
     case SCN_MARGINCLICK:
