@@ -96,7 +96,10 @@ void TextBoxImpl::set_monospaced(::mforms::TextBox *self, bool flag)
     Pango::FontDescription font(cb->_text->get_style()->get_font());
     
     if (flag)
+    {
       font.set_family("Bitstream Vera Sans Mono");
+      font.set_size(9 * Pango::SCALE);
+    }
     cb->_text->modify_font(font);
   }
 }
@@ -167,6 +170,7 @@ TextBoxImpl::TextBoxImpl(::mforms::TextBox *self, mforms::ScrollBars scroll_type
   _swin->set_policy(h_scrollbar_policy, v_scrollbar_policy);
   _swin->set_shadow_type(Gtk::SHADOW_IN);
   _text->show();
+  _swin->show();
 
   _text->get_buffer()->signal_changed().connect(sigc::mem_fun(*self, &::mforms::TextBox::callback));
 }
