@@ -27,10 +27,12 @@ extern "C" {
 #endif
 
 #include <sys/mman.h>
+#include <glib/gstdio.h>
 
 // this is broken
 //#undef USE_KEYRING
 
+#include "base/file_functions.h"
 #include "../lf_utilities.h"
 #include "gtk_helpers.h"
 #include "mforms.h"
@@ -188,7 +190,6 @@ PasswordCache PasswordCache::instance;
 
 //--------------------------------------------------------------------------------
   
-//sigc::slot<void,std::string> UtilitiesImpl::open_url_slot;
 
 int UtilitiesImpl::show_message(const std::string &title, const std::string &text,
                         const std::string &ok, const std::string &cancel,
@@ -299,7 +300,20 @@ std::string UtilitiesImpl::get_clipboard_text()
 
 void UtilitiesImpl::open_url(const std::string &url)
 {
-  open_url_slot(url);
+  const gchar *argv[] = {
+    "xdg-open",
+    url.c_str(),
+    NULL 
+  };
+  GError *error = NULL;
+  if (!g_spawn_async(NULL, (gchar**)argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error))
+  {
+    char *err = g_strdup_printf("Error opening url with xdg-open: %s", error->message);
+    g_error_free(error);
+    std::runtime_error exc(err);
+    g_free(err);
+    throw exc;
+  }
 }
 
 std::string UtilitiesImpl::get_special_folder(mforms::FolderType type)
@@ -325,6 +339,13 @@ std::string UtilitiesImpl::get_special_folder(mforms::FolderType type)
     g_free((void*)t);
 #endif
     break;
+  case mforms::ApplicationData:
+    path = g_get_user_data_dir();
+    break;
+  case WinProgramFiles:
+  case WinProgramFilesX86:
+    path = "/";
+    break;
   }
   if (path.empty())
   {
@@ -622,15 +643,32 @@ class TransparentMessage : public Gtk::Window
 {
   public:
     TransparentMessage();
-    void show_message(const std::string& title, const std::string& text);
+    void show_message(const std::string& title, const std::string& text, const sigc::slot<bool> &cancel_slot=sigc::slot<bool>());
+    void stop();
+    bool response;
+    bool running_modal;
   private:
+    Gtk::Button *cancel_button;
+    sigc::slot<bool> cancel_slot;
+    Glib::Mutex mutex;
+
     virtual bool on_button_release_event(GdkEventButton* ev);
+    void cancel_clicked();
 };
 
 //------------------------------------------------------------------------------
 TransparentMessage::TransparentMessage()
+  : response(false)
 {
-  add_events(Gdk::BUTTON_RELEASE_MASK);
+  Gtk::Window *owner = get_mainwindow();
+  if (owner)
+  {
+    set_transient_for(*owner);
+    set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
+  }
+  else
+    set_position(Gtk::WIN_POS_CENTER);
+
 
   property_skip_taskbar_hint() = true;
   property_skip_pager_hint() = true;
@@ -639,11 +677,35 @@ TransparentMessage::TransparentMessage()
   set_size_request(MESSAGE_WINDOW_WIDTH, MESSAGE_WINDOW_HEIGHT);
   
   set_style(get_style()->copy());
+
+  {
+    Gtk::VBox *vbox = Gtk::manage(new Gtk::VBox(false, 0));
+    vbox->set_border_width(20);
+    add(*vbox);
+
+    Gtk::HBox *hbox = Gtk::manage(new Gtk::HBox(false, 12));
+    vbox->pack_end(*hbox, false, false);
+
+    cancel_button = Gtk::manage(new Gtk::Button("Cancel"));
+    hbox->pack_end(*cancel_button, false, true);
+    vbox->show_all();
+
+    cancel_button->signal_clicked().connect(sigc::mem_fun(this, &TransparentMessage::cancel_clicked));
+  }
 }
 
 //------------------------------------------------------------------------------
-void TransparentMessage::show_message(const std::string& title, const std::string& text)
+void TransparentMessage::show_message(const std::string& title, const std::string& text, const sigc::slot<bool> &cancel_slot)
 {
+  this->cancel_slot = cancel_slot;
+  if (cancel_slot)
+    cancel_button->show();
+  else
+  {
+    cancel_button->hide();
+    add_events(Gdk::BUTTON_RELEASE_MASK);
+  }
+
   realize();
 
   Gdk::Color black("black"), white("white");
@@ -683,16 +745,6 @@ void TransparentMessage::show_message(const std::string& title, const std::strin
   pixmap->draw_layout(gc, icon->get_width()+30, 90, layout);
 
   get_style()->set_bg_pixmap(Gtk::STATE_NORMAL, pixmap);
-
-  Gtk::Window *owner = get_mainwindow();
-  if (owner)
-  {
-    set_transient_for(*owner);
-    set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
-  }
-  else
-    set_position(Gtk::WIN_POS_CENTER);
-
   Glib::RefPtr<Gdk::Window> window = get_window();
 #if GTK_VERSION_GE(2,12)
   window->set_opacity(0.85);
@@ -701,6 +753,37 @@ void TransparentMessage::show_message(const std::string& title, const std::strin
   show_now();
 }
 
+
+//------------------------------------------------------------------------------
+void TransparentMessage::stop()
+{
+  Glib::Mutex::Lock lock(mutex);
+  if (running_modal)
+  {
+    unrealize();
+    running_modal = false;
+    Gtk::Main::quit();
+  }
+  response= true;
+}
+
+
+void TransparentMessage::cancel_clicked()
+{
+  Glib::Mutex::Lock lock(mutex);
+  if (cancel_slot && cancel_slot())
+  {
+    if (running_modal)
+    {
+      unrealize();
+      running_modal = false;
+      Gtk::Main::quit();
+      hide();
+    }
+    response = false;
+  }
+}
+
 //------------------------------------------------------------------------------
 bool TransparentMessage::on_button_release_event(GdkEventButton* ev)
 {
@@ -709,6 +792,7 @@ bool TransparentMessage::on_button_release_event(GdkEventButton* ev)
 }
 
 static TransparentMessage *tm = 0;
+static TransparentMessage *tmc = 0;
 #endif
 
 //------------------------------------------------------------------------------
@@ -728,12 +812,68 @@ bool UtilitiesImpl::hide_wait_message()
 {
   #ifdef USE_TRANSPARENT_MESSAGE
   if (tm)
+  {
     tm->hide();
+    delete tm;
+    tm = 0;
+  }
   #endif
   return false;
 }
 
 
+//-------------------------------------------------------------------------------
+
+bool UtilitiesImpl::move_to_trash(const std::string &path)
+{
+  // trash in linux is chaos, just delete it
+  if (g_file_test(path.c_str(), G_FILE_TEST_IS_DIR))
+    base_rmdir_recursively(path.c_str());
+  else
+    g_remove(path.c_str());
+  return true;
+}
+
+//------------------------------------------------------------------------------
+
+
+bool UtilitiesImpl::run_cancelable_wait_message(const std::string &title, const std::string &text,
+                                                 const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_task)
+{
+  if (!tmc)
+    tmc = new TransparentMessage();
+  if (tmc)
+  {
+    tmc->show_message(title, text, cancel_task);
+    tmc->running_modal = true;
+
+    Glib::signal_idle().connect(sigc::bind_return(start_task, false));
+    Gtk::Main::run();
+    bool response = tmc->response;
+    delete tmc;
+    tmc = 0;
+    return response;
+  }
+
+  return false;
+}
+
+
+void UtilitiesImpl::stop_cancelable_wait_message()
+{
+  if (tmc)
+  {
+    if (Utilities::in_main_thread())
+      tmc->stop();
+    else
+      Utilities::perform_from_main_thread(sigc::bind_return(sigc::mem_fun(tmc, &TransparentMessage::stop), (void*)NULL));
+  }
+}
+
+
+
+//------------------------------------------------------------------------------
+
 void UtilitiesImpl::init()
 {
   ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();
@@ -743,6 +883,9 @@ void UtilitiesImpl::init()
   f->_utilities_impl.show_warning= &UtilitiesImpl::show_warning;
   f->_utilities_impl.show_wait_message= &UtilitiesImpl::show_wait_message;
   f->_utilities_impl.hide_wait_message= &UtilitiesImpl::hide_wait_message;
+  f->_utilities_impl.run_cancelable_wait_message= &UtilitiesImpl::run_cancelable_wait_message;
+  f->_utilities_impl.stop_cancelable_wait_message= &UtilitiesImpl::stop_cancelable_wait_message;
+
   f->_utilities_impl.set_clipboard_text= &UtilitiesImpl::set_clipboard_text;
   f->_utilities_impl.get_clipboard_text= &UtilitiesImpl::get_clipboard_text;
   f->_utilities_impl.open_url= &UtilitiesImpl::open_url;
@@ -751,11 +894,64 @@ void UtilitiesImpl::init()
   f->_utilities_impl.store_password= &UtilitiesImpl::store_password;
   f->_utilities_impl.find_password= &UtilitiesImpl::find_password;
   f->_utilities_impl.forget_password= &UtilitiesImpl::forget_password;
+  f->_utilities_impl.move_to_trash= &UtilitiesImpl::move_to_trash;
+  f->_utilities_impl.perform_from_main_thread = &MainThreadRequestQueue::perform;
+
+  MainThreadRequestQueue::get(); // init from main thread
 }
 
-void UtilitiesImpl::set_open_url_slot(const sigc::slot<void,std::string> &slot)
+
+//---------------------------------------------------------------------------------
+
+void MainThreadRequestQueue::from_main_thread()
 {
-  open_url_slot= slot;
+  Request *req;
+  {
+    Glib::Mutex::Lock lock(_mutex);
+    if (_queue.empty())
+      return;
+    req = _queue.front();
+    _queue.pop_front();
+  }
+  req->result = req->slot();
+
+  Glib::Mutex::Lock lock(req->mutex);
+  req->done = true;
+  req->cond.signal();
+}
+
+
+MainThreadRequestQueue::MainThreadRequestQueue()
+{
+  _disp.connect(sigc::mem_fun(this, &MainThreadRequestQueue::from_main_thread));
+}
+
+
+MainThreadRequestQueue *MainThreadRequestQueue::get()
+{
+  static MainThreadRequestQueue *q = new MainThreadRequestQueue();
+  return q;
+}
+
+void *MainThreadRequestQueue::perform(const sigc::slot<void*> &slot)
+{
+  MainThreadRequestQueue *self = MainThreadRequestQueue::get();
+
+  Request req;
+  req.slot = slot;
+  req.done = false;
+  req.result = 0;
+  {
+    Glib::Mutex::Lock lock(self->_mutex);
+    self->_queue.push_back(&req);
+  }
+  self->_disp.emit();
+
+  Glib::Mutex::Lock lock(req.mutex);
+  while (!req.done)
+    req.cond.wait(req.mutex);
+
+  return req.result;
 }
 
 
