@@ -249,9 +249,11 @@ void ViewImpl::set_needs_repaint(::mforms::View *self)
     Gtk::Widget *widget = view->get_outer();
     if (widget)
     {
-      Glib::RefPtr<Gdk::Window> window = widget->get_window();
-      if (window)
-        window->process_updates(true);
+//      Glib::RefPtr<Gdk::Window> window = widget->get_window();
+//      if (window)
+//        window->process_updates(true);
+//      else
+      widget->queue_draw();
     }
   }
 }
