@@ -33,12 +33,29 @@ Menu::Menu()
 void Menu::remove_item(int i)
 {
   _menu_impl->remove_item(this, i);
+  
+  std::string to_remove;
+  
+  for (std::map<const std::string, int>::iterator index = _item_map.begin(); index != _item_map.end(); index++)
+  {
+    if ((*index).second == i)
+      to_remove = (*index).first;
+    else if((*index).second > i)
+      (*index).second--;
+  }
+  
+  if (!to_remove.empty())
+    _item_map.erase(to_remove);
 }
 
 
 int Menu::add_item(const std::string &caption, const std::string &action)
 {
-  return _menu_impl->add_item(this, caption, action);
+  int item_index = _menu_impl->add_item(this, caption, action);
+  
+  _item_map[action] = item_index;
+  
+  return item_index;
 }
 
 
@@ -125,6 +142,20 @@ void Menu::handle_action(const std::string &action)
 void mforms::Menu::clear()
 {
   _menu_impl->clear(this);
+  _item_map.clear();
+}
+
+//--------------------------------------------------------------------------------------------------
+
+int mforms::Menu::get_item_index(const std::string &action)
+{
+  int item_index=-1;
+  std::map<const std::string, int>::iterator location= _item_map.find(action);
+  
+  if (location != _item_map.end() )
+    item_index = _item_map[action];
+  
+  return item_index;    
 }
 
 //--------------------------------------------------------------------------------------------------
