@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,12 +20,22 @@
 #ifndef _MFORMS_APP_H_
 #define _MFORMS_APP_H_
 
-#include <mforms/base.h>
 #include <map>
 #include <sigc++/sigc++.h>
 
+#include "mforms/base.h"
+#include "base/geometry.h"
+#include "base/drawing.h"
+
 namespace mforms {
 
+  // Known system colors.
+  enum SystemColor
+  {
+    SystemHighlight,         // The system-defined color of the background of selected items.
+                             // This includes selected menu items as well as selected text.
+  };
+
   class App;
   class AppView;
   class View;
@@ -49,6 +59,8 @@ namespace mforms {
     
     void (__stdcall *begin_thread_loop)();
     void (__stdcall *end_thread_loop)();
+
+    MySQL::Drawing::Color (__stdcall *get_system_color)(SystemColor type);
   };
 #endif
 #endif
@@ -118,7 +130,6 @@ namespace mforms {
     /** Exits from enter_event_loop() */
     void exit_event_loop(int retcode);
     
-    
     void set_view_for_identifier(View *view, const std::string &identifier);
     View *get_view_for_identifier(const std::string &identifier);
     
@@ -126,6 +137,8 @@ namespace mforms {
     static void begin_thread_loop();
     static void end_thread_loop();
     
+    // Retrieve system information like predefined colors, screen size, monitor count etc.
+    MySQL::Drawing::Color get_system_color(SystemColor type);
   public:
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 #ifndef SWIG
