@@ -22,6 +22,7 @@
 
 #include "mforms/base.h"
 #include "base/ui_form.h"
+#include <map>
 
 #include <sigc++/sigc++.h>
 
@@ -53,6 +54,7 @@ namespace mforms {
     MenuImplPtrs *_menu_impl;
     sigc::slot<void, const std::string&> _action_handler;
     sigc::signal<void> _on_will_show;
+    std::map<const std::string, int> _item_map;
   public:
     Menu();
 
@@ -72,6 +74,8 @@ namespace mforms {
 
     void handle_action(const std::string &action);    
     
+    int get_item_index(const std::string &action);
+    
     sigc::signal<void> signal_will_show() { return _on_will_show; }
   };
 };
