@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,7 +33,8 @@ namespace mforms {
     TitledBoxPanel,     // native grouping box with a title with border
     TitledGroupPanel,   // native grouping container with a title (may have no border) 
     CheckBoxTitlePanel, // container with 
-    FilledHeaderPanel   // Just like a filled panel but additionally has a header bar with a title.
+    FilledHeaderPanel,  // Just like a filled panel but additionally has a header bar with a title.
+    StyledHeaderPanel   // Panel which has top round corners for win, rect + gradient fill for osx, plain filled rect for linux
   };
 
   class Panel;
@@ -76,7 +77,7 @@ namespace mforms {
     /** Sets title of panel, if supported. */
     void set_title(const std::string &title);
     /** Sets background color of panel, if supported. */
-    void set_back_color(const std::string &color);
+    virtual void set_back_color(const std::string &color);
 
     /** Sets state of the panel checkbox, if supported. */
     void set_active(bool);
