@@ -61,7 +61,6 @@ namespace mforms {
     void (__stdcall *set_column_spacing)(Table *self, int);
 
     void (__stdcall *set_homogeneous)(Table *self, bool);
-    void (__stdcall *set_back_color)(Table *self, const std::string&);
   };
 #endif
 #endif
@@ -101,8 +100,6 @@ namespace mforms {
     /** Remove a child item from the table */
     virtual void remove(View *subview);
 
-    virtual void set_back_color(const std::string& color);
-
   protected:
     TableImplPtrs *_table_impl;
   };
