@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,12 +20,15 @@
 #ifndef _MFORMS_TABSWITCHER_H_
 #define _MFORMS_TABSWITCHER_H_
 
-#include "cairo/cairo.h"
-#include <mforms/base.h>
-#include <mforms/drawbox.h> 
-#include <mforms/tabview.h> 
 #include <vector>
 
+#include "cairo/cairo.h"
+
+#include "base/drawing.h"
+#include "mforms/base.h"
+#include "mforms/drawbox.h" 
+#include "mforms/tabview.h"
+
 namespace mforms
 {
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
@@ -53,27 +56,6 @@ namespace mforms
     TabLineColor   = 3
   };
   
-  struct Color {
-    double red;
-    double green;
-    double blue;
-    double alpha;
-    
-    Color() {
-      red= 1;
-      green= 1;
-      blue= 1;
-      alpha= 1;
-    }
-    Color(double r, double g, double b, double a) {
-      red= r;
-      green= g;
-      blue= b;
-      alpha= a;
-    }
-  };
-
-
   class MFORMS_EXPORT TabSwitcher : public DrawBox
   {
   public:
@@ -86,7 +68,7 @@ namespace mforms
                   const std::string &icon_path, const std::string &alt_icon_path);
     void set_icon(int index, const std::string &icon_path, const std::string &alt_icon_path);
 
-    void set_color(TabElementPart parts, Color new_color);
+    void set_color(TabElementPart parts, MySQL::Drawing::Color new_color);
     
     void set_selected(int index);
     int get_selected() { return _selected; }
@@ -108,7 +90,7 @@ namespace mforms
   private:
     sigc::signal<void> _signal_changed;
     TabView *_tabView;
-    Color _colors[4];
+    MySQL::Drawing::Color _colors[4];
     int _selected;
     int _last_clicked;
 
