@@ -32,7 +32,8 @@ namespace mforms {
   {
     StringColumnType, //!< simple string, with text entry editor
     IntegerColumnType, //!< numeric field, with text entry editor
-    CheckColumnType //!< boolean field, with checkbox
+    CheckColumnType, //!< boolean field, with checkbox
+    IconColumnType //!< icon field, value is the icon path
   };
 
   /** Options used to customize what to show in the tree. */
@@ -74,6 +75,8 @@ namespace mforms {
     int (__stdcall *get_selected)(TreeView *self);
     void (__stdcall *set_selected)(TreeView *self, const int idx);
 
+    void (__stdcall *set_row_height)(TreeView *self, int height);
+    
     void (__stdcall *set_allow_sorting)(TreeView *self, bool);
     
     int (__stdcall *count)(TreeView *self);
@@ -128,6 +131,9 @@ namespace mforms {
     /** Sets the selected index */
     void set_selected(const int idx);
     
+    /** Sets the height of a row in pixels */
+    void set_row_height(int height);
+    
     /** Toggles sorting of rows when the user clicks on a column header
      
      Be careful with the get_selected() and set_selected() methods when sorting is enabled,
