@@ -100,18 +100,24 @@ namespace mforms {
 
     void (__stdcall *show_wait_message)(const std::string &title, const std::string &text);
     bool (__stdcall *hide_wait_message)();
+    bool (__stdcall *run_cancelable_wait_message)(const std::string &title, const std::string &text,
+                                                  const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_task);
+    void (__stdcall *stop_cancelable_wait_message)();
     
     void (__stdcall *set_clipboard_text)(const std::string &text);
     std::string (__stdcall *get_clipboard_text)();
     std::string (__stdcall *get_special_folder)(mforms::FolderType type);
     
     void (__stdcall *open_url)(const std::string &url);
+    bool (__stdcall *move_to_trash)(const std::string &path);
     
     void (__stdcall *add_timeout)(float delay, const sigc::slot<bool> &callback);
     
     void (__stdcall *store_password)(const std::string &service, const std::string &account, const std::string &password);
     bool (__stdcall *find_password)(const std::string &service, const std::string &account, std::string &password);
     void (__stdcall *forget_password)(const std::string &service, const std::string &account);
+
+    void* (__stdcall *perform_from_main_thread)(const sigc::slot<void*> &slot);
   };
 #endif
 #endif
@@ -165,6 +171,11 @@ namespace mforms {
   public:
     static void show_wait_message(const std::string &title, const std::string &text);
     static bool hide_wait_message();
+    
+    static bool run_cancelable_task(const std::string &title, const std::string &text,
+                                    const sigc::slot<void*> &task,
+                                    const sigc::slot<bool> &cancel_task,
+                                    void *&task_result);
 
     /** Asks the user to enter a string, which is returned to the caller.
 
@@ -261,6 +272,10 @@ namespace mforms {
 
     /** Opens the given URL in the default system browser. */
     static void open_url(const std::string &url);
+    
+    /** Moves the given file or folder to the trash. The file might be permanently
+     deleted instead of being moved to trash, under some circumstances. */
+    static bool move_to_trash(const std::string &path);
 
     /** Sets up a callback to be called after a given interval. 
      
@@ -287,9 +302,11 @@ namespace mforms {
     static void enter_modal_loop();
     static void leave_modal_loop();
     static bool in_modal_loop();
+
 #endif
 #endif
 #endif
+    static void *perform_from_main_thread(const sigc::slot<void*> &slot);
     static bool in_main_thread();
   };
 
