@@ -221,7 +221,7 @@ void HeaderBox::mouse_down(int button, int x, int y)
 //----------------- SectionBox ---------------------------------------------------------------------
 
 SectionBox::SectionBox(bool expandable, const std::string& title, bool header_mode)
-  : Box(false), _content(NULL), _expanded(true), _expandable(expandable)
+  : Box(false), _content(NULL), _expandable(expandable), _expanded(true)
 {
   _title= title;
 
