@@ -69,6 +69,10 @@ void MenuImpl::popup_at(Menu* self, Object *control, int x, int y)
 {
 }
 
+void  MenuImpl::clear(Menu *self)
+{
+}
+
 //------------------------------------------------------------------------------
 void MenuImpl::init()
 {
@@ -81,6 +85,7 @@ void MenuImpl::init()
   f->_menu_impl.add_submenu = &MenuImpl::add_submenu;
   f->_menu_impl.set_item_enabled = &MenuImpl::set_item_enabled;
   f->_menu_impl.popup_at = &MenuImpl::popup_at; 
+  f->_menu_impl.clear = &MenuImpl::clear; 
 }
 
 }
