@@ -61,6 +61,10 @@ void __stdcall TextBoxImpl::set_monospaced(::mforms::TextBox *self, bool flag)
 {
 }
 
+void __stdcall TextBoxImpl::get_selected_range(TextBox *self, int &start, int &end)
+{
+}
+
 TextBoxImpl::TextBoxImpl(::mforms::TextBox *self, mforms::ScrollBars scroll_type)
   : ViewImpl(self)
 {
@@ -79,6 +83,7 @@ void TextBoxImpl::init()
   f->_textbox_impl.set_padding = &TextBoxImpl::set_padding;
   f->_textbox_impl.clear = &TextBoxImpl::clear;
   f->_textbox_impl.set_monospaced = &TextBoxImpl::set_monospaced;
+  f->_textbox_impl.get_selected_range = &TextBoxImpl::get_selected_range;
 }
 
 
