@@ -137,6 +137,19 @@ void __stdcall ViewImpl::set_back_image(::mforms::View *self, const std::string
 {
 }
   
+void __stdcall ViewImpl::destroy(View *self)
+{
+}
+
+void __stdcall ViewImpl::set_padding(View *self, const MySQL::Geometry::Padding&)
+{
+}
+
+void __stdcall ViewImpl::client_to_screen(View *self, MySQL::Geometry::Point&)
+{
+}
+
+  
 void ViewImpl::init()
 {
   ::mforms::ControlFactory *f= ::mforms::ControlFactory::get_instance();
@@ -164,6 +177,10 @@ void ViewImpl::init()
   f->_view_impl.set_back_image       = &ViewImpl::set_back_image;
 
   f->_view_impl.set_needs_repaint    = &ViewImpl::set_needs_repaint;
+  
+  f->_view_impl.destroy              = &ViewImpl::destroy;
+  f->_view_impl.set_padding          = &ViewImpl::set_padding;
+  f->_view_impl.client_to_screen     = &ViewImpl::client_to_screen;
 };
 
 };
