@@ -19,7 +19,7 @@
 #include "stdafx.h"
 #include "../stub_wizard.h"
 #include "../stub_view.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 
 namespace mforms{
