@@ -91,6 +91,12 @@ class FileChooserImpl : public ViewImpl
   {
   }
 
+  static bool __stdcall create(FileChooser *self, FileChooserType type, bool show_hidden)
+  {
+    return true;
+  }
+
+
   FileChooserImpl(::mforms::FileChooser *form, ::mforms::FileChooserType type)
     : ViewImpl(form)
   {
@@ -105,13 +111,15 @@ class FileChooserImpl : public ViewImpl
   {
     ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();
 
-    f->_filechooser_impl.create = &FileChooserImpl::create;
+    //TODO: Investigate how this should be addressed
+    //f->_filechooser_impl.create = &FileChooserImpl::create;
     f->_filechooser_impl.set_title = &FileChooserImpl::set_title;
     f->_filechooser_impl.run_modal = &FileChooserImpl::show_modal;
     f->_filechooser_impl.set_extensions = &FileChooserImpl::set_extensions;
     f->_filechooser_impl.set_directory = &FileChooserImpl::set_directory;
     f->_filechooser_impl.get_directory = &FileChooserImpl::get_directory;
     f->_filechooser_impl.get_path = &FileChooserImpl::get_path;
+    f->_filechooser_impl.create = &FileChooserImpl::create;
   }
 };
 
