@@ -58,6 +58,10 @@ protected:
   {
   }
 
+  static void __stdcall scroll_to_view(ScrollPanel*, View*)
+  {
+  }
+
  public:
   static void init()
   {
@@ -69,6 +73,7 @@ protected:
     f->_spanel_impl.remove         = &ScrollPanelImpl::remove;    
     f->_spanel_impl.set_visible_scrollers  = &ScrollPanelImpl::set_visible_scrollers;    
     f->_spanel_impl.set_autohide_scrollers = &ScrollPanelImpl::set_autohide_scrollers;    
+    f->_spanel_impl.scroll_to_view = &ScrollPanelImpl::scroll_to_view;    
   }
 };
 
