@@ -30,7 +30,9 @@
 #include "base/file_functions.h"
 #include <string.h>
 #include <math.h>
+#include <boost/shared_ptr.hpp>
 #include "base/log.h"
+#include <glib/gstdio.h>
 ENABLE_LOG("mforms.utils")
 
 using namespace mforms;
@@ -76,6 +78,9 @@ int Utilities::show_message_and_remember(const std::string &title, const std::st
 {
   if (remembered_message_answers.find(answer_id) != remembered_message_answers.end())
     return remembered_message_answers[answer_id];
+  
+  if (!ControlFactory::get_instance()->_utilities_impl.show_message_with_checkbox)
+    return show_message(title, text, ok, cancel, other);
 
   bool remember = false;
   int rc = ControlFactory::get_instance()->_utilities_impl.show_message_with_checkbox(title, text, ok, cancel, other, checkbox_text, remember);
@@ -147,6 +152,90 @@ bool Utilities::hide_wait_message()
 
 //--------------------------------------------------------------------------------------------------
 
+struct CancellableTaskData
+{
+  sigc::slot<void*> task;
+  boost::shared_ptr<bool> finished_flag;
+  boost::shared_ptr<void*> result_ptr;
+  GMutex *mutex;
+};
+
+static void* cancellable_task_thread(CancellableTaskData *data)
+{
+  void *ptr = data->task();
+
+  g_mutex_lock(data->mutex);
+
+  *data->finished_flag = true;
+  *data->result_ptr = ptr;
+  ControlFactory::get_instance()->_utilities_impl.stop_cancelable_wait_message();
+  g_mutex_unlock(data->mutex);
+  g_mutex_free(data->mutex);
+  delete data;
+  return 0;
+}
+
+static void real_mutex_unlock(GMutex *m)
+{
+  g_mutex_unlock(m);
+}
+
+bool Utilities::run_cancelable_task(const std::string &title, const std::string &text,
+                                    const sigc::slot<void*> &task,
+                                    const sigc::slot<bool> &cancel_task,
+                                    void *&task_result)
+{
+  GThread *thread;
+  GError *error = NULL;
+  CancellableTaskData *data = new CancellableTaskData(); // this is freed by the thread
+  boost::shared_ptr<bool> finished(new bool(false));
+  boost::shared_ptr<void*> result(new void*(0));
+  
+  data->mutex = g_mutex_new();
+  data->task = task;
+  data->finished_flag = finished;
+  
+  // result_ptr is used by the task thread to pass back the result from the task callback
+  // we cannot directly pass a pointer to task_result, because if the task is cancelled,
+  // this function will return and the caller may free the task_result object before the
+  // cancelled task actually finishes executing, which would invalidate any ptr to task_result 
+  data->result_ptr = result;
+  
+  g_mutex_lock(data->mutex);
+
+  // start a thread that will run the task
+  thread = g_thread_create((void*(*)(void*))cancellable_task_thread, data, 0, &error);
+  if (!thread)
+  {
+    g_mutex_unlock(data->mutex);
+    g_mutex_free(data->mutex);
+    delete data;
+    std::string msg("Error creating thread: ");
+    msg.append(error->message);
+    g_error_free(error);
+    throw std::runtime_error(msg);
+  }
+  
+  if (ControlFactory::get_instance()->_utilities_impl.run_cancelable_wait_message(title, text, 
+        sigc::bind(sigc::ptr_fun(real_mutex_unlock), data->mutex), cancel_task))
+  {
+    // task completed
+    if (*finished)
+    {
+      task_result = *result;
+      return true;
+    }
+    return false;
+  }
+  else
+  {
+    // task canceled by user
+    return false;
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void Utilities::set_clipboard_text(const std::string &text)
 {
   ControlFactory::get_instance()->_utilities_impl.set_clipboard_text(text);
@@ -175,6 +264,28 @@ void Utilities::open_url(const std::string &url)
 
 //--------------------------------------------------------------------------------------------------
 
+bool Utilities::move_to_trash(const std::string &path)
+{
+  if (ControlFactory::get_instance()->_utilities_impl.move_to_trash)
+    return ControlFactory::get_instance()->_utilities_impl.move_to_trash(path);
+  else
+  {
+    if (g_file_test(path.c_str(), G_FILE_TEST_IS_DIR))
+    {
+      if (base_rmdir_recursively(path.c_str()) < 0)
+        return false;
+    }
+    else
+    {
+      if (g_remove(path.c_str()) < 0)
+        return false;
+    }
+    return true;
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void Utilities::add_timeout(float interval, const sigc::slot<bool> &callback)
 {
   ControlFactory::get_instance()->_utilities_impl.add_timeout(interval, callback);
@@ -268,10 +379,17 @@ void Utilities::forget_password(const std::string &service, const std::string &a
   ControlFactory::get_instance()->_utilities_impl.forget_password(service, account);
 }
 
+//-------------------------------------------------------------------------------
+
+void *Utilities::perform_from_main_thread(const sigc::slot<void*> &slot)
+{
+  return ControlFactory::get_instance()->_utilities_impl.perform_from_main_thread(slot);
+}
+
 //--------------------------------------------------------------------------------------------------
 
-static bool _ask_for_password(const std::string &title, const std::string &service, std::string &username /*in/out*/,
-                             bool prompt_storage, std::string &ret_password /*out*/, bool &ret_store /*out*/)
+static void *_ask_for_password_main(const std::string &title, const std::string &service, std::string *username /*in/out*/,
+                             bool prompt_storage, std::string *ret_password /*out*/, bool *ret_store /*out*/)
 {
   mforms::Form password_form(NULL, (FormFlag) (FormDialogFrame | FormStayOnTop));
   mforms::Table content;
@@ -327,7 +445,7 @@ static bool _ask_for_password(const std::string &title, const std::string &servi
 
   // Create an edit box for the user name if the given one is not set, otherwise just display the name.
   mforms::TextEntry* user_edit = NULL;
-  if (username.empty())
+  if (username->empty())
   {
     user_edit = mforms::manage(new mforms::TextEntry());
     user_edit->set_value(_("<user name>"));
@@ -336,7 +454,7 @@ static bool _ask_for_password(const std::string &title, const std::string &servi
   }
   else
   {
-    mforms::Label* user_label = mforms::manage(new mforms::Label(username));
+    mforms::Label* user_label = mforms::manage(new mforms::Label(*username));
     content.add(&user_description_label, 1, 2, 2, 3, HFillFlag | VFillFlag);
     content.add(user_label, 2, 3, 2, 3, HFillFlag | VFillFlag);
   }
@@ -373,14 +491,24 @@ static bool _ask_for_password(const std::string &title, const std::string &servi
   bool result= password_form.run_modal(&ok_button, &cancel_button);
   if (result)
   {
-    ret_password= password_edit.get_string_value();
-    ret_store= save_password_box.get_active();
+    *ret_password= password_edit.get_string_value();
+    *ret_store= save_password_box.get_active();
 
     if (user_edit != NULL)
-      username = user_edit->get_string_value();
+      *username = user_edit->get_string_value();
   }
   
-  return result;  
+  return (void*)result;  
+}
+
+static bool _ask_for_password(const std::string &title, const std::string &service, std::string &username /*in/out*/,
+                             bool prompt_storage, std::string &ret_password /*out*/, bool &ret_store /*out*/)
+{
+  if (Utilities::in_main_thread())
+    return (bool)_ask_for_password_main(title, service, &username, prompt_storage, &ret_password, &ret_store);
+  else
+    return (bool)Utilities::perform_from_main_thread(sigc::bind(sigc::ptr_fun(_ask_for_password_main), 
+                                                     title, service, &username, prompt_storage, &ret_password, &ret_store));
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -410,6 +538,7 @@ bool Utilities::ask_for_password_check_store(const std::string &title, const std
   return _ask_for_password(title, service, username, true, password, store);
 }
 
+
 //--------------------------------------------------------------------------------------------------
 
 /**
