@@ -408,6 +408,13 @@ void View::set_front_color(const std::string &color)
 
 //--------------------------------------------------------------------------------------------------
 
+std::string View::get_front_color()
+{
+  return _view_impl->get_front_color(this);
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void View::set_back_color(const std::string &color)
 {
   _view_impl->set_back_color(this, color);
@@ -415,6 +422,13 @@ void View::set_back_color(const std::string &color)
 
 //--------------------------------------------------------------------------------------------------
 
+std::string View::get_back_color()
+{
+  return _view_impl->get_back_color(this);
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void View::set_back_image(const std::string &path, ImageLayout layout)
 {
   _view_impl->set_back_image(this, path, layout);
