@@ -47,6 +47,21 @@ void WebBrowser::navigate(const std::string& url)
   _webbrowser_impl->navigate(this, url);
 }
 
+//--------------------------------------------------------------------------------------------------
+void WebBrowser::set_link_click_handler(const sigc::slot<bool, const std::string &> &slot)
+{
+  _handle_link_click = slot;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+bool WebBrowser::on_link_clicked(const std::string& uri)
+{
+  if (_handle_link_click)
+    return _handle_link_click(uri);
+  return false;
+}
+
 //--------------------------------------------------------------------------------------------------
 
 std::string WebBrowser::get_document_title()
