@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -201,7 +201,7 @@ Rect BaseWidget::get_diagram_area()
   layout(_layout_context);
   
   Rect result(0, 0, get_width(), get_height());
-  result.height -= _description_height;
+  result.size.height -= _description_height;
   
   return result;
 }
@@ -620,11 +620,11 @@ void HeartbeatWidget::prepare_background()
   Rect bounds= get_diagram_area();
 
   if (_background == NULL 
-    || cairo_image_surface_get_width(_background) != bounds.width
-    || cairo_image_surface_get_height(_background) != bounds.height)
+    || cairo_image_surface_get_width(_background) != bounds.width()
+    || cairo_image_surface_get_height(_background) != bounds.height())
   {
     destroy_background();
-    _background= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, (int) bounds.width, (int) bounds.height);
+    _background= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, (int) bounds.width(), (int) bounds.height());
     cairo_t* cr= cairo_create(_background);
 
     // Erase background to constant color.
@@ -639,7 +639,7 @@ void HeartbeatWidget::prepare_background()
     cairo_set_source(cr, gradient);
     cairo_set_line_width(cr, 5);
     cairo_move_to(cr, 2.5, 3);
-    cairo_line_to(cr, bounds.width - 2.5, 3);
+    cairo_line_to(cr, bounds.width() - 2.5, 3);
     cairo_stroke(cr);
     
     cairo_pattern_destroy(gradient);
@@ -652,10 +652,10 @@ void HeartbeatWidget::prepare_background()
     cairo_set_line_width(cr, 1);
     
     double y= 4.5;
-    while (y < bounds.height)
+    while (y < bounds.height())
     {
       cairo_move_to(cr, 4.5, y);
-      cairo_line_to(cr, bounds.width - 4.5, y);
+      cairo_line_to(cr, bounds.width() - 4.5, y);
       y += 7;
     }
     cairo_stroke(cr);
@@ -710,24 +710,24 @@ void HeartbeatWidget::repaint(cairo_t *cr, int areax, int areay, int areaw, int
   cairo_set_line_width(cr, 2);
   cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
 
-  cairo_move_to(cr, 8, bounds.height / 2);
-  bounds.width -= 16; // Leave 8 pixels room left and right.
+  cairo_move_to(cr, 8, bounds.height() / 2);
+  bounds.size.width -= 16; // Leave 8 pixels room left and right.
 
   lock();
-  for (double pixel= 0; pixel < bounds.width; pixel++)
+  for (double pixel= 0; pixel < bounds.width(); pixel++)
   {
     // Transform pixel index into data array index. Merge values for fractions.
-    int index1= (int) floor(pixel * HEARTBEAT_DATA_SIZE / bounds.width);
+    int index1= (int) floor(pixel * HEARTBEAT_DATA_SIZE / bounds.width());
     int index2= index1 + 1;
     if (index2 == HEARTBEAT_DATA_SIZE)
       index2= 0;
-    double fraction= (pixel * HEARTBEAT_DATA_SIZE / bounds.width) - index1;
+    double fraction= (pixel * HEARTBEAT_DATA_SIZE / bounds.width()) - index1;
     
     double deflection= _deflection[index1] * (1 - fraction) + _deflection[index2] * fraction;
     double luminance= _luminance[index1] * (1 - fraction) + _luminance[index2] * fraction;
     
     double x= 8.5 + pixel;
-    double y= -deflection * (bounds.height - 8) / 2 + bounds.height / 2;
+    double y= -deflection * (bounds.height() - 8) / 2 + bounds.height() / 2;
     cairo_set_source_rgba(cr, 102 / 255.0, 171 / 255.0, 251 / 255.0, luminance);
     cairo_line_to(cr, x, y);
     cairo_stroke(cr);
@@ -1026,23 +1026,23 @@ void BarGraphWidget::prepare_background()
   Rect bounds= get_diagram_area();
 
   if (_background == NULL 
-    || cairo_image_surface_get_height(_background) != bounds.height)
+    || cairo_image_surface_get_height(_background) != bounds.height())
   {
     destroy_background();
-    _background= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, BAR_WIDTH, (int) bounds.height);
+    _background= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, BAR_WIDTH, (int) bounds.height());
     cairo_t* cr= cairo_create(_background);
 
     // The background is a constant color with a gradient overlay and a darker border.
     cairo_set_source_rgb(cr, 52 / 255.0, 54 / 255.0, 56 / 255.0);
     cairo_paint(cr);
 
-    cairo_pattern_t* gradient= cairo_pattern_create_linear(0, 0, 0, bounds.height - 2);
+    cairo_pattern_t* gradient= cairo_pattern_create_linear(0, 0, 0, bounds.height() - 2);
     cairo_pattern_add_color_stop_rgba(gradient, 0, 122 / 255.0, 140 / 255.0, 154 / 255.0, 0.4);
     cairo_pattern_add_color_stop_rgba(gradient, 0.08, 151 / 255.0, 170 / 255.0, 184 / 255.0, 0.6);
     cairo_pattern_add_color_stop_rgba(gradient, 0.09, 105 / 255.0, 122 / 255.0, 135 / 255.0, 0.6);
     cairo_pattern_add_color_stop_rgba(gradient, 1, 60 / 255.0, 66 / 255.0, 71 / 255.0, 0.6);
     
-    cairo_rectangle(cr, 1, 1, BAR_WIDTH - 2, bounds.height - 2);
+    cairo_rectangle(cr, 1, 1, BAR_WIDTH - 2, bounds.height() - 2);
     cairo_set_source(cr, gradient);
     cairo_fill(cr);
     cairo_pattern_destroy(gradient);
@@ -1050,18 +1050,18 @@ void BarGraphWidget::prepare_background()
     cairo_destroy(cr);
 
     // Grid overlay.
-    _grid= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, BAR_WIDTH, (int) bounds.height);
+    _grid= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, BAR_WIDTH, (int) bounds.height());
     cr= cairo_create(_grid);
     cairo_set_source_rgba(cr, 52 / 255.0, 54 / 255.0, 56 / 255.0, 0.2);
     cairo_set_line_width(cr, 1);
-    for (double y= bounds.height - 3.5; y > 1; y -= 3)
+    for (double y= bounds.height() - 3.5; y > 1; y -= 3)
     {
       cairo_move_to(cr, 0.5, y);
       cairo_line_to(cr, BAR_WIDTH - 0.5, y);
     }
     cairo_stroke(cr);
 
-    cairo_move_to(cr, BAR_WIDTH / 2 + 0.5, bounds.height - 0.5);
+    cairo_move_to(cr, BAR_WIDTH / 2 + 0.5, bounds.height() - 0.5);
     cairo_line_to(cr, BAR_WIDTH / 2 + 0.5, 0.5);
     cairo_stroke(cr);
 
@@ -1122,10 +1122,10 @@ void BarGraphWidget::create_value_gradient()
     cairo_pattern_destroy(_value_gradient);
   
   Rect bounds= get_diagram_area();
-  double split_point= (bounds.height - 2) * _value;
+  double split_point= (bounds.height() - 2) * _value;
   split_point = 3 * (split_point / 3); // Integer div.
 
-  _value_gradient= cairo_pattern_create_linear(0, bounds.height - 1 - split_point, 0, bounds.height - 1);
+  _value_gradient= cairo_pattern_create_linear(0, bounds.height() - 1 - split_point, 0, bounds.height() - 1);
   cairo_pattern_add_color_stop_rgb(_value_gradient, 0, 102 / 255.0, 171 / 255.0, 251 / 255.0);
   cairo_pattern_add_color_stop_rgb(_value_gradient, 1, 0 / 255.0, 119 / 255.0, 189 / 255.0);
 }
@@ -1156,11 +1156,11 @@ void BarGraphWidget::repaint(cairo_t *cr, int areax, int areay, int areaw, int a
   lock();
 
   // Compute the split point as multiple of 3 to simulate a discret bar graph.
-  double split_point= (bounds.height - 2) * _value;
+  double split_point= (bounds.height() - 2) * _value;
   split_point = 3 * (int) (split_point / 3);
 
   cairo_set_source(cr, _value_gradient);
-  cairo_rectangle(cr, 1, bounds.height - 1 - split_point, BAR_WIDTH - 2, split_point);
+  cairo_rectangle(cr, 1, bounds.height() - 1 - split_point, BAR_WIDTH - 2, split_point);
   cairo_fill(cr);
 
   // Finally the grid overlay.
@@ -1231,8 +1231,8 @@ void LineDiagramWidget::repaint(cairo_t *cr, int areax, int areay, int areaw, in
     // The first point just sets a location for the first curve to start.
     // This can be outside of the current window but we need it to correctly draw the first curve part.
     double deflection=  _deflection[index];
-    double x= (_timestamp[index] - start_time) * bounds.width / _time_in_view;
-    double y= (bounds.height - 2) * (1 - deflection) + 0.5;
+    double x= (_timestamp[index] - start_time) * bounds.width() / _time_in_view;
+    double y= (bounds.height() - 2) * (1 - deflection) + 0.5;
     cairo_move_to(cr, x, y);
     
     for (; index < LINE_SERIES_DATA_SIZE; index++)
@@ -1242,8 +1242,8 @@ void LineDiagramWidget::repaint(cairo_t *cr, int areax, int areay, int areaw, in
       double y1= y;
       
       deflection=  _deflection[index];
-      x= (_timestamp[index] - start_time) * bounds.width / _time_in_view;
-      y= (bounds.height - 2) * (1 - deflection) + 0.5;
+      x= (_timestamp[index] - start_time) * bounds.width() / _time_in_view;
+      y= (bounds.height() - 2) * (1 - deflection) + 0.5;
       
       double x2= x;
       double y2= y;
@@ -1257,15 +1257,15 @@ void LineDiagramWidget::repaint(cairo_t *cr, int areax, int areay, int areaw, in
     }
     
     // Close the figure for proper filling.
-    cairo_line_to(cr, bounds.width - 1.5, y);
-    cairo_line_to(cr, bounds.width - 1.5, bounds.height - 1.5);
-    cairo_line_to(cr, 1.5, bounds.height - 1.5);
+    cairo_line_to(cr, bounds.width() - 1.5, y);
+    cairo_line_to(cr, bounds.width() - 1.5, bounds.height() - 1.5);
+    cairo_line_to(cr, 1.5, bounds.height() - 1.5);
     
     cairo_fill(cr);
     
     // Part of the border has been overdrawn, fix it.
     cairo_set_source_rgb(cr, 52 / 255.0, 54 / 255.0, 56 / 255.0);
-    cairo_rectangle(cr, 0.5, 0.5, bounds.width - 1, bounds.height - 1);
+    cairo_rectangle(cr, 0.5, 0.5, bounds.width() - 1, bounds.height() - 1);
     cairo_stroke(cr);
   }
   
@@ -1310,24 +1310,24 @@ void LineDiagramWidget::prepare_background()
   Rect bounds= get_diagram_area();
   
   if (_background == NULL 
-     || cairo_image_surface_get_height(_background) != bounds.height
-     || cairo_image_surface_get_width(_background) != bounds.width)
+     || cairo_image_surface_get_height(_background) != bounds.height()
+     || cairo_image_surface_get_width(_background) != bounds.width())
   {
     destroy_background();
-    _background= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, (int) bounds.width, (int) bounds.height);
+    _background= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, (int) bounds.width(), (int) bounds.height());
     cairo_t* cr= cairo_create(_background);
     
     // The background is a constant color with a gradient overlay and a darker border.
     cairo_set_source_rgb(cr, 52 / 255.0, 54 / 255.0, 56 / 255.0);
     cairo_paint(cr);
     
-    cairo_pattern_t* gradient= cairo_pattern_create_linear(0, 0, 0, bounds.height - 2);
+    cairo_pattern_t* gradient= cairo_pattern_create_linear(0, 0, 0, bounds.height() - 2);
     cairo_pattern_add_color_stop_rgba(gradient, 0, 122 / 255.0, 140 / 255.0, 154 / 255.0, 0.4);
     cairo_pattern_add_color_stop_rgba(gradient, 0.08, 151 / 255.0, 170 / 255.0, 184 / 255.0, 0.6);
     cairo_pattern_add_color_stop_rgba(gradient, 0.09, 105 / 255.0, 122 / 255.0, 135 / 255.0, 0.6);
     cairo_pattern_add_color_stop_rgba(gradient, 1, 60 / 255.0, 66 / 255.0, 71 / 255.0, 0.6);
     
-    cairo_rectangle(cr, 1, 1, bounds.width - 2, bounds.height - 2);
+    cairo_rectangle(cr, 1, 1, bounds.width() - 2, bounds.height() - 2);
     cairo_set_source(cr, gradient);
     cairo_fill(cr);
     cairo_pattern_destroy(gradient);
@@ -1335,28 +1335,28 @@ void LineDiagramWidget::prepare_background()
     cairo_destroy(cr);
 
     // Grid overlay.
-    _grid= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, (int) bounds.width, (int) bounds.height);
+    _grid= cairo_image_surface_create(CAIRO_FORMAT_ARGB32, (int) bounds.width(), (int) bounds.height());
     cr= cairo_create(_grid);
     cairo_set_source_rgba(cr, 52 / 255.0, 54 / 255.0, 56 / 255.0, 0.2);
     cairo_set_line_width(cr, 1);
-    for (double y= bounds.height - 3.5; y > 5; y -= 3)
+    for (double y= bounds.height() - 3.5; y > 5; y -= 3)
     {
       cairo_move_to(cr, 0.5, y);
-      cairo_line_to(cr, (int) bounds.width - 0.5, y);
+      cairo_line_to(cr, (int) bounds.width() - 0.5, y);
     }
     cairo_stroke(cr);
     
     double dX= 15 * 60 / _time_in_view; // That is: a 16 pixel wide rectangle at 1 min. total time.
-    for (double x= bounds.width - dX - 0.5; x > 1; x -= dX)
+    for (double x= bounds.width() - dX - 0.5; x > 1; x -= dX)
     {
       cairo_move_to(cr, x, 0.5);
-      cairo_line_to(cr, x, (int) bounds.height - 0.5);
+      cairo_line_to(cr, x, (int) bounds.height() - 0.5);
     }
     cairo_stroke(cr);
     
     cairo_destroy(cr);
     
-    _value_gradient= cairo_pattern_create_linear(0, 0, 0, bounds.height - 2);
+    _value_gradient= cairo_pattern_create_linear(0, 0, 0, bounds.height() - 2);
     cairo_pattern_add_color_stop_rgb(_value_gradient, 0, 102 / 255.0, 171 / 255.0, 251 / 255.0);
     cairo_pattern_add_color_stop_rgb(_value_gradient, 1, 0 / 255.0, 119 / 255.0, 189 / 255.0);
   }
@@ -1482,8 +1482,8 @@ void LineDiagramWidget::show_feedback(cairo_t* cr, const Rect& bounds)
       cairo_text_extents(cr, WARNING_TEXT, &_warning_extents);
     
     // Place the warning in the upper left corner.
-    int y= (int) (bounds.top + 4 - _warning_extents.y_bearing);
-    int x= (int) (bounds.left + 4);
+    int y= (int) (bounds.top() + 4 - _warning_extents.y_bearing);
+    int x= (int) (bounds.left() + 4);
 
     cairo_push_group(cr); // Prepare composing.
     
