@@ -23,17 +23,21 @@
 
 #include "stdafx.h"
 
+#include "base/log.h"
 #include "wf_app.h"
-
 #include "GrtTemplates.h"
 
 using namespace System::Threading;
 
 using namespace MySQL::Forms;
 using namespace MySQL::Grt;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 //--------------------------------------------------------------------------------------------------
 
+ENABLE_LOG("mforms.wr")
+
 AppImpl::AppImpl(MySQL::Forms::Manager^ mgr,
   StrStrStrStrDelegate^ show_file_dialog, 
   VoidStrDelegate^ show_status_text,
@@ -526,3 +530,24 @@ void AppImpl::exit_event_loop(mforms::App *app, int ret_code)
 
 //--------------------------------------------------------------------------------------------------
 
+MySQL::Drawing::Color AppImpl::get_system_color(mforms::SystemColor type)
+{
+  switch (type)
+  {
+  case mforms::SystemHighlight:
+    {
+      System::Drawing::Color^ color = System::Drawing::Color::FromKnownColor(KnownColor::Highlight);
+      return NativeToColor(color);
+    }
+  default:
+#ifdef _DEBUG
+    throw new std::runtime_error("mforms::App: Invalid system color enumeration given.");
+#else
+    log_error("mforms::App: Invalid system color enumeration given.");
+    return MySQL::Drawing::Color::Black();
+#endif
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
