@@ -171,7 +171,7 @@ int PopupControl::Show(int x, int y)
   // In the base class the hot spot is the upper left corner.
   Point newLocation= Point(x, y);
   Screen^ activeScreen= Screen::FromControl(Form::ActiveForm);
-  Drawing::Rectangle screenBounds= activeScreen->Bounds;
+  System::Drawing::Rectangle screenBounds= activeScreen->Bounds;
   
   if (newLocation.X < screenBounds.Left)
     newLocation.X= screenBounds.Left;
@@ -268,15 +268,15 @@ int TransparentPopupControl::Show(int x, int y)
   hotSpot.X= x;
   hotSpot.Y= y;
 
-  baseSize = Drawing::Size(825, 351); // Size by design, without outer shadow.
-  Size = Drawing::Size(baseSize.Width + 2 * shadowSize + shadowOffset, baseSize.Height + 2 * shadowSize + shadowOffset);
+  baseSize = System::Drawing::Size(825, 351); // Size by design, without outer shadow.
+  Size = System::Drawing::Size(baseSize.Width + 2 * shadowSize + shadowOffset, baseSize.Height + 2 * shadowSize + shadowOffset);
 
   // The given position is a hot spot, i.e. we have to move the popup so that our hot spot is at that
   // location. For now we define a point on the border in the right upper border as hotspot.
   // This will later be extended to include an arrow or pointer tip.
   Point newLocation= Point(x - baseSize.Width - shadowSize + shadowOffset + cornerSize, y - shadowSize + shadowOffset);
   Screen^ currentScreen= Screen::FromControl(this);
-  Drawing::Rectangle screenBounds= currentScreen->WorkingArea;
+  System::Drawing::Rectangle screenBounds= currentScreen->WorkingArea;
 
   if (newLocation.X < screenBounds.Left)
     newLocation.X= screenBounds.Left;
@@ -343,7 +343,7 @@ GraphicsPath^ TransparentPopupControl::GetPath()
   float width = (float) baseSize.Width;
   float height = (float) baseSize.Height;
   float cornerSizeF = (float) cornerSize; // Just to avoid a dozen type casts.
-  Drawing::RectangleF bounds = Drawing::RectangleF(- width / 2, -height / 2, width, height);
+  System::Drawing::RectangleF bounds = System::Drawing::RectangleF(- width / 2, -height / 2, width, height);
   result->AddArc(bounds.Left, bounds.Top, cornerSizeF, cornerSizeF, 180, 90);
   result->AddArc(bounds.Right - cornerSizeF, bounds.Top, cornerSizeF, cornerSizeF, -90, 90);
   result->AddArc(bounds.Right - cornerSizeF, bounds.Bottom - cornerSizeF, cornerSizeF, cornerSizeF, 0, 90);
@@ -402,12 +402,12 @@ void TransparentPopupControl::PrepareBitmap()
   delete brush;
 
   // Clip out interior. Exclude both, the panel itself as well as its border.
-  Drawing::Region^ region = gcnew Drawing::Region(innerPath);
+  System::Drawing::Region^ region = gcnew System::Drawing::Region(innerPath);
   g->SetClip(region, CombineMode::Exclude);
   delete region;
 
   innerPath->Widen(borderPen);
-  region = gcnew Drawing::Region(innerPath);
+  region = gcnew System::Drawing::Region(innerPath);
   g->SetClip(region, CombineMode::Exclude);
   delete region;
 
@@ -429,7 +429,7 @@ void TransparentPopupControl::PrepareBitmap()
   RectangleF innerBounds = innerPath->GetBounds();
 
   // Create a 32 bit image surface for cairo from our bitmap.
-  Imaging::BitmapData^ bitmapData= contentBitmap->LockBits(Drawing::Rectangle(0, 0, Width, Height),
+  Imaging::BitmapData^ bitmapData= contentBitmap->LockBits(System::Drawing::Rectangle(0, 0, Width, Height),
     Imaging::ImageLockMode::ReadWrite, contentBitmap->PixelFormat);
   unsigned char* data= (unsigned char*) bitmapData->Scan0.ToPointer();
   cairo_surface_t* surface= cairo_image_surface_create_for_data(data, CAIRO_FORMAT_ARGB32, Width, Height, bitmapData->Stride);
@@ -440,8 +440,8 @@ void TransparentPopupControl::PrepareBitmap()
 
   mforms::Popup* popup= ObjectImpl::get_backend_control<mforms::Popup>(this);
   if (popup != NULL)
-    popup->repaint(cr, (int) displayRect.left, (int) displayRect.top, (int) displayRect.width,
-      (int) displayRect.height);
+    popup->repaint(cr, (int) displayRect.left(), (int) displayRect.top(), (int) displayRect.width(),
+      (int) displayRect.height());
 
   contentBitmap->UnlockBits(bitmapData);
   cairo_destroy(cr);
