@@ -58,6 +58,38 @@ int ColumnComparer::Compare(System::Object^ object1, System::Object^ object2)
     return _inner->Compare(node2->Text[_column], node1->Text[_column]);
 }
 
+//----------------- SortableTreeModel --------------------------------------------------------------
+
+/**
+ * Does a depth sort of the given nodes.
+ */
+void SortableTreeModel::SortNodes(Collection<Node^>^ nodes)
+{
+  // Since the original tree model uses a Collection class we have to do two copies of all nodes
+  // because a Collection is not itself sortable.
+  ArrayList^ list = gcnew ArrayList();
+  list->AddRange(nodes);
+  list->Sort(Comparer);
+  nodes->Clear();
+  for each (Object^ obj in list)
+    nodes->Add((Node^) obj);
+
+  // Sort all child node lists.
+  for each (Node^ node in nodes)
+    SortNodes(node->Nodes);
+}
+
+//--------------------------------------------------------------------------------------------------
+
+void SortableTreeModel::Sort()
+{
+  if (_comparer != nullptr)
+  {
+    SortNodes(Nodes);
+    OnStructureChanged(gcnew TreePathEventArgs(TreePath::Empty));
+  }
+}
+
 //----------------- TreeViewImpl static interface functions ----------------------------------------
 
 bool TreeViewImpl::create(::mforms::TreeView *self, ::mforms::TreeOptions options)
@@ -286,6 +318,12 @@ int TreeViewImpl::add_column(::mforms::TreeColumnType type, const string &name,
       nodeControl= box;
       break;
     }
+  case ::mforms::IconColumnType:
+    {
+      NodeIcon^ box= gcnew NodeIcon();
+      nodeControl = box;
+      break;
+    }
   default: // ::mforms::StringColumnType
     {
       NodeTextBox^ box= gcnew NodeTextBox();
@@ -326,6 +364,8 @@ void TreeViewImpl::TreeValueNeeded(System::Object^ sender, NodeControlValueEvent
     String^ value= ourNode->Text[control->ParentColumn->Index];
     if (control->GetType() == NodeCheckBox::typeid)
       e->Value = (value == "Checked") || (value == "1") ? true : false;
+    else if (control->GetType() == NodeIcon::typeid)
+      e->Value = gcnew Bitmap(value);
     else
       e->Value= value;
   }
@@ -613,7 +653,7 @@ void TreeViewImpl::freeze_refresh(bool flag)
   {
     ControlUtilities::ResumeDrawing(tree);
 
-    if (_can_sort_column)
+    if (_can_sort_column && _model->Comparer!=nullptr)
       _model->Sort();
     else
       tree->Refresh();
