@@ -25,6 +25,8 @@
 
 #include <sstream>
 #include <commctrl.h>
+#include <ShellAPI.h>
+#include <StrSafe.h>
 
 #include "base/string_utilities.h"
 #include "wf_Utilities.h"
@@ -109,6 +111,19 @@ CustomMessageBox::CustomMessageBox()
 
 //--------------------------------------------------------------------------------------------------
 
+/**
+ * Returns the window handle of the main form. If the main form handle is not yet created or we
+ * are in a background thread return 0.
+ */
+HWND get_mainform_handle()
+{
+  if (!Application::OpenForms[0]->IsHandleCreated || Application::OpenForms[0]->InvokeRequired)
+    return 0;
+  else
+    return (HWND) Application::OpenForms[0]->Handle.ToPointer();
+}
+//--------------------------------------------------------------------------------------------------
+
 // Some more task dialog icons, which are not defined in commctrl.h.
 #define TD_SHIELD_BLUE_ICON      MAKEINTRESOURCE(-5)
 #define TD_SECURITY_WARNING_ICON MAKEINTRESOURCE(-6)
@@ -165,7 +180,7 @@ mforms::DialogResult CustomMessageBox::ShowVistaStyle(const std::string& title,
   if (buttonCount > 1)
     config.dwFlags |= TDF_USE_COMMAND_LINKS;
 
-  config.hwndParent = (HWND) Application::OpenForms[0]->Handle.ToPointer(); // The main form.
+  config.hwndParent = GetForegroundWindow();
   
   config.pszMainIcon = mainIcon;
   config.pszWindowTitle = L"MySQL Workbench";
@@ -291,7 +306,7 @@ void CustomMessageBox::ComputeLayout()
   _checkbox->Visible = _checkbox->Enabled; 
 
   int visibleButtonCount= 0;
-  Drawing::Size size= Drawing::Size::Empty;
+  System::Drawing::Size size= System::Drawing::Size::Empty;
   if (_button1->Enabled)
   {
     size= _button1->Size;
@@ -316,7 +331,7 @@ void CustomMessageBox::ComputeLayout()
   // Since the font is assumed to be the same for all buttons they also should compute
   // the same height when asked for their preferred size.
   // Compute the total size of the button area on the way (including padding of the container).
-  Drawing::Size buttonSize= Drawing::Size::Empty;
+  System::Drawing::Size buttonSize= System::Drawing::Size::Empty;
   if (size.Width > 0)
   {
     // Compute only if there is at least one visible button.
@@ -355,7 +370,7 @@ void CustomMessageBox::ComputeLayout()
 
   // Compute message text layout. Start with a certain minimum width.
   int minWidth= (effective_button_width > MESSAGE_BOX_MIN_WIDTH) ? effective_button_width : MESSAGE_BOX_MIN_WIDTH;
-  Drawing::Size proposedSize= Drawing::Size(minWidth, 1);
+  System::Drawing::Size proposedSize= System::Drawing::Size(minWidth, 1);
   
   // We use the golden ratio to create an appealing layout.
   // Increase width in 10% steps until we found the proper ratio.
@@ -568,6 +583,33 @@ Windows::Forms::DialogResult CustomMessageBox::Show(MessageType type, String^ ti
   return Show(type, title, text, buttonOK, "", "", "", checked);
 }
 
+//----------------- DispatchControl ----------------------------------------------------------------
+
+delegate InvokationResult^ RunSlotDelegate();
+
+void* DispatchControl::RunOnMainThread(const sigc::slot<void*>& slot)
+{
+  if (InvokeRequired)
+  {
+    _slot = &slot;
+    InvokationResult^ result = (InvokationResult^) Invoke(
+      gcnew RunSlotDelegate(this, &DispatchControl::RunSlot));
+    return result->Result;
+  }
+
+  return slot();
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Helper function to run a given slot in the main thread.
+ */
+InvokationResult^ DispatchControl::RunSlot()
+{
+  return gcnew InvokationResult((*_slot)());
+}
+
 //----------------- UtilitiesImpl ------------------------------------------------------------------
 
 UtilitiesImpl::UtilitiesImpl()
@@ -639,6 +681,41 @@ bool UtilitiesImpl::hide_wait_message()
   return result;
 }
 
+//--------------------------------------------------------------------------------------------------
+ref class CallSlotDelegate
+{
+public:
+  CallSlotDelegate(const sigc::slot<bool> *s) : slot(s) {}
+  const sigc::slot<bool> *slot;
+  bool call_slot()
+  {
+    return (*slot)();
+  }
+};
+
+//-------------------------------------------------------------------------------------------------
+
+bool UtilitiesImpl::run_cancelable_wait_message(const string &title, const string &text, 
+                                                const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_slot)
+{
+  CallSlotDelegate ^caller = gcnew CallSlotDelegate(&cancel_slot);
+
+  BusyForm::CancelDelegate ^deleg = gcnew BusyForm::CancelDelegate(caller, &CallSlotDelegate::call_slot);
+  start_task();
+  return BusyForm::ShowModal(CppStringToNative(title), CppStringToNative(text), deleg) == Windows::Forms::DialogResult::OK;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Signals the operation being described in a previous run_cancelable_wait_message() call has
+ * finished and the message panel should be taken down.
+ */
+void UtilitiesImpl::stop_cancelable_wait_message()
+{
+  BusyForm::Finished();
+}
+
 //--------------------------------------------------------------------------------------------------
 
 /**
@@ -724,6 +801,27 @@ void UtilitiesImpl::open_url(const string &url)
 
 //--------------------------------------------------------------------------------------------------
 
+bool UtilitiesImpl::move_to_trash(const string &file_name)
+{
+  SHFILEOPSTRUCT shf = {0};
+
+  // Filenames must be double 0 terminated.
+  wchar_t path[MAX_PATH + 1] = {0};
+
+  shf.wFunc = FO_DELETE;
+  shf.fFlags = FOF_ALLOWUNDO | FOF_NOCONFIRMATION;
+
+  // Paths must be double 0 terminated.
+  std::wstring converted_filename = base::string_to_wstring(file_name);
+  StringCchCopyW(path, sizeof(path), converted_filename.c_str()); 
+  shf.pFrom = path;
+  int result = SHFileOperation(&shf); 
+
+  return (result == 0) && !shf.fAnyOperationsAborted;
+}
+
+//--------------------------------------------------------------------------------------------------
+
 // The password cache is a temporary storage and only used for a short time frame when looking up a password.
 static GStaticMutex password_mutex= G_STATIC_MUTEX_INIT;
 static std::map<std::string, std::string> password_cache;
@@ -919,6 +1017,13 @@ void UtilitiesImpl::forget_password(const std::string &service, const std::strin
 
 //--------------------------------------------------------------------------------------------------
 
+void* UtilitiesImpl::perform_from_main_thread(const sigc::slot<void*>& slot)
+{
+  return _dispatcher->RunOnMainThread(slot);
+}
+
+//--------------------------------------------------------------------------------------------------
+
 public ref class TimerHandler
 {
 public:
