@@ -333,7 +333,7 @@ void ViewImpl::client_to_screen(::mforms::View *self, MySQL::Geometry::Point& po
   ViewImpl^ view= (ViewImpl^)ObjectImpl::FromUnmanaged(self);
   if (view != nullptr)
   {
-    Drawing::Point location= Drawing::Point((int) position.x, (int) position.y);
+    System::Drawing::Point location= System::Drawing::Point((int) position.x, (int) position.y);
     location= view->get_control<Control>()->PointToScreen(location);
     position.x= location.X;
     position.y= location.Y;
@@ -432,6 +432,15 @@ void ViewImpl::set_front_color(mforms::View *self, const std::string &color)
     view->set_front_color(CppStringToNative(color));
 }
 
+//-------------------------------------------------------------------------------------------------
+
+std::string ViewImpl::get_front_color(mforms::View *self)
+{
+  ViewImpl^ view= (ViewImpl^)ObjectImpl::FromUnmanaged(self);
+  if (view != nullptr)
+    return NativeToCppString(view->get_front_color());
+  return "#ffffff";
+}
 
 //-------------------------------------------------------------------------------------------------
 
@@ -442,6 +451,15 @@ void ViewImpl::set_back_color(mforms::View *self, const std::string &color)
     view->set_back_color(CppStringToNative(color));
 }
 
+//-------------------------------------------------------------------------------------------------
+
+std::string ViewImpl::get_back_color(mforms::View *self)
+{
+  ViewImpl^ view= (ViewImpl^)ObjectImpl::FromUnmanaged(self);
+  if (view != nullptr)
+    return NativeToCppString(view->get_back_color());
+  return "#000000";
+}
 
 //-------------------------------------------------------------------------------------------------
 
@@ -562,6 +580,13 @@ void ViewImpl::set_front_color(String ^color)
 
 //-------------------------------------------------------------------------------------------------
 
+String^ ViewImpl::get_front_color()
+{
+  return System::Drawing::ColorTranslator::ToHtml(get_control<Control>()->ForeColor);
+}
+
+//-------------------------------------------------------------------------------------------------
+
 void ViewImpl::set_back_color(String ^color)
 {
   get_control<Control>()->BackColor= System::Drawing::ColorTranslator::FromHtml(color);
@@ -569,6 +594,13 @@ void ViewImpl::set_back_color(String ^color)
 
 //-------------------------------------------------------------------------------------------------
 
+String^ ViewImpl::get_back_color()
+{
+  return System::Drawing::ColorTranslator::ToHtml(get_control<Control>()->BackColor);
+}
+
+//-------------------------------------------------------------------------------------------------
+
 void ViewImpl::set_back_image(String ^path, mforms::ImageLayout layout)
 {
   Windows::Forms::ImageLayout native_layout;
@@ -602,7 +634,7 @@ void ViewImpl::set_back_image(String ^path, mforms::ImageLayout layout)
  * Resizes the given control according to its dock state. Sizes of the control which were not changed
  * are also reset in the given Size structure to allow for proper child layouting.
  */
-void ViewImpl::resize_with_docking(Control^ control, Drawing::Size& size)
+void ViewImpl::resize_with_docking(Control^ control, System::Drawing::Size& size)
 {
   // If the control is docked somewhere resizing must be restricted not to destroy the docked
   // appearance.
