@@ -43,7 +43,7 @@ namespace MySQL {
     {
     public:
       virtual bool Layout(Object^ container, LayoutEventArgs^ arguments) override;
-      Drawing::Size GetPreferredSize(Control^ container, Drawing::Size proposedSize);
+      System::Drawing::Size GetPreferredSize(Control^ container, System::Drawing::Size proposedSize);
     };
 
     /**
@@ -55,14 +55,14 @@ namespace MySQL {
       FormFillLayout^ layoutEngine;
 
     public:
-      delegate Windows::Forms::DialogResult ShowModalDelegate();
+      delegate Windows::Forms::DialogResult ShowModalDelegate(IWin32Window^ parent);
 
       FillForm()
       {
       }
 
-      Drawing::Size ComputeLayout(Drawing::Size proposedSize, bool resizeChildren);
-      virtual Drawing::Size GetPreferredSize(Drawing::Size proposedSize) override;
+      System::Drawing::Size ComputeLayout(System::Drawing::Size proposedSize, bool resizeChildren);
+      virtual System::Drawing::Size GetPreferredSize(System::Drawing::Size proposedSize) override;
 
       virtual property Windows::Forms::Layout::LayoutEngine^ LayoutEngine
       {
@@ -80,7 +80,7 @@ namespace MySQL {
     {
     private:
       bool _hide_on_close;
-      Form^ owner;
+      Form^ parent;
     protected:
       static bool create(::mforms::Form *self, ::mforms::Form *owner, ::mforms::FormFlag flag);
       static void set_title(::mforms::Form *self, const std::string &title);
