@@ -27,6 +27,7 @@
 
 using namespace std;
 using namespace mforms;
+
 using namespace Windows::Forms;
 
 namespace MySQL {
@@ -65,7 +66,7 @@ namespace MySQL {
         PCWSTR mainIcon, const std::string& buttonOK, const std::string& buttonCancel,
         const std::string& buttonOther, const std::string& checkbox, bool& checked);
 
-      static mforms::DialogResult ShowTraditionalStyle(String^ title, String^ text, Drawing::Image^ image,
+      static mforms::DialogResult ShowTraditionalStyle(String^ title, String^ text, System::Drawing::Image^ image,
         String^ button1, String^ button2, String^ button3, String^ checkbox, bool& checked);
     public:
       // C++ interface
@@ -79,11 +80,42 @@ namespace MySQL {
       static Windows::Forms::DialogResult Show(MessageType type, String^ title, String^ text, String^ buttonOK);
     };
 
+    private ref class InvokationResult
+    {
+    private:
+      void* _result;
+    public:
+      InvokationResult(void* result)
+      {
+        _result = result;
+      }
+
+      property void* Result
+      {
+        void* get()
+        {
+          return _result;
+        }
+      };
+    };
+
+    private ref class DispatchControl : Control
+    {
+    private:
+      const sigc::slot<void*>* _slot;
+      InvokationResult^ RunSlot();
+    public:
+      void* RunOnMainThread(const sigc::slot<void*>& slot);
+    };
+
     public ref class UtilitiesImpl
     {
     private:
+      static DispatchControl^ _dispatcher;
+
       static void load_passwords();
       static void unload_passwords(bool store);
+
     protected:
       UtilitiesImpl();
 
@@ -97,12 +129,16 @@ namespace MySQL {
         const string &cancel, const string &other, const std::string &checkbox_text, bool &isChecked);
       static void show_wait_message(const string &title, const string &text);
       static bool hide_wait_message();
+      static bool run_cancelable_wait_message(const string &title, const string &text, 
+        const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_slot);
+      static void stop_cancelable_wait_message();
 
       static void set_clipboard_text(const string &content);
       static string get_clipboard_text();
       static string get_special_folder(FolderType type);
 
       static void open_url(const string &url);
+      static bool move_to_trash(const string &file_name);
 
       static void add_timeout(float interval, const sigc::slot<bool> &slot);
 
@@ -110,9 +146,13 @@ namespace MySQL {
       static bool find_password(const std::string &service, const std::string &account, std::string &password);
       static void forget_password(const std::string &service, const std::string &account);
 
+      static void* perform_from_main_thread(const sigc::slot<void*> &slot);
     public:
       static void init(Manager ^mgr)
       {
+        _dispatcher = gcnew DispatchControl();
+        _dispatcher->Handle; // create window handle
+
         ::mforms::ControlFactory *f= ::mforms::ControlFactory::get_instance();
 
         DEF_CALLBACK5(int, const string&, const string&, const string&, const string&, const string&, 
@@ -126,14 +166,18 @@ namespace MySQL {
         DEF_CALLBACK2(void, const string&, const string&, mgr, f->_utilities_impl, UtilitiesImpl,
           show_wait_message);
         DEF_CALLBACK0(bool, mgr, f->_utilities_impl, UtilitiesImpl, hide_wait_message);
+        DEF_CALLBACK4(bool, const std::string&, const std::string&, const sigc::slot<void> &, const sigc::slot<bool>&, mgr, f->_utilities_impl, UtilitiesImpl, run_cancelable_wait_message);
+        DEF_CALLBACK0(void, mgr, f->_utilities_impl, UtilitiesImpl, stop_cancelable_wait_message);
         DEF_CALLBACK1(void, const string&, mgr, f->_utilities_impl, UtilitiesImpl, set_clipboard_text);
         DEF_CALLBACK0(string, mgr, f->_utilities_impl, UtilitiesImpl, get_clipboard_text);
         DEF_CALLBACK1(void, const string&, mgr, f->_utilities_impl, UtilitiesImpl, open_url);
+        DEF_CALLBACK1(bool, const string&, mgr, f->_utilities_impl, UtilitiesImpl, move_to_trash);
         DEF_CALLBACK2(void, float, const sigc::slot<bool>&, mgr, f->_utilities_impl, UtilitiesImpl, add_timeout);
         DEF_CALLBACK1(string, mforms::FolderType, mgr, f->_utilities_impl, UtilitiesImpl, get_special_folder);
         DEF_CALLBACK3(void, const string&, const string&, const string&, mgr, f->_utilities_impl, UtilitiesImpl, store_password);
         DEF_CALLBACK3(bool, const string&, const string&, string&, mgr, f->_utilities_impl, UtilitiesImpl, find_password);
         DEF_CALLBACK2(void, const string&, const string&, mgr, f->_utilities_impl, UtilitiesImpl, forget_password);
+        DEF_CALLBACK1(void*, const sigc::slot<void*>&, mgr, f->_utilities_impl, UtilitiesImpl, perform_from_main_thread);
       }
     };
   };
