@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -65,7 +65,9 @@ namespace MySQL {
       static bool is_shown(::mforms::View *self);
       static void suspend_layout(::mforms::View *self, bool flag);
       static void set_front_color(mforms::View *self, const std::string &color);
+      static std::string get_front_color(mforms::View *self);
       static void set_back_color(mforms::View *self, const std::string &color);
+      static std::string get_back_color(mforms::View *self);
       static void set_back_image(mforms::View *self, const std::string &path, mforms::ImageLayout layout);
       static void flush_events(::mforms::View *self);
 
@@ -77,7 +79,9 @@ namespace MySQL {
       virtual ViewImpl^ get_parent();
       virtual void relayout();
       void set_front_color(String ^color);
+      String^ get_front_color();
       void set_back_color(String ^color);
+      String^ get_back_color();
       void set_back_image(String ^path, mforms::ImageLayout layout);
       
     public:
@@ -108,7 +112,9 @@ namespace MySQL {
         DEF_CALLBACK1(bool, ::mforms::View*, mgr, f->_view_impl, ViewImpl, is_shown);
         DEF_CALLBACK2(void, ::mforms::View*, bool, mgr, f->_view_impl, ViewImpl, suspend_layout);
         DEF_CALLBACK2(void, ::mforms::View*, const std::string&, mgr, f->_view_impl, ViewImpl, set_front_color);
+        DEF_CALLBACK1(std::string, ::mforms::View*, mgr, f->_view_impl, ViewImpl, get_front_color);
         DEF_CALLBACK2(void, ::mforms::View*, const std::string&, mgr, f->_view_impl, ViewImpl, set_back_color);
+        DEF_CALLBACK1(std::string, ::mforms::View*, mgr, f->_view_impl, ViewImpl, get_back_color);
         DEF_CALLBACK3(void, ::mforms::View*, const std::string&, ::mforms::ImageLayout, mgr, f->_view_impl, ViewImpl, set_back_image);
         DEF_CALLBACK1(void, ::mforms::View*, mgr, f->_view_impl, ViewImpl, flush_events);
       }
@@ -127,7 +133,7 @@ namespace MySQL {
       static void set_auto_resize(Control^ control, mforms::AutoResizeMode mode);
       static bool is_layout_dirty(Control^ control);
       static void set_layout_dirty(Control^ control, bool value);
-      static void resize_with_docking(Control^ control, Drawing::Size& size);
+      static void resize_with_docking(Control^ control, System::Drawing::Size& size);
       static void adjust_auto_resize_from_docking(Control^ control);
     };
 
