@@ -1131,6 +1131,8 @@ namespace grt {
   public:
     typedef TypedListConstIterator<O> const_iterator;
     typedef TypedListConstReverseIterator<O> const_reverse_iterator;
+    typedef Ref<O> value_type;
+
     
     ListRef() {}
 
@@ -2445,6 +2447,7 @@ namespace grt {
 
     void add_module_loader(ModuleLoader *loader);
     bool load_module(const std::string &path, bool refresh);
+    void end_loading_modules();
      
     ModuleLoader *get_module_loader(const std::string &name);
     ModuleLoader *get_module_loader_for_file(const std::string &path);
