@@ -1,20 +1,20 @@
 /* 
- * (c) 2007-2008 MySQL AB, 2008-2010 Sun Microsystems, Inc.
+ * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 
@@ -23,8 +23,8 @@
 #include "grtpp_helper.h"
 #include "grtpp_util.h"
 
-#include "util_functions.h"
-#include "file_functions.h"
+#include "base/file_functions.h"
+#include "base/util_functions.h"
 
 #include <stdio.h>
 #include <errno.h>
@@ -607,10 +607,27 @@ struct ClassImplGenerator
          iter != members.end(); ++iter)
     {
       if (iter->second.calculated)
-        fprintf(f, "    meta->bind_member(\"%s\", new grt::MetaClass::Property<%s,%s >(&%s::%s));\n",
+      {
+        if (!iter->second.delegate_set)
+          fprintf(f, "    meta->bind_member(\"%s\", new grt::MetaClass::Property<%s,%s >(&%s::%s));\n",
                 iter->second.name.c_str(), 
                 cname.c_str(), format_type_cpp(iter->second.type).c_str(), 
                 cname.c_str(), iter->second.name.c_str());
+        else
+        {
+          fprintf(f, "    {\n");
+          fprintf(f, "      void (%s::*setter)(const %s &)= &%s::%s%s;\n", 
+                cname.c_str(), format_type_cpp(iter->second.type).c_str(), 
+                cname.c_str(), /*iter->second.read_only?"__":*/"", iter->second.name.c_str());
+          fprintf(f, "      %s (%s::*getter)() const= &%s::%s;\n",
+                format_type_cpp(iter->second.type).c_str(), cname.c_str(), cname.c_str(), iter->second.name.c_str());
+
+          fprintf(f, "      meta->bind_member(\"%s\", new grt::MetaClass::Property<%s,%s >(getter, setter));\n",
+                iter->second.name.c_str(), 
+                cname.c_str(), format_type_cpp(iter->second.type).c_str());
+          fprintf(f, "    }\n");
+        }
+      }
       else
       {
         fprintf(f, "    {\n");
@@ -810,7 +827,7 @@ static std::string generate_dll_export_name(const std::string &fname)
    name= cppize_class_name(name.substr(0, name.rfind('.')));
    for (size_t i= 0; i < name.size(); i++)
    {
-	name[i]= g_ascii_toupper(name[i]);
+  name[i]= g_ascii_toupper(name[i]);
    }
 
    return "GRT_"+name;
@@ -868,7 +885,7 @@ void grt::helper::generate_struct_code(GRT *grt, const std::string &target_file,
       {
           // forward declare classes that are mentioned and not in #included files
           for (MetaClass::MemberList::const_iterator mem= (*iter)->get_members_partial().begin();
- 	      mem != (*iter)->get_members_partial().end(); ++mem)
+        mem != (*iter)->get_members_partial().end(); ++mem)
           {
               std::string class_name= used_class_name(mem->second.type);
               if (!class_name.empty() && pkgname(package_for_struct[class_name]) != pkgname((*iter)->source())
