@@ -1,20 +1,20 @@
 /* 
- * © 2007-2008 MySQL AB, 2008-2009 Sun Microsystems, Inc.
+ * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 #include "stdafx.h"
@@ -911,17 +911,25 @@ void MetaClass::set_member_internal(internal::Object *object, const std::string
 {
   MetaClass *mc= this;
   MemberList::const_iterator mem, end;
+  bool found = false;
   do
   {
     mem= mc->_members.find(name);
     end= mc->_members.end();
-
+    
+    if (mem != end) found= true;
+    
     mc= mc->_parent;
   } while (mc && (mem == end || mem->second.overrides == true || !mem->second.property->has_setter()));
 
   if (mem == end)
-    throw bad_item(name);
-
+  {
+    if (found)
+      throw grt::read_only_item(_name+"."+name);
+    else
+      throw bad_item(_name+"."+name);
+  }
+  
   if (mem->second.read_only && !force)
   {
     if (mem->second.type.base.type == ListType || mem->second.type.base.type == DictType)
