@@ -26,6 +26,7 @@
 #include "base/string_utilities.h"
 
 #include <glib/gbase64.h>
+#include <functional>
 
 using namespace grt;
 
@@ -34,12 +35,13 @@ using namespace grt;
 #endif
 
 
-#if defined(HAVE_LIBUUID) || defined(__APPLE__)
-
-#ifdef __APPLE__
-# include <CoreFoundation/CoreFoundation.h>
+#if defined(_WIN32)
+#include <objbase.h>
+#elif defined(__APPLE__)
+#include <CoreFoundation/CoreFoundation.h>
 #else
-# include <uuid/uuid.h>
+// Linux specific
+#include <uuid/uuid.h>
 #endif
 
 std::string grt::get_guid()
@@ -92,61 +94,6 @@ std::string grt::get_guid()
 }
 
 
-#else
-#include <boost/uuid/uuid.hpp>
-#include <boost/uuid/uuid_generators.hpp>
-
-// not really base64 alphabet, since base64 uses /, which we dont want since the guid's are also used as filenames
-static const char base64_chars[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+=";
-
-static boost::mt19937 random_gen;
-static boost::uuids::basic_random_generator<boost::mt19937> uuid_gen(&random_gen);
-static GStaticMutex uuid_gen_mutex = G_STATIC_MUTEX_INIT;
-
-std::string grt::get_guid()
-{
-  g_static_mutex_lock(&uuid_gen_mutex);
-  boost::uuids::uuid uuid = uuid_gen();
-  g_static_mutex_unlock(&uuid_gen_mutex);
-  
-  const unsigned char *ptr = (const unsigned char*)&uuid;
- 
-  // 16 bytes encoded as base64 = 21 bytes + 2 bytes for {}
-  std::string uuid_str(23, ' ');
-
-  uuid_str[0] = '{';
-  uuid_str[1] = base64_chars[ptr[0] >> 2];
-  uuid_str[2] = base64_chars[((ptr[0] & 0x03) << 4) | (ptr[0+1] >> 4)];
-  uuid_str[3] = base64_chars[((ptr[0+1] & 0x0f) << 2) | (ptr[0+2] >> 6)];
-  uuid_str[4] = base64_chars[ptr[0+2] & 0x3f];
-  
-  uuid_str[5] = base64_chars[ptr[3] >> 2];
-  uuid_str[6] = base64_chars[((ptr[3] & 0x03) << 4) | (ptr[3+1] >> 4)];
-  uuid_str[7] = base64_chars[((ptr[3+1] & 0x0f) << 2) | (ptr[3+2] >> 6)];
-  uuid_str[8] = base64_chars[ptr[3+2] & 0x3f];
-  
-  uuid_str[9] = base64_chars[ptr[6] >> 2];
-  uuid_str[10] = base64_chars[((ptr[6] & 0x03) << 4) | (ptr[6+1] >> 4)];
-  uuid_str[11] = base64_chars[((ptr[6+1] & 0x0f) << 2) | (ptr[6+2] >> 6)];
-  uuid_str[12] = base64_chars[ptr[6+2] & 0x3f];
-  
-  uuid_str[13] = base64_chars[ptr[9] >> 2];
-  uuid_str[14] = base64_chars[((ptr[9] & 0x03) << 4) | (ptr[9+1] >> 4)];
-  uuid_str[15] = base64_chars[((ptr[9+1] & 0x0f) << 2) | (ptr[9+2] >> 6)];
-  uuid_str[16] = base64_chars[ptr[9+2] & 0x3f];
-  
-  uuid_str[17] = base64_chars[ptr[12] >> 2];
-  uuid_str[18] = base64_chars[((ptr[12] & 0x03) << 4) | (ptr[12+1] >> 4)];
-  uuid_str[19] = base64_chars[((ptr[12+1] & 0x0f) << 2) | (ptr[12+2] >> 6)];
-  uuid_str[20] = base64_chars[ptr[12+2] & 0x3f];
-  
-  uuid_str[21] = base64_chars[ptr[15] >> 2];
-  uuid_str[22] = '}';
-
-  return uuid_str;
-}
-#endif // !HAVE_LIBUUID
-
 std::string grt::fmt_simple_type_spec(const SimpleTypeSpec &type)
 {
   switch (type.type)
@@ -536,38 +483,24 @@ ObjectRef grt::find_child_object(const ObjectRef &object, const std::string &id,
 }
 
 
+class search_in_list_pred : public std::unary_function<std::string,bool>
+{
+private:
+  ObjectListRef _list;
+  public:
+    search_in_list_pred(const ObjectListRef& list) : _list(list) {};
+    result_type operator()(argument_type arg) const
+    {
+        return find_named_object_in_list(_list, arg).is_valid();
+    }
+};
+
 
 std::string grt::get_name_suggestion_for_list_object(const BaseListRef &baselist, const std::string &prefix, bool serial)
 {
-  ObjectListRef list(ObjectListRef::cast_from(baselist));
-
-  char buffer[30];
-  int x= 1;
-  std::string name;
-
-  if (serial)
-  {
-    do 
-    {
-      sprintf(buffer, "%i", x++);
-      name= prefix+buffer;
-    } while (find_named_object_in_list(list, name).is_valid());
-  }
-  else
-  {
-    name= prefix;
-    while (find_named_object_in_list(list, name).is_valid())
-    {
-      sprintf(buffer, "%i", x++);
-      name= prefix+buffer;
-    } 
-  }
-
-  return name;
+  return get_name_suggestion(search_in_list_pred(ObjectListRef::cast_from(baselist)),prefix,serial);
 }
 
-
-
 void CopyContext::copy_list(BaseListRef &list, const BaseListRef &source, bool dontfollow)
 {
   for (size_t c= source.count(), i= 0; i < c; i++)
@@ -806,6 +739,54 @@ ObjectRef CopyContext::duplicate_object(ObjectRef object, std::set<std::string>
   return ObjectRef();
 }
 
+void grt::update_ids(ObjectRef object, const std::set<std::string>& skip_members)
+{
+  if (!object.is_valid())
+    return;
+  MetaClass *metac(object.get_metaclass());
+
+  do
+  {
+    for (MetaClass::MemberList::const_iterator mem= metac->get_members_partial().begin(); 
+      mem != metac->get_members_partial().end(); ++mem)
+    {
+      std::string k= mem->second.name;
+      grt::ValueRef v= object.get_member(k);
+
+      if (skip_members.find(k) != skip_members.end() || mem->second.overrides)
+        continue;
+
+      if (mem->second.calculated)
+        continue;
+
+      Type type= mem->second.type.base.type;
+
+      if (!mem->second.owned_object)
+        continue;
+
+      if (type == ListType)
+      {
+        BaseListRef olist(BaseListRef::cast_from(v));
+        for (size_t c = olist.count(), i = 0; i < c; i++)
+        {
+          if (ObjectRef::can_wrap(olist[i]))
+            update_ids(ObjectRef::cast_from(olist[i]),skip_members);
+        }
+      }
+      else if (type == DictType)
+      {
+        DictRef::cast_from(v);
+      }
+      else if (type == ObjectType)
+      {
+        update_ids(ObjectRef::cast_from(v),skip_members);
+      }
+    }
+    metac= metac->parent();
+  }
+  while (metac != 0);
+  object->__set_id(get_guid());
+}
 
 void grt::append_contents(BaseListRef target, BaseListRef source)
 {
@@ -1068,7 +1049,7 @@ void grt::remove_list_items_matching(ObjectListRef list, const sigc::slot<bool,g
 bool grt::init_python_support(grt::GRT *grt, const std::string &module_path)
 {
 #ifdef ENABLE_PYTHON_MODULES
-  PythonModuleLoader *loader= new PythonModuleLoader(grt);
+  PythonModuleLoader *loader= new PythonModuleLoader(grt, module_path);
   if (!module_path.empty())
   {
     loader->get_python_context()->add_module_path(module_path, true);
