@@ -160,22 +160,39 @@ namespace grt
     }
    
    
-   template<class O>
+    template<class O>
     inline size_t find_object_index_in_list(ListRef<O> list,
-                                            const std::string &id)
+      const std::string &id)
     {
       size_t i, c= list.count();
       for (i= 0; i < c; i++)
       {
         Ref<O> value= list.get(i);
-        
+
         if (value.is_valid() && value.id() == id)
           return i;
       }
       return -1;
     }
-  
-  
+
+    template<typename TPredicate>
+    std::string get_name_suggestion(TPredicate duplicate_found_pred,const std::string &prefix, const bool serial)
+    {
+      char buffer[30] = "";
+      int x= 1;
+      std::string name;
+
+      if (serial)
+        sprintf(buffer, "%i", x);
+      name= prefix+buffer;
+      while (duplicate_found_pred(name))
+      {
+        sprintf(buffer, "%i", x++);
+        name= prefix+buffer;
+      } 
+      return name;
+    }
+
   MYSQLGRT_PUBLIC std::string get_name_suggestion_for_list_object(const BaseListRef &objlist, const std::string &prefix, bool serial= true);
   
   
@@ -183,6 +200,7 @@ namespace grt
   MYSQLGRT_PUBLIC ObjectRef find_child_object(const BaseListRef &list, const std::string &id, bool recursive= true);
   MYSQLGRT_PUBLIC ObjectRef find_child_object(const ObjectRef &object, const std::string &id, bool recursive= true);
 
+  MYSQLGRT_PUBLIC void update_ids(ObjectRef object, const std::set<std::string>& skip_members= std::set<std::string>());
   // the following merge functions are not recursive
   MYSQLGRT_PUBLIC void append_contents(BaseListRef target, BaseListRef source);
   MYSQLGRT_PUBLIC void replace_contents(BaseListRef target, BaseListRef source);
