@@ -71,19 +71,47 @@ static std::string flatten_class_name(std::string name)
   return name;
 }
 
-
-PythonContext::PythonContext(GRT *grt)
+PythonContext::PythonContext(GRT *grt, const std::string &module_path)
 : _grt(grt)
 {
   PyObject *main;
   static const char *argv[2]= { "/dev/null" , NULL };
 
+  if (getenv("PYTHON_DEBUG"))
+    Py_VerboseFlag = 5;
+
 #ifdef _WIN32
   // Hack needed in Windows because Python lib uses C:\Python26 as default pythonhome
   // That will cause conflicts if there is some other Python installed in there (bug #52949)
-  putenv("PYTHONHOME=C:\\nowhere");
+
+  // Program.cs also does this, but somehow, they don't seem to get reflected here
+  char *path = getenv("PATH");
+  if (path)
+  {
+    // strip away everything with Python in it
+    std::vector<std::string> parts = base::split(path, ";");
+    std::string npath;
+    for (std::vector<std::string>::const_iterator p = parts.begin(); p != parts.end(); ++p)
+    {
+      if (!strstr(base::tolower(*p).c_str(), "python"))
+      {
+        if (!npath.empty())
+          npath.append(";");
+        npath.append(*p);
+      }
+    }
+    putenv(g_strdup_printf("PATH=%s", npath.c_str()));
+  }
+
+  putenv(g_strdup_printf("PYTHONHOME=%s\\Python", module_path.c_str()));
+  putenv(g_strdup_printf("PYTHONPATH=%s\\Python;%s\\Python\\DLLs;%s\\Python\\Lib", 
+    module_path.c_str(), module_path.c_str(), module_path.c_str()));
+  //putenv("PYTHONHOME=C:\\nowhere");
 #endif
   Py_InitializeEx(0); // skips signal handler init
+
+  // Stores the main thread state
+  _main_thread_state = PyThreadState_Get();
  
   PySys_SetArgv(1, (char**)argv);
 
@@ -113,7 +141,10 @@ PythonContext::PythonContext(GRT *grt)
 
 PythonContext::~PythonContext()
 {
-//  Py_Finalize();
+  PyEval_RestoreThread(_main_thread_state);
+  _main_thread_state = NULL;
+
+  Py_Finalize();
 }
 
 
@@ -235,7 +266,6 @@ static PyObject *grt_print(PyObject *self, PyObject *args)
 #else
   g_print("%s", text.c_str()); // g_print is not routed to g_log
 #endif
-  base::Logger::log(base::Logger::LogInfo, "grt.python", text.c_str());
   ctx->get_grt()->send_output(text);
   
   Py_INCREF(Py_None);
@@ -324,7 +354,9 @@ static PyObject *grt_send_info(PyObject *self, PyObject *args)
       return NULL;
 
   ctx->get_grt()->send_info(text);
-  
+  // vvvv as each log output ends with new-line the one-item-at-time prints consume too much vertical space
+  //base::Logger::log(base::Logger::LogInfo, "grt.python", text.c_str());
+
   Py_INCREF(Py_None);
   return Py_None;
 }
@@ -357,6 +389,24 @@ static PyObject *grt_send_error(PyObject *self, PyObject *args)
   return Py_None;
 }
 
+
+static PyObject *grt_send_progress(PyObject *self, PyObject *args)
+{
+  PythonContext *ctx;
+  if (!(ctx= PythonContext::get_and_check()))
+    return NULL;
+  
+  float pct;
+  char *text, *detail= NULL;
+  if (!PyArg_ParseTuple(args, "fs|s", &pct, &text, &detail))
+    return NULL;
+  
+  ctx->get_grt()->send_progress(pct, text ? text : "", detail ? detail : "", NULL);
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+
 static PyObject *grt_get_by_path(PyObject *self, PyObject *args)
 {
   PythonContext *ctx;
@@ -422,6 +472,129 @@ static PyObject *grt_readline(PyObject *self, PyObject *args)
 }
 
 
+static bool call_handle_output(const std::string &text, PyObject *callable)
+{
+  WillEnterPython lock;
+  PyObject *ret;
+  
+  if (!(ret = PyObject_Call(callable, Py_BuildValue("s", text.c_str()), NULL)))
+  {
+    g_warning("Error calling Python output handler:");
+    PyErr_Print();
+    PyErr_Clear();
+    return false;
+  }
+  
+  if (ret == Py_None || ret == Py_False || PyInt_AsLong(ret) == 0)
+  {
+    Py_DECREF(ret);
+    return false;
+  }
+  Py_DECREF(ret);
+  return true;
+}
+
+
+static PyObject *grt_push_output_handler(PyObject *self, PyObject *args)
+{
+  PythonContext *ctx;
+  if (!(ctx= PythonContext::get_and_check()))
+    return NULL;
+  
+  PyObject *o;
+  if (!PyArg_ParseTuple(args, "O", &o))
+    return NULL;
+  
+  if (!PyCallable_Check(o))
+    return NULL;
+
+  ctx->push_output_handler(sigc::bind(sigc::ptr_fun(call_handle_output), AutoPyObject(o)));
+  
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+static PyObject *grt_pop_output_handler(PyObject *self, PyObject *args)
+{
+  PythonContext *ctx;
+  if (!(ctx= PythonContext::get_and_check()))
+    return NULL;
+
+  ctx->pop_output_handler();
+  
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+static PyObject *grt_serialize(PyObject *self, PyObject *args)
+{
+  PythonContext *ctx;
+  if (!(ctx= PythonContext::get_and_check()))
+    return NULL;
+  
+  PyObject *object;
+  char *path = NULL;
+  
+  if (!PyArg_ParseTuple(args, "Os", &object, &path))
+    return NULL;
+  
+  grt::ValueRef value(ctx->from_pyobject(object));
+  if (!value.is_valid())
+  {
+    PyErr_SetString(PyExc_TypeError, "First argument must be a GRT object");
+    return NULL;
+  }
+  
+  if (!path)
+  {
+    PyErr_SetString(PyExc_ValueError, "File path expected for argument #2");
+    return NULL;
+  }
+  
+  try
+  {
+    ctx->get_grt()->serialize(value, path);
+  }
+  catch (const std::exception &exc)
+  {
+    PythonContext::set_python_error(exc, "serializing object");
+    return NULL;
+  }
+  
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+
+static PyObject *grt_unserialize(PyObject *self, PyObject *args)
+{
+  PythonContext *ctx;
+  if (!(ctx= PythonContext::get_and_check()))
+    return NULL;
+  
+  char *path = NULL;
+  if (!PyArg_ParseTuple(args, "s", &path))
+    return NULL;
+  if (!path)
+  {
+    PyErr_SetString(PyExc_ValueError, "File path expected");
+    return NULL;
+  }
+  
+  try
+  {
+    grt::ValueRef value = ctx->get_grt()->unserialize(path);
+  }
+  catch (const std::exception &exc)
+  {
+    PythonContext::set_python_error(exc, base::strfmt("unserializing file %s", path));
+    return NULL;
+  }
+  
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
 /** Register grt related functionality as a module
 
  Stuff made available in the module include:
@@ -441,6 +614,13 @@ static PyMethodDef GrtModuleMethods[] = {
 "Write a warning message to the GRT shell."},
 {"send_info",  grt_send_info, METH_VARARGS,
 "Write a info message to the GRT shell."},
+{"send_progress",  grt_send_progress, METH_VARARGS,
+"Write a progress message."},
+
+{"push_output_handler", grt_push_output_handler, METH_VARARGS,
+"Pushes a callback of the form function(text) to be called when a plugin outputs text."},
+{"pop_output_handler", grt_push_output_handler, METH_NOARGS,
+ "Pops previously pushed handler."},
 
 {"readline", grt_readline, METH_VARARGS,
 "Waits for a line of text to be input to the scripting shell prompt."},
@@ -448,6 +628,12 @@ static PyMethodDef GrtModuleMethods[] = {
 {"get", grt_get_by_path, METH_VARARGS,
 "Gets a value from a GRT dict or object (or from the global tree) by path."},
 
+{"serialize", grt_serialize, METH_VARARGS,
+  "Serializes a GRT object into a XML file. serialize(object, path)"},
+{"unserialize", grt_unserialize, METH_VARARGS,
+  "Unserializes a GRT object from a XML file created by serialize. unserialize(path) -> object"},
+
+  
 {NULL, NULL, 0, NULL}        /* Sentinel */
 };
 
@@ -480,11 +666,17 @@ void PythonContext::register_grt_module()
   _grt_modules_module = Py_InitModule("grt.modules", NULL);
   if (!_grt_modules_module)
     throw std::runtime_error("Error initializing grt.modules module in Python support");
+  
+  // AutoPyObject need to keep a reference but PyModule_AddObject steals it
+  // so it is needed to increase it to avoid problems on destruction
+  Py_INCREF(_grt_modules_module);
   PyModule_AddObject(_grt_module, "modules", _grt_modules_module);
   
   _grt_classes_module = Py_InitModule("grt.classes", NULL);
   if (!_grt_classes_module)
     throw std::runtime_error("Error initializing grt.classes module in Python support");
+  
+  Py_INCREF(_grt_classes_module);
   PyModule_AddObject(_grt_module, "classes", _grt_classes_module);
   
   PyModule_AddObject(_grt_classes_module, "grt", _grt_module);
