@@ -22,8 +22,6 @@
 #define _GRT_PYTHON_CONTEXT_H_
 
 
-#ifdef ENABLE_PYTHON_MODULES
-
 #if defined(_WIN32) || defined(__APPLE__)
 # include <Python/Python.h>
 #else
@@ -95,7 +93,7 @@ namespace grt {
   class MYSQLGRT_PUBLIC PythonContext
   {
   public:
-    PythonContext(GRT *grt);
+    PythonContext(GRT *grt, const std::string &module_path);
     ~PythonContext();
 
     static PythonContext *get();
@@ -134,6 +132,10 @@ namespace grt {
 
     sigc::slot<std::string> stdin_readline_slot;
     
+    // slots to be assigned by GRTManager to allow python modules to register output handlers
+    sigc::slot<void, sigc::slot<bool, std::string> > push_output_handler;
+    sigc::slot<void> pop_output_handler;
+    
     static void set_python_error(const grt::type_error &exc, const std::string &location="");
     static void set_python_error(const grt::bad_item &exc, const std::string &location="");
     static void set_python_error(const std::exception &exc, const std::string &location="");
@@ -166,6 +168,9 @@ namespace grt {
     void init_grt_list_type();
     void init_grt_dict_type();
     void init_grt_object_type();
+
+    PyThreadState*  _main_thread_state;
+
   };
   
   // Must be placed when Python code will be called
@@ -205,5 +210,3 @@ namespace grt {
 };
 
 #endif
-
-#endif
