@@ -187,12 +187,17 @@ std::string Mysql_sql_specifics::query_connection_id()
 }
 
 
-std::string Mysql_sql_specifics::query_kill_connection(int connection_id)
+std::string Mysql_sql_specifics::query_kill_connection(boost::int64_t connection_id)
 {
   return strfmt("KILL CONNECTION %i", connection_id);
 }
 
 
+std::string Mysql_sql_specifics::query_kill_query(boost::int64_t connection_id)
+{
+  return strfmt("KILL QUERY %i", connection_id);
+}
+
 std::string Mysql_sql_specifics::query_variable(const std::string &name)
 {
   return strfmt("SHOW SESSION VARIABLES LIKE '%s'", name.c_str());
