@@ -23,7 +23,7 @@
 #include "mysql_sql_statement_decomposer.h"
 #include "mysql_sql_parser_utils.h"
 #include "mysql_sql_parser_fe.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 #include <boost/foreach.hpp>
 
 
