@@ -2277,7 +2277,7 @@ std::string DbMySQLImpl::makeAlterScriptForObject(GrtNamedObjectRef source, GrtN
   DictRef result(get_grt());
 
   options.set("UseFilteredLists", IntegerRef(0));
-  DiffChange* diff= diff_make(source, target, &omf, grt::NormalizedComparer<grt::GRT*>(get_grt()));
+  DiffChange* diff= diff_make(source, target, &omf, grt::NormalizedComparer(get_grt()));
 
   std::string sql;
   std::string non_std_sql_delimiter("$$");
@@ -2432,7 +2432,7 @@ std::string DbMySQLImpl::makeCreateScriptForObject(GrtNamedObjectRef object)
     return "";
 
   options.set("UseFilteredLists", IntegerRef(0));
-  DiffChange* diff= diff_make(ValueRef(), parent, NULL, grt::NormalizedComparer<grt::GRT*>(get_grt()));
+  DiffChange* diff= diff_make(ValueRef(), parent, NULL, grt::NormalizedComparer(get_grt()));
 
   std::string sql;
 
