@@ -26,6 +26,20 @@
 #include "grt/grt_manager.h"
 #include <grtpp_undo_manager.h>
 #include "base/string_utilities.h"
+#include "base/wb_iterators.h"
+#include <math.h>
+#include <algorithm>
+#include <stdlib.h>
+
+#ifndef M_PI
+# define M_PI   3.14159265358979323846
+#endif
+#ifndef M_PI_2
+# define M_PI_2  1.57079632679489661923
+#endif
+
+#define PI_38 M_PI * 0.375
+#define PI_58 M_PI * 0.625
 
 using namespace grt;
 using namespace std; // In VS min/max are not in the std namespace, so we have to split that.
@@ -286,8 +300,516 @@ int WbModelImpl::autolayout(model_DiagramRef view)
 }
 
 
+//==============================================================================
+//
+//==============================================================================
+class Layouter
+{
+  public:
+    Layouter(const model_LayerRef &layer);
 
+    void add_figure_to_layout(const model_FigureRef& figure);
+    void connect(const model_FigureRef& f1, const model_FigureRef& f2);
+
+    int do_layout();
+  private:
+    struct Node;
+
+    static bool compare_node_links(const Node& n1, const Node& n2);
+
+    bool shuffle();
+    double calc_energy();
+    double calc_node_energy(const int i, const Node& n);
+    long distance_to_node(const int n1, const int n2, bool *is_horiz = 0);
+    double calc_node_pair(const int i1, const int i2);
+    void prepare_layout_stages();
+
+    const double _w;
+    const double _h;
+
+    struct Node
+    {
+      Node(const model_FigureRef& figure);
+      void move_by(const long dx, const long dy);
+      void move(const long x, const long y);
+      bool is_linked_to(const int node) const;
+
+      long                  w;
+      long                  h;
+      long                  x1;
+      long                  y1;
+      long                  x2;
+      long                  y2;
+      model_FigureRef       fig;
+      std::vector<int>      linked;
+    };
+    typedef std::vector<Node> NodesList;
+    NodesList       _all_figures;
+    NodesList       _figures;
+    long            _min_dist; // desired dist between nodes
+    double          _min_energy;
+    int             _cell_w;
+    int             _cell_h;
+    model_LayerRef  _layer;
+};
+
+//------------------------------------------------------------------------------
+Layouter::Node::Node(const model_FigureRef& figure)
+          : w((long) figure->width())
+          , h((long) figure->height())
+          , x1((long) figure->left())
+          , y1((long) figure->top())
+          , x2(x1 + w)
+          , y2(y1 + h)
+          , fig(figure)
+{}
+
+//------------------------------------------------------------------------------
+void Layouter::Node::move(const long x, const long y)
+{
+  x1 = x;
+  y1 = y;
+  x2 = x1 + w;
+  y2 = y1 + h;
+}
+
+//------------------------------------------------------------------------------
+void Layouter::Node::move_by(const long dx, const long dy)
+{
+  x1 += dx;
+  y1 += dy;
+  x2 += dx;
+  y2 += dy;
+}
+
+//------------------------------------------------------------------------------
+bool Layouter::Node::is_linked_to(const int node) const
+{
+  bool found = false;
+
+  for (int i = linked.size() - 1; i >= 0; --i)
+  {
+    if (linked[i] == node)
+    {
+      found = true;
+      break;
+    }
+  }
+
+  return false;
+}
+
+//------------------------------------------------------------------------------
+Layouter::Layouter(const model_LayerRef &layer)
+         : _w(layer->width())
+         , _h(layer->height())
+         , _min_dist(80)
+         , _cell_w(0)
+         , _cell_h(0)
+         , _layer(layer)
+{
+  const ListRef<model_Figure> figures = layer->figures();
+  const int size = figures->count();
+
+  for (int i = 0; i < size; ++i)
+    _all_figures.push_back(figures[i]);
+}
+
+
+//------------------------------------------------------------------------------
+void Layouter::add_figure_to_layout(const model_FigureRef& figure)
+{
+  const int size = _all_figures.size();
+  for (int i = 0; i < size; ++i)
+  {
+    if (_all_figures[i].fig == figure)
+    {
+      _figures.push_back(figure);
+    }
+  }
+}
+
+//------------------------------------------------------------------------------
+void Layouter::connect(const model_FigureRef& f1, const model_FigureRef& f2)
+{
+  int n1 = -1;
+  int n2 = -1;
+
+  const int size = _figures.size();
+  for (int i = 0; i < size; ++i)
+  {
+    Node& n = _figures[i];
+    if (n1 == -1 && n.fig == f1)
+      n1 = i;
+    if (n2 == -1 && n.fig == f2)
+      n2 = i;
+    if (n1 >= 0 && n2 >= 0)
+      break;
+  }
+
+  if (n1 >= 0 && n2 >= 0)
+  {
+    Node& node1 = _figures[n1];
+    Node& node2 = _figures[n2];
+    node1.linked.push_back(n2);
+    node2.linked.push_back(n1);
+  }
+}
+
+//------------------------------------------------------------------------------
+long Layouter::distance_to_node(const int i1, const int i2, bool* is_horiz)
+{
+  const Node& n1 = _figures[i1];
+  const Node& n2 = _figures[i2];
+  const long x11 = n1.x1;
+  const long y11 = n1.y1;
+  const long x12 = n1.x2;
+  const long y12 = n1.y2;
+
+  const long x21 = n2.x1;
+  const long y21 = n2.y1;
+  const long x22 = n2.x2;
+  const long y22 = n2.y2;
+
+  const long cx1 = x11 + (x12 - x11)/2;
+  const long cy1 = y11 + (y12 - y11)/2;
+  const long cx2 = x21 + (x22 - x21)/2;
+  const long cy2 = y21 + (y22 - y21)/2;
+  const long dcx = cx2 - cx1;
+  const double qr = atan2((double)dcx, (double)(cy2 - cy1));
+
+  double dx = 0;
+  double dy = 0;
+  double l1 = 0;
+  double l2 = 0;
+  if (qr > M_PI_2)
+  {
+    dy = y11 - y22;
+    dx = x21 - x12;
+    l1 = dy ? ::fabs(dy/cos(qr)) : ::abs(dx);
+    l2 = dx ? ::fabs(dx/sin(qr)) : ::abs(dy);
+  }
+  else if (0.0 < qr && qr <= M_PI_2)
+  {
+    dy = y21 - y12;
+    dx = x21 - x12;
+    if (dy > dx)
+      l1 = l2 = dy ? ::fabs(dy/cos(qr)) : ::abs(dx);
+    else
+      l1 = l2 = dx ? ::fabs(dx/sin(qr)) : ::abs(dy);
+  }
+  else if (qr < -M_PI_2)
+  {
+    dy = y11 - y22;
+    dx = -(x22 - x11);
+    if (dy > dx)
+      l1 = l2 = dy ? ::fabs(dy/cos(qr)) : ::abs(dx);
+    else
+      l1 = l2 = dx ? ::fabs(dx/sin(qr)) : ::abs(dy);
+  }
+  else
+  {
+    dy = y21 - y12;
+    if (abs(dcx) > (x12-x11)/2)
+      dx = x11 - x22;
+    else
+      dx = dcx;
+    if (dy > dx)
+      l1 = l2 = dy ? ::fabs(dy/cos(qr)) : ::abs(dx);
+    else
+      l1 = l2 = (dx && qr != 0.0) ? ::fabs(dx/sin(qr)) : ::abs(dy);
+  }
+
+  //printf("qr %f (cos(qr) = %f, sin(rq) = %f), l1 %li, l2 %li, dy %li, dx %li\n", qr, cos(qr), sin(qr), l1, l2, dy, dx);
+
+  const double aqr = ::fabs(qr);
+  if (is_horiz)
+    *is_horiz = PI_38 < aqr && aqr < PI_58;
+  return l1 < l2 ? (long) l1 : (long) l2;
+}
+
+//------------------------------------------------------------------------------
+inline double line_len2(long x1, long y1, long x2, long y2)
+{
+  return sqrt(pow((double)(x2 - x1), 2) + pow((double)(y2 - y1), 2));
+}
+
+//------------------------------------------------------------------------------
+double Layouter::calc_node_pair(const int i1, const int i2)
+{
+  const Node* n1 = &(_figures[i1]);
+  const Node* n2 = &(_figures[i2]);
+  const bool is_linked = n1->is_linked_to(i2) || n2->is_linked_to(i1);
+
+  long S1 = n1->w * n1->h;
+  long S2 = n2->w * n2->h;
+  if (S1 > S2)
+  {
+    std::swap(n1, n2);
+    std::swap(S1, S2);
+  }
+
+  const long x11 = n1->x1;
+  const long y11 = n1->y1;
+  const long x12 = n1->x2;
+  const long y12 = n1->y2;
+
+  const long x21 = n2->x1;
+  const long y21 = n2->y1;
+  const long x22 = n2->x2;
+  const long y22 = n2->y2;
+
+  const long cx1 = x11 + (x12 - x11)/2;
+  const long cy1 = y11 + (y12 - y11)/2;
+  const long cx2 = x21 + (x22 - x21)/2;
+  const long cy2 = y21 + (y22 - y21)/2;
+
+  //Detect if nodes overlap
+  const bool is_overlap = ((x12 >= x21) && (x22 >= x11) && (y12 >= y21) && (y22 >= y11));
+
+  static const double overlap_quot = 1000.0;
+
+  double e = 0.0;
+  double distance = 0;
+  if (is_overlap)
+  {
+    distance = line_len2(cx1, cy1, cx2, cy2);
+
+    // calc area of overlap
+    const long sx1 = x11 > x21 ? x11 : x21;
+    const long sy1 = y11 > y21 ? y11 : y21;
+    const long sx2 = x12 < x22 ? x12 : x22;
+    const long sy2 = y12 < y22 ? y12 : y22;
+    const long dsx = sx2 - sx1;
+    const long dsy = sy2 - sy1;
+
+    const long Sov = dsx * dsy;
+
+    if (distance == 0.0)
+      distance = 0.0000001;
+
+    e = _min_dist * 1/distance * 100 + Sov;
+    e *= overlap_quot;
+  }
+  else
+  {
+    bool is_horiz = false;
+    distance = distance_to_node(i1, i2, &is_horiz);
+
+    if (distance <= _min_dist)
+    {
+      if (distance != 0)
+      {
+        if (is_linked)
+          e += _min_dist + overlap_quot * 1/distance;
+        else
+          e += _min_dist + overlap_quot * _min_dist/distance;
+      }
+      else
+      {
+        e += overlap_quot;
+      }
+    }
+    else
+    {
+      e += distance;
+      if (is_linked)
+        e += distance * distance;
+    }
+  }
+
+  return e;
+}
+
+//------------------------------------------------------------------------------
+double Layouter::calc_energy()
+{
+  const int size = _figures.size();
+  double e = 0.0;
+
+  for (int i = 0; i < size; ++i)
+  {
+    const Node& node = _figures[i];
+    if ((node.x1 < 0) || (node.y1 < 0) || (node.x2 + 20 > _w) || (node.y2 + 20 > _h))
+      e += 1000000000000.0;
+
+    for (int j = i + 1; j < size; ++j)
+    {
+      if (j >= size)
+        break;
+      e += calc_node_pair(i, j);
+    }
+  }
+
+  return e;
+}
+
+//------------------------------------------------------------------------------
+double Layouter::calc_node_energy(const int node_i, const Node& node)
+{
+  const int size = _figures.size();
+  double e = 0.0;
+
+  if ((node.x1 < 0) || (node.y1 < 0) || (node.x2 + 20 > _w) || (node.y2 + 20 > _h))
+    e += 1000000000000.0;
+
+  for (int i = 0; i < size; ++i)
+  {
+    if (node_i != i)
+      e += calc_node_pair(node_i, i);
+  }
+
+  return e;
+}
+
+//------------------------------------------------------------------------------
+bool Layouter::shuffle()
+{
+  bool found_smaller_energy = false;
+  const int step = (rand() % 5) + 1;
+
+  const int size = _figures.size();
+  for (int i = 0; i < size; ++i)
+  {
+    Node& n = _figures[i];
+    const int wstep = _cell_w * step;
+    const int hstep = _cell_w * step;
+    double node_energy = calc_node_energy(i, n);
+
+    const int wsteps[] = {wstep, -wstep,     0,      0};
+    const int hsteps[] = {    0,      0, hstep, -hstep};
+    for (int ns = sizeof(wsteps)/sizeof(int) - 1; ns >= 0; --ns)
+    {
+      n.move_by(wsteps[ns], hsteps[ns]);
+      const double energy = calc_node_energy(i, n);
+      if (energy < node_energy)
+      {
+        node_energy = energy;
+        found_smaller_energy = true;
+      }
+      else
+        n.move_by(-wsteps[ns], -hsteps[ns]);
+    }
+  }
+
+  if (found_smaller_energy)
+    _min_energy = calc_energy();
+
+  return found_smaller_energy;
+}
+
+//------------------------------------------------------------------------------
+bool Layouter::compare_node_links(const Node& n1, const Node& n2)
+{
+  return n1.linked.size() > n2.linked.size();
+}
+
+//------------------------------------------------------------------------------
+void Layouter::prepare_layout_stages()
+{
+  double total_w = 0;
+  double total_h = 0;
+  std::sort(_figures.begin(), _figures.end(), compare_node_links);
+  const int size = _figures.size();
+
+  // reset layout
+  for (int i = 0; i < size; ++i)
+  {
+    Node& n = _figures[i];
+    // place all tables in some initial position
+    n.move((long) _w / 4, (long) _h / 4);
+
+    // Calculate total dimensions and find max cell size.
+    total_w += n.w;
+    total_h += n.h;
+    if (_cell_w < n.w)
+      _cell_w = n.w;
+    if (_cell_h < n.h)
+      _cell_h = n.h;
+  }
+  _cell_w = (int) (1.1 * _cell_w);
+
+  //printf("_cell_w = %i, _cell_h = %i, _w = %.1f, _h = %.1f, total_w = %.1f, total_h = %.1f\n", _cell_w, _cell_h, _w, _h, total_w, total_h);
+  //if (_w < total_w)
+  //  _layer->width(total_w);
+  //if (_h < total_h)
+  //  _layer->height(total_h);
+
+  // find nodes with most links
+}
+
+//------------------------------------------------------------------------------
+int Layouter::do_layout()
+{
+  prepare_layout_stages();
+
+  _min_energy = calc_energy();
+  int de0_count = 10; // de=0 count
+  double de = 1; // energy delta
+  double prev_energy = 0;
+  while (de0_count > 0)
+  {
+    shuffle();
+    de = prev_energy - _min_energy;
+    prev_energy = _min_energy;
+    if (de == 0)
+      --de0_count;
+    else
+      de0_count = 10;
+  }
+
+  // update actual figures with new coords
+  const int size = _figures.size();
+  for (int i = 0; i < size; ++i)
+  {
+    Node& n = _figures[i];
+    model_FigureRef& f = n.fig;
+
+    f->left(n.x1);
+    f->top(n.y1);
+  }
+  return 0;
+}
+
+//------------------------------------------------------------------------------
 int WbModelImpl::do_autolayout(const model_LayerRef &layer, ListRef<model_Object> &selection)
+{
+  Layouter  layout(layer);
+  if (selection.count() > 0)
+  {
+    const int size = selection->count();
+    for (int i = 0; i < size; ++i)
+    {
+      const model_ObjectRef figure = selection[i];
+      if (workbench_physical_TableFigureRef::can_wrap(figure) || workbench_physical_ViewFigureRef::can_wrap(figure))
+        layout.add_figure_to_layout(model_FigureRef::cast_from(figure));
+    }
+  }
+  else
+  {
+    const ListRef<model_Figure> figures = layer->figures();
+    const int size = figures->count();
+    for (int i = 0; i < size; ++i)
+    {
+      const model_ObjectRef figure = figures[i];
+      if (workbench_physical_TableFigureRef::can_wrap(figure) || workbench_physical_ViewFigureRef::can_wrap(figure))
+        layout.add_figure_to_layout(model_FigureRef::cast_from(figure));
+    }
+  }
+
+  ListRef<model_Connection> connections = layer->owner()->connections();
+  const int size = connections->count();
+  for (int i = 0; i < size; ++i)
+  {
+    const model_ConnectionRef conn = connections[i];
+    layout.connect(conn->startFigure(), conn->endFigure());
+  }
+
+  return layout.do_layout();
+}
+
+#if 0
+int WbModelImpl::do_autolayout_old(const model_LayerRef &layer, ListRef<model_Object> &selection)
 {
   int result= 0;
 
@@ -449,7 +971,7 @@ int WbModelImpl::do_autolayout(const model_LayerRef &layer, ListRef<model_Object
 
   return result;
 }
-
+#endif
 
 static bool calculate_view_size(const app_PageSettingsRef &page, double &width, double &height)
 {
