@@ -61,10 +61,16 @@ def printAllColumns(catalog):
   
 
 def get_linux_terminal_program():
-    options = ["gnome-terminal", "konsole", "xterm", "rxvt"]
-    for opt in options:
-        if any(os.path.exists(d+"/"+opt) for d in os.getenv("PATH").split(":")):
-            return opt
+    paths = os.getenv("PATH").split(":")
+    if not paths:
+        paths = ['/usr/bin', '/usr/local/bin', '/bin']
+
+    for term in ["gnome-terminal", "konsole", "xterm", "rxvt"]:
+        for d in paths:
+            full_path = os.path.join(d, term)
+            if os.path.exists(full_path):
+                return full_path
+
     return None
 
 
@@ -93,7 +99,11 @@ def startCommandLineClientForConnection(conn):
     port = conn.parameterValues["port"]
     if port is None:
         port = 3306
-    schema = conn.parameterValues["schema"].replace("\\", "\\\\").replace('"', '\\"')
+    schema = conn.parameterValues["schema"]
+    if schema:
+        schema = schema.replace("\\", "\\\\").replace('"', '\\"')
+    else:
+        schema = ""
 
     if platform.system() == "Darwin":
         command = """mysql \\"-u%s\\" \\"-h%s\\" -P%i %s -p %s""" % (user, host, port, socket, schema)
@@ -112,7 +122,7 @@ import sys
 # find out version of default python interpreter
 if sys.platform != "win32":
     pyversion, junk = subprocess.Popen("python --version", stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True).communicate()
-    if [int(i) for i in pyversion.split(" ")[1].strip().split(".")] < [2, 6, 0]:
+    if [int(i) for i in pyversion.split(" ")[1].strip().split(".")[:2]] < [2, 6]:
         disable_utilities = True
 
 if not disable_utilities:
@@ -141,17 +151,22 @@ if not disable_utilities:
             os.chmod(setup_script, 0700)
             os.system("""osascript -e 'tell application "Terminal" to do script "source \\"%s\\""' -e 'tell front window of application "Terminal" to set custom title to "MySQL Utilities"'""" % setup_script)
         else:
-            import tempfile
-            fd, setup_script = tempfile.mkstemp(prefix="delme.", dir=mforms.App.get().get_user_data_folder())
-            f = os.fdopen(fd, "w+")
-            f.write('echo "The following MySQL Utilities are available:"\n')
-            f.write('echo $MYSQL_UTILITIES_COMMANDS\n')
-            f.write('rm -f "%s"\n' % setup_script)
-            f.write('bash -i\n')
-            f.close()
-            os.chmod(setup_script, 0700)
-     
-            subprocess.call(["/bin/bash", "-c", "%s -e %s &" % (get_linux_terminal_program(), setup_script)])
+            term = get_linux_terminal_program()
+            if term:
+                import tempfile
+                fd, setup_script = tempfile.mkstemp(prefix="delme.", dir=mforms.App.get().get_user_data_folder())
+                f = os.fdopen(fd, "w+")
+                f.write('echo "The following MySQL Utilities are available:"\n')
+                f.write('echo $MYSQL_UTILITIES_COMMANDS\n')
+                f.write('rm -f "%s"\n' % setup_script)
+                f.write('bash -i\n')
+                f.close()
+                os.chmod(setup_script, 0700)
+
+                if 'konsole' in term:
+                    subprocess.call([term, "-e", "/bin/bash", setup_script])
+                else:
+                    subprocess.call(["/bin/bash", "-c", "%s -e %s &" % (term, setup_script)])
 
 
 @ModuleInfo.plugin("wb.tools.utilitiesShellFor", caption="Start MySQL Utilities Shell for Connection", input= [wbinputs.selectedConnection()], pluginMenu="Home/Connections")
