@@ -25,7 +25,7 @@
 #include "db.mysql/src/module_db_mysql.h"
 #include "grt/validation_manager.h"
 
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 using namespace bec;
 using namespace base;
