@@ -52,7 +52,7 @@ static void call_refresh(DbMysqlTableEditor* theEditor)
   // As it turns out, this call-back can be called from non-main threads.
   [theEditor performSelectorOnMainThread: @selector(refreshTableEditorGUI)
                               withObject: nil
-                           waitUntilDone: NO];
+                           waitUntilDone: YES];
 }
 
 
