@@ -21,7 +21,7 @@
 
 #import "MCPPUtilities.h"
 #import "GRTTreeDataSource.h"
-#import "string_utilities.h"
+#include "base/string_utilities.h"
 
 @implementation DbMysqlUserEditor
 
