@@ -63,6 +63,8 @@ namespace MySQL.GUI.Workbench.Plugins
 
       sqlEd = new SqlEditorHelper(GrtManager, triggersTabPage, triggersEditorParseLogCallback);
 
+      dbObjectEditorPages = new DbObjectEditorPages(grtManager, tableEditorBE);
+
       InitializingControls = true;
       try
       {
@@ -123,6 +125,8 @@ namespace MySQL.GUI.Workbench.Plugins
 
     protected void InitFormData()
     {
+      int current_page = mainTabControl.SelectedIndex;
+
       // Init Columns TreeView
       columnsTreeView.SelectedNode = null;
       if (columnsTreeView.Model != null && columnsTreeView.Model is DbMysqlTableColumnsListModel)
@@ -217,16 +221,30 @@ namespace MySQL.GUI.Workbench.Plugins
         columnCollationComboBox.Items.Add(coll);
       }
 
-      mainTabControl.TabPages.Remove(insertsTabPage);
-      if (!IsEditingLiveObject)
-        mainTabControl.TabPages.Add(insertsTabPage);
+      // This validation was added to avoid removing the page if not needed
+      // as it causes flickering
+      if (mainTabControl.TabPages.Contains(insertsTabPage))
+      {
+        if (IsEditingLiveObject)
+          mainTabControl.TabPages.Remove(insertsTabPage);
+      }
+      else
+      {
+        if (!IsEditingLiveObject)
+          mainTabControl.TabPages.Add(insertsTabPage);
+      }
 
-      // Add privileges tab sheet
-      if (dbObjectEditorPages != null)
-        mainTabControl.TabPages.Remove(dbObjectEditorPages.PrivilegesTabPage);
-      dbObjectEditorPages = new DbObjectEditorPages(grtManager, tableEditorBE);
-      if (!IsEditingLiveObject)
-        mainTabControl.TabPages.Add(dbObjectEditorPages.PrivilegesTabPage);
+
+      if (mainTabControl.TabPages.Contains(dbObjectEditorPages.PrivilegesTabPage))
+      {
+        if (IsEditingLiveObject)
+          mainTabControl.TabPages.Remove(dbObjectEditorPages.PrivilegesTabPage);
+      }
+      else
+      {
+        if (!IsEditingLiveObject)
+          mainTabControl.TabPages.Add(dbObjectEditorPages.PrivilegesTabPage);
+      }
 
       // Partitioning stuff
       if (partitionTreeView.Model != null && partitionTreeView.Model is SimpleGrtTreeModel)
@@ -418,7 +436,10 @@ namespace MySQL.GUI.Workbench.Plugins
 
       // table inserts editor
       if (null != insertsRecordsetView)
+      {
         insertsRecordsetView.Model = tableEditorBE.get_inserts_model();
+        insertsRecordsetView.Model.refresh();
+      }
 
       if (InitializingControls)
       {
@@ -503,13 +524,21 @@ namespace MySQL.GUI.Workbench.Plugins
       {
         fkListModel.RefreshModel();
 
-        // if the fk tab is selected, auto-edit a fk
-        if (fkTreeView.Root.Children.Count >= 1)
+        if (!IsEditingLiveObject || optEngine.SelectedIndex == 0 || // Index 0 is the server default.
+          optEngine.Text.Equals("InnoDB", StringComparison.InvariantCultureIgnoreCase))
         {
-          ActiveControl = fkTreeView;
-          fkTreeView.SelectedNode = fkTreeView.Root.Children[fkTreeView.Root.Children.Count - 1];
-          nameFkNodeControl.BeginEdit();
+          foreignKeyWarningPanel.Visible = false;
+
+          // if the fk tab is selected, auto-edit a fk
+          if (fkTreeView.Root.Children.Count >= 1)
+          {
+            ActiveControl = fkTreeView;
+            fkTreeView.SelectedNode = fkTreeView.Root.Children[fkTreeView.Root.Children.Count - 1];
+            nameFkNodeControl.BeginEdit();
+          }
         }
+        else
+          foreignKeyWarningPanel.Visible = true;
       }
       else if (mainTabControl.SelectedTab == insertsTabPage)
       {
