@@ -242,8 +242,8 @@ ValueRef DbMySQLSQLExport::export_task(grt::GRT* grt, grt::StringRef)
 
 //  return diff_make(cat, org_cat, &omf, sigc::mem_fun(cmp, &NormalizedComparer<grt::GRT*>::normalizedComparison));
 
-    DiffChange* create_change= diff_make(e, _catalog, NULL, grt::NormalizedComparer<grt::GRT*>(grt));
-    DiffChange* drop_change= diff_make(_catalog, e, NULL, grt::NormalizedComparer<grt::GRT*>(grt));
+    DiffChange* create_change= diff_make(e, _catalog, NULL, grt::NormalizedComparer(grt));
+    DiffChange* drop_change= diff_make(_catalog, e, NULL, grt::NormalizedComparer(grt));
     DictRef create_map(grt);
     DictRef drop_map(grt);
 
