@@ -242,7 +242,7 @@ void update_all_old_names(db_mysql_CatalogRef cat, bool update_only_empty, Catal
 }
 
 DbMySQLScriptSync::DbMySQLScriptSync(bec::GRTManager *grtm)
-  : DbMySQLValidationPage(grtm), _diff_tree(NULL)
+  : DbMySQLValidationPage(grtm), _alter_list(grtm->get_grt()), _alter_object_list(grtm->get_grt())
 {
   _manager= grtm;
 }
@@ -381,7 +381,7 @@ ValueRef DbMySQLScriptSync::sync_task(grt::GRT* grt, grt::StringRef)
 
   grt::DbObjectMatchAlterOmf omf;
   omf.dontdiff_mask = 3;
-  DiffChange* alter_change= diff_make(org_cat_copy, mod_cat_copy, &omf,NormalizedComparer<grt::GRT*>(_manager->get_grt()));
+  DiffChange* alter_change= diff_make(org_cat_copy, mod_cat_copy, &omf,NormalizedComparer(_manager->get_grt()));
 
   // nothing changed
   if(!alter_change)
@@ -417,19 +417,6 @@ void DbMySQLScriptSync::update_model_old_names()
   update_all_old_names(get_model_catalog(), false, cm);
 }
 
-DiffTreeBE *DbMySQLScriptSync::init_diff_tree(const ValueRef &ext_cat, const ValueRef &cat2)
-{
-  std::vector<std::string> schemata;
-
-  db_mysql_CatalogRef catalog= db_mysql_CatalogRef::cast_from(ext_cat);
-  grt::ListRef<db_mysql_Schema> sch(catalog->schemata());
-  for (size_t i= 0; i < sch.count(); i++)
-    schemata.push_back(sch.get(i)->name().c_str());
-
-  return init_diff_tree(schemata, ext_cat, cat2);
-}
-
-
 DiffTreeBE *DbMySQLScriptSync::init_diff_tree(const std::vector<std::string>& schemata, const ValueRef &ext_cat, 
                                               const ValueRef &cat2,StringListRef SchemaSkipList)
 {
@@ -502,13 +489,39 @@ DiffTreeBE *DbMySQLScriptSync::init_diff_tree(const std::vector<std::string>& sc
 
   grt::DbObjectMatchAlterOmf omf;
   omf.dontdiff_mask = 3;
-  _alter_change= diff_make(_org_cat, _mod_cat_copy, &omf,NormalizedComparer<grt::GRT*>(_manager->get_grt()));
+  _alter_change= diff_make(_org_cat, _mod_cat_copy, &omf,NormalizedComparer(_manager->get_grt()));
+
+  DbMySQLImpl *diffsql_module= _manager->get_grt()->find_native_module<DbMySQLImpl>("DbMySQL");
+  grt::DictRef options(_manager->get_grt());
+  options.set("OutputContainer", _alter_list);
+  options.set("OutputObjectContainer", _alter_object_list);
+  options.set("UseFilteredLists", grt::IntegerRef(0));
+
+  if(_alter_change && diffsql_module)
+  {
+    //_alter_change->dump_log(0);
+    char buf1[128];
+    sprintf(buf1, "%p", _alter_change);
+    diffsql_module->generateSQL(_org_cat, options, std::string(buf1));
+    //TODO: use this result in generate_diff_tree_report
+  }
 
   // 3. build the tree
   return _diff_tree= new ::DiffTreeBE(
     schemata, _mod_cat_copy, _org_cat, _alter_change);
 }
 
+std::string DbMySQLScriptSync::get_sql_for_object(GrtNamedObjectRef obj)
+{
+  std::string result;
+  for (size_t i = 0; i < _alter_list.count(); ++i)
+    if (_alter_object_list.get(i) == obj)
+    {
+      result.append(_alter_list.get(i)).append("\n");
+    }
+  return result;
+};
+
 std::string DbMySQLScriptSync::generate_diff_tree_script()
 {
   DbMySQLImpl *diffsql_module= _manager->get_grt()->find_native_module<DbMySQLImpl>("DbMySQL");
@@ -1141,10 +1154,19 @@ void DbMySQLScriptSync::apply_changes_to_model()
   undo.end(_("Apply Changes from DB to Model"));
 }
 
-std::string DbMySQLScriptSync::save_script_to_file(const std::string& script, const std::string& filename)
-{
-  GError *err= NULL;
-  if(!g_file_set_contents(filename.c_str(), script.c_str(), (gssize)strlen(script.c_str()), &err))
-    return std::string(err->message);
-  return std::string();
-}
+std::string DbMySQLScriptSync::get_col_name(const size_t col_id)
+  {
+    switch(col_id)
+    {
+      case 0:
+        return "Model";
+        break;
+      case 1:
+        return "Update";
+        break;
+      case 2:
+        return "Source";
+        break;
+    };
+    return "No Column Name Defined";  
+  };
