@@ -69,8 +69,7 @@ public:
     _options_box.add(&_in_descr, 0, 3, 0, 1, (TableItemFlags)HFillFlag);
     _options_box.add(&_in_label, 0, 1, 1, 2, (TableItemFlags)HFillFlag);
     _options_box.add(&_in_entry, 1, 2, 1, 2, (TableItemFlags)(HExpandFlag | HFillFlag));
-    _options_box.add(&_in_button, 2, 3, 1, 2, NoFillExpandFlag);
-    _in_button.set_size(80,-1);
+    _options_box.add(&_in_button, 2, 3, 1, 2, (TableItemFlags)0);
     
     _in_descr.set_text(_("Pick the SQL script file to be compared with the current model. Script must include schema qualifiers."));
     _in_label.set_text(_("Input File:"));
@@ -84,9 +83,8 @@ public:
     _options_box.add(&_out_descr, 0, 3, 2, 3, (TableItemFlags)HFillFlag);
     _options_box.add(&_out_label, 0, 1, 3, 4, (TableItemFlags)HFillFlag);
     _options_box.add(&_out_entry, 1, 2, 3, 4, (TableItemFlags)(HExpandFlag|HFillFlag));
-    _options_box.add(&_out_button, 2, 3, 3, 4, (TableItemFlags)NoFillExpandFlag);
+    _options_box.add(&_out_button, 2, 3, 3, 4, (TableItemFlags)0);
     _options_box.add(&_skip_out_label, 1, 2, 4, 5, (TableItemFlags)HFillFlag);
-    _out_button.set_size(80, -1);
     
     _skip_out_label.set_text(_("Leave blank to view generated script but not save to a file."));
     _skip_out_label.set_style(SmallHelpTextStyle);
@@ -178,10 +176,7 @@ public:
     {
       try
       {
-        ((WbPluginSQLExportAlter*)_form)->get_be()->init_diff_tree(std::vector<std::string>(), db_CatalogRef(), db_CatalogRef());
-        
         set_text(((WbPluginSQLExportAlter*)_form)->get_be()->generate_diff_tree_script());
-        
         _form->clear_problem();
       }
       catch (std::exception &exc)
