@@ -75,7 +75,6 @@ public:
     _options_box.add(&_in_button, 2, 3, 1, 2, NoFillExpandFlag);
     _in_descr.set_text(_("Pick the SQL script file to be compared with the current model. Script must include schema qualifiers."));
     _in_label.set_text(_("Input File:"));
-    _in_button.set_size(80, -1);
     
     std::string input= form->module()->document_string_data("input_filename", "");
     _in_selector= mforms::manage(new FsObjectSelector(&_in_button, &_in_entry));
@@ -89,7 +88,6 @@ public:
     _options_box.add(&_skip_out_label, 1, 2, 4, 5, HFillFlag);
     _skip_out_label.set_text(_("Leave blank to view generated script but not save to a file."));
     _skip_out_label.set_style(SmallHelpTextStyle);
-    _out_button.set_size(80, -1);
     
     _out_descr.set_text(_("Enter the path for the ALTER script to be created."));
     _out_label.set_text(_("Output File:"));
@@ -170,11 +168,7 @@ public:
   virtual void enter(bool advancing)
   {
     if (advancing)
-    {
-//      ((WbPluginSQLSynchronize*)_form)->get_be()->init_diff_tree(std::vector<std::string>(), db_CatalogRef(), db_CatalogRef());
-
       set_text(((WbPluginSQLSynchronize*)_form)->get_be()->generate_diff_tree_script());
-    }
   }
 
 
