@@ -1,14 +1,17 @@
 
 #include "mforms/grttreeview.h"
+#include "db_mysql_sql_script_sync.h"
 
 class SynchronizeDifferencesPage : public WizardPage
 {
-  DbMySQLScriptSync *_be;
+  SynchronizeDifferencesPageBEInterface *_be;
   sigc::slot<db_CatalogRef> get_source_catalog;
+  db_CatalogRef _src,_dst;
 
 public:
-  SynchronizeDifferencesPage(WizardForm *form, DbMySQLScriptSync *be)
-    : WizardPage(form, "diffs"), _be(be), _tree(mforms::TreeDefault), _bottom_box(true)
+  SynchronizeDifferencesPage(WizardForm *form, SynchronizeDifferencesPageBEInterface *be)
+    : WizardPage(form, "diffs"), _be(be), _tree(mforms::TreeDefault),
+      _bottom_box(true), _diff_sql_text(mforms::BothScrollBars),_splitter(false)
   {    
     set_title(_("Choose Direction to Apply Changes"));
     set_short_title(_("Select Changes to Apply"));
@@ -17,9 +20,14 @@ public:
     _heading.set_text(_("Double click arrows in the list to choose whether to ignore changes, update "
       "the model with database changes or vice-versa. You can also apply an action to multiple selected rows."));
     add(&_heading, false, true);
+    add(&_splitter,true,true);
     
-    add(&_tree, true, true);
+    _splitter.add(&_tree);
     _tree.set_allow_multi_selection(true);
+    _diff_sql_text.set_read_only(true);
+    _splitter.add(&_diff_sql_text);
+
+
     
     add(&_bottom_box, false, false);
     
@@ -42,19 +50,35 @@ public:
     
     _tree.add_column(mforms::IconStringGRTColumnType,
                      DiffTreeBE::ModelObjectName,
-                     _("Model"));
+                     _be->get_col_name(0));
     _tree.add_column(mforms::IconGRTColumnType,
                      DiffTreeBE::ApplyDirection,
-                     _("Update"));
+                     _be->get_col_name(1));
     _tree.add_column(mforms::IconStringGRTColumnType,
                      DiffTreeBE::DbObjectName,
-                     _("Source"));
+                     _be->get_col_name(2));
     
     _tree.set_column_width(1, 50);
 
     _tree.signal_row_activate().connect(sigc::mem_fun(this, &SynchronizeDifferencesPage::activate_row));
+    _tree.signal_changed().connect(sigc::mem_fun(this, &SynchronizeDifferencesPage::select_row));
   }
 
+  void select_row()
+  {
+    bec::NodeId node;
+    std::string sql;
+    if (_tree.get_selected_node(node))
+    {
+    ValueRef obj = _be->get_model_object(node);
+    if (GrtNamedObjectRef::can_wrap(obj))
+      sql.append(_be->get_sql_for_object(GrtNamedObjectRef::cast_from(obj)));
+    obj = _be->get_db_object(node);
+    if (GrtNamedObjectRef::can_wrap(obj))
+      sql.append(_be->get_sql_for_object(GrtNamedObjectRef::cast_from(obj)));
+    }
+    _diff_sql_text.set_value(sql);
+  }
 
   void activate_row(const bec::NodeId &node, int column)
   {
@@ -70,17 +94,19 @@ public:
     get_source_catalog= source_catalog_slot;
   }
 
+  void set_src(const db_CatalogRef cat){_src = cat;};
+  void set_dst(const db_CatalogRef cat){_dst = cat;};
 
   virtual bool pre_load()
   {
     grt::StringListRef schemas_to_skip(grt::StringListRef::cast_from(values().get("unSelectedSchemata")));
-    bec::TreeModel *diff_tree= _be->init_diff_tree(std::vector<std::string>(),
-                                                   get_source_catalog ? get_source_catalog() : db_CatalogRef(),
-                                                   db_CatalogRef(),schemas_to_skip);
+    if (get_source_catalog)
+      _src = get_source_catalog();
+    bec::TreeModel *diff_tree= _be->init_diff_tree(std::vector<std::string>(),_src,_dst,schemas_to_skip);
 
     _tree.set_model(diff_tree);
     for (int i= 0, c= diff_tree->count_children(bec::NodeId()); i < c; i++)
-        _tree.set_expanded(bec::NodeId(i), true);
+         _tree.set_expanded(bec::NodeId(i), true);
     
     return true;
   }
@@ -143,6 +169,8 @@ public:
 protected:
   GRTTreeView _tree;
   Label _heading;
+  mforms::TextBox _diff_sql_text;
+  mforms::Splitter _splitter;
   
   Box _bottom_box;
   Button _select_all;
