@@ -1,4 +1,22 @@
+# Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation; version 2 of the
+# License.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+# 02110-1301  USA
+
 import re
+import time
 import Queue
 import threading
 import wb_admin_utils
@@ -71,14 +89,14 @@ class EventManager:
       dprint_ex(3, "Found valid but unrequested event", name, "in list")
 
 #===============================================================================
-
+import thread
 class SQLQueryExecutor:
     dbconn = None
     mtx     = None
 
     def __init__(self, dbconn):
         dprint_ex(1, "Constructing SQL query runner, dbconn", dbconn)
-        self.mtx = threading.RLock()
+        self.mtx = threading.Lock()
         self.dbconn = dbconn
 
     def is_connected(self):
@@ -86,7 +104,11 @@ class SQLQueryExecutor:
 
     def close(self):
         if self.is_connected():
-            self.dbconn.disconnect()
+            self.mtx.acquire()
+            try:
+              self.dbconn.disconnect()
+            finally:
+              self.mtx.release()
         self.dbconn = None
 
     def exec_query(self, query):
@@ -327,6 +349,9 @@ class WbAdminControl:
 
         self.add_me_for_event("server_started", self)
         self.add_me_for_event("server_stopped", self)
+        # We'll use server_status to store information from self.sql_status_callback
+        # The callback is called on success and failure of execution of a query
+        self.server_status = {}
 
         
     def init(self):
@@ -394,6 +419,7 @@ class WbAdminControl:
         else:
             if self.server_profile.uses_wmi:
                 self.server_control = ServerControlWMI(self.server_profile, self.server_helper, self.password_handler)
+                self.server_control.set_filter_functions(build_filters, apply_filters)
             elif self.server_profile.uses_ssh or self.server_profile.is_local:
                 self.server_control = ServerControlShell(self.server_profile, self.server_helper, self.password_handler)
                 self.server_control.set_filter_functions(build_filters, apply_filters)
@@ -406,17 +432,36 @@ class WbAdminControl:
         self.events.event('shutdown')
         self.running = False
         self.disconnect_sql()
+        if self.ssh:
+            self.ssh.close()
 
     #---------------------------------------------------------------------------
-    def is_server_running(self, verbose = 0):
-      # Perform SQL ping if ping fails run self.server_control.get_status()
-      ret = "unknown"
-      if self.sql_ping() == True:
-        ret = "running"
-      else:
-        ret = self.server_control.get_status(verbose=verbose)
+    def is_server_running(self, verbose = 0, force_process_check = False):
+        # Check recent information from query runs. If last query (not older than 4 secs)
+        # was performed successfully, then we imply that server is up.
+        ret = "unknown"
 
-      return ret
+        use_process_check = True
+
+        if not self.server_control:
+          use_process_check = False
+          force_process_check = False
+
+        if not force_process_check:
+            ts = time.time()
+            connid = self.server_profile.db_connection_params.hostIdentifier
+            if connid is not None:
+                (status, stime) = self.server_status.get(connid, (False, 0))
+                # time diff is not sufficient for MacOS->RemoteWin, so WBA 
+                # has recurring sql connection drop with follwing re-connect.
+                if ts - stime < 8 and status:
+                    ret = 'running'
+                    use_process_check = False
+
+        if use_process_check:
+            ret = self.server_control.get_status(verbose=verbose)
+
+        return ret
 
     #---------------------------------------------------------------------------
     def uitask(self, task, *args):
@@ -490,21 +535,40 @@ class WbAdminControl:
     def get_new_sql_connection(self, interactive):
         connection = None
         try:
-            connection = MySQLConnection(self.server_profile.db_connection_params)
+            connection = MySQLConnection(self.server_profile.db_connection_params, self.sql_status_callback)
             connection.connect()
         except MySQLError, err:
             print "Error creating SQL connection for monitoring: %r" % err
+            connection = None
             if interactive:
                 mforms.Utilities.show_error("Connection Error", "Error connecting to MySQL: %s\nMySQL stat graphs may be disabled." % err, "OK", "", "")
             return None
           
         return connection
-        
-        
+
+    #---------------------------------------------------------------------------
+    """
+    This method is passed to MySQLConnection.__init__. MySQLConnection will call
+    this method when connection created/destroyed, also on success or error when
+    executing query
+    """
+    def sql_status_callback(self, code, error, connect_info):
+        connid = connect_info.hostIdentifier
+        self.server_status = {}
+        ts = time.time()
+
+        if connid is not None:
+            if code == 0:
+                self.server_status[connid] = (True, ts)
+        else:
+            e = QueryError(code, error)
+            if e.is_connection_error():
+                self.server_status[connid] = (False, ts)
+
     #---------------------------------------------------------------------------
     def connect_sql(self): # from GUI thread only, throws MySQLError
         if self.sql is None or not self.sql.is_connected():
-            connection = MySQLConnection(self.server_profile.db_connection_params)
+            connection = MySQLConnection(self.server_profile.db_connection_params, self.sql_status_callback)
             connection.connect()
 
             self.sql = SQLQueryExecutor(connection)
