@@ -1,21 +1,38 @@
+# Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
 #
-#  wb_admin_security_be.py
-#  MySQLWorkbench
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation; version 2 of the
+# License.
 #
-#  Created by Alfredo Kojima on 7/Oct/09.
-#  Copyright (c) 2009 Sun Microsystems Inc. All rights reserved.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+# 02110-1301  USA
 
 import grt
 from grt import modules
-from wb_common import dprint_ex
+from db_utils import QueryError, escape_sql_string
+from wb_common import dprint_ex, PermissionDeniedError
+from grt import modules;
+
+import hashlib
+def make_scrambled_password(pwd):
+    ret = hashlib.sha1(pwd).digest()
+    ret = hashlib.sha1(ret).hexdigest()
+    return "*" + ret.upper()
+
 
 class WBSecurityValidationError(Exception):
     pass
 
 
-LIST_ACCOUNTS_QUERY = "SELECT User, Host FROM mysql.user"
+LIST_ACCOUNTS_QUERY = "SELECT User, Host FROM mysql.user ORDER BY User"
 LIST_SCHEMAS_QUERY = "SHOW DATABASES"
 
 GET_ACCOUNT_QUERY = "SELECT * FROM mysql.user WHERE User='%(user)s' AND Host='%(host)s'"
@@ -25,9 +42,10 @@ GET_ACCOUNT_SCHEMA_PRIVS_QUERY = "SELECT * FROM mysql.db WHERE User='%(user)s'"
 GET_ACCOUNT_MYSQL_TABLE_PRIVS_QUERY = "SELECT * FROM mysql.tables_priv WHERE Host='%(host)s' AND User='%(user)s' AND Db='mysql'"
 #GET_ACCOUNT_IS_TABLE_PRIVS_QUERY = "SELECT * FROM mysql.tables_priv WHERE Host='%(host)s' AND User='%(user)s' AND Db='information_schema'"
 
-DELETE_ACCOUNT_QUERY = "DELETE FROM mysql.user WHERE User='%(old_user)s' AND Host='%(old_host)s'"
 UPDATE_ACCOUNT_QUERY = "UPDATE mysql.user SET %(assignments)s WHERE User='%(old_user)s' AND Host='%(old_host)s'"
-INSERT_ACCOUNT_QUERY = "INSERT INTO mysql.user (User, Host, Password, %(field_names)s) VALUES ('%(user)s', '%(host)s', PASSWORD('%(password)s'), %(field_values)s)"
+CREATE_USER_QUERY = "CREATE USER '%(user)s'@'%(host)s' identified by password '%(password)s'"
+#INSERT_ACCOUNT_QUERY = "INSERT INTO mysql.user (User, Host, Password, %(field_names)s) VALUES ('%(user)s', '%(host)s', PASSWORD('%(password)s'), %(field_values)s)"
+#INSERT_ACCOUNT_QUERY_NO_PASSWORD = "INSERT INTO mysql.user (User, Host, Password, %(field_names)s) VALUES ('%(user)s', '%(host)s', '', %(field_values)s)"
 
 DELETE_SCHEMA_PRIV = "DELETE FROM mysql.db WHERE User='%(user)s'"
 INSERT_SCHEMA_PRIV = "INSERT INTO mysql.db (User, Host, Db, %(priv_names)s) VALUES ('%(user)s', '%(host)s', '%(db)s', %(priv_values)s)"
@@ -152,11 +170,6 @@ SecurityAdminRoles = [
 ]
 
 
-def escape_sql_string(s):
-    if s:
-        return s.replace("\\", "\\\\").replace("'", "\\'")
-    return s
-
 
 # for sorting tuples containing host, db, user entries in the same order as the server
 def get_acl_sort(tup):
@@ -197,10 +210,27 @@ class AdminSecurity:
         self.user_table_fields = []
 
 
+    def get_valid_privileges(self):
+        # self.global_privilege_names - column names from user table
+        # PrivilegeInfo: map of user table's column name to privilege and its description
+        privs = []
+        for name in self.global_privilege_names:
+            (priv, desc) = PrivilegeInfo.get(name, (None, None))
+            if priv:
+                privs.append(priv)
+
+        return privs
+
     def async_refresh(self, callback):
         # get list of privileges that actually exist
         if not self.schema_privilege_names:
-            result = self.ctrl_be.exec_query("DESCRIBE mysql.db")
+            try:
+              result = self.ctrl_be.exec_query("DESCRIBE mysql.db")
+            except QueryError, e:
+              if e.error == 1142:
+                raise PermissionDeniedError("Please make sure the used account has rights to the MySQL grant tables.\n%s"%e)
+              raise e
+
             if result is not None:
               while result.nextRow():
                 field= result.stringByName("Field")
@@ -208,7 +238,13 @@ class AdminSecurity:
                   self.schema_privilege_names.append(field)
 
         if not self.user_table_fields:
-            result = self.ctrl_be.exec_query("DESCRIBE mysql.user")
+            try:
+              result = self.ctrl_be.exec_query("DESCRIBE mysql.user")
+            except QueryError, e:
+              if e.error == 1142:
+                raise PermissionDeniedError("Please make sure the used account has rights to the MySQL grant tables.\n%s"%e)
+              raise e
+
             if result is not None:
               while result.nextRow():
                 field= result.stringByName("Field")
@@ -223,6 +259,10 @@ class AdminSecurity:
         schema_names = []
         try:
           result = self.ctrl_be.exec_query(LIST_SCHEMAS_QUERY)
+        except QueryError, e:
+          if e.error == 1142:
+            raise PermissionDeniedError("Please make sure the used account has rights to the MySQL grant tables.\n%s"%e)
+          raise e
         except Exception, e:
           raise Exception("Error querying security information: %s" % e)
 
@@ -395,7 +435,7 @@ class AdminUserDbPrivs:
 
     def load(self, username):
         # Schema privileges from Db table
-        query = GET_ACCOUNT_SCHEMA_PRIVS_QUERY % {"user":username}
+        query = GET_ACCOUNT_SCHEMA_PRIVS_QUERY % {"user": escape_sql_string(username)}
         try:
             result = self._owner.ctrl_be.exec_query(query)
         except Exception, e:
@@ -424,10 +464,10 @@ class AdminUserDbPrivs:
     def save(self):
         ##XXX begin transaction
 
-        self._owner.ctrl_be.exec_sql(DELETE_SCHEMA_PRIV % {"user":self.username})
+        self._owner.ctrl_be.exec_sql(DELETE_SCHEMA_PRIV % {"user":escape_sql_string(self.username) if self.username else self.username})
         
         for entry in self.entries:
-            fields = {"user":self.username, "host":entry.host, "db":entry.db}
+            fields = {"user":escape_sql_string(self.username), "host":entry.host, "db":entry.db}
             priv_names = []
             priv_values = []
             for priv in self._owner.schema_privilege_names:
@@ -466,7 +506,7 @@ class AdminAccount:
     _global_privs = set()
     _orig_global_privs = set()
 
-    is_commited = False
+    is_commited = False # False means that account was not pushed to mysql server
     
     def __init__(self, owner):
         self._owner = owner
@@ -530,7 +570,7 @@ class AdminAccount:
 
 
     def revoke_all(self):
-        command = REVOKE_ALL % {"user":self.username,"host":self.host}
+        command = REVOKE_ALL % {"user":escape_sql_string(self.username),"host":self.host}
         self._owner.ctrl_be.exec_sql(command)
 
 
@@ -553,11 +593,11 @@ class AdminAccount:
                 raise WBSecurityValidationError("The '%s'@'%s' account already exists and cannot be saved." % (self.username, self.host))
 
         fields = {
-            "old_user" : escape_sql_string(self._orig_username),
-            "old_host" : escape_sql_string(self._orig_host),
+            "old_user" : escape_sql_string(self._orig_username) if self._orig_username else self._orig_username,
+            "old_host" : escape_sql_string(self._orig_host) if self._orig_host else self._orig_host,
             "user" : escape_sql_string(self.username) or "NULL",
             "host" : escape_sql_string(self.host) or "",
-            "password" : escape_sql_string(self.password or self._orig_password),
+            "password" : escape_sql_string(self.password or self._orig_password or ""),
         }
 
         if self.is_commited:
@@ -568,7 +608,6 @@ class AdminAccount:
                   assignments.append("%s='%s'" % (priv, 'Y'))
                 else:
                   assignments.append("%s='%s'" % (priv, 'N'))
-                #assignments.append("%s='%s'" % (priv, 'Y' if priv in self._global_privs else 'N'))
 
             for limit in ["max_questions", "max_updates", "max_connections"] + (self._owner.has_max_user_connections and ["max_user_connections"] or []):
                 assignments.append("%s='%s'" % (limit, getattr(self, limit)))
@@ -586,52 +625,70 @@ class AdminAccount:
 
             try:
                 result = self._owner.ctrl_be.exec_sql(query)
+            except QueryError, e:
+                if e.error == 1142:
+                    raise Exception("Error updating account %s@%s: Insufficient rights to perform operation"%(self.username, self.host))
+                else:
+                    raise Exception("Error updating account %s@%s: %s"%(self.username, self.host, e))
             except Exception, e:
                 raise Exception("Error updating account %s@%s: %s"%(self.username, self.host, e))
 
-
+            self._owner.ctrl_be.exec_sql(FLUSH_PRIVILEGES)
         else:
-            priv_values = []        
-            for priv in self._owner.global_privilege_names:
-                if priv in self._global_privs:
-                  fields[priv] = 'Y'
-                  priv_values.append("'Y'")
-                else:
-                  fields[priv] = 'N'
-                  priv_values.append("'N'")
-                #fields[priv] = 'Y' if priv in self._global_privs else 'N'
-                #priv_values.append("'Y'" if priv in self._global_privs else "'N'")
+            # Account was nost saved yet
+            def run_query(query):
+                result = None
+                try:
+                    result = self._owner.ctrl_be.exec_sql(query)
+                except QueryError, e:
+                    if e.error == 1142:
+                        raise Exception("Error creating account %s@%s: Insufficient rights to perform operation"%(self.username, self.host))
+                    else:
+                        raise Exception("Error creating account %s@%s: %s"%(self.username, self.host, e))
+                except Exception, e:
+                    raise Exception("Error creating account %s@%s: %s"%(self.username, self.host, e))
+                return result
 
-            field_names = self._owner.global_privilege_names[:]
-            field_values = priv_values
-            
-            field_names += ["max_questions", "max_updates", "max_connections"] + (self._owner.has_max_user_connections and ["max_user_connections"] or [])
-            field_values += [str(s) for s in [self.max_questions, self.max_updates, self.max_connections] + (self._owner.has_max_user_connections and [self.max_user_connections] or [])]
+            raw_pwd = fields['password']
+            fields['password'] = make_scrambled_password(raw_pwd)
+            create_query = CREATE_USER_QUERY % fields
+            run_query(create_query)
 
-            # workaround a bug in MySQL servers < 5.1.3? where the user table had no default value
-            # for ssl_cipher, x509_issuer, x509_subject causing an error if these are ommited from
-            # the INSERT
-            for field in ["ssl_cipher", "x509_issuer", "x509_subject"]:
-                if field in self._owner.user_table_fields:
-                    field_names.append(field)
-                    field_values.append("''")
+            fields['password'] = raw_pwd
 
-            fields["field_names"] = ", ".join(field_names)
-            fields["field_values"] = ", ".join(field_values)
+            names = ["MAX_QUERIES_PER_HOUR", "MAX_UPDATES_PER_HOUR", "MAX_CONNECTIONS_PER_HOUR"] + (self._owner.has_max_user_connections and ["MAX_USER_CONNECTIONS"] or [])
+            values = [str(s) for s in [self.max_questions, self.max_updates, self.max_connections] + (self._owner.has_max_user_connections and [self.max_user_connections] or [])]
 
-            query = INSERT_ACCOUNT_QUERY % fields
+            grants = []
 
-            try:
-                result = self._owner.ctrl_be.exec_sql(query)
-            except Exception, e:
-                raise Exception("Error adding account %s@%s: %s"%(self.username, self.host, e))
+            valid_privs = self._owner.get_valid_privileges()
+            for priv_field_name in self._global_privs:
+                (grant_priv_type, description) = PrivilegeInfo.get(priv_field_name, (None,None))
+                if grant_priv_type == 'GRANT OPTION':
+                    # these will be glued to 'GRANT OPTION' below at 'for name, value...
+                    names.append("GRANT") 
+                    values.append("OPTION")
+                elif grant_priv_type and (grant_priv_type[0] != '*'):
+                    if grant_priv_type in valid_privs:
+                        grants.append(grant_priv_type)
 
-        self._owner.ctrl_be.exec_sql(FLUSH_PRIVILEGES)
+            if len(grants) == 0:
+              grants.append("USAGE")
+
+            fields["grants"] = ", ".join(grants)
+
+            grant_query = "GRANT %(grants)s ON *.* TO '%(user)s'@'%(host)s' with " % fields
+
+            for name, value in zip(names, values):
+              if value:
+                grant_query += "%s %s "%(name, str(value))
+
+            run_query(grant_query)
 
         new_attrs = set([p for p in self._global_privs if p.endswith("_attr")])
         old_attrs = set([p for p in self._orig_global_privs if p.endswith("_attr")])
 
-        
+
         def grant_special(priv):
             db, tables, privs, grant, revoke = AdminAttributes[priv]
             if "%(table)s" in grant:
@@ -668,7 +725,7 @@ class AdminAccount:
     def load(self, username, hostname):
         self.is_commited = True
         # Basic stuff from User table
-        query = GET_ACCOUNT_QUERY % {"user":username,"host":hostname}
+        query = GET_ACCOUNT_QUERY % {"user":escape_sql_string(username),"host":hostname}
         try:
             result = self._owner.ctrl_be.exec_query(query)
         except Exception, e:
@@ -713,7 +770,7 @@ class AdminAccount:
         """
 
         # privs from mysql tables
-        query = GET_ACCOUNT_MYSQL_TABLE_PRIVS_QUERY % {"user":username,"host":hostname}
+        query = GET_ACCOUNT_MYSQL_TABLE_PRIVS_QUERY % {"user":escape_sql_string(username),"host":hostname}
         try:
             result = self._owner.ctrl_be.exec_query(query)
         except Exception, e:
