@@ -699,18 +699,18 @@ class ServerControlWMI(ServerControlBase):
         service = profile.wmi_service_name
         #  return self._str_server_info("sys.mysqld.service_name")
         if service == "":
-            serverInfo["sys.mysqld.service_name"] = "MySQL"
+            service = serverInfo["sys.mysqld.service_name"] = "MySQL"
             self.info("MySQL service was empty. Set to 'MySQL'. Check this in 'Manage Server Instances' from 'Home'.")
 
-        if profile.start_server_cmd == "":
+        if profile.start_server_cmd == "" or (service not in profile.start_server_cmd):
             serverInfo["sys.mysqld.start"] = "sc start " + service
             print "WMIShell: start command set to '%s'"%profile.start_server_cmd
 
-        if profile.stop_server_cmd == "":
+        if profile.stop_server_cmd == "" or (service not in profile.stop_server_cmd):
             serverInfo["sys.mysqld.stop"] = "sc stop " + service
             print "WMIShell: stop command set to '%s'"%profile.stop_server_cmd
 
-        if profile.check_server_status_cmd == "":
+        if profile.check_server_status_cmd == "" or (service not in profile.check_server_status_cmd):
             serverInfo["sys.mysqld.status"] = "sc query %s | wba_filter(RUNNING)"%service
             print "WMIShell: status command set to '%s'"%profile.check_server_status_cmd
 
