@@ -104,9 +104,9 @@ class WbAdminConfigFileUI(mforms.Box):
       search_box.set_padding(2)
       search_box.set_spacing(4)
       #search_box.set_size(300, -1)
-      search_box.add(search_label, False, True)
+      search_box.add(search_label, False, False)
       search_box.add(self.option_lookup_entry, False, True)
-      search_box.add(search_btn, False, True)
+      search_box.add(search_btn, False, False)
       search_panel = newPanel(mforms.FilledPanel)
       search_panel.add(search_box)
       self.main_view.ui_profile.apply_style(search_panel, 'option-search-panel')
@@ -333,7 +333,7 @@ class WbAdminConfigFileUI(mforms.Box):
       btn.add_clicked_callback(lambda: self.open_file_chooser(OpenDirectory, te, name))
 
       dir_box.add(te, True, True)
-      dir_box.add(btn, False, True)
+      dir_box.add(btn, False, False)
       te.set_enabled(False)
       btn.set_enabled(False)
 
