@@ -266,7 +266,7 @@ def openExportImport():
         tab = do_open_administrator(server)
         if tab:   
             tab.wait_server_check(4)
-            tab.configuration.switch_to(5)
+            tab.configuration.switch_to("DATA EXPORT / RESTORE", "Data Export and Restore")
             return 1
     return 0
 
@@ -280,7 +280,7 @@ def openSecurityManager():
         tab = do_open_administrator(server)
         if tab:
             tab.wait_server_check(4)
-            tab.configuration.switch_to(2)
+            tab.configuration.switch_to("SECURITY", "Users and Privileges")
             return 1
     return 0
 
