@@ -73,7 +73,7 @@ class LogBox(mforms.Box):
         
         
     def refresh(self):
-        self.range_label.set_text("Showing entries %i to %i out of %i" % (self.show_start, self.show_start+self.show_count, self.total_count))
+        self.range_label.set_text("Showing entries %i to %i out of %i" % (max(self.show_start, 0), self.show_start+self.show_count, self.total_count))
 
         self.bof_button.set_enabled(self.show_start > 0)
         self.eof_button.set_enabled(self.show_start + self.show_count < self.total_count)
@@ -89,7 +89,7 @@ class LogBox(mforms.Box):
 
 
     def go_eof(self):
-        self.show_start = self.total_count - self.show_count/2
+        self.show_start = max(self.total_count - self.show_count/2, 0)
         self.showing_newest = True
         self.refresh()
 
@@ -135,7 +135,10 @@ class GeneralLogView(LogBox):
         self.total_count = result.intByName("count")
 
         if self.showing_newest:
-            self.show_start = self.total_count - self.show_count
+            if self.show_count < self.total_count:
+                self.show_start = self.total_count - self.show_count
+            else:
+                self.show_start = self.show_count
 
         try:
             result = self.owner.ctrl_be.exec_query("SELECT * FROM mysql.general_log ORDER BY event_time DESC LIMIT %i, %i"  % (self.total_count - self.show_start, self.show_count))
@@ -278,7 +281,7 @@ class WbAdminLogs(mforms.Box):
     def update_ui(self):
 
         dest = self.get_log_destination()
-        if dest != "TABLE":
+        if dest.find("TABLE") == -1:
             self.slow_log= None
             self.general_log= None
             if dest:
