@@ -1,11 +1,19 @@
+# Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
 #
-#  wb_admin_security.py
-#  MySQLWorkbench
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation; version 2 of the
+# License.
 #
-#  Created by Alfredo Kojima on 7/Oct/09.
-#  Copyright (c) 2009 Sun Microsystems Inc. All rights reserved.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+# 02110-1301  USA
 
 from mforms import newBox, newLabel, newButton, newTextEntry, newTreeView, newTable, newRadioButton, newListBox, newSelector, newPanel, newTabView, Utilities, newCheckBox, newImageBox, App
 import mforms
@@ -33,6 +41,7 @@ SCHEMA_DDL_RIGHTS = [
 "Create_routine_priv",
 "Alter_routine_priv",
 "Drop_priv",
+"Trigger_priv"
 ]
 
 SCHEMA_OTHER_RIGHTS = [
@@ -56,7 +65,7 @@ def dLabel(text):
     
 class AddSchemaPrivilegeForm(mforms.Form):
     def __init__(self, secman, user=""):
-        mforms.Form.__init__(self, None, 0)
+        mforms.Form.__init__(self, None, mforms.FormResizable | mforms.FormMinimizable)
 
         self.set_title("New Schema Privilege Definition")
 
@@ -229,11 +238,16 @@ class SecurityAccount(mforms.Box):
         bottom_box.add(self.del_button, False, True)
         self.del_button.add_clicked_callback(self.del_account)
 
+        self.refresh_button = newButton()
+        self.refresh_button.set_text("Refresh")
+        self.refresh_button.add_clicked_callback(self.owner.refresh)
+        bottom_box.add_end(self.refresh_button, False, True)
+
         self.save_button = newButton()
         self.save_button.set_text("Apply")
         bottom_box.add_end(self.save_button, False, True)
         self.save_button.add_clicked_callback(self.commit)
-        
+
         self.revert_button = newButton()
         self.revert_button.set_text("Revert")
         bottom_box.add_end(self.revert_button, False, True)        
@@ -258,7 +272,7 @@ class SecurityAccount(mforms.Box):
         #searchbox = TextEntry(SearchEntry)
         #account_list_box.add(searchbox, False, True)
 
-        self.user_list = newTreeView(mforms.TreeShowHeader)
+        self.user_list = newTreeView(mforms.TreeDefault)
         self.user_list.add_column(mforms.StringColumnType, "User", 80, False)
         self.user_list.add_column(mforms.StringColumnType, "From Host", 120, False)
         self.user_list.end_columns()
@@ -343,7 +357,7 @@ class SecurityAccount(mforms.Box):
         lbox.set_spacing(12)
         lbox.set_padding(12)
 
-        self.role_list = newTreeView(mforms.TreeShowHeader)
+        self.role_list = newTreeView(mforms.TreeDefault)
         self.role_list.add_column(mforms.CheckColumnType, "", 30, True)
         self.role_list.add_column(mforms.StringColumnType, "Role", 150, False)
         self.role_list.add_column(mforms.StringColumnType, "Description", 300, False)
@@ -351,7 +365,7 @@ class SecurityAccount(mforms.Box):
         lbox.add(self.role_list, True, True)
         self.role_list.set_cell_edited_callback(self.role_list_toggled)
 
-        self.role_priv_list = newTreeView(mforms.TreeShowHeader)
+        self.role_priv_list = newTreeView(mforms.TreeDefault)
         self.role_priv_list.add_column(mforms.StringColumnType, "Global Privileges Assigned to User", 200, False)
         self.role_priv_list.end_columns()
         self.role_priv_list.set_size(220, -1)
@@ -663,10 +677,11 @@ class SecuritySchemaPrivileges(mforms.Box):
         #searchbox = TextEntry(SearchEntry)
         #schema_list_box.add(searchbox, False, True)
 
-        self.user_list = newTreeView(mforms.TreeShowHeader)
+        self.user_list = newTreeView(mforms.TreeDefault)
         self.user_list.add_column(mforms.StringColumnType, "Users", 140, False)
         self.user_list.end_columns()
         self.user_list.add_changed_callback(self.user_selected)
+        self.user_list.set_allow_sorting(True)
         schema_list_box.add(self.user_list, True, True)
 
         self.schema_rights_checks = {}
@@ -677,7 +692,7 @@ class SecuritySchemaPrivileges(mforms.Box):
         
         priv_vbox.add(newLabel("Select a user and pick the privileges it has for a given Schema and Host combination."), False, True)
         
-        self.privs_list = newTreeView(mforms.TreeShowHeader)
+        self.privs_list = newTreeView(mforms.TreeDefault)
         self.privs_list.add_column(mforms.StringColumnType, "Host", 100, True)
         self.privs_list.add_column(mforms.StringColumnType, "Schema", 100, True)
         self.privs_list.add_column(mforms.StringColumnType, "Privileges", 800, False)
@@ -1013,11 +1028,14 @@ class WbAdminSecurity(mforms.Box):
     _schema_priv_entries = []
     ui_created = False
 
-    def __init__(self, ctrl_be):
+    def __init__(self, ctrl_be, server_profile, main_view):
         mforms.Box.__init__(self, False)
+        main_view.ui_profile.apply_style(self, 'page')
         self.set_managed()
         self.ctrl_be = ctrl_be
         self.secman  = None
+        self.main_view = main_view
+        self.main_view.add_content_page(self, "SECURITY", "Users and Privileges", "admin_manage_privs_win")
 
 
     def create_ui(self):
@@ -1053,6 +1071,7 @@ class WbAdminSecurity(mforms.Box):
 
 
     def page_activated(self):
+        self.main_view.set_content_label(" Users and Privileges")
         if not self.ui_created:
             self.create_ui()
             self.ui_created = True
