@@ -3,5 +3,5 @@
 
 #include "model_reporting_form.h"
 #include "grt/icon_manager.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
